package sun.beans.ole.event;

import java.beans.IntrospectionException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.EventObject;
import java.util.Hashtable;
import java.util.Vector;

public abstract class EncapsulatedEventAdaptor {
   protected EncapsulatedEventInformation eei;
   protected Object source;
   protected Vector listeners = new Vector(0, 1);
   private static Hashtable cache = new Hashtable();

   public static EncapsulatedEventAdaptor getEncapsulatedEventAdaptor(EncapsulatedEventInformation var0, Object var1) throws ClassNotFoundException, InstantiationException, IllegalAccessException, IntrospectionException {
      Class var2 = null;
      EncapsulatedEventAdaptor var3 = null;
      var2 = (Class)cache.get(var0.getListenerType().getName());
      if (var2 == null) {
         var2 = getEncapsulatedEventAdaptorClass(var0.getListenerType());
         cache.put(var0.getListenerType().getName(), var2);
      }

      var3 = (EncapsulatedEventAdaptor)var2.newInstance();
      var3.setEventInformation(var0);
      var3.source = var1;
      return var3;
   }

   public static Class getEncapsulatedEventAdaptorClass(Class var0) throws ClassNotFoundException {
      if (!(class$java$util$EventListener == null ? (class$java$util$EventListener = class$("java.util.EventListener")) : class$java$util$EventListener)
         .isAssignableFrom(var0)) {
         throw new IllegalArgumentException("Class is not a subinterface of java.util.EventListenerEventListener");
      } else {
         return EncapsulatedEventAdaptorGenerator.getAdaptorClassForListenerClass(var0);
      }
   }

   protected EncapsulatedEventAdaptor() {
   }

   public abstract Class getListenerClass();

   public void setEventInformation(EncapsulatedEventInformation var1) {
      this.eei = var1;
   }

   public String getListenerClassName() {
      return this.getListenerClass().getName();
   }

   public synchronized Object getSource() {
      return this.source;
   }

   public void addEncapsulatedEventListener(EncapsulatedEventListener var1) {
      Vector var2 = this.listeners;
      synchronized (var2) {
         if (!this.listeners.contains(var1)) {
            this.listeners.addElement(var1);
         }
      }
   }

   public void removeEncapsulatedEventListener(EncapsulatedEventListener var1) {
      Vector var2 = this.listeners;
      synchronized (var2) {
         if (this.listeners.contains(var1)) {
            this.listeners.removeElement(var1);
         }
      }
   }

   public int getEncapsulatedListenerCount() {
      Vector var2 = this.listeners;
      synchronized (var2) {
         return this.listeners.size();
      }
   }

   public Vector getEncapsulatedListeners() {
      Vector var2 = this.listeners;
      synchronized (var2) {
         return (Vector)this.listeners.clone();
      }
   }

   protected void fire(EventObject var1, Method var2) throws Exception {
      Vector var3 = null;
      EncapsulatedEvent var4 = new EncapsulatedEvent(var1, var2);
      EncapsulatedEventListener var5 = null;
      Vector var6 = this.listeners;
      synchronized (var6) {
         var3 = (Vector)this.listeners.clone();
      }

      for (int var7 = 0; var7 < var3.size(); var7++) {
         try {
            var5 = (EncapsulatedEventListener)var3.elementAt(var7);
            var5.encapsulatedEvent(var4);
         } catch (EncapsulatedEventException var9) {
            this.handleEncapsulatedEventException(var9, var5, var2);
         }
      }
   }

   protected void fire(Object[] var1, Method var2) throws Exception {
      Vector var3 = null;
      EncapsulatedEvent var4 = new EncapsulatedEvent(this.source, var2, var1);
      EncapsulatedEventListener var5 = null;
      Vector var6 = this.listeners;
      synchronized (var6) {
         var3 = (Vector)this.listeners.clone();
      }

      for (int var7 = 0; var7 < var3.size(); var7++) {
         try {
            var5 = (EncapsulatedEventListener)var3.elementAt(var7);
            var5.encapsulatedEvent(var4);
         } catch (EncapsulatedEventException var9) {
            this.handleEncapsulatedEventException(var9, var5, var2);
         }
      }
   }

   protected final void handleEncapsulatedEventException(EncapsulatedEventException var1, EncapsulatedEventListener var2, Method var3) throws Exception {
      Class var4 = var1.getExceptionClass();
      Class[] var5 = var3.getExceptionTypes();

      for (int var6 = 0; var6 < var5.length; var6++) {
         if (var5[var6].isAssignableFrom(var4)) {
            throw var1.getException();
         }
      }

      throw new RuntimeException("Event Source [" + this.source + "] is not prepared to catch [" + var1.getException() + "] from listener [" + var2);
   }

   protected void addAdaptorToSource() {
      try {
         Object[] var1 = new Object[]{this};
         this.eei.getAddListenerMethod().invoke(this.source, var1);
      } catch (InvocationTargetException var3) {
         System.err.println("cannot add adaptor [" + this + "] to source [" + this.source + "] InvocationTargetException: " + var3.getMessage());
      } catch (IllegalAccessException var4) {
         System.err.println("cannot add adaptor [" + this + "] to source [" + this.source + "] IllegalAccessException: " + var4.getMessage());
      }
   }

   protected void removeAdaptorFromSource() {
      try {
         Object[] var1 = new Object[]{this};
         this.eei.getRemoveListenerMethod().invoke(this.source, var1);
      } catch (InvocationTargetException var3) {
         System.err.println("cannot remove adaptor [" + this + "] from source [" + this.source + "] InvocationTargetException: " + var3.getMessage());
      } catch (IllegalAccessException var4) {
         System.err.println("cannot remove adaptor [" + this + "] from source [" + this.source + "] IllegalAccessException: " + var4.getMessage());
      }
   }
}
