package sun.beans.ole.event;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import sunw.demo.classfile.EncapsulatedEventAdaptorClassFile;

public final class EncapsulatedEventAdaptorGenerator extends ClassLoader {
   private static String packagePrefix = "sunw.demo.encapsulatedEvents";
   private static String adaptorInfix = ".DYN_EE_ADAPTOR.";
   private static String adaptorClassNamePrefix = packagePrefix + adaptorInfix;
   private ClassLoader delegateLoader;
   private static EncapsulatedEventAdaptorGenerator generator = new EncapsulatedEventAdaptorGenerator();

   private boolean debug() {
      return false;
   }

   private EncapsulatedEventAdaptorGenerator() {
   }

   private static Class loadClassNamed(ClassLoader var0, String var1) throws ClassNotFoundException {
      generator.delegateLoader = var0;
      return generator.loadClass(var1);
   }

   static Class getAdaptorClassForListenerClass(Class var0) throws ClassNotFoundException {
      return loadClassNamed(var0.getClassLoader(), mapListenerNameToAdaptorName(var0.getName()));
   }

   protected Class loadClass(String var1, boolean var2) throws ClassNotFoundException {
      Class var3 = this.findLoadedClass(var1);
      if (this.debug()) {
         System.err.println("loadClass(" + var1 + ")");
      }

      if (var3 == null) {
         if (isAdaptorClassName(var1)) {
            var3 = this.generateAdaptorClass(var1);
         } else {
            try {
               ClassLoader var4 = this.getClass().getClassLoader();
               if (var4 != null) {
                  var3 = var4.loadClass(var1);
               }

               if (var3 == null && this.delegateLoader != null) {
                  var3 = this.delegateLoader.loadClass(var1);
               }

               if (var3 == null) {
                  var3 = this.findSystemClass(var1);
               }
            } catch (NoClassDefFoundError var5) {
               throw new ClassNotFoundException(var5.getMessage());
            }
         }
      }

      if (var3 != null) {
         if (var2) {
            this.resolveClass(var3);
         }

         if (this.debug()) {
            System.err.println("loaded: " + var3.getName());
         }

         return var3;
      } else {
         throw new ClassNotFoundException(var1);
      }
   }

   private static String mapListenerNameToAdaptorName(String var0) {
      return adaptorClassNamePrefix + var0;
   }

   private static boolean isAdaptorClassName(String var0) {
      return var0.startsWith(adaptorClassNamePrefix);
   }

   public static String getBaseNameFromAdaptorName(String var0) {
      return var0 != null && isAdaptorClassName(var0) ? var0.substring(adaptorClassNamePrefix.length()) : null;
   }

   private Class generateAdaptorClass(String var1) {
      ByteArrayOutputStream var2 = new ByteArrayOutputStream(512);
      Object var3 = null;
      Class var4 = null;
      if (this.debug()) {
         System.err.println("generateAdaptorClass(" + var1 + ")");
      }

      try {
         Class var5;
         if (this.delegateLoader != null) {
            var5 = this.delegateLoader.loadClass(getBaseNameFromAdaptorName(var1));
         } else {
            var5 = Class.forName(getBaseNameFromAdaptorName(var1));
         }

         new EncapsulatedEventAdaptorClassFile(var1, var5, var2);
      } catch (IOException var9) {
         var9.printStackTrace();
         return null;
      } catch (ClassNotFoundException var10) {
         var10.printStackTrace();
         return null;
      } catch (Throwable var11) {
         var11.printStackTrace();
         return null;
      }

      var3 = var2.toByteArray();

      try {
         var4 = this.defineClass(var1, (byte[])var3, 0, ((Object[])var3).length);
      } catch (ClassFormatError var8) {
         System.err.println("Failed to define adaptor for " + var1);
         System.err.println("Caught: " + var8);
         var8.printStackTrace();
      }

      return var4;
   }
}
