package sun.beans.ole.event;

import java.beans.IntrospectionException;
import java.util.EventObject;
import java.util.Hashtable;

public class EventManager implements EncapsulatedEventManager, EncapsulatedEventListener {
   private EncapsulatedEventInformation[] interfacesInfo;
   private transient Hashtable sources = new Hashtable();
   private Object source;

   public EventManager(EncapsulatedEventInformation[] var1, Object var2) {
      this.interfacesInfo = var1;
      this.source = var2;
   }

   public Class[] getSourceEventListenerInterfaces(Object var1) {
      Class[] var2 = new Class[this.interfacesInfo.length];

      for (int var3 = 0; var3 < this.interfacesInfo.length; var3++) {
         var2[var3] = this.interfacesInfo[var3].getListenerType();
      }

      return var2;
   }

   public void addEncapsulatedEventListener(Object var1, EncapsulatedEventListener var2) {
      this.addEncapsulatedEventListener(var1, var2, this.getSourceEventListenerInterfaces(var1));
   }

   public void removeEncapsulatedEventListener(Object var1, EncapsulatedEventListener var2) {
      this.removeEncapsulatedEventListener(var1, var2, this.getSourceEventListenerInterfaces(var1));
   }

   public synchronized void addEncapsulatedEventListener(Object var1, EncapsulatedEventListener var2, Class[] var3) {
      if (var1 == null) {
         throw new NullPointerException("Source");
      } else if (var2 == null) {
         throw new NullPointerException("Listener");
      } else if (var3 == null) {
         throw new NullPointerException("Interfaces");
      } else {
         Hashtable var4 = (Hashtable)this.sources.get(var1);
         if (var4 == null) {
            var4 = new Hashtable();
            this.sources.put(var1, var4);
         }

         for (int var5 = 0; var5 < var3.length; var5++) {
            EncapsulatedEventAdaptor var6 = (EncapsulatedEventAdaptor)var4.get(var3[var5]);
            if (var6 == null) {
               try {
                  var6 = EncapsulatedEventAdaptor.getEncapsulatedEventAdaptor(this.interfacesInfo[var5], var1);
               } catch (ClassNotFoundException var15) {
                  System.err.println("Cant create adaptor class");
               } catch (InstantiationException var16) {
                  System.err.println("Cant instantiate adaptor");
               } catch (IllegalAccessException var17) {
                  System.err.println("illegal access");
               } catch (IntrospectionException var18) {
                  System.err.println("introspection error");
               } catch (Throwable var19) {
                  var19.printStackTrace();
               }

               if (var6 != null) {
                  synchronized (var6) {
                     var6.addEncapsulatedEventListener(var2);

                     try {
                        var6.addAdaptorToSource();
                     } catch (Exception var13) {
                        var13.printStackTrace();
                        throw new RuntimeException("Failed to register with source");
                     }
                  }

                  var4.put(var3[var5], var6);
               } else {
                  var4.put(var3[var5], null);
               }
            }
         }
      }
   }

   public synchronized void removeEncapsulatedEventListener(Object var1, EncapsulatedEventListener var2, Class[] var3) {
      if (var1 == null) {
         if (this.source == null) {
            throw new NullPointerException("Source");
         }

         var1 = this.source;
      }

      if (var2 == null) {
         throw new NullPointerException("Listener");
      } else if (var3 == null) {
         throw new NullPointerException("Interfaces");
      } else {
         Hashtable var4 = (Hashtable)this.sources.get(var1);
         if (var4 == null) {
            throw new IllegalArgumentException("Source");
         } else {
            for (int var5 = 0; var5 < var3.length; var5++) {
               EncapsulatedEventAdaptor var6 = (EncapsulatedEventAdaptor)var4.get(var3[var5]);
               if (var6 != null) {
                  var6.removeEncapsulatedEventListener(var2);

                  try {
                     var6.removeAdaptorFromSource();
                  } catch (Exception var12) {
                     var12.printStackTrace();
                     throw new RuntimeException("Failed to register with source");
                  }

                  synchronized (var6) {
                     if (var6.getEncapsulatedListenerCount() == 0) {
                        try {
                           var6.setEventInformation(null);
                        } catch (Exception var10) {
                           System.err.println("failed to unregister source");
                        }
                     }

                     var4.remove(var3[var5]);
                  }
               }
            }
         }
      }
   }

   public void encapsulatedEvent(EncapsulatedEvent var1) {
      Object var2 = var1.getEventSource();
      EventObject var3 = var1.getEvent();
   }
}
