package sun.net.www.protocol.https;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import java.security.SecureRandom;
import java.text.MessageFormat;
import java.util.List;
import java.util.Map;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import sun.plugin.cache.CachedFile;
import sun.plugin.cache.FileCache;
import sun.plugin.net.cookie.PluginCookieManager;
import sun.plugin.net.proxy.PluginProxyManager;
import sun.plugin.net.proxy.ProxyInfo;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.security.X509PluginTrustManager;
import sun.plugin.usability.ProgressInputStream;
import sun.plugin.usability.Trace;

public class PluginDelegateHttpsURLConnection extends DelegateHttpsURLConnection {
   protected String proxy = null;
   protected int proxyPort = -1;
   private Map cachedHeaders = null;
   private static HostnameVerifier hostnameVerifier = null;
   private static MessageFormat mf1 = new MessageFormat(ResourceHandler.getMessage("net.connect.no_proxy"));
   private static MessageFormat mf2 = new MessageFormat(ResourceHandler.getMessage("net.connect.proxy_is"));
   private boolean securityCheck = false;
   private boolean cacheConnect = false;
   private boolean realConnect = false;
   private boolean checkSetCookie = false;
   private InputStream cacheStream = null;

   public PluginDelegateHttpsURLConnection(URL var1, Handler var2, HttpsURLConnection var3, SecureRandom var4) throws IOException {
      super(var1, var2, var3);

      try {
         AccessController.doPrivileged(new PluginDelegateHttpsURLConnection.PrivilegedBlockAction(var3, var4));
      } catch (PrivilegedActionException var6) {
         var6.printStackTrace();
      }
   }

   public synchronized void connect() throws IOException {
      if (!this.isConnected()) {
         this.checkPermission();
         this.connectWithCache();
         if (this.cacheStream == null) {
            try {
               this.connectSetup();
               AccessController.doPrivileged(new PluginDelegateHttpsURLConnection$2(this));
            } catch (PrivilegedActionException var3) {
               IOException var2 = (IOException)var3.getException();
               throw var2;
            }
         }

         this.setConnected(true);
      }
   }

   public synchronized void disconnect() {
      super.disconnect();
      if (this.cacheStream != null) {
         this.cacheStream = null;
      }

      if (this.cachedHeaders != null) {
         this.cachedHeaders.clear();
      }
   }

   public void checkPermission() throws IOException {
      if (!this.securityCheck) {
         SecurityManager var1 = System.getSecurityManager();
         if (var1 != null) {
            var1.checkConnect(this.url.getHost(), this.url.getPort());
         }

         this.securityCheck = true;
      }
   }

   public void connectWithCache() throws IOException {
      if (!this.cacheConnect) {
         if (this.getUseCaches() && this.getRequestMethod().equalsIgnoreCase("GET")) {
            try {
               CachedFile var1 = FileCache.get(this.url);
               if (var1 != null) {
                  InputStream var2 = null;

                  try {
                     var2 = AccessController.doPrivileged(new PluginDelegateHttpsURLConnection$3(this, var1));
                  } catch (PrivilegedActionException var4) {
                  }

                  if (var2 != null) {
                     this.responseCode = 200;
                     this.cachedHeaders = var1.getHeaderFields();
                     this.cacheStream = new ProgressInputStream(var2, this);
                  }
               }
            } catch (IOException var5) {
               Trace.netPrintException(var5);
            }
         }

         this.cacheConnect = true;
      }
   }

   public String getHeaderField(String var1) {
      String var2 = null;

      try {
         this.getInputStream();
      } catch (IOException var4) {
      }

      if (this.cachedHeaders != null) {
         var2 = (String)this.cachedHeaders.get(var1.toLowerCase());
      } else {
         var2 = super.getHeaderField(var1);
      }

      return var2;
   }

   public void connectSetup() throws IOException {
      if (!this.realConnect) {
         if (this.proxy == null) {
            ProxyInfo var1 = PluginProxyManager.getProxyInfo(this.url);
            if (var1 != null) {
               this.proxy = var1.getProxy();
               this.proxyPort = var1.getPort();
            }
         }

         if (this.proxy == null) {
            Object[] var2 = new Object[]{this.url};
            Trace.netPrintln(mf1.format(var2), 2);
         } else {
            Object[] var3 = new Object[]{this.url, this.proxy + (this.proxyPort != -1 ? ":" + this.proxyPort : "")};
            Trace.netPrintln(mf2.format(var3), 2);
         }

         if (this.getRequestProperty("cookie") == null) {
            String var4 = PluginCookieManager.getCookieInfo(this.url);
            if (var4 != null) {
               this.addRequestProperty("cookie", var4);
            }
         }

         this.realConnect = true;
      }
   }

   private void superConnect() throws IOException {
      if (!this.isConnected()) {
         if (this.proxy == null) {
            this.setNewClient(this.url, true);
         } else {
            this.setProxiedClient(this.url, this.proxy, this.proxyPort, true);
         }
      }
   }

   public synchronized InputStream getInputStream() throws IOException {
      this.connect();
      if (this.cacheStream != null) {
         return this.cacheStream;
      } else {
         this.checkCookieHeader();
         InputStream var1 = super.getInputStream();
         if (var1 != null) {
            this.cacheStream = new ProgressInputStream(var1, this);
         }

         return this.cacheStream;
      }
   }

   public boolean usingProxy() {
      ProxyInfo var1 = PluginProxyManager.getProxyInfo(this.url);
      return var1 != null && var1.getProxy() != null;
   }

   public synchronized void checkCookieHeader() {
      if (!this.checkSetCookie) {
         this.checkSetCookie = true;
         Map var1 = this.getHeaderFields();

         for (String var3 : var1.keySet()) {
            if (var3 != null && var3.equalsIgnoreCase("Set-Cookie")) {
               for (String var6 : (List)var1.get(var3)) {
                  if (var6 != null) {
                     PluginCookieManager.setCookieInfo(this.url, var6);
                  }
               }
            }
         }
      }
   }

   static {
      try {
         AccessController.doPrivileged(new PluginDelegateHttpsURLConnection$1());
      } catch (PrivilegedActionException var1) {
         var1.printStackTrace();
      }
   }

   class PrivilegedBlockAction implements PrivilegedExceptionAction {
      HttpsURLConnection conn;
      SecureRandom random;

      PrivilegedBlockAction(HttpsURLConnection var2, SecureRandom var3) {
         this.conn = var2;
         this.random = var3;
      }

      public Object run() throws Exception {
         SSLContext var1 = SSLContext.getInstance("SSL");
         X509PluginTrustManager var2 = new X509PluginTrustManager();
         TrustManager[] var3 = new TrustManager[]{var2};
         var1.init(null, var3, this.random);
         SSLSocketFactory var4 = var1.getSocketFactory();
         this.conn.setSSLSocketFactory(var4);
         return null;
      }
   }
}
