package sun.plugin;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.security.AccessController;
import java.util.Properties;
import javax.swing.SwingUtilities;
import sun.plugin.usability.Trace;
import sun.plugin.usability.UserProfile;
import sun.security.action.GetPropertyAction;

public class JavaRunTime {
   private static boolean onWindows = false;
   private static Object syncObject = new Object();
   private static OutputStream traceStream = null;
   private static ConsoleWindow console = null;
   private static int hStatusIconWnd = 0;
   private static boolean noConsole = false;

   protected static void initEnvironment(String var0, String var1, String var2) {
      Properties var3 = System.getProperties();
      var3.put("java.home", var0);
      if (var2 == null) {
         var3.put("user.home", var0);
      } else {
         var3.put("user.home", var2);
      }

      var3.put("bridge.home", var1);
      AppletViewer.loadPropertiesFiles();

      try {
         String var4 = AccessController.doPrivileged(new GetPropertyAction("os.name"));
         if (var4.indexOf("Windows") != -1) {
            onWindows = true;
         }
      } catch (Exception var5) {
         Trace.printException(var5);
      }
   }

   public static synchronized ConsoleWindow getJavaConsole() {
      if (console != null) {
         return console;
      } else if (noConsole) {
         return null;
      } else {
         console = new ConsoleWindow();
         OutputStream var0 = getTraceOutputStream();
         MainConsoleWriter var1 = new MainConsoleWriter(console, var0);
         DebugOutputStream var2 = new DebugOutputStream(var1);
         PrintStream var3 = new PrintStream(var2, true);
         System.setErr(var3);
         DebugOutputStream var4 = new DebugOutputStream(var1);
         PrintStream var5 = new PrintStream(var4, true);
         System.setOut(var5);
         String var6 = console.displayVersion();
         System.out.print(var6);
         return console;
      }
   }

   public static boolean isJavaConsoleVisible() {
      ConsoleWindow var0 = getJavaConsole();
      if (var0 != null) {
         return onWindows ? var0.isVisible() : var0.getState() == 0;
      } else {
         return false;
      }
   }

   public static void showJavaConsole(boolean var0) {
      if (!noConsole || var0) {
         ConsoleWindow var1 = getJavaConsole();
         if (var1 != null) {
            try {
               SwingUtilities.invokeAndWait(new JavaRunTime$1(var1, var0));
            } catch (Throwable var3) {
               var3.printStackTrace();
            }
         }
      }
   }

   public static void showJavaConsoleLater(boolean var0) {
      if (!noConsole) {
         ConsoleWindow var1 = getJavaConsole();
         if (var1 != null) {
            try {
               SwingUtilities.invokeLater(new JavaRunTime$2(var1, var0));
            } catch (Throwable var3) {
               var3.printStackTrace();
            }
         }
      }
   }

   public static void showJavaConsoleHelp() {
      ConsoleWindow var0 = getJavaConsole();
      if (var0 != null) {
         String var1 = var0.displayHelp();
         System.out.print(var1);
      }
   }

   public static void showSystemProperties() {
      ConsoleWindow var0 = getJavaConsole();
      if (var0 != null) {
         var0.displaySystemProperties();
      }
   }

   public static void printToJavaConsole(String var0) {
      ConsoleWindow var1 = getJavaConsole();
      if (var1 != null) {
         var1.append(var0);
      }
   }

   public static void setStatusIconWindowHandle(int var0) {
      hStatusIconWnd = var0;
   }

   public static int getStatusIconWindowHandle() {
      return hStatusIconWnd;
   }

   public static OutputStream getTraceOutputStream() {
      if (traceStream != null) {
         return traceStream;
      } else {
         try {
            File var0 = new File(UserProfile.getTraceFile());
            if (var0.exists()) {
               var0.delete();
            }

            traceStream = new BufferedOutputStream(new FileOutputStream(var0));
         } catch (IOException var1) {
            var1.printStackTrace();
         }

         return traceStream;
      }
   }

   public static native void ConsoleStatus(boolean var0);

   public static void setNoConsole(boolean var0) {
      noConsole = var0;
   }
}
