package sun.plugin;

import java.util.StringTokenizer;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.Trace;

public class ProgressInfo {
   private int progress = 0;
   private int base_progress = 0;
   private int step;
   private int progress_max = 10000;
   private int jar_num = 0;
   private int current_jar = 0;
   private AppletViewer av = null;
   private Pattern pattern;
   int count = 0;

   ProgressInfo() {
      try {
         this.pattern = Pattern.compile(".*(jar|jarjar|zip)$", 2);
      } catch (PatternSyntaxException var3) {
         var3.printStackTrace();
      } catch (IllegalArgumentException var4) {
         var4.printStackTrace();
      }
   }

   public void init(AppletViewer var1) {
      this.av = var1;
      this.jar_num = this.calcJars();
      if (this.jar_num != 0) {
         this.step = (int)(this.progress_max * 1.0 / this.jar_num);
      } else {
         this.step = this.progress_max;
      }
   }

   public synchronized void doOnStart(Object var1) {
      if (this.jar_num != 0) {
         if (this.av.getLoadingStatus() == 3) {
            Matcher var2 = this.pattern.matcher(var1.toString());
            if (var2.matches()) {
               Trace.println(ResourceHandler.getMessage("progress_info.downloading"), 1);
            }
         }
      } else {
         this.step /= 2;
      }
   }

   public synchronized void doOnProgress(Object var1, int var2, int var3) {
      if (this.jar_num != 0) {
         Matcher var4 = this.pattern.matcher(var1.toString());
         if (var4.matches()) {
            this.progress = (int)(this.step * (this.current_jar + var2 * 1.0 / var3));
         }
      } else {
         this.progress = this.base_progress + (int)(this.step * (var2 * 1.0 / var3));
      }

      if (this.progress > this.progress_max) {
         this.progress = this.progress_max;
      }
   }

   public synchronized void doOnFinish(Object var1) {
      if (this.jar_num != 0) {
         Matcher var2 = this.pattern.matcher(var1.toString());
         if (var2.matches()) {
            this.current_jar++;
            this.progress = this.step * this.current_jar;
         }
      } else {
         this.progress = this.base_progress + this.step;
         this.base_progress = this.progress;
      }

      if (this.progress > this.progress_max) {
         this.progress = this.progress_max;
         this.base_progress = this.progress_max;
      }
   }

   public synchronized int getProgress() {
      return this.progress;
   }

   public synchronized int getProgressMax() {
      return this.progress_max;
   }

   public int calcJars() {
      int var1 = 0;
      if (this.av.getParameter("cache_archive_ex") != null) {
         StringTokenizer var2 = new StringTokenizer(this.av.getParameter("cache_archive_ex"), ",", false);

         while (var2.hasMoreTokens()) {
            String var3 = var2.nextToken().trim();
            int var4 = var3.indexOf(";preload");
            if (var4 != -1) {
               var1++;
            }
         }
      } else if (this.av.getJarFiles() != null) {
         StringTokenizer var5 = new StringTokenizer(this.av.getJarFiles(), ",", false);

         while (var5.hasMoreTokens()) {
            String var6 = var5.nextToken();
            if (!var6.equalsIgnoreCase("null")) {
               var1++;
            }
         }
      }

      return var1;
   }
}
