package sun.plugin.cache;

import java.io.File;
import java.io.FilePermission;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.SocketPermission;
import java.net.URL;
import java.net.URLConnection;
import java.security.AccessController;
import java.security.Permission;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Random;
import sun.plugin.usability.Trace;

public class Cache {
   protected static long maxSize;
   protected static long threadThresholdSize;
   protected static long deleteThresholdSize;
   protected static boolean cachingDisabled = false;
   protected static Random random = new Random();
   protected static CleanupThread cleanupThread = null;
   protected static final byte INCOMPLETE = 0;
   protected static final byte UNUSABLE = 1;
   protected static final byte INUSE = 2;
   protected static final byte VERSION = 16;
   protected static final String INDEX_FILE_EXT = ".idx";
   protected static final long CLEANUP_INTERVAL = 1L;
   protected static final long MINIMUM_CACHE_SIZE = 5L;
   protected static final String DISABLED_PROP = "javaplugin.cache.disabled";
   protected static final String DIRECTORY_PROP = "javaplugin.cache.directory";
   protected static final String SIZE_PROP = "javaplugin.cache.size";
   protected static String KB = "{0} KB";
   protected static String MB = "{0} MB";
   protected static String BYTES = "{0} bytes";
   protected static String UNLIMITED = "unlimited";

   public static void init() {
   }

   protected static final boolean isSupportedProtocol(URL var0) {
      String var1 = var0.getProtocol();
      return var1 != null && (var1.equalsIgnoreCase("http") || var1.equalsIgnoreCase("https"));
   }

   protected static final void message(String var0, Object[] var1) {
      MessageFormat var2 = new MessageFormat(var0);
      Trace.println(var2.format(var1), 2);
   }

   protected static final Object privileged(Cache.CacheIOAction var0) throws IOException {
      try {
         return AccessController.doPrivileged(var0);
      } catch (PrivilegedActionException var2) {
         throw (IOException)var2.getException();
      }
   }

   protected static final File getIndexFile(File var0, URL var1) {
      String var2 = var0.getName();
      var2 = var2.substring(0, var2.length() - getFileExtension(var1.toString()).length());
      var2 = var2 + ".idx";
      return new File(var0.getParentFile(), var2);
   }

   protected static final File getDataFile(File var0, String var1) {
      String var2 = var0.getName();
      var2 = var2.substring(0, var2.length() - ".idx".length());
      var2 = var2 + getFileExtension(var1);
      return new File(var0.getParentFile(), var2);
   }

   protected static final String getFileExtension(String var0) {
      String var1 = "";
      int var2 = var0.lastIndexOf(46);
      if (var2 != -1) {
         var1 = var0.substring(var2);
      }

      if (var1.equalsIgnoreCase(".jar") || var1.equalsIgnoreCase(".jarjar")) {
         var1 = ".zip";
      }

      return var1;
   }

   protected static String generateCacheFileName(File var0, URL var1) throws IOException {
      String var2 = getKey(var1);

      String var3;
      File var4;
      File var5;
      do {
         var3 = var2 + Integer.toString(getRandom(), 16);
         var4 = new File(var0, var3 + getFileExtension(var1.toString()));
         var5 = new File(var0, var3 + ".idx");
      } while (var5.exists() || var4.exists());

      var5 = null;
      var4 = null;
      return var3;
   }

   protected static Enumeration getMatchingFiles(File var0, URL var1) {
      String var2 = getKey(var1);
      File[] var3 = var0.listFiles(new Cache$2(var2));
      return new Cache$3(var3);
   }

   protected static final void touch(File var0) throws IOException {
      privileged(new Cache$4(var0));
   }

   protected static String getKey(URL var0) {
      String var1 = var0.getPath();
      int var2 = var1.lastIndexOf("/");
      if (var2 != -1) {
         var1 = var1.substring(var2 + 1);
      }

      int var3 = var0.hashCode();
      if (var3 < 0) {
         var3 += Integer.MIN_VALUE;
      }

      return var1 + "-" + Integer.toString(var3, 16) + "-";
   }

   protected static String parseKey(String var0) {
      String var1 = null;
      int var2 = var0.lastIndexOf("-");
      if (var2 != -1) {
         var1 = var0.substring(0, var2 + 1);
      }

      return var1;
   }

   protected static final int getRandom() {
      return 268435456 + random.nextInt(1879048191);
   }

   protected static void checkPermission(URLConnection var0) throws IOException {
      Permission var1 = var0.getPermission();
      URL var2 = var0.getURL();
      if (var1 != null) {
         SecurityManager var3 = System.getSecurityManager();
         if (var3 != null) {
            try {
               var3.checkPermission(var1);
            } catch (SecurityException var5) {
               if (var1 instanceof FilePermission && var1.getActions().indexOf("read") != -1) {
                  var3.checkRead(var1.getName());
               } else {
                  if (!(var1 instanceof SocketPermission) || var1.getActions().indexOf("connect") == -1) {
                     throw var5;
                  }

                  var3.checkConnect(var2.getHost(), var2.getPort());
               }
            }
         }
      }
   }

   protected static long getFileSizeFromServer(URL var0) throws IOException {
      long var1 = -1L;
      HttpURLConnection var3 = (HttpURLConnection)var0.openConnection();
      var3.setUseCaches(false);
      var3.setRequestMethod("HEAD");
      var1 = var3.getContentLength();
      var3.disconnect();
      return var1;
   }

   protected static void addToTable(File var0, Hashtable var1) {
      String var2 = parseKey(var0.getName());
      ArrayList var3 = (ArrayList)var1.get(var2);
      if (var3 == null) {
         var3 = new ArrayList();
         var3.add(var0);
         var1.put(var2, var3);
      } else if (var3.indexOf(var0) == -1) {
         var3.add(var0);
      }
   }

   protected static void removeFromTable(File var0, Hashtable var1) {
      String var2 = parseKey(var0.getName());
      ArrayList var3 = (ArrayList)var1.get(var2);
      if (var3 != null) {
         int var4 = var3.indexOf(var0);
         if (var4 != -1) {
            var3.remove(var4);
         }

         if (var3.size() == 0) {
            var1.remove(var2);
         }
      }
   }

   protected static boolean updateTable(File var0, Hashtable var1, String var2) {
      boolean var3 = false;
      File[] var4 = var0.listFiles(new Cache$5(var2));

      for (int var5 = 0; var5 < var4.length; var5++) {
         ArrayList var6 = (ArrayList)var1.get(var2);
         if (var6 == null) {
            var6 = new ArrayList();
            var6.add(var4[var5]);
            var1.put(var2, var6);
            var3 = true;
         } else if (var6.indexOf(var4[var5]) == -1) {
            var6.add(var4[var5]);
            var3 = true;
         }
      }

      return var3;
   }

   protected static void createTable(File var0, Hashtable var1) {
      File[] var2 = var0.listFiles(new Cache$6());

      for (int var3 = 0; var3 < var2.length; var3++) {
         String var4 = parseKey(var2[var3].getName());
         ArrayList var5 = (ArrayList)var1.get(var4);
         if (var5 == null) {
            var5 = new ArrayList();
            var5.add(var2[var3]);
            var1.put(var4, var5);
         } else {
            var5.add(var2[var3]);
         }
      }
   }

   static {
      AccessController.doPrivileged(new Cache$1());
   }

   protected static class CacheIOAction implements PrivilegedExceptionAction {
      public Object run() throws IOException {
         return null;
      }
   }
}
