package sun.plugin.cache;

import java.io.File;
import java.io.IOException;
import java.security.cert.Certificate;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import java.util.zip.ZipEntry;

public class CachedJarFile extends JarFile {
   private Certificate[] certificates;
   private HashMap signerMap = null;
   private Manifest manifest = null;

   protected CachedJarFile(File var1, Certificate[] var2, HashMap var3, Manifest var4) throws IOException {
      super(var1, false);
      this.certificates = var2;
      this.signerMap = var3;
      this.manifest = var4;
      super.getManifest();
   }

   public ZipEntry getEntry(String var1) {
      ZipEntry var2 = super.getEntry(var1);
      return var2 != null ? new CachedJarFile.JarFileEntry(var2) : null;
   }

   public Enumeration entries() {
      Enumeration var1 = super.entries();
      return new CachedJarFile$1(this, var1);
   }

   public Manifest getManifest() throws IOException {
      Manifest var1 = null;
      if (this.manifest != null) {
         var1 = new Manifest();
         Attributes var2 = var1.getMainAttributes();
         var2.putAll((Map<?, ?>)this.manifest.getMainAttributes().clone());
         Map var3 = this.manifest.getEntries();
         if (var3 != null) {
            Map var4 = var1.getEntries();

            for (Object var6 : var3.keySet()) {
               Attributes var7 = (Attributes)var3.get(var6);
               var4.put(var6, var7.clone());
            }
         }
      }

      return var1;
   }

   private class JarFileEntry extends JarEntry {
      JarFileEntry(ZipEntry var2) {
         super(var2);
      }

      public Attributes getAttributes() throws IOException {
         return CachedJarFile.this.manifest != null ? (Attributes)CachedJarFile.this.manifest.getAttributes(this.getName()).clone() : null;
      }

      public Certificate[] getCertificates() {
         Certificate[] var1 = null;
         if (CachedJarFile.this.signerMap != null && !CachedJarFile.this.signerMap.isEmpty()) {
            int[] var2 = (int[])CachedJarFile.this.signerMap.get(this.getName());
            if (var2 != null) {
               var1 = new Certificate[var2.length];

               for (int var3 = 0; var3 < var2.length; var3++) {
                  var1[var3] = CachedJarFile.this.certificates[var2[var3]];
               }
            }
         }

         return var1;
      }
   }
}
