package sun.plugin.cache;

import java.io.File;
import java.util.Arrays;
import java.util.HashMap;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.UserProfile;

public class CleanupThread extends Thread {
   private boolean cleanupRequested = false;
   private Thread thisThread = null;
   private long timeToWait = 0L;
   private long prevCacheSize;

   public CleanupThread(ThreadGroup var1) {
      this(var1, 600000L);
   }

   public CleanupThread(ThreadGroup var1, long var2) {
      super(var1, "Cache Cleanup Thread");
      this.setPriority(4);
      this.timeToWait = var2;
      this.setCacheSize();
   }

   public void addedFile(long var1) {
      synchronized (this) {
         this.prevCacheSize += var1;
      }
   }

   public void addedJar(long var1) {
      synchronized (this) {
         this.prevCacheSize += var1;
      }
   }

   private void setCacheSize() {
      long var1 = 0L;
      long var3 = 0L;
      File var6 = new File(UserProfile.getNewJarCacheDir());
      if (var6.exists()) {
         File[] var5 = var6.listFiles();
         var3 = 0L;

         for (int var7 = 0; var7 < var5.length; var7++) {
            var3 += var5[var7].length();
         }
      }

      File var10 = new File(UserProfile.getNewFileCacheDir());
      if (var10.exists()) {
         File[] var9 = var10.listFiles();
         var1 = 0L;

         for (int var8 = 0; var8 < var9.length; var8++) {
            var1 += var9[var8].length();
         }
      }

      this.prevCacheSize = var1 + var3;
   }

   public void run() {
      this.thisThread = Thread.currentThread();

      try {
         while (true) {
            synchronized (this) {
               if (this.cleanupRequested) {
                  this.cleanupRequested = false;
                  if (this.prevCacheSize > Cache.threadThresholdSize) {
                     Cache.message(ResourceHandler.getMessage("cache.cleanup"), new Object[]{new Long(this.prevCacheSize).toString()});
                     this.cleanCache();
                  }
               } else {
                  this.wait(this.timeToWait);
                  this.cleanupRequested = true;
               }
            }
         }
      } catch (InterruptedException var4) {
         this.thisThread = null;
      }
   }

   protected void trigger() {
      if (this.thisThread != null) {
         synchronized (this) {
            this.cleanupRequested = true;
            this.notifyAll();
         }
      }
   }

   private void cleanCache() {
      Object[] var1 = this.getFilesInCache();
      int var2 = var1.length;
      long var3 = 0L;
      long var5 = 0L;

      for (int var7 = 0; var7 < var2; var7++) {
         var5 += ((CacheFile)var1[var7]).getSize();
      }

      var3 = Cache.deleteThresholdSize;

      for (int var8 = 0; var5 > var3 && var8 < var2; var5 -= ((CacheFile)var1[var8++]).delete()) {
         Cache.message(ResourceHandler.getMessage("cache.size"), new Object[]{new Long(var5)});
      }

      synchronized (this) {
         this.prevCacheSize = var5;
      }
   }

   private Object[] getFilesInCache() {
      HashMap var1 = new HashMap();
      Object var2 = null;
      var2 = FileCache.directory.listFiles();

      for (int var3 = 0; var3 < ((Object[])var2).length; var3++) {
         String var4 = ((Object[])var2)[var3].getName();
         String var5 = Cache.getFileExtension(var4);
         String var6 = var4.substring(0, var4.length() - var5.length()).toLowerCase();
         CacheFile var7 = (CacheFile)var1.get(var6);
         if (var7 == null) {
            var7 = new CacheFile(var6);
            var1.put(var6, var7);
         }

         var7.addFile((File)((Object[])var2)[var3], var5);
      }

      var2 = JarCache.directory.listFiles();

      for (int var11 = 0; var11 < ((Object[])var2).length; var11++) {
         String var12 = ((Object[])var2)[var11].getName();
         String var14 = Cache.getFileExtension(var12);
         String var15 = var12.substring(0, var12.length() - var14.length()).toLowerCase();
         CacheFile var8 = (CacheFile)var1.get(var15);
         if (var8 == null) {
            var8 = new CacheFile(var15);
            var1.put(var15, var8);
         }

         var8.addFile((File)((Object[])var2)[var11], var14);
      }

      Object[] var13 = var1.values().toArray();
      Arrays.sort(var13, new CleanupThread$1(this));
      return var13;
   }
}
