package sun.plugin.cache;

import java.io.BufferedInputStream;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.net.URL;
import java.security.AccessController;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Hashtable;
import sun.plugin.resources.ResourceHandler;

public class FileCache {
   protected static File directory;
   protected static Hashtable loadedFiles = new Hashtable();
   protected static ReferenceQueue refQueue = new ReferenceQueue();
   protected static final String[] exts = new String[]{".class", ".gif", ".jpg", ".au", ".wav"};
   protected static long lastCacheModifyTime = 0L;
   protected static Hashtable filesInCache = new Hashtable();

   public static void init() {
   }

   public static CachedFile get(URL var0) throws IOException {
      CachedFile var1 = null;
      if (Cache.cachingDisabled) {
         return null;
      } else {
         if (isSupported(var0)) {
            FileCache.FileReference var2 = (FileCache.FileReference)loadedFiles.get(var0);
            if (var2 != null) {
               var1 = (CachedFile)var2.get();
            }

            if (var1 == null) {
               try {
                  var1 = new CachedFileLoader(var0).load();
                  loadedFiles.put(var0, new FileCache.FileReference(var1, refQueue, var0));

                  while ((var2 = (FileCache.FileReference)refQueue.poll()) != null) {
                     loadedFiles.remove(var2.getURL());
                  }
               } catch (IOException var4) {
                  Cache.message(ResourceHandler.getMessage("cache.cache_warning"), new Object[]{var0});
                  var1 = null;
               }
            }
         }

         return var1;
      }
   }

   protected static final boolean isSupported(URL var0) {
      boolean var1 = false;
      if (Cache.isSupportedProtocol(var0)) {
         String var2 = Cache.getFileExtension(var0.toString());
         if (var2 != null) {
            for (int var3 = 0; var3 < exts.length; var3++) {
               if (var2.equalsIgnoreCase(exts[var3])) {
                  var1 = true;
               }
            }
         }
      }

      return var1;
   }

   protected static final File getDataFile(File var0, URL var1) {
      String var2 = var0.getName();
      var2 = var2.substring(0, var2.length() - ".idx".length());
      var2 = var2 + Cache.getFileExtension(var1.toString());
      return new File(var0.getParentFile(), var2);
   }

   protected static String generateCacheFileName(URL var0) throws IOException {
      return Cache.generateCacheFileName(directory, var0);
   }

   protected static Enumeration getMatchingFiles(URL var0) {
      return Cache.getMatchingFiles(directory, var0);
   }

   public static void clearLoadedFiles() {
      loadedFiles.clear();

      while (refQueue.poll() != null) {
      }
   }

   protected static boolean getMatchingFile(CachedFileLoader var0) throws IOException {
      boolean var1 = false;
      String var2 = Cache.getKey(var0.getURL());
      var1 = match(var0, var2);
      if (!var1 && Cache.updateTable(directory, filesInCache, var2)) {
         var1 = match(var0, var2);
      }

      return var1;
   }

   protected static boolean match(CachedFileLoader var0, String var1) throws IOException {
      boolean var2 = false;
      ArrayList var3 = (ArrayList)filesInCache.get(var1);
      if (var3 != null) {
         for (int var4 = 0; var4 < var3.size(); var4++) {
            File var5 = (File)var3.get(var4);
            File var6 = getDataFile(var5, var0.getURL());
            if (var5.exists() && var6.exists()) {
               var2 = verifyFile(var5, var0);
            } else {
               var3.remove(var4);
               if (var3.size() == 0) {
                  filesInCache.remove(var1);
               }
            }

            if (var2) {
               var0.setDataFile(var6);
               break;
            }
         }
      }

      return var2;
   }

   protected static boolean verifyFile(File var0, CachedFileLoader var1) throws IOException {
      boolean var2 = false;
      RandomAccessFile var3 = new RandomAccessFile(var0, "r");

      try {
         if (var3.readByte() == 16) {
            String var4 = var3.readUTF();
            if (var4.equals(var1.getURL().toString())) {
               var2 = true;
               var1.setIndexFile(var0);
               var1.setLastModify(var3.readLong());
               var1.setExpiration(var3.readLong());
               var3.readInt();
               var1.setHeaderMap(readHeaderFields(var3));
            }
         }
      } catch (IOException var14) {
      } finally {
         try {
            var3.close();
            Object var16 = null;
         } catch (IOException var13) {
         }
      }

      return var2;
   }

   public static HashMap readHeaderFields(RandomAccessFile var0) throws IOException {
      HashMap var1 = new HashMap();
      BufferedInputStream var2 = new BufferedInputStream(new FileInputStream(var0.getFD()));
      DataInputStream var3 = new DataInputStream(var2);

      try {
         for (int var4 = var3.readInt(); var4 > 0; var4--) {
            var1.put(var3.readUTF(), var3.readUTF());
         }

         return var1;
      } finally {
         ;
      }
   }

   static {
      AccessController.doPrivileged(new FileCache$1());
   }

   protected static class FileReference extends WeakReference {
      URL url;

      public FileReference(Object var1, ReferenceQueue var2, URL var3) {
         super(var1, var2);
         this.url = var3;
      }

      public URL getURL() {
         return this.url;
      }
   }
}
