package sun.plugin.cache;

import java.util.StringTokenizer;
import java.util.regex.Pattern;
import sun.plugin.resources.ResourceHandler;

public class FileVersion {
   private String strVersion;
   private long longVersion;
   private static final int VERSION_DIGITS = 4;
   private static final int VERSION_DIGITS_BITSIZE = 16;
   private static final int VERSION_DIGITS_BYTESIZE = 4;
   private static final int VERSION_DIGITS_RADIX = 16;
   public static final String defStrVersion = "x.x.x.x";
   public static final int defIntVersion = 0;
   public static final String regEx = "\\p{XDigit}{1,4}\\.\\p{XDigit}{1,4}\\.\\p{XDigit}{1,4}\\.\\p{XDigit}{1,4}";

   public FileVersion() {
      this.strVersion = "x.x.x.x";
      this.longVersion = 0L;
   }

   public FileVersion(String var1) throws JarCacheVersionException {
      this.strVersion = var1;
      this.longVersion = convertToLong(var1);
   }

   public FileVersion(long var1) {
      this.strVersion = convertToString(var1);
      this.longVersion = var1;
   }

   public void setVersion(long var1) {
      if (var1 > 0L) {
         this.longVersion = var1;
         this.strVersion = convertToString(var1);
      }
   }

   public void setVersion(String var1) throws JarCacheVersionException {
      if (var1 != null) {
         this.strVersion = var1;
         this.longVersion = convertToLong(var1);
      }
   }

   public long getVersionAsLong() {
      return this.longVersion;
   }

   public String getVersionAsString() {
      return this.strVersion;
   }

   public boolean isUpToDate(FileVersion var1) {
      return !this.strVersion.equals("x.x.x.x") && this.longVersion >= var1.longVersion;
   }

   public static long convertToLong(String var0) throws JarCacheVersionException {
      long var1 = 0L;
      if (!Pattern.matches("\\p{XDigit}{1,4}\\.\\p{XDigit}{1,4}\\.\\p{XDigit}{1,4}\\.\\p{XDigit}{1,4}", var0)) {
         throw new JarCacheVersionException(var0 + ResourceHandler.getMessage("cache.version_format_error"));
      } else {
         StringTokenizer var3 = new StringTokenizer(var0, ".", false);

         while (var3.hasMoreTokens()) {
            String var4 = var3.nextToken().trim();
            var1 <<= 16;
            var1 += Integer.parseInt(var4, 16);
         }

         return var1;
      }
   }

   public static String convertToString(long var0) {
      String var2 = "";
      long var3 = var0;

      for (int var5 = 0; var5 < 4; var5++) {
         long var6 = var3 >> 48 & 65535L;
         var3 <<= 16;
         var2 = var2 + Long.toString(var6, 16);
         var2 = var2 + (var5 != 3 ? "." : "");
      }

      return var2;
   }

   public static String getMessage(String var0) {
      return ResourceHandler.getMessage(var0);
   }
}
