package sun.plugin.cache;

import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.net.URL;
import java.security.AccessController;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.jar.JarFile;
import sun.plugin.resources.ResourceHandler;

public class JarCache {
   protected static File directory;
   protected static int compression;
   protected static Hashtable loadedJars = new Hashtable();
   protected static Hashtable currentJars = new Hashtable();
   protected static long lastCacheModifyTime = 0L;
   protected static Hashtable filesInCache = new Hashtable();
   protected static ReferenceQueue refQueue = new ReferenceQueue();
   protected static final String DATA_FILE_EXT = ".zip";
   protected static final String JAR_FILE_EXT = ".jar";
   protected static final String JARJAR_FILE_EXT = ".jarjar";
   protected static final String META_FILE_DIR = "meta-inf/";
   protected static final String COMPRESSION_PROP = "javaplugin.cache.compression";

   public static void init() {
   }

   public static JarFile get(URL var0) {
      CachedJarFile var1 = null;
      if (Cache.cachingDisabled) {
         return null;
      } else {
         if (isSupported(var0)) {
            JarCache.JarReference var2 = (JarCache.JarReference)loadedJars.get(var0);
            if (var2 != null) {
               var1 = (CachedJarFile)var2.get();
            }

            if (var1 == null) {
               try {
                  CachedJarLoader var3 = (CachedJarLoader)currentJars.remove(var0);
                  if (var3 != null) {
                     var1 = var3.load();
                  } else {
                     var1 = new CachedJarLoader(var0, false).load();
                  }

                  loadedJars.put(var0, new JarCache.JarReference(var1, refQueue, var0));

                  while ((var2 = (JarCache.JarReference)refQueue.poll()) != null) {
                     loadedJars.remove(var2.getURL());
                  }
               } catch (IOException var4) {
                  var4.printStackTrace();
                  Cache.message(ResourceHandler.getMessage("cache.cache_warning"), new Object[]{var0});
                  var1 = null;
               }
            }
         }

         return var1;
      }
   }

   protected static final boolean isSupported(URL var0) {
      return Cache.isSupportedProtocol(var0);
   }

   protected static long getJarSize(URL var0) throws IOException {
      long var1 = -1L;
      if (isSupported(var0)) {
         if (Cache.cachingDisabled) {
            var1 = Cache.getFileSizeFromServer(var0);
         } else {
            CachedJarLoader var3 = new CachedJarLoader(var0, true);
            var1 = var3.getJarSize();
            currentJars.put(var0, var3);
         }
      }

      return var1;
   }

   protected static boolean checkJarVersion(URL var0, FileVersion var1) throws IOException {
      boolean var2 = true;
      if (isSupported(var0) && !Cache.cachingDisabled) {
         CachedJarLoader var3 = new CachedJarLoader(var0, false);
         if (!var3.isVersionUpToDate(var1)) {
            var3.setVersion(var1);
            JarCache.JarReference var4 = (JarCache.JarReference)loadedJars.get(var0);
            if (var4 != null) {
               loadedJars.remove(var0);
            }

            currentJars.put(var0, var3);
            var2 = false;
         }
      }

      return var2;
   }

   protected static final File getDataFile(File var0) {
      String var1 = var0.getName();
      var1 = var1.substring(0, var1.length() - ".idx".length());
      var1 = var1 + ".zip";
      return new File(var0.getParentFile(), var1);
   }

   protected static String generateCacheFileName(URL var0) throws IOException {
      return Cache.generateCacheFileName(directory, var0);
   }

   public static void clearLoadedJars() {
      loadedJars.clear();
      currentJars.clear();

      while (refQueue.poll() != null) {
      }
   }

   protected static Enumeration getMatchingFiles(URL var0) {
      return Cache.getMatchingFiles(directory, var0);
   }

   protected static boolean getMatchingFile(CachedJarLoader var0) throws IOException {
      boolean var1 = false;
      String var2 = Cache.getKey(var0.getURL());
      var1 = match(var0, var2);
      if (!var1 && Cache.updateTable(directory, filesInCache, var2)) {
         var1 = match(var0, var2);
      }

      return var1;
   }

   protected static boolean match(CachedJarLoader var0, String var1) throws IOException {
      boolean var2 = false;
      ArrayList var3 = (ArrayList)filesInCache.get(var1);
      if (var3 != null) {
         Iterator var4 = var3.iterator();

         while (var4.hasNext()) {
            File var5 = (File)var4.next();
            File var6 = FileCache.getDataFile(var5, var0.getURL());
            if (var5.exists() && var6.exists()) {
               var2 = verifyFile(var5, var0);
            } else {
               var4.remove();
               if (var3.size() == 0) {
                  filesInCache.remove(var1);
               }
            }

            if (var2) {
               var0.setDataFile(var6);
               break;
            }
         }
      }

      return var2;
   }

   protected static boolean verifyFile(File var0, CachedJarLoader var1) throws IOException {
      boolean var2 = false;
      RandomAccessFile var3 = new RandomAccessFile(var0, "r");

      try {
         if (var3.readByte() == 16) {
            String var4 = var3.readUTF();
            if (var4.equals(var1.getURL().toString())) {
               var2 = true;
               var1.setIndexFile(var0);
               var1.setLastModify(var3.readLong());
               var1.setExpiration(var3.readLong());
               var3.readInt();
               String var5 = var3.readUTF();
               var1.setVersion(new FileVersion(var5));
            }
         }
      } catch (IOException var17) {
      } catch (JarCacheVersionException var18) {
      } finally {
         try {
            var3.close();
            Object var20 = null;
         } catch (IOException var16) {
         }
      }

      return var2;
   }

   static {
      AccessController.doPrivileged(new JarCache$1());
   }

   protected static class JarReference extends WeakReference {
      URL url;

      public JarReference(Object var1, ReferenceQueue var2, URL var3) {
         super(var1, var2);
         this.url = var3;
      }

      public URL getURL() {
         return this.url;
      }
   }
}
