package sun.plugin.cache;

import java.awt.Font;
import java.awt.Panel;
import java.io.File;
import java.io.IOException;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.LinkedList;
import sun.plugin.resources.ResourceHandler;

class JarCacheEntry {
   public static final String NAME = ResourceHandler.getMessage("cache_viewer.name");
   public static final String TYPE = ResourceHandler.getMessage("cache_viewer.type");
   public static final String SIZE = ResourceHandler.getMessage("cache_viewer.size");
   public static final String MODIFY_DATE = ResourceHandler.getMessage("cache_viewer.modify_date");
   public static final String EXPIRY_DATE = ResourceHandler.getMessage("cache_viewer.expiry_date");
   public static final String VERSION = ResourceHandler.getMessage("cache_viewer.version");
   public static final String URL = ResourceHandler.getMessage("cache_viewer.url");
   public static final String NAME_HELP = ResourceHandler.getMessage("cache_viewer.help.name");
   public static final String TYPE_HELP = ResourceHandler.getMessage("cache_viewer.help.type");
   public static final String SIZE_HELP = ResourceHandler.getMessage("cache_viewer.help.size");
   public static final String MODIFY_DATE_HELP = ResourceHandler.getMessage("cache_viewer.help.modify_date");
   public static final String EXPIRY_DATE_HELP = ResourceHandler.getMessage("cache_viewer.help.expiry_date");
   public static final String VERSION_HELP = ResourceHandler.getMessage("cache_viewer.help.version");
   public static final String URL_HELP = ResourceHandler.getMessage("cache_viewer.help.url");
   private String url;
   private long expiration = 0L;
   private long lastModified = 0L;
   String version = null;
   private File indexFile = null;
   private File dataFile = null;

   public String getURL() {
      return this.url;
   }

   public String getExpiration() {
      return this.formatDate(this.expiration);
   }

   public String getLastModifyDate() {
      return this.formatDate(this.lastModified);
   }

   public String getVersion() {
      if (this.version == null || this.version.equals("x.x.x.x")) {
         this.version = "N/A";
      }

      return this.version;
   }

   public String getSize() {
      long var1 = 0L;
      long var3 = this.dataFile.length();
      var1 = var3 / 1024L;
      if (var3 - var1 * 1024L > 0L) {
         var1++;
      }

      return new Long(var1).toString();
   }

   public String getName() {
      return this.dataFile.getName();
   }

   public String getFileExtenstion() {
      return FileType.getFileDescription(Cache.getFileExtension(this.url));
   }

   public Object getDisplayValue(String var1) {
      String var2 = null;
      if (var1.equals(URL)) {
         var2 = this.getURL();
      } else if (var1.equals(EXPIRY_DATE)) {
         var2 = this.getExpiration();
      } else if (var1.equals(MODIFY_DATE)) {
         var2 = this.getLastModifyDate();
      } else if (var1.equals(VERSION)) {
         var2 = this.getVersion();
      } else if (var1.equals(SIZE)) {
         var2 = this.getSize() + "KB";
      } else if (var1.equals(NAME)) {
         var2 = this.getName();
      } else if (var1.equals(TYPE)) {
         var2 = this.getFileExtenstion();
      }

      return var2;
   }

   public Object getValue(String var1) {
      Object var2 = null;
      if (var1.equals(URL)) {
         var2 = this.getURL();
      } else if (var1.equals(EXPIRY_DATE)) {
         var2 = new Date(this.expiration);
      } else if (var1.equals(MODIFY_DATE)) {
         var2 = new Date(this.lastModified);
      } else if (var1.equals(VERSION)) {
         var2 = this.getVersion();
      } else if (var1.equals(SIZE)) {
         var2 = new Long(this.dataFile.length());
      } else if (var1.equals(NAME)) {
         var2 = this.getName();
      } else if (var1.equals(TYPE)) {
         var2 = this.getFileExtenstion();
      }

      return var2;
   }

   private String formatDate(long var1) {
      SimpleDateFormat var3 = new SimpleDateFormat("MM/dd/yy hh:mm a");
      Date var4 = new Date(var1);
      return var3.format(var4);
   }

   public static int getTextWidth(Font var0, String var1) {
      Panel var2 = new Panel();
      String var3 = "";
      if (var1.equals(URL)) {
         var3 = "http://java.sun.com/javaweb/products/plugin/swingapplet.html";
      } else if (var1.equals(EXPIRY_DATE) || var1.equals(MODIFY_DATE)) {
         var3 = "12/13/69 04:00 PM  ";
      } else if (var1.equals(VERSION)) {
         var3 = "Version    ";
      } else if (var1.equals(SIZE)) {
         var3 = "999,999KB ";
      } else if (var1.equals(NAME)) {
         var3 = "test-images.jar-2bc62790-5ad1049d";
      } else if (var1.equals(TYPE)) {
         var3 = "Jpeg Image  ";
      }

      return var2.getFontMetrics(var0).stringWidth(var3);
   }

   public boolean delete() {
      boolean var1 = this.dataFile.delete();
      if (var1) {
         this.dataFile = null;
         if (this.indexFile.delete()) {
            this.indexFile = null;
         }
      }

      return var1;
   }

   public static LinkedList getEntries() {
      LinkedList var0 = new LinkedList();
      String var1 = File.separator;
      File var2 = new File(JarCacheViewer.getCacheLocation() + var1 + "jar" + var1 + "1.0");
      getFileEntries(var2, var0);
      File var3 = new File(JarCacheViewer.getCacheLocation() + var1 + "file" + var1 + "1.0");
      getFileEntries(var3, var0);
      return var0;
   }

   private static void getFileEntries(File var0, LinkedList var1) {
      if (var0.exists()) {
         File[] var2 = var0.listFiles(new JarCacheEntry$1());

         for (int var3 = 0; var3 < var2.length; var3++) {
            Object var4 = null;

            try {
               var4 = getDetails(var2[var3]);
            } catch (IOException var6) {
               var6.printStackTrace();
               var4 = null;
            }

            if (var4 != null) {
               var1.add(var4);
            }
         }
      }
   }

   private static JarCacheEntry getDetails(File var0) throws IOException {
      return (JarCacheEntry)privileged(new JarCacheEntry$2(var0));
   }

   private static final Object privileged(JarCacheEntry.CacheIOAction var0) throws IOException {
      try {
         return AccessController.doPrivileged(var0);
      } catch (PrivilegedActionException var2) {
         throw (IOException)var2.getException();
      }
   }

   private static class CacheIOAction implements PrivilegedExceptionAction {
      private CacheIOAction() {
      }

      public Object run() throws IOException {
         return null;
      }
   }
}
