package sun.plugin.cache;

import java.awt.Color;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Insets;
import javax.swing.JTable;
import javax.swing.KeyStroke;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

public class JarCacheTable extends JTable {
   public static final Font tableFont = new Font("Arial", 0, 10);
   private final Color shadeColor = new Color(232, 232, 232);
   private DefaultTableCellRenderer tableCellRenderer = new JarCacheTableCellRenderer(tableFont, this.shadeColor);
   private JarCacheTableColumnModel tableColumnModel = new JarCacheTableColumnModel();
   private JarCacheTableColumn[] tableColumns = null;
   private JarCacheTableSorter sorter = null;
   private String[] colNames = null;

   public JarCacheTable() {
      this.sizeColumnsToFit(3);
      this.setAutoResizeMode(0);
      this.setColumnModel(this.tableColumnModel);
      this.tableColumns = this.tableColumnModel.getColumnArray();
      this.colNames = new String[this.tableColumns.length];

      for (int var1 = 0; var1 < this.tableColumns.length; var1++) {
         this.colNames[var1] = this.tableColumns[var1].getHeaderValue().toString();
      }

      this.sorter = new JarCacheTableSorter(this.colNames);
      this.sorter.addMouseListenerToHeaderInTable(this);
      this.setModel(this.sorter);
      int var2 = this.tableColumnModel.getColumnCount();
      TableColumn var3 = null;

      for (int var4 = 0; var4 < var2; var4++) {
         var3 = this.columnModel.getColumn(var4);
         if (this.tableColumns[var4].isVisible()) {
            var3.setMinWidth(this.tableColumns[var4].getMinWidth());
            var3.setPreferredWidth(this.tableColumns[var4].getPreferredWidth());
            var3.setResizable(this.tableColumns[var4].getResizable());
         } else {
            var3.setMinWidth(0);
            var3.setMaxWidth(0);
         }
      }

      this.setHeaderRenderers();
      JarCacheTable$1 var5 = new JarCacheTable$1(this);
      this.registerKeyboardAction(var5, KeyStroke.getKeyStroke(127, 0), 2);
      this.getTableHeader().setReorderingAllowed(false);
      this.setPreferredScrollableViewportSize(this.getPreferredSize());
   }

   public void setHeaderRenderers() {
      TableColumnModel var1 = this.getColumnModel();
      int var2 = var1.getColumnCount();

      for (int var3 = 0; var3 < var2; var3++) {
         var1.getColumn(var3).setHeaderRenderer(new JarCacheTableHeaderRenderer());
      }
   }

   public void refresh() {
      this.sorter.refresh();
   }

   public JarCacheTableColumnModel getJarCacheTableColumnModel() {
      return this.tableColumnModel;
   }

   public JarCacheTableColumn[] getJarCacheTableColumns() {
      return this.tableColumns;
   }

   public TableCellRenderer getCellRenderer(int var1, int var2) {
      return this.tableCellRenderer;
   }

   public Font getFont() {
      return tableFont;
   }

   public void removeRows() {
      this.sorter.removeRows(this.getSelectedRows());
   }

   public void adjustColumnSize(Container var1) {
      int var2 = this.tableColumnModel.getColumnCount();
      int var3 = 0;
      int var4 = 0;
      TableColumn var5 = null;

      for (int var6 = 0; var6 < var2 - 1; var6++) {
         var5 = this.columnModel.getColumn(var6);
         if (this.tableColumns[var6].isVisible()) {
            var3 += this.tableColumns[var6].getWidth();
            var4 += var5.getPreferredWidth();
         }
      }

      Dimension var7 = var1.getSize();
      Insets var8 = var1.getInsets();
      var5 = this.columnModel.getColumn(var2 - 1);
      int var9 = (int)(var7.getWidth() - var3 - var8.left - var8.right - 3.0);
      var5.setPreferredWidth(var9);
   }
}
