package sun.plugin.cachescheme;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.security.AccessController;
import java.util.Hashtable;
import java.util.StringTokenizer;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.DialogFactory;
import sun.plugin.usability.Trace;
import sun.plugin.usability.UserProfile;
import sun.security.action.GetPropertyAction;

public class HTMLInstaller {
   String relativeCacheDir = UserProfile.getHTMLCacheDir();

   public boolean install(Hashtable var1, URL var2) throws AppletInstallationException, EntryNotFoundException, IOException {
      Trace.println(ResourceHandler.getMessage("html.install.check"), 2);
      Hashtable var3 = (Hashtable)var1.clone();
      var3.remove("codebase");
      var3.remove("java_codebase");
      var3.put("codebase", var2.toString());
      String var4 = (String)var3.get("applet_html_title");
      String var5 = (String)var3.get("applet_html_version");
      String var6 = (String)var3.get("applet_object_clsid");
      String var7 = (String)var3.get("applet_object_codebase");
      String var8 = (String)var3.get("applet_embed_pluginpage");
      String var9 = (String)var3.get("applet_embed_pluginsurl");
      String var10 = (String)var3.get("type");
      String var11 = (String)var3.get("code");
      String var12 = (String)var3.get("codebase");
      if (var4 == null) {
         return false;
      } else if (var5 == null) {
         throw new AppletInstallationException("\"applet_html_version\" is missing from HTML parameter");
      } else if (var6 == null) {
         throw new AppletInstallationException("\"applet_object_clsid\" is missing from HTML parameter");
      } else if (var10 == null) {
         throw new AppletInstallationException("\"type\" is missing from HTML parameter");
      } else if (var11 == null) {
         throw new AppletInstallationException("\"code\" is missing from HTML parameter");
      } else {
         String var13 = this.mangleName(var4);

         try {
            Trace.println(ResourceHandler.getMessage("html.install.version.checklocal"), 2);
            long var14 = this.calculateVersion(var5);
            HTMLVersionTable var16 = new HTMLVersionTable();
            var16.load();
            String var17 = var16.getVersion(var4);
            Trace.messagePrintln("html.install.version.remote.local", new Object[]{var5, var17}, null, 2);
            if (this.calculateVersion(var17) >= var14) {
               String var18 = var16.getPath(var4);
               String var19 = var16.getFilename(var4);
               File var20 = new File(var18, var19);
               if (var20.exists()) {
                  Trace.println(ResourceHandler.getMessage("html.install.local.uptodated"), 2);
                  return true;
               }

               Trace.println(ResourceHandler.getMessage("html.install.local.outdated"), 2);
            } else {
               Trace.println(ResourceHandler.getMessage("html.install.remote.uptodated"), 2);
            }
         } catch (EntryNotFoundException var21) {
            Trace.println(ResourceHandler.getMessage("html.install.info.missing"), 2);
         }

         if (!this.promptUserForHTMLInstallation()) {
            Trace.println(ResourceHandler.getMessage("html.install.user.deny"), 2);
            return true;
         } else {
            String var22 = AccessController.doPrivileged(new GetPropertyAction("user.home"));
            String var15 = UserProfile.getHTMLCacheDir() + File.separator + var13;
            String var23 = "index.html";
            this.installHTML(var4, var5, var15, var23, var3);
            return true;
         }
      }
   }

   public long calculateVersion(String var1) throws AppletInstallationException {
      long var2 = 0L;
      StringTokenizer var4 = new StringTokenizer(var1, ".", false);
      if (var4.countTokens() != 4) {
         throw new AppletInstallationException("\"applet_html_version\" " + var1 + " must be in X.X.X.X form where X is 0 to F");
      } else {
         try {
            while (var4.hasMoreTokens()) {
               String var5 = var4.nextToken().trim();
               var2 *= 16L;
               var2 += Integer.parseInt(var5, 16);
            }

            return var2;
         } catch (Throwable var6) {
            throw new AppletInstallationException("\"applet_html_version\" " + var1 + " must be in X.X.X.X form where X is 0 to F");
         }
      }
   }

   public String mangleName(String var1) throws AppletInstallationException {
      if (var1.indexOf("/") == -1
         && var1.indexOf("\\") == -1
         && var1.indexOf(":") == -1
         && var1.indexOf("*") == -1
         && var1.indexOf("?") == -1
         && var1.indexOf("\"") == -1
         && var1.indexOf("<") == -1
         && var1.indexOf(">") == -1
         && var1.indexOf("|") == -1) {
         StringBuffer var2 = new StringBuffer();

         for (int var3 = 0; var3 < var1.length(); var3++) {
            char var4 = var1.charAt(var3);
            if (var4 == ' ') {
               var2.append('_');
            } else {
               var2.append(var4);
            }
         }

         return var2.toString();
      } else {
         throw new AppletInstallationException("\"applet_html_title\" can not contain the following characters: / \\ : * ? \" < > |");
      }
   }

   private void installHTML(String var1, String var2, String var3, String var4, Hashtable var5) throws IOException {
      Trace.println(ResourceHandler.getMessage("html.install.html.generate"), 2);
      HTMLGenerator var6 = new HTMLGenerator();
      var6.generate(var5, new File(var3, var4));
      Trace.println(ResourceHandler.getMessage("html.install.version.update"), 2);
      HTMLVersionTable var7 = new HTMLVersionTable();
      var7.load();
      var7.add(var1, var2, var3, var4);
      var7.save();
      Trace.println(ResourceHandler.getMessage("html.install.bookmark.add"), 2);
      BookmarkManager var8 = new BookmarkManager();
      var8.addBookmark(var1, var3 + File.separator + var4);
   }

   private boolean promptUserForHTMLInstallation() {
      String var1 = ResourceHandler.getMessage("html.caption");
      String var2 = ResourceHandler.getMessage("html.prompt_user");
      int var3 = 0;
      if (!Trace.isAutomationEnabled()) {
         var3 = DialogFactory.showConfirmDialog(var2, var1);
      } else {
         Trace.println(ResourceHandler.getMessage("html.install.automation"), 2);
         var3 = 0;
      }

      return var3 == 0;
   }
}
