package sun.plugin.dom;

import netscape.javascript.JSException;
import netscape.javascript.JSObject;
import org.w3c.dom.DOMException;
import sun.plugin.dom.exception.InvalidAccessException;
import sun.plugin.dom.exception.InvalidStateException;
import sun.plugin.security.ActivatorSecurityManager;

public class DOMObject {
   private JSObject jsobj;

   public DOMObject(JSObject var1) {
      this.jsobj = var1;
   }

   public Object call(String var1, Object[] var2) throws DOMException {
      this.checkThreadAccess();

      try {
         Object[] var3 = null;
         if (var2 != null) {
            var3 = new Object[var2.length];

            for (int var4 = 0; var4 < var2.length; var4++) {
               var3[var4] = this.unwrapObject(var2[var4]);
            }
         }

         return this.jsobj.call(var1, var3);
      } catch (JSException var5) {
         throw new InvalidStateException(var5.toString());
      }
   }

   public Object getMember(String var1) throws DOMException {
      this.checkThreadAccess();

      try {
         Object var2 = this.jsobj.getMember(var1);
         return this.wrapObject(var2);
      } catch (JSException var3) {
         throw new InvalidStateException(var3.toString());
      }
   }

   public void setMember(String var1, Object var2) throws DOMException {
      this.checkThreadAccess();
      var2 = this.unwrapObject(var2);

      try {
         this.jsobj.setMember(var1, var2);
      } catch (JSException var4) {
         throw new InvalidStateException(var4.toString());
      }
   }

   public void removeMember(String var1) throws DOMException {
      this.checkThreadAccess();

      try {
         this.jsobj.removeMember(var1);
      } catch (JSException var3) {
         throw new InvalidStateException(var3.toString());
      }
   }

   public Object getSlot(int var1) throws DOMException {
      this.checkThreadAccess();

      try {
         Object var2 = this.jsobj.getSlot(var1);
         return this.wrapObject(var2);
      } catch (JSException var3) {
         throw new InvalidStateException(var3.toString());
      }
   }

   public void setSlot(int var1, Object var2) throws DOMException {
      this.checkThreadAccess();
      var2 = this.unwrapObject(var2);

      try {
         this.jsobj.setSlot(var1, var2);
      } catch (JSException var4) {
         throw new InvalidStateException(var4.toString());
      }
   }

   private void checkThreadAccess() throws InvalidAccessException {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null && var1 instanceof ActivatorSecurityManager) {
         ActivatorSecurityManager var2 = (ActivatorSecurityManager)var1;
         Class[] var3 = var2.getExecutionStackContext();

         for (int var4 = 0; var4 < var3.length; var4++) {
            Class var5 = var3[var4];
            if ((class$sun$plugin$dom$DOMService == null
                  ? (class$sun$plugin$dom$DOMService = class$("sun.plugin.dom.DOMService"))
                  : class$sun$plugin$dom$DOMService)
               .isAssignableFrom(var5)) {
               return;
            }
         }
      }

      throw new InvalidAccessException("Invalid access to DOM object from non-dispatch thread.");
   }

   private Object wrapObject(Object var1) {
      if (var1 == null) {
         return var1;
      } else {
         return var1 instanceof JSObject ? new DOMObject((JSObject)var1) : var1;
      }
   }

   private Object unwrapObject(Object var1) {
      if (var1 == null) {
         return var1;
      } else if (var1 instanceof DOMObject) {
         DOMObject var2 = (DOMObject)var1;
         return var2.getJSObject();
      } else {
         return var1;
      }
   }

   private Object getJSObject() {
      return this.jsobj;
   }
}
