package sun.plugin.extension;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.security.AccessController;
import java.security.CodeSource;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.text.MessageFormat;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.StringTokenizer;
import java.util.Vector;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import java.util.jar.Attributes.Name;
import sun.misc.ExtensionInfo;
import sun.misc.ExtensionInstallationException;
import sun.misc.ExtensionInstallationProvider;
import sun.plugin.AppletViewer;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.security.TrustDecider;
import sun.plugin.usability.DialogFactory;
import sun.plugin.usability.Trace;
import sun.security.action.GetPropertyAction;

public class ExtensionInstallationImpl implements ExtensionInstallationProvider {
   public boolean installExtension(ExtensionInfo var1, ExtensionInfo var2) throws ExtensionInstallationException {
      Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.info") + var1, 6);

      try {
         AccessController.doPrivileged(new ExtensionInstallationImpl$1(this, var1, var2));
      } catch (Throwable var6) {
         Object var4 = var6;
         Object var5 = null;
         if (var6 instanceof PrivilegedActionException) {
            var4 = ((PrivilegedActionException)var6).getException();
            if (var4 instanceof CertificateExpiredException) {
               var5 = ResourceHandler.getMessage("optpkg.cert_expired");
            } else if (var4 instanceof CertificateNotYetValidException) {
               var5 = ResourceHandler.getMessage("optpkg.cert_notyieldvalid");
            } else if (var4 instanceof CertificateException) {
               var5 = ResourceHandler.getMessage("optpkg.cert_notverify");
            } else {
               var5 = ResourceHandler.getMessage("optpkg.general_error");
            }
         } else {
            var5 = ResourceHandler.getMessage("optpkg.general_error");
         }

         Trace.extPrintException((Throwable)var4, (String)var5, ResourceHandler.getMessage("optpkg.caption"));
         Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.fail"), 2);
         return true;
      }

      Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.ok"), 2);
      return true;
   }

   private void verifyJar(String var1, String var2) throws ExtensionInstallationException, CertificateException, CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, KeyStoreException, NoSuchAlgorithmException, IOException {
      try {
         boolean var3 = false;
         JarFile var4 = new JarFile(var2, true);
         Vector var5 = new Vector();
         byte[] var6 = new byte[8192];
         Enumeration var7 = var4.entries();

         while (var7.hasMoreElements()) {
            JarEntry var8 = (JarEntry)var7.nextElement();
            var5.addElement(var8);
            InputStream var9 = var4.getInputStream(var8);

            while (var9.read(var6, 0, var6.length) != -1) {
            }

            var9.close();
         }

         var4.close();
         Manifest var17 = var4.getManifest();
         if (var17 != null) {
            HashMap var18 = new HashMap();
            Enumeration var10 = var5.elements();

            while (var10.hasMoreElements()) {
               JarEntry var11 = (JarEntry)var10.nextElement();
               String var12 = var11.getName();
               Certificate[] var13 = var11.getCertificates();
               boolean var14 = var13 != null && var13.length > 0;
               var3 |= var14;
               if (var14) {
                  CodeSource var15 = (CodeSource)var18.get(var13);
                  if (var15 == null) {
                     var15 = new CodeSource(new URL(var1), var13);
                     var18.put(var13, var15);
                     if (!TrustDecider.isAllPermissionGranted(var15)) {
                        throw new ExtensionInstallationException("User deny optional package installer to be launched.");
                     }
                  }
               }
            }
         }

         if (var17 == null) {
            throw new ExtensionInstallationException("No manifest in the optional package installer.");
         } else if (!var3) {
            throw new ExtensionInstallationException("Optional package installer is unsigned. (signatures missing or not parsable)");
         }
      } catch (IOException var16) {
         throw new ExtensionInstallationException("IO Error. Unable to verify optional package installer.");
      }
   }

   private int askUserForAcknowledgment(ExtensionInfo var1, ExtensionInfo var2) {
      Object var3 = null;
      if (var2 != null) {
         int var4 = var2.isCompatibleWith(var1);
         switch (var4) {
            case 1:
               MessageFormat var12 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.new_spec.text"));
               Object[] var18 = new Object[]{var1.specVersion, var2.title, var1.url};
               var3 = var12.format(var18);
               break;
            case 2:
               MessageFormat var11 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.new_impl.text"));
               Object[] var17 = new Object[]{var1.implementationVersion, var2.title, var1.url};
               var3 = var11.format(var17);
               break;
            case 3:
               MessageFormat var10 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.new_vendor.text"));
               Object[] var16 = new Object[]{var1.vendor, var1.vendorId, var2.title, var1.url};
               var3 = var10.format(var16);
               break;
            default:
               MessageFormat var5 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.default.text"));
               Object[] var6 = new Object[]{var1.name, var1.url};
               var3 = var5.format(var6);
         }
      } else {
         MessageFormat var8 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.default.text"));
         Object[] var13 = new Object[]{var1.name, var1.url};
         var3 = var8.format(var13);
      }

      Object[] var9 = new Object[]{getMessage("security_dialog.buttonYes"), getMessage("security_dialog.buttonNo"), getMessage("security_dialog.buttonAlways")};
      int var14 = 0;
      if (!Trace.isAutomationEnabled()) {
         var14 = DialogFactory.showOptionDialog(var3, getMessage("security_dialog.caption"), var9, var9[0]);
      } else {
         Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.automation"), 2);
         var14 = 0;
      }

      if (var14 == 0) {
         Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.granted") + var1.url, 2);
      } else {
         Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.deny"), 2);
      }

      return var14;
   }

   private void installJarFile(String var1, String var2) throws ExtensionInstallationException, IOException, InterruptedException {
      Trace.extPrintln(ResourceHandler.getMessage("optpkg.install.begin") + var2, 6);
      JarFile var3 = new JarFile(var2);
      Manifest var4 = var3.getManifest();
      if (var4 != null) {
         String var5 = AccessController.doPrivileged(new GetPropertyAction("java.ext.dirs"));
         StringTokenizer var6 = new StringTokenizer(var5, File.pathSeparator);
         String var7 = var6.nextToken();
         Attributes var8 = var4.getMainAttributes();
         Object var9 = new RawExtensionInstaller();
         if (var8 != null) {
            if (var8.getValue(Name.MAIN_CLASS) != null) {
               var9 = new JavaExtensionInstaller();
            } else if (var8.getValue(Name.EXTENSION_INSTALLATION) != null) {
               var9 = new NativeExtensionInstaller();
            }
         }

         Object var10 = null;
         ((ExtensionInstaller)var9).install(var1, var2, var7);
      }
   }

   private static String getMessage(String var0) {
      return AppletViewer.getMessage(var0);
   }
}
