package sun.plugin.net.protocol.file;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FilePermission;
import java.io.IOException;
import java.io.InputStream;
import java.net.FileNameMap;
import java.net.URL;
import java.security.Permission;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.TimeZone;
import sun.net.www.MessageHeader;
import sun.net.www.ParseUtil;
import sun.net.www.URLConnection;
import sun.plugin.usability.ProgressInputStream;

public class PluginFileURLConnection extends URLConnection {
   static String CONTENT_LENGTH = "content-length";
   static String CONTENT_TYPE = "content-type";
   static String TEXT_PLAIN = "text/plain";
   static String LAST_MODIFIED = "last-modified";
   String contentType;
   InputStream is;
   java.net.URLConnection conn;
   File file;
   String filename;
   boolean isDirectory = false;
   boolean exists = false;
   List files;
   private boolean initializedHeaders = false;
   long length = 0L;
   long lastModified = 0L;
   Permission permission;

   PluginFileURLConnection(URL var1, java.net.URLConnection var2) {
      super(var1);
      this.conn = var2;
   }

   public synchronized InputStream getInputStream() throws IOException {
      InputStream var1 = this.conn.getInputStream();
      return new ProgressInputStream(var1, this.conn);
   }

   public void connect() throws IOException {
      if (!this.connected) {
         try {
            String var1 = ParseUtil.decode(this.url.getPath());
            this.file = new File(var1.replace('/', File.separatorChar));
            this.filename = this.file.toString();
            this.isDirectory = this.file.isDirectory();
            if (this.isDirectory) {
               this.files = Arrays.asList(this.file.list());
            } else {
               this.is = new BufferedInputStream(new FileInputStream(this.filename));
            }
         } catch (IOException var2) {
            throw var2;
         }

         this.connected = true;
      }
   }

   private void initializeHeaders() {
      try {
         this.connect();
         this.exists = this.file.exists();
      } catch (IOException var4) {
      }

      if (!this.initializedHeaders || !this.exists) {
         this.length = this.file.length();
         this.lastModified = this.file.lastModified();
         if (!this.isDirectory) {
            FileNameMap var1 = java.net.URLConnection.getFileNameMap();
            this.contentType = var1.getContentTypeFor(this.filename);
            if (this.contentType != null) {
               this.properties.add(CONTENT_TYPE, this.contentType);
            }

            this.properties.add(CONTENT_LENGTH, String.valueOf(this.length));
            if (this.lastModified != 0L) {
               Date var2 = new Date(this.lastModified);
               SimpleDateFormat var3 = new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss 'GMT'", Locale.US);
               var3.setTimeZone(TimeZone.getTimeZone("GMT"));
               this.properties.add(LAST_MODIFIED, var3.format(var2));
            }
         } else {
            this.properties.add(CONTENT_TYPE, TEXT_PLAIN);
         }

         this.initializedHeaders = true;
      }
   }

   public String getHeaderField(String var1) {
      this.initializeHeaders();
      return super.getHeaderField(var1);
   }

   public String getHeaderField(int var1) {
      this.initializeHeaders();
      return super.getHeaderField(var1);
   }

   public int getContentLength() {
      this.initializeHeaders();
      return super.getContentLength();
   }

   public String getHeaderFieldKey(int var1) {
      this.initializeHeaders();
      return super.getHeaderFieldKey(var1);
   }

   public MessageHeader getProperties() {
      this.initializeHeaders();
      return super.getProperties();
   }

   public Permission getPermission() throws IOException {
      if (this.permission == null) {
         String var1 = ParseUtil.decode(this.url.getPath());
         if (File.separatorChar == '/') {
            this.permission = new FilePermission(var1, "read");
         } else {
            this.permission = new FilePermission(var1.replace('/', File.separatorChar), "read");
         }
      }

      return this.permission;
   }
}
