package sun.plugin.net.protocol.http;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import java.text.MessageFormat;
import java.util.List;
import java.util.Map;
import java.util.ResourceBundle;
import java.util.StringTokenizer;
import sun.plugin.cache.CachedFile;
import sun.plugin.cache.FileCache;
import sun.plugin.net.cookie.PluginCookieManager;
import sun.plugin.net.proxy.PluginProxyManager;
import sun.plugin.net.proxy.ProxyInfo;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.ProgressInputStream;
import sun.plugin.usability.Trace;

public class HttpURLConnection extends sun.net.www.protocol.http.HttpURLConnection {
   protected String proxy = null;
   protected int proxyPort = -1;
   protected boolean resolveProxy = true;
   boolean failedOnce = false;
   private Map cachedHeaders = null;
   private static MessageFormat mf1 = new MessageFormat(ResourceHandler.getMessage("net.connect.no_proxy"));
   private static MessageFormat mf2 = new MessageFormat(ResourceHandler.getMessage("net.connect.proxy_is"));
   private boolean securityCheck = false;
   private boolean cacheConnect = false;
   private boolean realConnect = false;
   private boolean checkSetCookie = false;
   private InputStream cacheStream = null;
   private static ResourceBundle rb;

   public HttpURLConnection(URL var1, Handler var2) throws IOException {
      super(var1, var2);
   }

   public HttpURLConnection(URL var1, String var2, int var3) throws IOException {
      this(var1, var2, var3, true);
   }

   public HttpURLConnection(URL var1, String var2, int var3, boolean var4) throws IOException {
      super(var1, var2, var3);
      this.proxy = var2;
      this.proxyPort = var3;
      this.resolveProxy = var4;
   }

   protected boolean fromClassLoader() {
      new Exception();
      ByteArrayOutputStream var2 = new ByteArrayOutputStream();
      new PrintStream(var2);
      String var4 = var2.toString();
      StringTokenizer var5 = new StringTokenizer(var4);
      Object var6 = null;

      while (var5.hasMoreTokens()) {
         var6 = var5.nextToken();
         if (var6.startsWith("sun.applet.AppletClassLoader")
            || var6.startsWith("sun.applet.AppletResourceLoader")
            || var6.startsWith("sun.plugin.security.PluginClassLoader")) {
            return true;
         }
      }

      return false;
   }

   void privBlock() throws Exception {
      try {
         if ("http".equals(this.url.getProtocol()) && !this.failedOnce) {
            this.http = HttpClient.New(this.url, this.proxy, this.proxyPort, this.resolveProxy);
         } else {
            this.http = this.getProxiedClient(this.url, this.proxy, this.proxyPort);
         }

         this.ps = (PrintStream)this.http.getOutputStream();
      } catch (IOException var2) {
         throw var2;
      }
   }

   public synchronized void connect() throws IOException {
      if (!this.connected) {
         this.checkPermission();
         this.connectWithCache();
         if (this.cacheStream == null) {
            try {
               this.connectSetup();
               AccessController.doPrivileged(new HttpURLConnection.PrivilegedBlockAction(this));
            } catch (PrivilegedActionException var3) {
               IOException var2 = (IOException)var3.getException();
               throw var2;
            }
         }

         this.connected = true;
      }
   }

   public synchronized void disconnect() {
      super.disconnect();
      if (this.cacheStream != null) {
         this.cacheStream = null;
      }

      if (this.cachedHeaders != null) {
         this.cachedHeaders.clear();
      }
   }

   public void checkPermission() throws IOException {
      if (!this.securityCheck) {
         SecurityManager var1 = System.getSecurityManager();
         if (var1 != null) {
            var1.checkConnect(this.url.getHost(), this.url.getPort());
         }

         this.securityCheck = true;
      }
   }

   public void connectWithCache() throws IOException {
      if (!this.cacheConnect) {
         if (this.getUseCaches() && this.getRequestMethod().equalsIgnoreCase("GET")) {
            try {
               CachedFile var1 = FileCache.get(this.url);
               if (var1 != null) {
                  InputStream var2 = null;

                  try {
                     var2 = AccessController.doPrivileged(new HttpURLConnection$1(this, var1));
                  } catch (PrivilegedActionException var4) {
                  }

                  if (var2 != null) {
                     this.responseCode = 200;
                     this.cachedHeaders = var1.getHeaderFields();
                     this.cacheStream = new ProgressInputStream(var2, this);
                  }
               }
            } catch (IOException var5) {
               Trace.netPrintException(var5);
            }
         }

         this.cacheConnect = true;
      }
   }

   public String getHeaderField(String var1) {
      String var2 = null;

      try {
         this.getInputStream();
      } catch (IOException var4) {
      }

      if (this.cachedHeaders != null) {
         var2 = (String)this.cachedHeaders.get(var1.toLowerCase());
      } else {
         var2 = super.getHeaderField(var1);
      }

      return var2;
   }

   public void connectSetup() throws IOException {
      if (!this.realConnect) {
         if (this.proxy == null && this.resolveProxy) {
            ProxyInfo var1 = PluginProxyManager.getProxyInfo(this.url);
            if (var1 != null) {
               this.proxy = var1.getProxy();
               this.proxyPort = var1.getPort();
            }
         }

         if (this.proxy == null) {
            Object[] var2 = new Object[]{this.url};
            Trace.netPrintln(mf1.format(var2), 2);
         } else {
            Object[] var3 = new Object[]{this.url, this.proxy + (this.proxyPort != -1 ? ":" + this.proxyPort : "")};
            Trace.netPrintln(mf2.format(var3), 2);
         }

         if (this.getRequestProperty("cookie") == null) {
            String var4 = PluginCookieManager.getCookieInfo(this.url);
            if (var4 != null) {
               this.addRequestProperty("cookie", var4);
            }
         }

         this.realConnect = true;
      }
   }

   public synchronized void checkCookieHeader() {
      if (!this.checkSetCookie) {
         this.checkSetCookie = true;
         Map var1 = this.getHeaderFields();

         for (String var3 : var1.keySet()) {
            if (var3 != null && var3.equalsIgnoreCase("Set-Cookie")) {
               for (String var6 : (List)var1.get(var3)) {
                  if (var6 != null) {
                     PluginCookieManager.setCookieInfo(this.url, var6);
                  }
               }
            }
         }
      }
   }

   public synchronized InputStream getInputStream() throws IOException {
      this.connect();
      if (this.cacheStream != null) {
         return this.cacheStream;
      } else {
         this.checkCookieHeader();
         InputStream var1 = super.getInputStream();
         if (var1 != null) {
            this.cacheStream = new ProgressInputStream(var1, this);
         }

         return this.cacheStream;
      }
   }

   protected sun.net.www.http.HttpClient getNewClient(URL var1) throws IOException {
      this.failedOnce = true;
      return this.getProxiedClient(var1, this.proxy, this.proxyPort);
   }

   protected sun.net.www.http.HttpClient getProxiedClient(URL var1, String var2, int var3) throws IOException {
      return new HttpClient(var1, var2, var3, this.resolveProxy);
   }

   public static String getMessage(String var0) {
      return ResourceHandler.getMessage(var0);
   }

   class PrivilegedBlockAction implements PrivilegedExceptionAction {
      HttpURLConnection conn;

      PrivilegedBlockAction(HttpURLConnection var2) {
         this.conn = var2;
      }

      public Object run() throws Exception {
         this.conn.privBlock();
         return null;
      }
   }
}
