package sun.plugin.net.protocol.socks;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.InetAddress;
import java.net.Socket;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.security.AccessController;
import sun.security.action.GetPropertyAction;

public class SocksSocket extends Socket {
   private Socket socket = null;
   private static final int SOCKS_PROTO_VERS = 4;
   private static final int SOCKS_REPLY_VERS = 4;
   private static final int COMMAND_CONNECT = 1;
   private static final int COMMAND_BIND = 2;
   private static final int REQUEST_GRANTED = 90;
   private static final int REQUEST_REJECTED = 91;
   private static final int REQUEST_REJECTED_NO_IDENTD = 92;
   private static final int REQUEST_REJECTED_DIFF_IDENTS = 93;
   public static final int socksDefaultPort = 1080;
   InetAddress address = null;
   int port = -1;

   public SocksSocket(String var1, int var2, String var3, int var4) throws UnknownHostException, IOException {
      this(InetAddress.getByName(var1), var2, InetAddress.getByName(var3), var4);
   }

   public SocksSocket(InetAddress var1, int var2, InetAddress var3, int var4) throws IOException {
      this.connect(var1, var2, var3, var4);
   }

   private void connect(InetAddress var1, int var2, InetAddress var3, int var4) throws IOException {
      if (var4 == -1) {
         var4 = 1080;
      }

      this.address = var1;
      this.port = var2;
      if (var3 != null) {
         this.socket = new Socket(var3, var4);
         this.sendSOCKSCommandPacket(1, var1, var2);
         int var5 = this.getSOCKSReply();
         switch (var5) {
            case 90:
               return;
            case 91:
            case 92:
               throw new SocketException("SOCKS server cannot conect to identd");
            case 93:
               throw new SocketException("User name does not match identd name");
         }
      } else {
         this.socket = new Socket(var1, var2);
      }
   }

   private int getSOCKSReply() throws IOException {
      InputStream var1 = this.getInputStream();
      byte[] var2 = new byte[8];
      int var3 = 0;
      int var4 = var2.length;

      for (int var5 = 0; var3 < var4 && var5 < 3; var5++) {
         int var6 = var1.read(var2, var3, var4 - var3);
         if (var6 < 0) {
            throw new SocketException("Malformed reply from SOCKS server");
         }

         var3 += var6;
      }

      if (var3 != var4) {
         throw new SocketException("Reply from SOCKS server has bad length: " + var3);
      } else if (var2[0] != 0) {
         throw new SocketException("Reply from SOCKS server has bad version " + var2[0]);
      } else {
         return var2[1];
      }
   }

   private void sendSOCKSCommandPacket(int var1, InetAddress var2, int var3) throws IOException {
      byte[] var4 = this.makeCommandPacket(var1, var2, var3);
      OutputStream var5 = this.getOutputStream();
      var5.write(var4);
   }

   private byte[] makeCommandPacket(int var1, InetAddress var2, int var3) {
      ByteArrayOutputStream var4 = new ByteArrayOutputStream(9);
      var4.write(4);
      var4.write(var1);
      var4.write(var3 >> 8 & 0xFF);
      var4.write(var3 >> 0 & 0xFF);
      byte[] var5 = var2.getAddress();
      var4.write(var5, 0, var5.length);
      String var6 = AccessController.doPrivileged(new GetPropertyAction("user.name"));
      byte[] var7 = new byte[var6.length()];
      var7 = var6.getBytes();
      var4.write(var7, 0, var7.length);
      var4.write(0);
      return var4.toByteArray();
   }

   public InetAddress getInetAddress() {
      return this.address;
   }

   public InetAddress getLocalAddress() {
      return this.socket.getLocalAddress();
   }

   public int getPort() {
      return this.port;
   }

   public int getLocalPort() {
      return this.socket.getLocalPort();
   }

   public InputStream getInputStream() throws IOException {
      return this.socket.getInputStream();
   }

   public OutputStream getOutputStream() throws IOException {
      return this.socket.getOutputStream();
   }

   public void setTcpNoDelay(boolean var1) throws SocketException {
      this.socket.setTcpNoDelay(var1);
   }

   public boolean getTcpNoDelay() throws SocketException {
      return this.socket.getTcpNoDelay();
   }

   public void setSoLinger(boolean var1, int var2) throws SocketException {
      this.socket.setSoLinger(var1, var2);
   }

   public int getSoLinger() throws SocketException {
      return this.socket.getSoLinger();
   }

   public synchronized void setSoTimeout(int var1) throws SocketException {
      this.socket.setSoTimeout(var1);
   }

   public synchronized int getSoTimeout() throws SocketException {
      return this.socket.getSoTimeout();
   }

   public synchronized void close() throws IOException {
      this.socket.close();
   }

   public String toString() {
      return "SocksSocket[addr=" + this.getInetAddress() + ",port=" + this.getPort() + ",localport=" + this.getLocalPort() + "]";
   }
}
