package sun.plugin.net.proxy;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.Trace;

public class NSPreferences {
   private static String parseValue(String var0) {
      int var1 = var0.indexOf(",");
      if (var1 != -1) {
         int var2 = var0.lastIndexOf(")");
         if (var2 != -1 && var1 + 1 < var2) {
            return var0.substring(var1 + 1, var2).trim();
         }
      }

      return null;
   }

   private static String parseString(String var0) {
      String var1 = parseValue(var0);
      return var1 != null && var1.length() > 1 && var1.startsWith("\"") && var1.endsWith("\"") ? var1.substring(1, var1.length() - 1) : null;
   }

   private static int parseInt(String var0) {
      String var1 = parseValue(var0);
      if (var1 != null) {
         try {
            return Integer.parseInt(var1);
         } catch (NumberFormatException var3) {
         }
      }

      return -1;
   }

   private static List parseList(String var0) {
      StringTokenizer var1 = new StringTokenizer(parseString(var0), ", ");
      ArrayList var2 = new ArrayList();

      while (var1.hasMoreTokens()) {
         var2.add("*" + var1.nextToken());
      }

      return var2;
   }

   private static boolean isKeyword(String var0, String var1) {
      int var2 = var0.indexOf("(");
      return var2 != -1 && var0.substring(var2 + 1, var0.length()).startsWith("\"" + var1 + "\"");
   }

   public static void parseFile(File var0, BrowserProxyInfo var1) {
      BufferedReader var2 = null;

      try {
         var2 = new BufferedReader(new InputStreamReader(new FileInputStream(var0), "ISO-8859-1"));

         String var3;
         while ((var3 = var2.readLine()) != null) {
            if (var3.startsWith("user_pref")) {
               if (isKeyword(var3, "network.proxy.type")) {
                  Trace.netPrintln(ResourceHandler.getMessage("net.proxy.browser.proxyEnable") + parseInt(var3));
                  var1.setType(parseInt(var3));
               } else if (isKeyword(var3, "network.proxy.http")) {
                  String var4 = parseString(var3);

                  try {
                     URL var5 = new URL(var4);
                     var4 = var5.getHost();
                  } catch (MalformedURLException var11) {
                  }

                  Trace.netPrintln("    network.proxy.http=" + var4);
                  var1.setHttpHost(var4);
               } else if (isKeyword(var3, "network.proxy.http_port")) {
                  int var13 = parseInt(var3);
                  Trace.netPrintln("    network.proxy.http_port=" + var13);
                  var1.setHttpPort(var13);
               } else if (isKeyword(var3, "network.proxy.ssl")) {
                  String var14 = parseString(var3);

                  try {
                     URL var23 = new URL(var14);
                     var14 = var23.getHost();
                  } catch (MalformedURLException var10) {
                  }

                  Trace.netPrintln("    network.proxy.ssl=" + var14);
                  var1.setHttpsHost(var14);
               } else if (isKeyword(var3, "network.proxy.ssl_port")) {
                  int var15 = parseInt(var3);
                  Trace.netPrintln("    network.proxy.ssl_port=" + var15);
                  var1.setHttpsPort(var15);
               } else if (isKeyword(var3, "network.proxy.ftp")) {
                  String var16 = parseString(var3);

                  try {
                     URL var24 = new URL(var16);
                     var16 = var24.getHost();
                  } catch (MalformedURLException var9) {
                  }

                  Trace.netPrintln("    network.proxy.ftp=" + var16);
                  var1.setFtpHost(var16);
               } else if (isKeyword(var3, "network.proxy.ftp_port")) {
                  int var17 = parseInt(var3);
                  Trace.netPrintln("    network.proxy.ftp_port=" + var17);
                  var1.setFtpPort(var17);
               } else if (isKeyword(var3, "network.proxy.gopher")) {
                  String var18 = parseString(var3);

                  try {
                     URL var25 = new URL(var18);
                     var18 = var25.getHost();
                  } catch (MalformedURLException var8) {
                  }

                  Trace.netPrintln("    network.proxy.gopher=" + var18);
                  var1.setGopherHost(var18);
               } else if (isKeyword(var3, "network.proxy.gopher_port")) {
                  int var19 = parseInt(var3);
                  Trace.netPrintln("    network.proxy.gopher_port=" + var19);
                  var1.setGopherPort(var19);
               } else if (isKeyword(var3, "network.proxy.socks")) {
                  String var20 = parseString(var3);

                  try {
                     URL var26 = new URL(var20);
                     var20 = var26.getHost();
                  } catch (MalformedURLException var7) {
                  }

                  Trace.netPrintln("    network.proxy.socks=" + var20);
                  var1.setSocksHost(var20);
               } else if (isKeyword(var3, "network.proxy.socks_port")) {
                  int var21 = parseInt(var3);
                  Trace.netPrintln("    network.proxy.socks_port=" + var21);
                  var1.setSocksPort(var21);
               } else if (isKeyword(var3, "network.proxy.no_proxies_on")) {
                  Trace.netPrintln(ResourceHandler.getMessage("net.proxy.browser.proxyOverride") + parseString(var3));
                  var1.setOverrides(parseList(var3));
               } else if (isKeyword(var3, "network.proxy.autoconfig_url")) {
                  String var22 = parseString(var3);
                  Trace.netPrintln(ResourceHandler.getMessage("net.proxy.browser.autoConfigURL") + var22);
                  var1.setAutoConfigURL(var22);
               }
            }
         }

         var2.close();
      } catch (IOException var12) {
         if (var2 != null) {
            try {
               var2.close();
            } catch (IOException var6) {
            }
         }
      }
   }
}
