package sun.plugin.net.proxy;

import java.net.URL;
import java.rmi.server.RMISocketFactory;
import java.security.AccessController;
import java.util.HashMap;
import java.util.Properties;
import sun.plugin.net.protocol.rmi.RMIPluginSocketFactory;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.services.BrowserService;
import sun.plugin.services.ServiceProvider;
import sun.plugin.services.ServiceUnavailableException;
import sun.plugin.usability.DialogFactory;
import sun.plugin.usability.Trace;

public class PluginProxyManager {
   private static HashMap proxyCache = new HashMap();
   private static ProxyHandler handler = null;

   public static synchronized ProxyInfo getProxyInfo(URL var0) {
      StringBuffer var1 = new StringBuffer();
      var1.append(var0.getProtocol());
      var1.append(var0.getHost());
      var1.append(var0.getPort());
      String var2 = var1.toString();
      ProxyInfo var3 = null;
      if (handler.isProxyCacheSupported()) {
         var3 = (ProxyInfo)proxyCache.get(var2);
      }

      if (var3 == null) {
         try {
            var3 = handler.getProxyInfo(var0);
            if (var3 == null) {
               var3 = new ProxyInfo(null);
            }

            proxyCache.put(var2.toString(), var3);
         } catch (ServiceUnavailableException var5) {
            Trace.messageNetPrintln("net.proxy.service.not_available", new Object[]{var0});
            var3 = new ProxyInfo(null);
         }
      }

      return var3;
   }

   public static synchronized void reset() {
      try {
         proxyCache.clear();
         UserDefinedProxyConfig var0 = new UserDefinedProxyConfig();
         BrowserProxyInfo var1 = var0.getBrowserProxyInfo();
         if (var1.getType() == 3) {
            BrowserService var2 = ServiceProvider.getService();
            BrowserProxyConfig var3 = var2.getProxyConfig();
            var1 = var3.getBrowserProxyInfo();
         }

         switch (var1.getType()) {
            case 0:
               try {
                  handler = new DirectProxyHandler();
                  handler.init(var1);
                  break;
               } catch (ProxyConfigException var12) {
                  if ($assertionsDisabled) {
                     break;
                  }

                  throw new AssertionError();
               }
            case 1:
               try {
                  handler = new ManualProxyHandler();
                  handler.init(var1);
               } catch (ProxyConfigException var11) {
                  Trace.netPrintln(ResourceHandler.getMessage("net.proxy.loading.manual.error"));

                  try {
                     var1.setType(0);
                     handler = new DirectProxyHandler();
                     handler.init(var1);
                  } catch (ProxyConfigException var8) {
                     if ($assertionsDisabled) {
                        break;
                     }

                     throw new AssertionError();
                  }
               }
               break;
            case 2:
               try {
                  handler = new AutoProxyHandler();
                  handler.init(var1);
               } catch (ProxyConfigException var10) {
                  Trace.netPrintln(ResourceHandler.getMessage("net.proxy.loading.auto.error"));

                  try {
                     var1.setType(1);
                     handler = new ManualProxyHandler();
                     handler.init(var1);
                  } catch (ProxyConfigException var7) {
                     Trace.netPrintln(ResourceHandler.getMessage("net.proxy.loading.manual.error"));

                     try {
                        var1.setType(0);
                        handler = new DirectProxyHandler();
                        handler.init(var1);
                     } catch (ProxyConfigException var6) {
                        if ($assertionsDisabled) {
                           break;
                        }

                        throw new AssertionError();
                     }
                  }
               }
               break;
            case 3:
               try {
                  handler = new BrowserProxyHandler();
                  handler.init(var1);
                  break;
               } catch (ProxyConfigException var9) {
                  if ($assertionsDisabled) {
                     break;
                  }

                  throw new AssertionError();
               }
            default:
               if (!$assertionsDisabled) {
                  throw new AssertionError();
               }
         }

         try {
            if (var1.getType() != 0) {
               RMISocketFactory.setSocketFactory(new RMIPluginSocketFactory());
            }
         } catch (Throwable var5) {
         }

         AccessController.doPrivileged(new PluginProxyManager$1(var1));
         System.err.println(var1.toString());
      } catch (Throwable var13) {
         var13.printStackTrace();
         DialogFactory.showExceptionDialog(var13);
      }
   }

   public static void setProperties(BrowserProxyInfo var0) {
      Properties var1 = System.getProperties();
      int var2 = var0.getType();
      StringBuffer var3 = new StringBuffer();
      if (var0.getHttpHost() != null) {
         var3.append("http=" + var0.getHttpHost());
         if (var0.getHttpPort() != -1) {
            var3.append(":" + var0.getHttpPort());
         }
      }

      if (var0.getHttpsHost() != null) {
         var3.append(",https=" + var0.getHttpsHost());
         if (var0.getHttpsPort() != -1) {
            var3.append(":" + var0.getHttpsPort());
         }
      }

      if (var0.getFtpHost() != null) {
         var3.append(",ftp=" + var0.getFtpHost());
         if (var0.getFtpPort() != -1) {
            var3.append(":" + var0.getFtpPort());
         }
      }

      if (var0.getGopherHost() != null) {
         var3.append(",gopher=" + var0.getGopherHost());
         if (var0.getGopherPort() != -1) {
            var3.append(":" + var0.getGopherPort());
         }
      }

      if (var0.getSocksHost() != null) {
         var3.append(",socks=" + var0.getSocksHost());
         if (var0.getSocksPort() != -1) {
            var3.append(":" + var0.getSocksPort());
         }
      }

      String var4 = var3.toString();
      String[] var5 = var0.getOverrides();
      String var6 = null;
      if (var5 != null) {
         var3 = new StringBuffer();
         boolean var7 = true;

         for (int var8 = 0; var8 < var5.length; var8++) {
            if (var8 != 0) {
               var3.append(",");
            }

            var3.append(var5[var8]);
         }

         var6 = var3.toString();
      }

      var1.remove("javaplugin.proxy.config.type");
      var1.remove("javaplugin.proxy.config.list");
      var1.remove("javaplugin.proxy.config.bypass");
      if (var2 == 0) {
         var1.put("javaplugin.proxy.config.type", "direct");
      } else if (var2 == 1) {
         var1.put("javaplugin.proxy.config.type", "manual");
         if (var4 != null) {
            var1.put("javaplugin.proxy.config.list", var4);
         }

         if (var6 != null) {
            var1.put("javaplugin.proxy.config.bypass", var6);
         }
      } else if (var2 == 2) {
         var1.put("javaplugin.proxy.config.type", "auto");
      } else if (var2 == 3) {
         var1.put("javaplugin.proxy.config.type", "browser");
      } else {
         var1.put("javaplugin.proxy.config.type", "unknown");
      }

      if (var2 == 1) {
         String var10 = var0.getSocksHost();
         int var11 = var0.getSocksPort();
         if (var10 != null) {
            var1.put("socksProxyHost", var10);
         }

         if (var11 != -1) {
            var1.put("socksProxyPort", new Integer(var11));
         }
      }

      System.setProperties(var1);
   }
}
