package sun.plugin.panel;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import sun.plugin.usability.Trace;

public class ActivatorPanel extends ActivatorSubPanel implements ActionListener, PropertyChangeListener {
   private DefaultPanel defaultPanel;
   private BasicPanel basicPanel;
   private AdvancedPanel advancedPanel;
   private BrowserPanel browserPanel;
   private ProxyPanel proxyPanel;
   private CertificatePanel certPanel;
   private CachePanel cachePanel;
   JButton cancel;
   JButton apply;
   private MessageHandler mh = new MessageHandler("panel");

   ActivatorPanel(ConfigurationInfo var1) {
      super(var1);
      PlatformDependentInterface var2 = this.getPlatformObject();
      if (var2 != null) {
         var2.onLoad(var1);
      }

      var1.addPropertyChangeListener(this);
      JTabbedPane var3 = new JTabbedPane();
      this.basicPanel = new BasicPanel(var1);
      var3.addTab(this.mh.getMessage("basic"), this.basicPanel);
      this.advancedPanel = new AdvancedPanel(var1);
      var3.addTab(this.mh.getMessage("advanced"), this.advancedPanel);
      if (var1.isShowBrowserPanel()) {
         this.browserPanel = new BrowserPanel(var1);
         var3.addTab(this.mh.getMessage("browser"), this.browserPanel);
      }

      this.proxyPanel = new ProxyPanel(var1);
      var3.addTab(this.mh.getMessage("proxies"), this.proxyPanel);
      this.cachePanel = new CachePanel(var1);
      var3.addTab(this.mh.getMessage("cache"), this.cachePanel);
      this.certPanel = new CertificatePanel(var1);
      var3.addTab(this.mh.getMessage("cert"), this.certPanel);
      this.defaultPanel = new DefaultPanel(var1);
      var3.addTab(this.mh.getMessage("about"), this.defaultPanel);
      this.setLayout(new BorderLayout());
      this.add("Center", var3);
      JPanel var4 = new JPanel();
      this.apply = this.addButton(var4, this.mh.getMessage("apply"));
      this.apply.setMnemonic(65);
      this.cancel = this.addButton(var4, this.mh.getMessage("cancel"));
      this.cancel.setMnemonic(82);
      this.apply.setEnabled(false);
      this.add("South", var4);
   }

   public void propertyChange(PropertyChangeEvent var1) {
      if (this.apply != null) {
         this.apply.setEnabled(true);
      }
   }

   private PlatformDependentInterface getPlatformObject() {
      String var1 = System.getProperty("os.name");

      try {
         String var2 = var1;
         if (var1.indexOf(32) != -1) {
            var2 = var1.substring(0, var1.indexOf(32));
         }

         String var3 = "sun.plugin.panel." + var2 + "Platform";
         Class var4 = Class.forName(var3);
         if (var4 != null) {
            Object var5 = var4.newInstance();
            if (var5 instanceof PlatformDependentInterface) {
               return (PlatformDependentInterface)var5;
            }
         }
      } catch (Exception var7) {
         Trace.printException(var7);
      }

      return null;
   }

   public void actionPerformed(ActionEvent var1) {
      if (var1.getSource() == this.cancel) {
         try {
            this.model.reset();
            PlatformDependentInterface var2 = this.getPlatformObject();
            if (var2 != null) {
               var2.onLoad(this.model);
            }

            this.basicPanel.reset();
            this.advancedPanel.reset();
            if (this.browserPanel != null) {
               this.browserPanel.reset();
            }

            this.proxyPanel.reset();
            this.certPanel.reset();
            this.cachePanel.reset();
            this.apply.setEnabled(false);
         } catch (Exception var4) {
            Trace.printException(var4);
         }
      }

      if (var1.getSource() == this.apply) {
         try {
            this.model.applyChanges();
            this.apply.setEnabled(false);
            PlatformDependentInterface var5 = this.getPlatformObject();
            if (var5 != null) {
               var5.onSave(this.model);
            }
         } catch (Exception var3) {
            Trace.printException(var3, this.mh.getMessage("apply_failed") + ": " + var3.getMessage(), this.mh.getMessage("apply_failed_title"));
         }
      }
   }

   public ConfigurationInfo getModel() {
      return this.model;
   }

   private JButton addButton(JPanel var1, String var2) {
      JButton var3 = new JButton(var2);
      var3.addActionListener(this);
      var1.add(var3);
      return var3;
   }

   public void setBasicPanelText() {
      this.advancedPanel.setJavaParmsText();
   }

   public void setCertificatePanelText() {
      this.certPanel.reset();
   }

   public void setAdvancedPanel(int var1) {
      this.advancedPanel.setTextSize(var1);
   }
}
