package sun.plugin.panel;

import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.text.MessageFormat;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.border.Border;
import sun.plugin.usability.DialogFactory;

public class AdvancedPanel extends ActivatorSubPanel implements ItemListener, KeyListener {
   private MessageHandler mh = new MessageHandler("advanced");
   private JTextField javaParms;
   private JTextField jdkPath;
   private JComboBox jdkInstalled;
   private final String otherJDK = this.mh.getMessage("other_jdk");
   private final String defaultJRE = this.mh.getMessage("default_jdk");
   private JLabel pathLabel;
   private int jreNb;
   private int jdkNb;

   AdvancedPanel(ConfigurationInfo var1) {
      super(var1);
      this.setLayout(new BoxLayout(this, 1));
      JPanel var2 = new JPanel();
      Border var3 = BorderFactory.createEtchedBorder();
      var2.setBorder(
         BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4), BorderFactory.createTitledBorder(var3, this.mh.getMessage("jre_name")))
      );
      JPanel var4 = new JPanel();
      var4.setLayout(new BoxLayout(var4, 1));
      var2.setLayout(new BoxLayout(var2, 0));
      var4.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
      var2.add(var4);
      this.jdkInstalled = new JComboBox();
      this.jdkInstalled.setMaximumRowCount(3);
      var4.add(Box.createGlue());
      if (this.setInstalledJavaList()) {
         this.jdkInstalled.addItemListener(this);
         var4.add(this.jdkInstalled);
      }

      var4.add(Box.createGlue());
      this.add(var2);
      this.add(Box.createGlue());
      JPanel var5 = new JPanel();
      var5.setLayout(new GridLayout(3, 0));
      var5.setBorder(BorderFactory.createEmptyBorder(15, 8, 4, 4));
      var5.add(Box.createGlue());
      JPanel var6 = new JPanel();
      var6.setLayout(new BoxLayout(var6, 0));
      this.pathLabel = new JLabel(this.mh.getMessage("path"));
      var6.add(this.pathLabel);
      this.jdkPath = new JTextField();
      this.jdkPath.setEnabled(false);
      var6.add(this.jdkPath);
      var5.add(var6);
      var5.add(Box.createGlue());
      var2.setLayout(new BoxLayout(var2, 1));
      var2.add(var5);
      this.add(Box.createGlue());
      JPanel var7 = new JPanel();
      var7.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
      GridLayout var8 = new GridLayout(2, 1);
      var7.setLayout(var8);
      var7.add(new JLabel(this.mh.getMessage("java_parms"), 2));
      this.javaParms = new JTextField();
      var7.add(this.javaParms);
      this.javaParms.addKeyListener(this);
      this.add(var7);
      this.add(Box.createGlue());
   }

   public void setJavaParmsText() {
      this.javaParms.setText(this.model.getJavaParms());
      this.reset();
   }

   private boolean setInstalledJavaList() {
      if (this.jdkInstalled.getItemCount() > 0) {
         this.jdkInstalled.removeAllItems();
      }

      this.jdkInstalled.addItem(this.defaultJRE);
      String[][] var1 = this.model.getInstalledJREList();
      if (var1 == null) {
         this.jreNb = 0;
      } else {
         this.jreNb = var1.length;
      }

      for (int var2 = 0; var2 < this.jreNb; var2++) {
         String var3 = var1[var2][0];
         String var4 = var1[var2][1];
         Object[] var5 = new Object[]{var3, var4};
         this.jdkInstalled.addItem(MessageFormat.format(this.mh.getMessage("jre_format"), var5));
      }

      String[][] var8 = this.model.getInstalledJDKList();
      if (var8 == null) {
         this.jdkNb = 0;
      } else {
         this.jdkNb = var8.length;
      }

      for (int var9 = 0; var9 < this.jdkNb; var9++) {
         String var10 = var8[var9][0];
         String var6 = var8[var9][1];
         Object[] var7 = new Object[]{var10, var6};
         this.jdkInstalled.addItem(MessageFormat.format(this.mh.getMessage("jdk_format"), var7));
      }

      this.jdkInstalled.addItem(this.otherJDK);
      return true;
   }

   public void itemStateChanged(ItemEvent var1) {
      if (var1.getSource() == this.jdkInstalled && var1.getStateChange() == 1) {
         int var2 = this.jdkInstalled.getSelectedIndex();
         if (var2 == 0) {
            this.model.setJavaRuntimeType("Default");
            this.model.setJavaRuntimeVersion(null);
            this.jdkPath.setText("");
         }

         if (var2 > 0 && var2 <= this.jreNb) {
            this.model.setJavaRuntimeType("JRE");
            String[][] var3 = this.model.getInstalledJREList();
            this.model.setJavaRuntimeVersion(var3[var2 - 1][0]);
            this.jdkPath.setText("");
         }

         if (var2 > this.jreNb && var2 <= this.jreNb + this.jdkNb) {
            this.model.setJavaRuntimeType("JDK");
            String[][] var8 = this.model.getInstalledJDKList();
            this.model.setJavaRuntimeVersion(var8[var2 - this.jreNb - 1][0]);
            this.jdkPath.setText("");
         }

         if (var2 == this.jdkInstalled.getItemCount() - 1 && (this.jdkPath.getText() == null || this.jdkPath.getText().length() < 1)) {
            Object[] var9 = new Object[]{"OK", "Cancel"};
            int var4 = DialogFactory.showOptionDialog(this.mh.getMessage("jre_selection_warning.info"), "Warning", var9, var9[0]);
            if (var4 == 0) {
               JFileChooser var5 = new JFileChooser();
               var5.setFileSelectionMode(2);
               boolean var6 = false;

               while (!var6) {
                  int var7 = var5.showOpenDialog(this);
                  if (var7 == 0) {
                     if (var5.getSelectedFile().isDirectory()) {
                        this.jdkPath.setText(var5.getSelectedFile().getAbsolutePath());
                        this.model.setJavaRuntimeType(this.jdkPath.getText());
                        this.jdkInstalled.setSelectedIndex(this.jdkInstalled.getItemCount() - 1);
                        var6 = true;
                     } else {
                        DialogFactory.showMessageDialog(this.mh.getMessage("file_message"));
                        var6 = false;
                     }
                  } else {
                     this.model.setJavaRuntimeType("Default");
                     this.jdkInstalled.setSelectedIndex(0);
                     var6 = true;
                  }
               }
            } else {
               this.model.setJavaRuntimeType("Default");
               this.jdkInstalled.setSelectedIndex(0);
            }
         }

         this.reset();
      }
   }

   public void keyTyped(KeyEvent var1) {
      if (var1.getSource() == this.javaParms) {
         this.model.setJavaParms(this.javaParms.getText());
      } else if (var1.getSource() == this.jdkPath) {
         this.model.setJavaRuntimeType(this.jdkPath.getText());
      }
   }

   public void keyReleased(KeyEvent var1) {
      this.keyTyped(var1);
   }

   public void keyPressed(KeyEvent var1) {
   }

   public void reset() {
      this.javaParms.setText(this.model.getJavaParms());
      boolean var1 = true;
      String var2 = this.model.getJavaRuntimeType();
      this.pathLabel.setEnabled(false);
      this.jdkPath.setEnabled(false);

      try {
         if (var2.equalsIgnoreCase("Default")) {
            this.jdkInstalled.setSelectedIndex(0);
         } else if (var2.equalsIgnoreCase("JDK")) {
            String[][] var3 = this.model.getInstalledJDKList();
            String var4 = this.model.getJavaRuntimeVersion();
            int var5 = 0;

            while (!var3[var5][0].equalsIgnoreCase(var4)) {
               var5++;
            }

            this.jdkInstalled.setSelectedIndex(this.jreNb + var5 + 1);
         } else if (var2.equalsIgnoreCase("JRE")) {
            String[][] var7 = this.model.getInstalledJREList();
            String var8 = this.model.getJavaRuntimeVersion();
            int var9 = 0;

            while (!var7[var9][0].equalsIgnoreCase(var8)) {
               var9++;
            }

            this.jdkInstalled.setSelectedIndex(var9 + 1);
         } else {
            this.jdkPath.setText(var2);
            this.pathLabel.setEnabled(true);
            this.jdkInstalled.setSelectedIndex(this.jdkInstalled.getItemCount() - 1);
         }
      } catch (Exception var6) {
         this.jdkInstalled.setSelectedIndex(0);
         this.model.firePropertyChange();
      }
   }

   public void setTextSize(int var1) {
      this.jdkPath.setMaximumSize(new Dimension(var1, 25));
      this.jdkPath.revalidate();
   }
}
