package sun.plugin.panel;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.Principal;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.Collection;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Properties;
import java.util.Vector;
import sun.plugin.security.HttpsRootCACertStore;
import sun.plugin.security.PluginCertificateStore;
import sun.plugin.security.PluginHttpsCertStore;
import sun.plugin.security.RootCACertificateStore;
import sun.plugin.usability.DialogFactory;
import sun.plugin.usability.Trace;
import sun.plugin.usability.UserProfile;

public class ConfigurationInfo {
   private static File theUserPropertiesFile;
   private Properties props;
   private boolean debugMode = false;
   private boolean javapluginEnabled = true;
   private String showConsole = "hide";
   private boolean showException = false;
   private String debugPort = "2502";
   private String[][] installedJREs;
   private String[][] installedJDKs;
   private boolean useDefaultProxy = true;
   private String proxySettings;
   private String proxyByPass;
   private String autoProxyURL;
   private String javaParms;
   private String javaVersion;
   private String javaRuntimePath = null;
   private String javaRuntimeType = "Default";
   private boolean cacheEnabled;
   private String cacheLocation = null;
   private String cacheSize;
   private int JARCacheCompression;
   private File defaultCacheLocation;
   private boolean iexplorerDefault = false;
   private boolean netscape6Default = false;
   private boolean showBrowserPanel = false;
   private HashMap activeCertsMap = new HashMap();
   private HashMap inactiveCertsMap = new HashMap();
   private HashMap inactiveImpCertsMap = new HashMap();
   private HashMap activeHttpsCertsMap = new HashMap();
   private HashMap inactiveHttpsCertsMap = new HashMap();
   private HashMap inactiveImpHttpsCertsMap = new HashMap();
   private HashMap activeRootCACertsMap = new HashMap();
   private HashMap activeHttpsRootCACertsMap = new HashMap();
   private PropertyChangeSupport pcs = new PropertyChangeSupport(this);
   private MessageHandler mh = new MessageHandler("config");

   public ConfigurationInfo() {
      if (theUserPropertiesFile == null) {
         theUserPropertiesFile = new File(UserProfile.getPropertyFile());
         new File(theUserPropertiesFile.getParent()).mkdirs();
      }

      this.reset();
   }

   public void setJavaEnabled(boolean var1) {
      this.javapluginEnabled = var1;
      this.firePropertyChange();
   }

   public boolean isJavaEnabled() {
      return this.javapluginEnabled;
   }

   public void setConsoleEnabled(String var1) {
      this.showConsole = var1;
      this.firePropertyChange();
   }

   public String isConsoleEnabled() {
      return this.showConsole;
   }

   public void setShowException(boolean var1) {
      this.showException = var1;
      this.firePropertyChange();
   }

   public boolean isShowExceptionEnabled() {
      return this.showException;
   }

   public void setDebugEnabled(boolean var1) {
      this.debugMode = var1;
      this.firePropertyChange();
   }

   public boolean isDebugEnabled() {
      return this.debugMode;
   }

   public void setDebugPort(String var1) {
      this.debugPort = var1;
      this.firePropertyChange();
   }

   public String getDebugPort() {
      return this.debugPort;
   }

   public void setInstalledJREList(Vector var1) {
      this.installedJREs = new String[var1.size() / 2][2];
      int var2 = 0;

      for (Enumeration var3 = var1.elements(); var3.hasMoreElements(); var2++) {
         this.installedJREs[var2][0] = (String)var3.nextElement();
         this.installedJREs[var2][1] = (String)var3.nextElement();
      }
   }

   public String[][] getInstalledJREList() {
      return this.installedJREs;
   }

   public void setInstalledJDKList(Vector var1) {
      this.installedJDKs = new String[var1.size() / 2][2];
      int var2 = 0;

      for (Enumeration var3 = var1.elements(); var3.hasMoreElements(); var2++) {
         this.installedJDKs[var2][0] = (String)var3.nextElement();
         this.installedJDKs[var2][1] = (String)var3.nextElement();
      }
   }

   public String[][] getInstalledJDKList() {
      return this.installedJDKs;
   }

   public void setJavaRuntimeVersion(String var1) {
      if (this.javaVersion != var1) {
         this.javaVersion = var1;
         this.firePropertyChange();
      }
   }

   public String getJavaRuntimeVersion() {
      return this.javaVersion;
   }

   public void setJavaRuntimeType(String var1) {
      if (var1 != null) {
         if (var1.equalsIgnoreCase("Default")) {
            this.javaRuntimeType = "Default";
            this.javaRuntimePath = null;
         } else if (var1.equalsIgnoreCase("JDK")) {
            this.javaRuntimeType = "JDK";
            this.javaRuntimePath = null;
         } else if (var1.equalsIgnoreCase("JRE")) {
            this.javaRuntimeType = "JRE";
            this.javaRuntimePath = null;
         } else {
            this.javaRuntimeType = "Other";
            this.javaRuntimePath = var1;
         }

         this.firePropertyChange();
      }
   }

   public String getJavaRuntimeType() {
      return this.javaRuntimeType != null && this.javaRuntimeType.equalsIgnoreCase("Other") ? this.javaRuntimePath : this.javaRuntimeType;
   }

   public boolean isIExplorerDefault() {
      return this.iexplorerDefault;
   }

   public void setIExplorerDefault(boolean var1) {
      this.iexplorerDefault = var1;
      this.firePropertyChange();
   }

   public boolean isNetscape6Default() {
      return this.netscape6Default;
   }

   public void setNetscape6Default(boolean var1) {
      this.netscape6Default = var1;
      this.firePropertyChange();
   }

   public boolean useDefaultProxy() {
      return this.useDefaultProxy;
   }

   public void setDefaultProxySettings(boolean var1) {
      this.useDefaultProxy = var1;
      this.firePropertyChange();
   }

   public void setProxySettingsString(String var1) {
      this.proxySettings = var1;
      this.firePropertyChange();
   }

   public String getProxyByPass() {
      return this.proxyByPass;
   }

   public void setProxyByPass(String var1) {
      this.proxyByPass = var1;
      this.firePropertyChange();
   }

   public String getAutoProxyURL() {
      return this.autoProxyURL;
   }

   public void setAutoProxyURL(String var1) {
      this.autoProxyURL = var1;
      this.firePropertyChange();
   }

   public String getProxySettingsString() {
      return this.proxySettings;
   }

   public void setJavaParms(String var1) {
      this.javaParms = var1;
      this.firePropertyChange();
   }

   public String getJavaParms() {
      return this.javaParms;
   }

   public Collection getCertificateAliases() {
      return this.activeCertsMap.keySet();
   }

   public Collection getHttpsCertificateAliases() {
      return this.activeHttpsCertsMap.keySet();
   }

   public Collection getRootCACertificateAliases() {
      return this.activeRootCACertsMap.keySet();
   }

   public Collection getHttpsRootCACertAliases() {
      return this.activeHttpsRootCACertsMap.keySet();
   }

   public Certificate getCertificate(String var1) {
      try {
         PluginCertificateStore var2 = new PluginCertificateStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public Certificate getHttpsCertificate(String var1) {
      try {
         PluginHttpsCertStore var2 = new PluginHttpsCertStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public Certificate getRootCACertificate(String var1) {
      try {
         RootCACertificateStore var2 = new RootCACertificateStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public Certificate getHttpsRootCACertificate(String var1) {
      try {
         HttpsRootCACertStore var2 = new HttpsRootCACertStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public void deactivateCertificate(String var1) {
      Object var2 = this.activeCertsMap.remove(var1);
      this.inactiveCertsMap.put(var1, var2);
      this.firePropertyChange();
   }

   public void deactivateImpCertificate(X509Certificate var1) {
      String var2 = this.extractAliasName(var1);
      this.activeCertsMap.put(var2, var1);
      this.inactiveImpCertsMap.put(var2, var1);
      this.firePropertyChange();
   }

   public X509Certificate getImpCertificate(String var1) {
      Object var2 = this.inactiveImpCertsMap.get(var1);
      return (X509Certificate)var2;
   }

   public void deactivateHttpsCertificate(String var1) {
      Object var2 = this.activeHttpsCertsMap.remove(var1);
      this.inactiveHttpsCertsMap.put(var1, var2);
      this.firePropertyChange();
   }

   public void deactivateImpHttpsCertificate(X509Certificate var1) {
      String var2 = this.extractAliasName(var1);
      this.activeHttpsCertsMap.put(var2, var1);
      this.inactiveImpHttpsCertsMap.put(var2, var1);
      this.firePropertyChange();
   }

   public X509Certificate getImpHttpsCertificate(String var1) {
      Object var2 = this.inactiveImpHttpsCertsMap.get(var1);
      return (X509Certificate)var2;
   }

   private String extractAliasName(X509Certificate var1) {
      String var2 = "Unknown subject";
      String var3 = "Unknown Issuer";
      int var4 = 0;
      int var5 = 0;

      try {
         Principal var6 = var1.getSubjectDN();
         Principal var7 = var1.getIssuerDN();
         String var8 = var6.getName();
         String var9 = var7.getName();
         var4 = var8.indexOf("CN=");
         if (var4 < 0) {
            var2 = "Unknown subject";
         } else {
            var4 += 3;
            if (var8.charAt(var4) == '"') {
               var5 = var8.indexOf(34, ++var4);
            } else {
               var5 = var8.indexOf(44, var4);
            }

            if (var5 < 0) {
               var2 = var8.substring(var4);
            } else {
               var2 = var8.substring(var4, var5);
            }
         }

         var4 = var9.indexOf("CN=");
         int var16 = 0;
         if (var4 < 0) {
            var2 = "Unknown issuer";
         } else {
            var4 += 3;
            if (var9.charAt(var4) == '"') {
               var16 = var9.indexOf(34, ++var4);
            } else {
               var16 = var9.indexOf(44, var4);
            }

            if (var16 < 0) {
               var3 = var9.substring(var4);
            } else {
               var3 = var9.substring(var4, var16);
            }
         }
      } catch (Exception var10) {
         Trace.printException(var10);
      }

      return var2 + "(" + var3 + ")";
   }

   public void applyChanges() throws IOException {
      this.props.put("javaplugin.console", this.showConsole);
      this.props.put("javaplugin.exception", this.showException ? "true" : "false");
      this.props.put("javaplugin.enabled", this.javapluginEnabled ? "true" : "false");
      if (this.debugMode) {
         this.props.put("javaplugin.debug.mode", "true");
         this.props.put("javaplugin.debug.port", this.debugPort);
      } else {
         this.props.put("javaplugin.debug.mode", "false");
      }

      if (this.useDefaultProxy) {
         this.props.put("javaplugin.proxy.usebrowsersettings", "true");
      } else {
         this.props.put("javaplugin.proxy.usebrowsersettings", "false");
      }

      if (this.proxySettings != null) {
         this.props.put("javaplugin.proxy.settings", this.proxySettings);
      } else {
         this.props.remove("javaplugin.proxy.settings");
      }

      if (this.proxyByPass != null) {
         this.props.put("javaplugin.proxy.bypass", this.proxyByPass);
      } else {
         this.props.remove("javaplugin.proxy.bypass");
      }

      try {
         if (this.autoProxyURL != null && !this.autoProxyURL.trim().equals("")) {
            new URL(this.autoProxyURL);
            this.props.put("javaplugin.proxy.auto.url", this.autoProxyURL);
         }
      } catch (MalformedURLException var16) {
         DialogFactory.showExceptionDialog(var16);
         this.props.remove("javaplugin.proxy.auto.url");
         this.autoProxyURL = null;
      }

      if (this.javaRuntimeType != null) {
         this.props.put("javaplugin.jre.type", this.javaRuntimeType);
      } else {
         this.javaRuntimeType = "Default";
         this.props.put("javaplugin.jre.type", "Default");
      }

      String var1 = null;
      if (this.javaVersion != null && this.javaVersion.length() > 0) {
         String[][] var2 = null;
         if (this.javaRuntimeType.equalsIgnoreCase("JRE")) {
            var2 = this.getInstalledJREList();
         }

         if (this.javaRuntimeType.equalsIgnoreCase("JDK")) {
            var2 = this.getInstalledJDKList();
         }

         if (var2 != null) {
            for (int var3 = 0; var3 < var2.length; var3++) {
               if (var2[var3][0].equalsIgnoreCase(this.javaVersion)) {
                  var1 = var2[var3][1];
               }
            }
         }
      }

      if (this.javaRuntimeType.equalsIgnoreCase("Other") && this.javaRuntimePath != null && !this.javaRuntimePath.trim().equals("")) {
         var1 = this.javaRuntimePath;
      }

      if (var1 != null) {
         this.props.put("javaplugin.jre.path", var1);
      } else {
         this.props.put("javaplugin.jre.type", "Default");
         this.props.put("javaplugin.jre.path", "Default");
      }

      if (this.javaVersion != null && this.javaVersion.length() > 0) {
         this.props.put("javaplugin.jre.version", this.javaVersion);
      } else {
         this.props.remove("javaplugin.jre.version");
      }

      if (this.javaParms != null && this.javaParms.length() > 0) {
         this.props.put("javaplugin.jre.params", this.javaParms);
      } else {
         this.props.remove("javaplugin.jre.params");
      }

      if (!this.cacheEnabled) {
         this.props.put("javaplugin.cache.disabled", "true");
      } else {
         this.props.remove("javaplugin.cache.disabled");
      }

      File var18 = new File(this.cacheLocation);
      if (var18.equals(this.defaultCacheLocation)) {
         this.props.remove("javaplugin.cache.directory");
      } else {
         this.props.put("javaplugin.cache.directory", this.cacheLocation);
      }

      if (!this.cacheSize.equals("50m")) {
         this.props.put("javaplugin.cache.size", this.cacheSize);
      } else {
         this.props.remove("javaplugin.cache.size");
      }

      if (this.JARCacheCompression != 0) {
         this.props.put("javaplugin.cache.compression", String.valueOf(this.JARCacheCompression));
      } else {
         this.props.remove("javaplugin.cache.compression");
      }

      FileOutputStream var19 = new FileOutputStream(theUserPropertiesFile);
      BufferedOutputStream var4 = new BufferedOutputStream(var19);
      PrintWriter var5 = new PrintWriter(var4);
      var5.println(this.mh.getMessage("property_file_header"));
      var5.flush();
      this.props.store(var4, "");
      var4.close();
      var19.close();

      try {
         PluginCertificateStore var6 = new PluginCertificateStore();
         PluginHttpsCertStore var7 = new PluginHttpsCertStore();
         var6.load();
         var7.load();
         Collection var8 = this.inactiveCertsMap.values();
         Iterator var9 = var8.iterator();

         while (var9.hasNext()) {
            var6.remove((Certificate)var9.next());
         }

         Collection var10 = this.inactiveImpCertsMap.values();
         Iterator var11 = var10.iterator();

         while (var11.hasNext()) {
            var6.add((Certificate)var11.next());
         }

         Collection var12 = this.inactiveHttpsCertsMap.values();
         Iterator var13 = var12.iterator();

         while (var13.hasNext()) {
            var7.remove((Certificate)var13.next());
         }

         Collection var14 = this.inactiveImpHttpsCertsMap.values();
         Iterator var15 = var14.iterator();

         while (var15.hasNext()) {
            var7.add((Certificate)var15.next());
         }

         var6.save();
         var7.save();
      } catch (Exception var17) {
         Trace.printException(var17);
      }

      this.inactiveCertsMap.clear();
      this.inactiveImpCertsMap.clear();
      this.inactiveHttpsCertsMap.clear();
      this.inactiveImpHttpsCertsMap.clear();
   }

   public void reset() {
      this.firePropertyChange();
      this.props = new Properties();

      try {
         FileInputStream var1 = new FileInputStream(theUserPropertiesFile);
         BufferedInputStream var2 = new BufferedInputStream(var1);
         this.props.load(var2);
         var2.close();
         var1.close();
      } catch (Exception var14) {
      }

      String var16 = this.props.getProperty("javaplugin.console");
      if (var16 != null) {
         this.showConsole = var16;
      } else {
         this.showConsole = "hide";
      }

      var16 = this.props.getProperty("javaplugin.exception");
      if (var16 != null && !var16.equals("false")) {
         this.showException = true;
      } else {
         this.showException = false;
      }

      var16 = this.props.getProperty("javaplugin.enabled");
      if (var16 != null && !var16.equals("true")) {
         this.javapluginEnabled = false;
      } else {
         this.javapluginEnabled = true;
      }

      var16 = this.props.getProperty("javaplugin.debug.mode");
      if (var16 != null && var16.equals("true")) {
         this.debugMode = true;
      } else {
         this.debugMode = false;
      }

      this.debugPort = this.props.getProperty("javaplugin.debug.port");
      if (this.debugPort == null) {
         this.debugPort = "2502";
      }

      var16 = this.props.getProperty("javaplugin.proxy.usebrowsersettings");
      if (var16 != null && !var16.equals("true")) {
         this.useDefaultProxy = false;
      } else {
         this.useDefaultProxy = true;
      }

      this.proxySettings = this.props.getProperty("javaplugin.proxy.settings");
      this.proxyByPass = this.props.getProperty("javaplugin.proxy.bypass");

      try {
         String var23 = this.props.getProperty("javaplugin.proxy.auto.url");
         if (var23 != null && !var23.trim().equals("")) {
            new URL(var23);
            this.autoProxyURL = var23;
         }
      } catch (MalformedURLException var13) {
         DialogFactory.showExceptionDialog(var13);
         this.autoProxyURL = null;
      }

      this.javaRuntimePath = this.props.getProperty("javaplugin.jre.path");
      this.javaRuntimeType = this.props.getProperty("javaplugin.jre.type");
      if (this.javaRuntimeType == null) {
         if (this.javaRuntimePath != null && !this.javaRuntimePath.trim().equals("")) {
            this.javaRuntimeType = "Other";
         } else {
            this.javaRuntimeType = "Default";
         }
      } else if (this.javaRuntimeType.equalsIgnoreCase("JRE")) {
         this.javaRuntimeType = "JRE";
      } else if (this.javaRuntimeType.equalsIgnoreCase("JDK")) {
         this.javaRuntimeType = "JDK";
      } else if (this.javaRuntimeType.equalsIgnoreCase("Other")) {
         if (this.javaRuntimePath != null && !this.javaRuntimePath.trim().equals("")) {
            this.javaRuntimeType = "Other";
         } else {
            this.javaRuntimeType = "Default";
         }
      } else {
         this.javaRuntimeType = "Default";
      }

      if (this.javaRuntimeType == null) {
         this.javaRuntimeType = "Default";
      }

      this.javaVersion = this.props.getProperty("javaplugin.jre.version");
      this.javaParms = this.props.getProperty("javaplugin.jre.params");
      var16 = this.props.getProperty("javaplugin.cache.disabled");
      if (var16 != null && var16.equalsIgnoreCase("true")) {
         this.cacheEnabled = false;
      } else {
         this.cacheEnabled = true;
      }

      this.defaultCacheLocation = new File(UserProfile.getCommonCacheDir());
      this.cacheLocation = this.props.getProperty("javaplugin.cache.directory");
      if (this.cacheLocation == null) {
         this.cacheLocation = this.defaultCacheLocation.getPath();
      }

      this.cacheSize = this.props.getProperty("javaplugin.cache.size", "50m");
      var16 = this.props.getProperty("javaplugin.cache.compression");
      if (var16 != null) {
         try {
            this.JARCacheCompression = Integer.valueOf(var16);
         } catch (NumberFormatException var12) {
            this.JARCacheCompression = 0;
         }
      } else {
         this.JARCacheCompression = 0;
      }

      this.activeCertsMap.clear();
      this.inactiveCertsMap.clear();
      this.inactiveImpCertsMap.clear();
      this.activeHttpsCertsMap.clear();
      this.inactiveHttpsCertsMap.clear();
      this.inactiveImpHttpsCertsMap.clear();
      this.activeRootCACertsMap.clear();
      this.activeHttpsRootCACertsMap.clear();

      try {
         PluginCertificateStore var24 = new PluginCertificateStore();
         PluginHttpsCertStore var3 = new PluginHttpsCertStore();
         RootCACertificateStore var4 = new RootCACertificateStore();
         HttpsRootCACertStore var5 = new HttpsRootCACertStore();
         var24.load();
         var3.load();
         var4.load();
         var5.load();
         Iterator var6 = var24.iterator();
         Iterator var7 = var3.iterator();
         Iterator var8 = var4.iterator();
         Iterator var9 = var5.iterator();

         while (var6.hasNext()) {
            X509Certificate var10 = (X509Certificate)var6.next();
            String var11 = this.extractAliasName(var10);
            this.activeCertsMap.put(var11, var10);
         }

         while (var7.hasNext()) {
            X509Certificate var25 = (X509Certificate)var7.next();
            String var28 = this.extractAliasName(var25);
            this.activeHttpsCertsMap.put(var28, var25);
         }

         while (var8.hasNext()) {
            X509Certificate var26 = (X509Certificate)var8.next();
            String var29 = this.extractAliasName(var26);
            this.activeRootCACertsMap.put(var29, var26);
         }

         while (var9.hasNext()) {
            X509Certificate var27 = (X509Certificate)var9.next();
            String var30 = this.extractAliasName(var27);
            this.activeHttpsRootCACertsMap.put(var30, var27);
         }
      } catch (Exception var15) {
         Trace.printException(var15);
      }
   }

   boolean getCacheEnabled() {
      return this.cacheEnabled;
   }

   void setCacheEnabled(boolean var1) {
      this.cacheEnabled = var1;
      this.firePropertyChange();
   }

   String getCacheLocation() {
      return this.cacheLocation;
   }

   void setCacheLocation(String var1) {
      this.cacheLocation = var1;
      this.firePropertyChange();
   }

   String getCacheSize() {
      return this.cacheSize;
   }

   void setCacheSize(String var1) {
      this.cacheSize = var1;
      this.firePropertyChange();
   }

   int getJARCacheCompression() {
      return this.JARCacheCompression;
   }

   void setJARCacheCompression(int var1) {
      this.JARCacheCompression = var1;
      this.firePropertyChange();
   }

   protected void firePropertyChange() {
      this.pcs.firePropertyChange(null, null, null);
   }

   public void addPropertyChangeListener(PropertyChangeListener var1) {
      this.pcs.addPropertyChangeListener(var1);
   }

   public void removePropertyChangeListener(PropertyChangeListener var1) {
      this.pcs.removePropertyChangeListener(var1);
   }

   public void setShowBrowserPanel(boolean var1) {
      this.showBrowserPanel = var1;
   }

   public boolean isShowBrowserPanel() {
      return this.showBrowserPanel;
   }
}
