package sun.plugin.security;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FilePermission;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.AccessController;
import java.security.AllPermission;
import java.security.CodeSource;
import java.security.PermissionCollection;
import java.security.Policy;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.PropertyPermission;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import sun.applet.AppletClassLoader;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.ProgressTracker;
import sun.plugin.usability.Trace;
import sun.security.action.GetPropertyAction;

public class PluginClassLoader extends AppletClassLoader {
   private static RuntimePermission usePolicyPermission;
   private URL base;
   private HashMap JARJARtoJAR = new HashMap();

   public PluginClassLoader(URL var1) {
      super(var1);
      this.base = var1;
   }

   public URL getBaseURL() {
      return this.base;
   }

   protected PermissionCollection getPermissions(CodeSource var1) {
      PermissionCollection var2 = super.getPermissions(var1);
      Object var3 = null;
      Policy var4 = AccessController.doPrivileged(new PluginClassLoader$1(this));
      var3 = var4.getPermissions(var1);
      var2.add(new RuntimePermission("accessClassInPackage.sun.audio"));
      var2.add(new PropertyPermission("browser", "read"));
      var2.add(new PropertyPermission("browser.version", "read"));
      var2.add(new PropertyPermission("browser.vendor", "read"));
      var2.add(new PropertyPermission("http.agent", "read"));
      var2.add(new PropertyPermission("javaplugin.version", "read"));
      var2.add(new PropertyPermission("javaplugin.proxy.config.type", "read"));
      var2.add(new PropertyPermission("javaplugin.proxy.config.list", "read"));
      var2.add(new PropertyPermission("javaplugin.proxy.config.bypass", "read"));
      if (usePolicyPermission == null) {
         usePolicyPermission = new RuntimePermission("usePolicy");
      }

      if (!var3.implies(usePolicyPermission) && var1.getCertificates() != null) {
         try {
            if (TrustDecider.isAllPermissionGranted(var1)) {
               var2.add(new AllPermission());
            }
         } catch (CertificateExpiredException var8) {
            Trace.securityPrintException(var8, ResourceHandler.getMessage("rsa.cert_expired"), ResourceHandler.getMessage("security_dialog.caption"));
         } catch (CertificateNotYetValidException var9) {
            Trace.securityPrintException(var9, ResourceHandler.getMessage("rsa.cert_notyieldvalid"), ResourceHandler.getMessage("security_dialog.caption"));
         } catch (Exception var10) {
            Trace.securityPrintException(var10, ResourceHandler.getMessage("rsa.general_error"), ResourceHandler.getMessage("security_dialog.caption"));
         }
      }

      String var5 = AccessController.doPrivileged(new GetPropertyAction("java.home"));
      String var6 = var5 + File.separator + "lib" + File.separator + "applet" + File.separator;
      var2.add(new FilePermission(var6 + "*", "read"));
      return var2;
   }

   public void addMyJar(URL var1) {
      this.addURL(var1);
   }

   protected Class findClass(String var1) throws ClassNotFoundException {
      Trace.println(ResourceHandler.getMessage("applet.progress.loadClass") + var1, 4);
      return super.findClass(var1);
   }

   public URL findResource(String var1) {
      if (var1 != null && var1.indexOf("META-INF/services/javax.sound") == -1) {
         Trace.println(ResourceHandler.getMessage("applet.progress.loadResource") + var1, 4);
      }

      return super.findResource(var1);
   }

   public Enumeration findResources(String var1) throws IOException {
      if (var1 != null && var1.indexOf("META-INF/services/javax.sound") == -1) {
         Trace.println(ResourceHandler.getMessage("applet.progress.loadResource") + var1, 4);
      }

      return this.findResourcesByURLPath(var1);
   }

   private Enumeration findResourcesByURLPath(String var1) throws IOException {
      return (Enumeration)(var1 != null && var1.indexOf("META-INF/services/javax.sound") != -1 ? new PluginClassLoader$2(this) : super.findResources(var1));
   }

   protected void addJar(String var1) throws IOException {
      if (var1.toUpperCase().endsWith(".JARJAR") && this.base.getProtocol().equalsIgnoreCase("file")) {
         String var2 = this.base.toString() + var1;
         if (!this.JARJARtoJAR.containsKey(var2)) {
            JarFile var3 = null;
            File var4 = null;
            boolean var5 = false;

            try {
               var3 = new JarFile(this.base.getPath() + var1, true);
               Enumeration var6 = var3.entries();
               int var7 = 0;
               if (!var6.hasMoreElements()) {
                  throw new IOException("Invalid jarjar file");
               }

               JarEntry var8 = null;

               while (var6.hasMoreElements()) {
                  var8 = (JarEntry)var6.nextElement();
                  if (!var8.toString().toUpperCase().startsWith("META-INF/")) {
                     if (!var8.toString().toUpperCase().endsWith(".JAR")) {
                        throw new IOException("Invalid entry in jarjar file.");
                     }

                     if (++var7 > 1) {
                        break;
                     }
                  }
               }

               if (var7 > 1) {
                  var8 = null;
                  throw new IOException("Multiple JAR files inside JARJAR file");
               }

               byte[] var9 = new byte[8192];
               BufferedInputStream var10 = null;
               BufferedOutputStream var11 = null;
               FileOutputStream var12 = null;
               InputStream var13 = var3.getInputStream(var8);
               boolean var14 = false;

               try {
                  var4 = File.createTempFile(var8.toString().substring(0, var8.toString().lastIndexOf(46)), ".jar");
                  Trace.println(ResourceHandler.getMessage("pluginclassloader.created_file") + var4.getPath(), 2);
                  ProgressTracker.onProgressComplete(this.base.toString() + var1);
                  var10 = new BufferedInputStream(var13);
                  var12 = new FileOutputStream(var4);
                  var11 = new BufferedOutputStream(var12);

                  int var15;
                  while ((var15 = var10.read(var9, 0, var9.length)) != -1) {
                     var11.write(var9, 0, var15);
                  }

                  var11.flush();
                  this.JARJARtoJAR.put(this.base.toString() + var1, var4);
                  var14 = true;

                  URL var16;
                  try {
                     var16 = var4.toURL();
                  } catch (MalformedURLException var28) {
                     throw new IllegalArgumentException("name");
                  }

                  this.addURL(var16);
               } finally {
                  if (var10 != null) {
                     var10.close();
                  }

                  if (var11 != null) {
                     var11.close();
                  }

                  if (var12 != null) {
                     var12.close();
                  }

                  Object var32 = null;
                  Object var33 = null;
                  Object var34 = null;
                  if (!var14) {
                     Trace.println(var4.getName() + ResourceHandler.getMessage("pluginclassloader.empty_file"), 2);
                     if (var4 != null) {
                        var4.delete();
                     }
                  }
               }
            } finally {
               if (var3 != null) {
                  var3.close();
               }
            }
         }
      } else {
         super.addJar(var1);
         if (this.base.getProtocol().equalsIgnoreCase("file")) {
            ProgressTracker.onProgressComplete(this.base.toString() + var1);
         }
      }
   }

   protected void release() {
      if (!this.JARJARtoJAR.isEmpty()) {
         Trace.println(ResourceHandler.getMessage("pluginclassloader.deleting_files"), 2);

         for (Object var3 : this.JARJARtoJAR.keySet()) {
            File var4 = (File)this.JARJARtoJAR.get(var3);
            if (var4 != null) {
               Trace.println(ResourceHandler.getMessage("pluginclassloader.file") + var4.getPath(), 2);
               var4.delete();
            }
         }

         this.JARJARtoJAR.clear();
      }

      super.release();
   }
}
