package sun.plugin.security;

import java.io.IOException;
import java.security.AccessController;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Random;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.Trace;
import sun.plugin.usability.UserProfile;

public class PluginHttpsCertStore implements CertificateStore {
   private static String _filename = null;
   private KeyStore _jpicerts = null;

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.loading") + _filename, 2);

      try {
         AccessController.doPrivileged(new PluginHttpsCertStore$1(this));
      } catch (PrivilegedActionException var3) {
         Exception var2 = var3.getException();
         if (var2 instanceof IOException) {
            throw (IOException)var2;
         }

         if (var2 instanceof CertificateException) {
            throw (CertificateException)var2;
         }

         if (var2 instanceof KeyStoreException) {
            throw (KeyStoreException)var2;
         }

         if (var2 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var2;
         }

         Trace.securityPrintException(var3);
      }

      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.loaded") + _filename, 2);
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.saving") + _filename, 2);

      try {
         AccessController.doPrivileged(new PluginHttpsCertStore$2(this));
      } catch (PrivilegedActionException var3) {
         Exception var2 = var3.getException();
         if (var2 instanceof IOException) {
            throw (IOException)var2;
         }

         if (var2 instanceof CertificateException) {
            throw (CertificateException)var2;
         }

         if (var2 instanceof KeyStoreException) {
            throw (KeyStoreException)var2;
         }

         if (var2 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var2;
         }

         Trace.securityPrintException(var3);
      }

      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.saved") + _filename, 2);
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.adding"), 2);
      if (!this.contains(var1)) {
         Random var2 = new Random();
         boolean var3 = false;
         Object var4 = null;

         do {
            var4 = "jpicert" + var2.nextLong();
            Certificate var5 = this._jpicerts.getCertificate((String)var4);
            if (var5 == null) {
               var3 = true;
            }
         } while (!var3);

         this._jpicerts.setCertificateEntry((String)var4, var1);
         Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.added") + var4, 2);
      }
   }

   public void remove(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.removing"), 2);
      String var2 = this._jpicerts.getCertificateAlias(var1);
      if (var2 != null) {
         this._jpicerts.deleteEntry(var2);
      }

      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.removed"), 2);
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.instore"), 2);
      Object var2 = null;
      var2 = this._jpicerts.getCertificateAlias(var1);
      return var2 != null;
   }

   public boolean verify(Certificate var1) {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.canverify"), 2);
      return false;
   }

   public Iterator iterator() throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("jpihttpscertstore.cert.iterator"), 2);
      HashSet var1 = new HashSet();
      Enumeration var2 = this._jpicerts.aliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         Certificate var4 = this._jpicerts.getCertificate(var3);
         var1.add(var4);
      }

      return var1.iterator();
   }

   static {
      _filename = UserProfile.getHttpsCertificateFile();
   }
}
