package sun.plugin.security;

import java.io.IOException;
import java.security.AccessController;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.Trace;
import sun.plugin.usability.UserProfile;

public class RootCACertificateStore implements CertificateStore {
   private static String _filename = null;
   private KeyStore _cacerts = null;

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.loading") + _filename, 2);

      try {
         AccessController.doPrivileged(new RootCACertificateStore$1(this));
      } catch (PrivilegedActionException var3) {
         Exception var2 = var3.getException();
         if (var2 instanceof IOException) {
            throw (IOException)var2;
         }

         if (var2 instanceof CertificateException) {
            throw (CertificateException)var2;
         }

         if (var2 instanceof KeyStoreException) {
            throw (KeyStoreException)var2;
         }

         if (var2 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var2;
         }

         Trace.securityPrintException(var3);
      }

      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.loaded") + _filename, 2);
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.saving") + _filename, 2);
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.adding"), 2);
      throw new KeyStoreException("Cannot add root CA certificate");
   }

   public void remove(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.removing"), 2);
      throw new KeyStoreException("Cannot remove root CA certificate");
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.instore"), 2);
      return false;
   }

   public boolean verify(Certificate var1) throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.canverify"), 2);
      StringBuffer var2 = new StringBuffer();
      var2.append("Certificate to be verified:\n");
      var2.append(var1.toString());
      Trace.securityPrintln(var2.toString(), 2);
      Enumeration var3 = this._cacerts.aliases();

      while (var3.hasMoreElements()) {
         String var4 = (String)var3.nextElement();
         Certificate var5 = this._cacerts.getCertificate(var4);
         var2.setLength(0);
         var2.append("Comparing certificate against Root CA certificate:\n");
         var2.append(var5.toString());
         Trace.securityPrintln(var2.toString(), 2);

         try {
            var1.verify(var5.getPublicKey());
            Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.verify.ok"), 2);
            return true;
         } catch (Exception var7) {
         }
      }

      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.verify.fail"), 2);
      return false;
   }

   public Iterator iterator() throws KeyStoreException {
      Trace.securityPrintln(ResourceHandler.getMessage("rootcertstore.cert.iterator"), 2);
      HashSet var1 = new HashSet();
      Enumeration var2 = this._cacerts.aliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         Certificate var4 = this._cacerts.getCertificate(var3);
         var1.add(var4);
      }

      return var1.iterator();
   }

   static {
      _filename = UserProfile.getRootCertificateFile();
   }
}
