package sun.plugin.security;

import java.io.IOException;
import java.security.AccessController;
import java.security.CodeSource;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.Principal;
import java.security.PrivilegedAction;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.Trace;

public class TrustDecider {
   private static CertificateStore rootStore = new RootCACertificateStore();
   private static CertificateStore permanentStore = new PluginCertificateStore();
   private static CertificateStore sessionStore = new SessionCertificateStore();
   private static CertificateStore deniedStore = new DeniedCertificateStore();

   public static void reset() {
      rootStore = new RootCACertificateStore();
      permanentStore = new PluginCertificateStore();
      sessionStore = new SessionCertificateStore();
      deniedStore = new DeniedCertificateStore();
   }

   public static boolean isAllPermissionGranted(CodeSource var0) throws CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, CertificateException, KeyStoreException, NoSuchAlgorithmException, IOException {
      Certificate[] var1 = var0.getCertificates();
      String var2 = var0.getLocation().toString();
      if (var1 == null) {
         return isBrowserMozilla() ? isAllPermissionGranted(var0, var2, null, null, 0, null, 0, "") : false;
      } else {
         int var3 = 0;

         for (int var4 = 0; var4 < var1.length; var3 = var4) {
            int var5 = var3;
            CertificateExpiredException var6 = null;
            CertificateNotYetValidException var7 = null;
            if (var1.length == 1 && var1[0] instanceof X509Certificate) {
               try {
                  ((X509Certificate)var1[0]).checkValidity();
               } catch (CertificateExpiredException var15) {
                  if (var6 == null) {
                     var6 = var15;
                  }
               } catch (CertificateNotYetValidException var16) {
                  if (var7 == null) {
                     var7 = var16;
                  }
               }
            } else {
               for (;
                  var5 + 1 < var1.length
                     && var1[var5] instanceof X509Certificate
                     && var1[var5 + 1] instanceof X509Certificate
                     && isIssuerOf((X509Certificate)var1[var5], (X509Certificate)var1[var5 + 1]);
                  var5++
               ) {
                  try {
                     ((X509Certificate)var1[var5]).checkValidity();
                     ((X509Certificate)var1[var5 + 1]).checkValidity();
                  } catch (CertificateExpiredException var17) {
                     if (var6 == null) {
                        var6 = var17;
                     }
                  } catch (CertificateNotYetValidException var18) {
                     if (var7 == null) {
                        var7 = var18;
                     }
                  }
               }
            }

            var4 = var5 + 1;
            if (!isBrowserMozilla()) {
               boolean var19 = false;
               rootStore.load();
               permanentStore.load();
               sessionStore.load();
               deniedStore.load();
               boolean var20 = false;
               boolean var21 = false;
               if (deniedStore.contains(var1[var3])) {
                  return false;
               }

               if (!rootStore.verify(var1[var5])) {
                  var20 = true;
               }

               if (permanentStore.contains(var1[var3])) {
                  return true;
               }

               if (sessionStore.contains(var1[var3])) {
                  return true;
               }

               if (var6 != null || var7 != null) {
                  var21 = true;
               }

               int var22 = showSecurityDialog(var0, var20, var21);
               if (var22 == 0) {
                  Trace.securityPrintln(ResourceHandler.getMessage("trustdecider.user.grant.session"), 2);
                  sessionStore.add(var1[var3]);
                  sessionStore.save();
                  var19 = true;
               } else if (var22 == 2) {
                  Trace.securityPrintln(ResourceHandler.getMessage("trustdecider.user.grant.forever"), 2);
                  permanentStore.add(var1[var3]);
                  permanentStore.save();
                  var19 = true;
               } else {
                  Trace.securityPrintln(ResourceHandler.getMessage("trustdecider.user.deny"), 2);
                  deniedStore.add(var1[var3]);
                  deniedStore.save();
               }

               return var19;
            }

            byte[][] var8 = makeChain(var1, var3, var4);
            if (var8 != null) {
               int[] var9 = new int[var8.length];

               for (int var10 = 0; var10 < var8.length; var10++) {
                  var9[var10] = var8[var10].length;
               }

               X509Certificate var11 = (X509Certificate)var1[0];
               byte[] var12 = var11.getSignature();
               Principal var13 = var11.getSubjectDN();
               String var14 = var13.getName();
               if (isAllPermissionGranted(var0, var2, var8, var9, var8.length, var12, var12.length, var14)) {
                  return true;
               }
            }
         }

         return false;
      }
   }

   private static boolean isBrowserMozilla() {
      return false;
   }

   private static boolean isAllPermissionGranted(CodeSource var0, String var1, byte[][] var2, int[] var3, int var4, byte[] var5, int var6, String var7) {
      return false;
   }

   private static byte[][] makeChain(Certificate[] var0, int var1, int var2) throws CertificateEncodingException {
      if (var1 == var2) {
         return null;
      } else {
         byte[][] var3 = new byte[var2 - var1][];

         for (int var4 = var1; var4 < var2; var4++) {
            var3[var4 - var1] = var0[var4].getEncoded();
         }

         return var3;
      }
   }

   private static boolean isIssuerOf(X509Certificate var0, X509Certificate var1) {
      Principal var2 = var0.getIssuerDN();
      Principal var3 = var1.getSubjectDN();
      return var2.equals(var3);
   }

   static int showSecurityDialog(CodeSource var0, boolean var1, boolean var2) {
      Integer var3 = AccessController.doPrivileged(new TrustDecider.PrivilegedBlockAction(var0, var1, var2));
      int var4 = 2;
      if (var3 != null) {
         var4 = var3;
      }

      return var4;
   }

   private static class PrivilegedBlockAction implements PrivilegedAction {
      Certificate[] certs;
      boolean rootCANotValid = false;
      boolean timeNotValid = false;

      PrivilegedBlockAction(CodeSource var1, boolean var2, boolean var3) {
         this.certs = var1.getCertificates();
         this.rootCANotValid = var2;
         this.timeNotValid = var3;
      }

      public Object run() {
         TrustDeciderDialog var1 = new TrustDeciderDialog(this.certs, this.rootCANotValid, this.timeNotValid);
         return new Integer(var1.DoModal());
      }
   }
}
