package sun.plugin.security;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;
import java.security.AccessController;
import java.security.Principal;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.text.MessageFormat;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.usability.DialogFactory;
import sun.plugin.usability.Trace;

class TrustDeciderDialog implements ActionListener {
   public static final int TrustOption_GrantThisSession = 0;
   public static final int TrustOption_Deny = 1;
   public static final int TrustOption_GrantAlways = 2;
   private Certificate[] certs = null;
   private boolean rootCANotValid = false;
   private boolean timeNotValid = false;
   private boolean httpsDialog = false;
   CertificateDialog dialog;

   TrustDeciderDialog(Certificate[] var1, boolean var2, boolean var3) {
      this.certs = var1;
      this.rootCANotValid = var2;
      this.timeNotValid = var3;
      this.dialog = new CertificateDialog(var1, 0);
   }

   int DoModal() {
      int var1 = -1;
      if (this.certs[0] instanceof X509Certificate && this.certs[this.certs.length - 1] instanceof X509Certificate) {
         X509Certificate var2 = (X509Certificate)this.certs[0];
         X509Certificate var3 = (X509Certificate)this.certs[this.certs.length - 1];
         Principal var4 = var2.getSubjectDN();
         Principal var5 = var3.getIssuerDN();
         String var6 = var4.getName();
         Object var7 = null;
         int var8 = var6.indexOf("CN=");
         int var9 = 0;
         if (var8 < 0) {
            var7 = getMessage("security_dialog.unknown.subject");
         } else {
            try {
               var8 += 3;
               if (var6.charAt(var8) == '"') {
                  var9 = var6.indexOf(34, ++var8);
               } else {
                  var9 = var6.indexOf(44, var8);
               }

               if (var9 < 0) {
                  var7 = var6.substring(var8);
               } else {
                  var7 = var6.substring(var8, var9);
               }
            } catch (Throwable var19) {
               var7 = getMessage("security_dialog.unknown.subject");
            }
         }

         String var10 = var5.getName();
         Object var11 = null;
         var8 = var10.indexOf("O=");
         int var25 = 0;
         if (var8 < 0) {
            var11 = getMessage("security_dialog.unknown.issuer");
         } else {
            try {
               var8 += 2;
               if (var10.charAt(var8) == '"') {
                  var25 = var10.indexOf(34, ++var8);
               } else {
                  var25 = var10.indexOf(44, var8);
               }

               if (var25 < 0) {
                  var11 = var10.substring(var8);
               } else {
                  var11 = var10.substring(var8, var25);
               }
            } catch (Throwable var18) {
               var11 = getMessage("security_dialog.unknown.issuer");
            }
         }

         Object[] var12 = new Object[6];
         MessageFormat var13 = null;
         if (this.getHttpsDialog()) {
            var13 = new MessageFormat(getMessage("security_dialog_https.text0"));
         } else {
            var13 = new MessageFormat(getMessage("security_dialog.text0"));
         }

         Object[] var14 = new Object[]{var7, var11};
         var12[0] = var13.format(var14);
         var12[1] = "";
         if (this.rootCANotValid) {
            JLabel var15 = new JLabel(getMessage("security_dialog.rootCANotValid"));
            var15.setIcon(this.getWarningIcon());
            var12[2] = var15;
         } else {
            JLabel var30 = new JLabel(getMessage("security_dialog.rootCAValid"));
            var30.setIcon(this.getInfoIcon());
            var12[2] = var30;
         }

         var12[3] = "";
         if (this.timeNotValid) {
            JLabel var31 = new JLabel(getMessage("security_dialog.timeNotValid"));
            var31.setIcon(this.getWarningIcon());
            var12[4] = var31;
         } else {
            JLabel var32 = new JLabel(getMessage("security_dialog.timeValid"));
            var32.setIcon(this.getInfoIcon());
            var12[4] = var32;
         }

         var13 = new MessageFormat(getMessage("security_dialog.text1"));
         Object[] var33 = new Object[]{var7, var7};
         var12[5] = var13.format(var33);
         JButton var16 = new JButton(getMessage("security_dialog.buttonViewCert"));
         var16.setMnemonic(86);
         var16.addActionListener(this);
         Object[] var17 = new Object[]{
            getMessage("security_dialog.buttonYes"), getMessage("security_dialog.buttonNo"), getMessage("security_dialog.buttonAlways"), var16
         };
         if (!Trace.isAutomationEnabled()) {
            var1 = DialogFactory.showOptionDialog(var12, getMessage("security_dialog.caption"), var17, var17[0]);
         } else {
            Trace.securityPrintln(ResourceHandler.getMessage("trustdecider.automation.trustcert"), 2);
            var1 = 0;
         }
      }

      return var1;
   }

   public void actionPerformed(ActionEvent var1) {
      this.dialog.DoModal();
   }

   private static String getMessage(String var0) {
      return ResourceHandler.getMessage(var0);
   }

   private Icon getWarningIcon() {
      Icon var1 = null;

      try {
         var1 = AccessController.doPrivileged(new TrustDeciderDialog$1(this));
      } catch (Throwable var3) {
         var3.printStackTrace();
      }

      return var1;
   }

   private Icon getInfoIcon() {
      ImageIcon var1 = null;

      try {
         URL var2 = ClassLoader.getSystemResource("javax/swing/plaf/metal/icons/Inform.gif");
         var1 = new ImageIcon(var2);
      } catch (Throwable var3) {
         var3.printStackTrace();
      }

      return var1;
   }

   public boolean getHttpsDialog() {
      return this.httpsDialog;
   }

   public void setHttpsDialog(boolean var1) {
      this.httpsDialog = var1;
   }
}
