package sun.plugin.usability;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.lang.reflect.Array;
import java.security.AccessController;
import javax.swing.Icon;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import sun.applet.AppletClassLoader;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.security.ActivatorSecurityManager;

public class DialogFactory {
   private static String confirmDialogTitle = ResourceHandler.getMessage("usability.confirmDialogTitle");
   private static String inputDialogTitle = ResourceHandler.getMessage("usability.inputDialogTitle");
   private static String messageDialogTitle = ResourceHandler.getMessage("usability.messageDialogTitle");
   private static String exceptionDialogTitle = ResourceHandler.getMessage("usability.exceptionDialogTitle");
   private static String optionDialogTitle = ResourceHandler.getMessage("usability.optionDialogTitle");
   private static String aboutDialogTitle = ResourceHandler.getMessage("usability.aboutDialogTitle");

   public static Icon loadIcon() {
      Icon var0 = null;

      try {
         var0 = AccessController.doPrivileged(new DialogFactory$1());
      } catch (Throwable var2) {
         var2.printStackTrace();
      }

      return var0;
   }

   public static void showAboutPluginDialog() {
      AccessController.doPrivileged(new DialogFactory$2());
   }

   public static int showConfirmDialog(Object var0) {
      return showConfirmDialog(var0, confirmDialogTitle);
   }

   public static String showInputDialog(Object var0) {
      return showInputDialog(var0, inputDialogTitle);
   }

   public static void showMessageDialog(Object var0) {
      showMessageDialog(var0, messageDialogTitle);
   }

   public static void showExceptionDialog(Object var0) {
      showExceptionDialog(var0, exceptionDialogTitle);
   }

   public static int showConfirmDialog(Object var0, String var1) {
      String var2 = ResourceHandler.getMessage("usability.confirm.yes");
      String var3 = ResourceHandler.getMessage("usability.confirm.no");
      Object[] var4 = new Object[]{var2, var3};
      if (var1 == null) {
         var1 = confirmDialogTitle;
      }

      return showOptionDialog(var0, var1, var4, var4[0]);
   }

   public static int showOptionDialog(Object var0, String var1, Object[] var2, Object var3) {
      int var4 = -1;
      JOptionPane var5 = new JOptionPane();
      var5.setIcon(loadIcon());
      var5.setOptions(var2);
      var5.setInitialValue(var3);
      var5.setWantsInput(false);
      Object var6 = extractMessage(var5, var0);
      if (var1 == null) {
         var1 = optionDialogTitle;
      }

      if (showDialog(var5, var1, var6)) {
         Object var7 = var5.getValue();
         if (var7 != null) {
            for (int var8 = 0; var8 < var2.length; var8++) {
               if (var2[var8].equals(var7)) {
                  var4 = var8;
                  break;
               }
            }

            Trace.println(ResourceHandler.getMessage("dialogfactory.user.selected") + var4, 2);
         }
      }

      return var4;
   }

   public static String showInputDialog(Object var0, String var1) {
      String var2 = null;
      JOptionPane var3 = new JOptionPane();
      var3.setIcon(loadIcon());
      var3.setOptionType(2);
      var3.setWantsInput(true);
      Object var4 = extractMessage(var3, var0);
      if (var1 == null) {
         var1 = inputDialogTitle;
      }

      if (showDialog(var3, var1, var4)) {
         Object var5 = var3.getInputValue();
         if (var5 != null) {
            if (var5 instanceof String) {
               var2 = var5.toString();
            }

            Trace.println(ResourceHandler.getMessage("dialogfactory.user.typed") + var2, 2);
         }
      }

      return var2;
   }

   public static void showMessageDialog(Object var0, String var1, boolean var2) {
      JOptionPane var3 = new JOptionPane();
      var3.setIcon(loadIcon());
      var3.setOptionType(-1);
      var3.setWantsInput(false);
      Object var4 = extractMessage(var3, var0);
      if (var1 == null) {
         var1 = messageDialogTitle;
      }

      showDialog(var3, var1, var4, var2);
   }

   public static void showMessageDialog(Object var0, String var1) {
      showMessageDialog(var0, var1, true);
   }

   public static void showExceptionDialog(Object var0, String var1) {
      JOptionPane var2 = new JOptionPane();
      var2.setIcon(loadIcon());
      var2.setOptionType(-1);
      var2.setWantsInput(false);
      Object var3 = extractMessage(var2, var0);
      if (var1 == null) {
         var1 = exceptionDialogTitle;
      }

      showDialog(var2, var1, var3);
   }

   private static boolean showDialog(JOptionPane var0, String var1, Object var2) {
      return showDialog(var0, var1, var2, true);
   }

   private static boolean showDialog(JOptionPane var0, String var1, Object var2, boolean var3) {
      boolean var4 = true;

      try {
         AccessController.doPrivileged(new DialogFactory$3(var0, var1, var2, var3));
      } catch (Exception var6) {
         var6.printStackTrace();
         var4 = false;
      }

      return var4;
   }

   private static Object extractMessage(JOptionPane var0, Throwable var1) {
      return formatExceptionMessage(var0, var1);
   }

   private static Object extractMessage(JOptionPane var0, String var1) {
      return formatStringMessage(var0, var1);
   }

   private static Object extractMessage(JOptionPane var0, Object[] var1) {
      Object[] var2 = null;
      if (var1 != null) {
         var2 = new Object[var1.length];

         for (int var3 = 0; var3 < var1.length; var3++) {
            var2[var3] = extractMessage(var0, var1[var3]);
         }
      }

      return var2;
   }

   private static Object extractMessage(JOptionPane var0, Object var1) {
      if (var1 instanceof Object[]) {
         return extractMessage(var0, (Object[])var1);
      } else if (var1 instanceof String) {
         return extractMessage(var0, (String)var1);
      } else {
         return var1 instanceof Exception ? extractMessage(var0, (Throwable)((Exception)var1)) : var1;
      }
   }

   private static Object formatStringMessage(JOptionPane var0, String var1) {
      if (!$assertionsDisabled && var1 == null) {
         throw new AssertionError();
      } else {
         JTextArea var2 = new JTextArea();
         var2.setColumns(40);
         var2.setAutoscrolls(true);
         var2.setEditable(false);
         var2.setLineWrap(true);
         var2.setWrapStyleWord(true);
         var2.setBackground(var0.getBackground());
         var2.setText("" + var1);
         return var2;
      }
   }

   private static Object formatExceptionMessage(JOptionPane var0, Throwable var1) {
      StringWriter var2 = new StringWriter();
      PrintWriter var3 = new PrintWriter(var2);
      var1.printStackTrace(var3);
      JTextArea var4 = new JTextArea("" + var2.toString());
      var4.setColumns(40);
      var4.setRows(10);
      var4.setEditable(false);
      JScrollPane var5 = new JScrollPane(var4);
      var4.setBackground(var0.getBackground());
      return var5;
   }

   private static boolean isInClassLoader() {
      SecurityManager var0 = System.getSecurityManager();
      if (var0 != null && var0 instanceof ActivatorSecurityManager) {
         ActivatorSecurityManager var1 = (ActivatorSecurityManager)var0;
         Class[] var2 = var1.getExecutionStackContext();

         for (int var3 = 0; var3 < var2.length; var3++) {
            Class var4 = var2[var3];
            ClassLoader var5 = var4.getClassLoader();
            if (var5 instanceof AppletClassLoader
               || (class$sun$applet$AppletClassLoader == null
                     ? (class$sun$applet$AppletClassLoader = class$("sun.applet.AppletClassLoader"))
                     : class$sun$applet$AppletClassLoader)
                  .isAssignableFrom(var4)) {
               return true;
            }
         }
      }

      return false;
   }

   private static void fixSwingLayoutBug(Object var0) {
      if (var0 != null) {
         if (var0 instanceof JTextArea) {
            JTextArea var3 = (JTextArea)var0;
            var3.getUI().getPreferredSize(var3);
         } else {
            if (var0.getClass().isArray()) {
               int var1 = Array.getLength(var0);

               for (int var2 = 0; var2 < var1; var2++) {
                  fixSwingLayoutBug(Array.get(var0, var2));
               }
            }
         }
      }
   }
}
