package sun.plugin.usability;

import java.security.AccessController;
import java.text.MessageFormat;
import java.util.HashMap;
import java.util.StringTokenizer;
import sun.plugin.resources.ResourceHandler;
import sun.security.action.GetBooleanAction;
import sun.security.action.GetPropertyAction;

public class Trace {
   private static boolean bBasicTraceOn = false;
   private static boolean bExtTraceOn = false;
   private static boolean bSecurityTraceOn = false;
   private static boolean bNetTraceOn = false;
   private static boolean bLiveConnectTraceOn = false;
   private static boolean bAutomationOn = false;
   private static HashMap threadGroups = new HashMap();

   public static void reset() {
      if (AccessController.doPrivileged(new GetBooleanAction("javaplugin.trace"))) {
         String var0 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.trace.option"));
         if (var0 == null) {
            bBasicTraceOn = true;
            bNetTraceOn = true;
            bSecurityTraceOn = true;
            bExtTraceOn = true;
            bLiveConnectTraceOn = true;
         } else {
            StringTokenizer var1 = new StringTokenizer(var0, "|");

            while (var1.hasMoreTokens()) {
               String var2 = var1.nextToken();
               if (var2 == null || var2.equalsIgnoreCase("all")) {
                  bBasicTraceOn = true;
                  bNetTraceOn = true;
                  bSecurityTraceOn = true;
                  bExtTraceOn = true;
                  bLiveConnectTraceOn = true;
                  break;
               }

               if (var2.equalsIgnoreCase("basic")) {
                  bBasicTraceOn = true;
               } else if (var2.equalsIgnoreCase("net")) {
                  bNetTraceOn = true;
               } else if (var2.equalsIgnoreCase("security")) {
                  bSecurityTraceOn = true;
               } else if (var2.equalsIgnoreCase("ext")) {
                  bExtTraceOn = true;
               } else if (var2.equalsIgnoreCase("liveconnect")) {
                  bLiveConnectTraceOn = true;
               }
            }
         }
      }
   }

   public static boolean isEnabled() {
      return bBasicTraceOn || bNetTraceOn || bSecurityTraceOn || bExtTraceOn || bLiveConnectTraceOn;
   }

   public static void setBasicTrace(boolean var0) {
      bBasicTraceOn = var0;
   }

   public static void setNetTrace(boolean var0) {
      bNetTraceOn = var0;
   }

   public static void setSecurityTrace(boolean var0) {
      bSecurityTraceOn = var0;
   }

   public static void setExtTrace(boolean var0) {
      bExtTraceOn = var0;
   }

   public static void setLiveConnectTrace(boolean var0) {
      bLiveConnectTraceOn = var0;
   }

   public static boolean isAutomationEnabled() {
      return bAutomationOn;
   }

   public static void println(String var0) {
      println(var0, null);
   }

   public static void println(String var0, int var1) {
      println(var0, null, var1);
   }

   public static void println(String var0, TraceListener var1) {
      println(var0, var1, 6);
   }

   public static void println(String var0, TraceListener var1, int var2) {
      if (bBasicTraceOn && (var2 & 2) == 2) {
         System.err.println(var0);
         System.err.flush();
         PluginLogger.log(var0);
      }

      firePrintlnEvent(var0, var1, var2);
   }

   public static void messagePrintln(String var0, Object[] var1, TraceListener var2, int var3) {
      if (bBasicTraceOn || (var3 & 1) == 1 || (var3 & 4) == 4) {
         MessageFormat var4 = new MessageFormat(ResourceHandler.getMessage(var0));
         println(var4.format(var1), var2, var3);
      }
   }

   public static void printException(Throwable var0) {
      var0.printStackTrace();
      PluginLogger.logException(var0);
      if (!isAutomationEnabled()) {
         Object[] var1 = new Object[]{ResourceHandler.getMessage("usability.general_error"), var0};
         DialogFactory.showExceptionDialog(var1, null);
      }
   }

   public static void printException(Throwable var0, String var1, String var2) {
      var0.printStackTrace();
      PluginLogger.logException(var1, var0);
      if (!isAutomationEnabled()) {
         Object[] var3 = new Object[]{var1, var0};
         DialogFactory.showExceptionDialog(var3, var2);
      }
   }

   public static void netPrintln(String var0) {
      netPrintln(var0, 2);
   }

   public static void netPrintln(String var0, int var1) {
      if (bNetTraceOn && (var1 & 2) == 2) {
         System.err.println(var0);
         System.err.flush();
         PluginLogger.log(var0);
      }

      firePrintlnEvent(var0, null, var1);
   }

   public static void messageNetPrintln(String var0, Object[] var1) {
      if (bNetTraceOn) {
         MessageFormat var2 = new MessageFormat(ResourceHandler.getMessage(var0));
         netPrintln(var2.format(var1));
      }
   }

   public static void netPrintException(Throwable var0) {
      var0.printStackTrace();
      PluginLogger.logException(var0);
      if (!isAutomationEnabled()) {
         Object[] var1 = new Object[]{ResourceHandler.getMessage("usability.net_error"), var0};
      }
   }

   public static void netPrintException(Throwable var0, String var1, String var2) {
      var0.printStackTrace();
      PluginLogger.logException(var1, var0);
      Object[] var3 = new Object[]{var1, var0};
   }

   public static void securityPrintln(String var0) {
      securityPrintln(var0, 2);
   }

   public static void securityPrintln(String var0, int var1) {
      if (bSecurityTraceOn && (var1 & 2) == 2) {
         System.err.println(var0);
         System.err.flush();
         PluginLogger.log(var0);
      }

      firePrintlnEvent(var0, null, var1);
   }

   public static void securityPrintException(Throwable var0) {
      var0.printStackTrace();
      PluginLogger.logException(var0);
      if (!isAutomationEnabled()) {
         Object[] var1 = new Object[]{ResourceHandler.getMessage("usability.security_error"), var0};
         DialogFactory.showExceptionDialog(var1, null);
      }
   }

   public static void securityPrintException(Throwable var0, String var1, String var2) {
      var0.printStackTrace();
      PluginLogger.logException(var1, var0);
      if (!isAutomationEnabled()) {
         Object[] var3 = new Object[]{var1, var0};
         DialogFactory.showExceptionDialog(var3, var2);
      }
   }

   public static void extPrintln(String var0) {
      extPrintln(var0, 2);
   }

   public static void extPrintln(String var0, int var1) {
      if (bExtTraceOn && (var1 & 2) == 2) {
         System.err.println(var0);
         System.err.flush();
         PluginLogger.log(var0);
      }

      firePrintlnEvent(var0, null, var1);
   }

   public static void extPrintException(Throwable var0) {
      var0.printStackTrace();
      PluginLogger.logException(var0);
      if (!isAutomationEnabled()) {
         Object[] var1 = new Object[]{ResourceHandler.getMessage("usability.ext_error"), var0};
         DialogFactory.showExceptionDialog(var1, null);
      }
   }

   public static void extPrintException(Throwable var0, String var1, String var2) {
      var0.printStackTrace();
      PluginLogger.logException(var1, var0);
      if (!isAutomationEnabled()) {
         Object[] var3 = new Object[]{var1, var0};
         DialogFactory.showExceptionDialog(var3, var2);
      }
   }

   public static void liveConnectPrintln(String var0) {
      liveConnectPrintln(var0, 2);
   }

   public static void liveConnectPrintln(String var0, int var1) {
      if (bLiveConnectTraceOn && (var1 & 2) == 2) {
         System.err.println(var0);
         System.err.flush();
         PluginLogger.log(var0);
      }

      firePrintlnEvent(var0, null, var1);
   }

   public static void messageLiveConnectPrintln(String var0, Object[] var1, int var2) {
      if (bLiveConnectTraceOn || (var2 & 1) == 1 || (var2 & 4) == 4) {
         MessageFormat var3 = new MessageFormat(ResourceHandler.getMessage(var0));
         liveConnectPrintln(var3.format(var1), var2);
      }
   }

   public static void liveConnectPrintException(Throwable var0) {
      var0.printStackTrace();
      PluginLogger.logException(var0);
   }

   public static void addTraceListener(ThreadGroup var0, TraceListener var1) {
      println(ResourceHandler.getMessage("trace.listener.added") + var1, 2);
      HashMap var2 = threadGroups;
      synchronized (var2) {
         TraceListener var3 = (TraceListener)threadGroups.get(new Integer(var0.hashCode()));
         var3 = EventMulticaster.add(var3, var1);
         threadGroups.put(new Integer(var0.hashCode()), var3);
      }
   }

   public static void removeTraceListener(ThreadGroup var0, TraceListener var1) {
      println(ResourceHandler.getMessage("trace.listener.removed") + var1, 2);
      HashMap var2 = threadGroups;
      synchronized (var2) {
         TraceListener var3 = (TraceListener)threadGroups.get(new Integer(var0.hashCode()));
         var3 = EventMulticaster.remove(var3, var1);
         if (var3 != null) {
            threadGroups.put(new Integer(var0.hashCode()), var3);
         } else {
            threadGroups.remove(new Integer(var0.hashCode()));
         }
      }
   }

   private static void firePrintlnEvent(String var0, TraceListener var1, int var2) {
      if (var1 != null && var1.isSupported(var2)) {
         var1.println(var0, var2);
      } else {
         Thread var3 = Thread.currentThread();
         ThreadGroup var4 = var3.getThreadGroup();
         TraceListener var5 = null;
         HashMap var6 = threadGroups;
         synchronized (var6) {
            var5 = (TraceListener)threadGroups.get(new Integer(var4.hashCode()));
         }

         if (var5 != null) {
            var5.println(var0, var2);
         }
      }
   }

   static {
      reset();
      bAutomationOn = AccessController.doPrivileged(new GetBooleanAction("javaplugin.automation"));
   }
}
