package sunw.demo.classfile;

import java.beans.BeanInfo;
import java.beans.IntrospectionException;
import java.beans.Introspector;
import java.beans.MethodDescriptor;
import java.io.IOException;
import java.io.OutputStream;
import java.lang.reflect.Method;
import java.util.Hashtable;

public final class DelegatorClassFile {
   private Class[] targets;
   private FieldConstant[] fields;
   private static String superclassName;
   private String className;
   private ClassFile classFile;
   private Hashtable generatedMethods = new Hashtable();
   private char[] buff = new char[200];
   private int ix;

   public DelegatorClassFile(String var1, Class[] var2) throws IOException, ClassNotFoundException {
      this.className = var1;
      this.targets = var2;
      superclassName = this.targets[0].getName();
      this.classFile = new ClassFile(var1, this.targets[0].getName());
      this.allocateFields();
      this.recordInheritedMethods();
      this.generateDelegatedMethods();
      this.generateConstructor();
   }

   private void allocateFields() {
      this.fields = new FieldConstant[this.targets.length];

      for (int var1 = 1; var1 < this.targets.length; var1++) {
         String var2 = "t" + var1;
         String var3 = this.getInternalTypeString(this.targets[var1]);
         this.classFile.addFieldDesc(new FieldDesc(var2, var3, (short)2, this.classFile, null));
         FieldConstant var4 = this.classFile.addFieldConstant(this.className, var2, var3);
         this.fields[var1] = var4;
      }
   }

   private void recordInheritedMethods() {
      Method[] var1 = this.targets[0].getMethods();

      for (int var2 = 0; var2 < var1.length; var2++) {
         Method var3 = var1[var2];
         String var4 = this.getMethodTypeString(var3);
         String var5 = var3.getName() + var4;
         this.generatedMethods.put(var5, var5);
      }
   }

   private void generateDelegatedMethods() {
      for (int var1 = 0; var1 < this.targets.length; var1++) {
         Class var2 = this.targets[var1];

         BeanInfo var3;
         try {
            var3 = Introspector.getBeanInfo(var2);
         } catch (IntrospectionException var8) {
            System.err.println("Introspection failed on " + var2);
            return;
         }

         MethodDescriptor[] var4 = var3.getMethodDescriptors();

         for (int var5 = 0; var5 < var4.length; var5++) {
            MethodDescriptor var6 = var4[var5];
            Method var7 = var6.getMethod();
            this.generateDelegateMethod(this.fields[var1], var7);
         }
      }
   }

   private void generateConstructor() {
      Code var1 = new Code(this.classFile, (short)(this.targets.length + 2), (short)(this.targets.length + 4));
      String var2 = "(";

      for (int var3 = 1; var3 < this.targets.length; var3++) {
         var2 = var2 + this.getInternalTypeString(this.targets[var3]);
      }

      var2 = var2 + ")V";
      var1.addOp((byte)42);
      MethodConstant var4 = this.classFile.addMethodConstant(ClassFile.fullyQualifiedForm(superclassName), "<init>", "()V");
      var1.addOpShort((byte)-73, var4.getConstantPoolIndex());

      for (int var5 = 1; var5 < this.fields.length; var5++) {
         var1.addOp((byte)42);
         this.pushArg(var1, this.targets[var5], var5);
         var1.addOpShort((byte)-75, this.fields[var5].getConstantPoolIndex());
      }

      var1.addOp((byte)-79);
      this.classFile.addMethodDesc(new MethodDesc("<init>", var2, (short)1, this.classFile, var1));
   }

   private void generateDelegateMethod(FieldConstant var1, Method var2) {
      Class[] var3 = var2.getParameterTypes();
      String var4 = this.getMethodTypeString(var2);
      String var5 = var2.getName() + var4;
      if (this.generatedMethods.get(var5) == null) {
         this.generatedMethods.put(var5, var5);
         Code var6 = new Code(this.classFile, (short)(var3.length + 2), (short)(2 + 2 * var3.length));
         var6.addOp((byte)42);
         var6.addOpShort((byte)-76, var1.getConstantPoolIndex());

         for (int var7 = 0; var7 < var3.length; var7++) {
            this.pushArg(var6, var3[var7], var7 + 1);
         }

         MethodConstant var8 = this.classFile.addMethodConstant(var2.getDeclaringClass().getName().replace('.', '/'), var2.getName(), var4);
         var6.addOpShort((byte)-74, var8.getConstantPoolIndex());
         this.generateReturn(var6, var2.getReturnType());
         MethodDesc var9 = new MethodDesc(var2.getName(), var4, (short)1, this.classFile, var6);
         this.classFile.addMethodDesc(var9);
      }
   }

   void pushArg(Code var1, Class var2, int var3) {
      byte var4;
      byte var5;
      if (var2.isPrimitive()) {
         if (var2 == long.class) {
            var4 = 22;
            var5 = 30;
         } else if (var2 == float.class) {
            var4 = 23;
            var5 = 34;
         } else if (var2 == double.class) {
            var4 = 24;
            var5 = 38;
         } else {
            var4 = 21;
            var5 = 26;
         }
      } else {
         var4 = 25;
         var5 = 42;
      }

      if (var3 < 4) {
         var1.addOp((byte)(var5 + var3));
      } else {
         var1.addOp1(var4, (byte)var3);
      }
   }

   void generateReturn(Code var1, Class var2) {
      byte var3;
      if (var2.isPrimitive()) {
         if (var2 == void.class) {
            var3 = -79;
         } else if (var2 == long.class) {
            var3 = -83;
         } else if (var2 == float.class) {
            var3 = -82;
         } else if (var2 == double.class) {
            var3 = -81;
         } else {
            var3 = -84;
         }
      } else {
         var3 = -80;
      }

      var1.addOp(var3);
   }

   public void write(OutputStream var1) throws IOException {
      this.classFile.write(var1);
   }

   private String getInternalTypeString(Class var1) {
      this.ix = 0;
      this.push(var1);
      return new String(this.buff, 0, this.ix);
   }

   private String getMethodTypeString(Method var1) {
      this.ix = 0;

      try {
         this.buff[this.ix++] = '(';
         Class[] var3 = var1.getParameterTypes();

         for (int var4 = 0; var4 < var3.length; var4++) {
            this.push(var3[var4]);
         }

         this.buff[this.ix++] = ')';
         this.push(var1.getReturnType());
         return new String(this.buff, 0, this.ix);
      } catch (ArrayIndexOutOfBoundsException var5) {
         if (this.ix >= this.buff.length) {
            this.buff = new char[2 * this.buff.length];
            return this.getMethodTypeString(var1);
         } else {
            throw var5;
         }
      }
   }

   private void push(Class var1) {
      while (var1.isArray()) {
         var1 = var1.getComponentType();
         this.buff[this.ix++] = '[';
      }

      if (var1.isPrimitive()) {
         if (var1 == void.class) {
            this.buff[this.ix++] = 'V';
         } else if (var1 == int.class) {
            this.buff[this.ix++] = 'I';
         } else if (var1 == boolean.class) {
            this.buff[this.ix++] = 'Z';
         } else if (var1 == long.class) {
            this.buff[this.ix++] = 'J';
         } else if (var1 == float.class) {
            this.buff[this.ix++] = 'F';
         } else if (var1 == double.class) {
            this.buff[this.ix++] = 'D';
         } else if (var1 == char.class) {
            this.buff[this.ix++] = 'C';
         } else if (var1 == byte.class) {
            this.buff[this.ix++] = 'B';
         } else {
            if (var1 != short.class) {
               throw new Error("Unexpected primitive type " + var1.getName());
            }

            this.buff[this.ix++] = 'S';
         }
      } else {
         this.buff[this.ix++] = 'L';
         String var2 = var1.getName();
         int var3 = var2.length();

         for (int var4 = 0; var4 < var3; var4++) {
            char var5 = var2.charAt(var4);
            if (var5 == '.') {
               var5 = '/';
            }

            this.buff[this.ix++] = var5;
         }

         this.buff[this.ix++] = ';';
      }
   }
}
