package foxtrot;

import foxtrot.pumps.JDK13QueueEventPump;
import foxtrot.pumps.SunJDK140ConditionalEventPump;
import foxtrot.pumps.SunJDK141ConditionalEventPump;
import foxtrot.workers.DefaultWorkerThread;
import java.security.AccessController;
import javax.swing.SwingUtilities;

public class Worker {
   private static EventPump eventPump;
   private static WorkerThread workerThread;
   static final boolean debug = false;

   private Worker() {
   }

   public static Object post(Task task) throws Exception {
      initializeWorkerThread();
      initializeEventPump();
      boolean isEventThread = SwingUtilities.isEventDispatchThread();
      if (!isEventThread && !workerThread.isWorkerThread()) {
         throw new IllegalStateException("Worker.post() can be called only from the AWT Event Dispatch Thread or from another Task");
      } else {
         if (!workerThread.isAlive()) {
            workerThread.start();
         }

         if (isEventThread) {
            workerThread.postTask(task);
            eventPump.pumpEvents(task);
         } else {
            workerThread.runTask(task);
         }

         Object var2;
         try {
            var2 = task.getResultOrThrow();
         } finally {
            task.reset();
         }

         return var2;
      }
   }

   public static Object post(Job job) {
      try {
         return post((Task)job);
      } catch (RuntimeException var4) {
         throw var4;
      } catch (Exception var5) {
         throw new RuntimeException(var5.toString());
      } catch (Error var6) {
         throw var6;
      }
   }

   public static EventPump getEventPump() {
      initializeEventPump();
      return eventPump;
   }

   public static void setEventPump(EventPump eventPump) {
      if (eventPump == null) {
         throw new IllegalArgumentException("EventPump cannot be null");
      } else {
         Worker.eventPump = eventPump;
      }
   }

   public static WorkerThread getWorkerThread() {
      initializeWorkerThread();
      return workerThread;
   }

   public static void setWorkerThread(WorkerThread workerThread) {
      if (workerThread == null) {
         throw new IllegalArgumentException("WorkerThread cannot be null");
      } else {
         Worker.workerThread = workerThread;
      }
   }

   private static void initializeWorkerThread() {
      if (workerThread == null) {
         String workerThreadClassName = AccessController.doPrivileged(new Worker$1());
         if (workerThreadClassName == null) {
            workerThread = new DefaultWorkerThread();
         } else {
            ClassLoader loader = (class$foxtrot$Worker == null ? (class$foxtrot$Worker = class$("foxtrot.Worker")) : class$foxtrot$Worker).getClassLoader();
            if (loader == null) {
               loader = ClassLoader.getSystemClassLoader();
            }

            try {
               workerThread = (WorkerThread)loader.loadClass(workerThreadClassName).newInstance();
            } catch (Throwable var3) {
               workerThread = new DefaultWorkerThread();
            }
         }
      }
   }

   private static void initializeEventPump() {
      if (eventPump == null) {
         String eventPumpClassName = AccessController.doPrivileged(new Worker$2());
         if (eventPumpClassName != null) {
            ClassLoader loader = (class$foxtrot$Worker == null ? (class$foxtrot$Worker = class$("foxtrot.Worker")) : class$foxtrot$Worker).getClassLoader();
            if (loader == null) {
               loader = ClassLoader.getSystemClassLoader();
            }

            try {
               eventPump = (EventPump)loader.loadClass(eventPumpClassName).newInstance();
               return;
            } catch (Throwable var3) {
            }
         }

         if (JREVersion.isJRE141()) {
            eventPump = new SunJDK141ConditionalEventPump();
         } else if (JREVersion.isJRE140()) {
            eventPump = new SunJDK140ConditionalEventPump();
         } else {
            if (!JREVersion.isJRE13() && !JREVersion.isJRE12()) {
               throw new Error("JDK 1.1 is not supported");
            }

            eventPump = new JDK13QueueEventPump();
         }
      }
   }
}
