package foxtrot.pumps;

import foxtrot.EventPump;
import foxtrot.Task;
import java.awt.AWTEvent;
import java.awt.ActiveEvent;
import java.awt.Component;
import java.awt.EventQueue;
import java.awt.MenuComponent;
import java.lang.reflect.Method;
import java.security.AccessController;

public class JDK13QueueEventPump implements EventPump, EventFilterable {
   private static final boolean debug = false;
   private EventFilter filter;

   public void setEventFilter(EventFilter filter) {
      this.filter = filter;
   }

   public EventFilter getEventFilter() {
      return this.filter;
   }

   public void pumpEvents(Task task) {
      if (task != null) {
         EventQueue queue = this.getEventQueue();

         while (!task.isCompleted()) {
            try {
               AWTEvent event = queue.getNextEvent();
               if (this.filter == null || this.filter.accept(event)) {
                  try {
                     this.dispatchEvent(queue, event);
                  } catch (Throwable var5) {
                     this.handleThrowable(var5);
                  }
               }
            } catch (InterruptedException var6) {
               Thread.currentThread().interrupt();
               break;
            }
         }
      }
   }

   protected void dispatchEvent(EventQueue queue, AWTEvent event) {
      Object source = event.getSource();
      if (event instanceof ActiveEvent) {
         ((ActiveEvent)event).dispatch();
      } else if (source instanceof Component) {
         ((Component)source).dispatchEvent(event);
      } else if (source instanceof MenuComponent) {
         ((MenuComponent)source).dispatchEvent(event);
      } else {
         System.err.println("[JDK13QueueEventPump] Unable to dispatch event " + event);
      }
   }

   protected void handleThrowable(Throwable x) {
      String handlerName = AccessController.doPrivileged(new JDK13QueueEventPump$1(this));
      if (handlerName != null) {
         try {
            Object handler = Thread.currentThread().getContextClassLoader().loadClass(handlerName).newInstance();
            Method handle = handler.getClass()
               .getMethod("handle", class$java$lang$Throwable == null ? (class$java$lang$Throwable = class$("java.lang.Throwable")) : class$java$lang$Throwable);
            handle.invoke(handler, x);
            return;
         } catch (Throwable var5) {
            System.err.println("[JDK13QueueEventPump] Exception occurred while invoking AWT exception handler: " + var5);
         }
      }

      System.err.println("[JDK13QueueEventPump] Exception occurred during event dispatching:");
      x.printStackTrace();
   }

   private EventQueue getEventQueue() {
      return AccessController.doPrivileged(new JDK13QueueEventPump$2(this));
   }
}
