package foxtrot.pumps;

import foxtrot.EventPump;
import foxtrot.Task;
import java.awt.AWTEvent;
import java.awt.EventQueue;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.security.AccessController;

public abstract class SunJDK14ConditionalEventPump implements EventPump {
   private static final boolean debug = false;
   private static Class conditionalClass;
   private static Method pumpEventsMethod;
   protected static Class sequencedEventClass;

   public void pumpEvents(Task task) {
      if (task != null) {
         try {
            Object conditional = Proxy.newProxyInstance(
               conditionalClass.getClassLoader(), new Class[]{conditionalClass}, new SunJDK14ConditionalEventPump.Conditional(task, null)
            );
            pumpEventsMethod.invoke(Thread.currentThread(), conditional);
         } catch (InvocationTargetException var9) {
            Throwable t = var9.getTargetException();
            System.err.println("[SunJDK14ConditionalEventPump] Exception occurred during event dispatching:");
            t.printStackTrace();
            if (t instanceof RuntimeException) {
               throw (RuntimeException)t;
            }

            throw (Error)t;
         } catch (Throwable var10) {
            System.err.println("[SunJDK14ConditionalEventPump] PANIC: uncaught exception in Foxtrot code");
            var10.printStackTrace();
         } finally {
            this.waitForTask(task);
         }
      }
   }

   protected abstract Boolean canPumpSequencedEvent(AWTEvent var1);

   private void waitForTask(Task task) {
      try {
         synchronized (task) {
            while (!task.isCompleted()) {
               task.wait();
            }
         }
      } catch (InterruptedException var5) {
         Thread.currentThread().interrupt();
      }
   }

   static {
      try {
         AccessController.doPrivileged(new SunJDK14ConditionalEventPump$1());
      } catch (Throwable var1) {
         throw new Error(var1.toString());
      }
   }

   private class Conditional implements InvocationHandler {
      private Task task;

      private Conditional(Task task) {
         this.task = task;
      }

      public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
         String name = method.getName();
         if (!"evaluate".equals(name)) {
            throw new Error("Unknown " + SunJDK14ConditionalEventPump.conditionalClass.getName() + " method: " + name);
         } else {
            AWTEvent nextEvent = this.getEventQueue().peekEvent();
            if (SunJDK14ConditionalEventPump.sequencedEventClass.isInstance(nextEvent)) {
               return SunJDK14ConditionalEventPump.this.canPumpSequencedEvent(nextEvent);
            } else {
               return this.task.isCompleted() ? Boolean.FALSE : Boolean.TRUE;
            }
         }
      }

      private EventQueue getEventQueue() {
         return AccessController.doPrivileged(new SunJDK14ConditionalEventPump$2(this));
      }
   }

   public static class ThrowableHandler {
      public void handle(Throwable t) {
         System.err.println("[SunJDK14ConditionalEventPump] Exception occurred during event dispatching:");
         t.printStackTrace();
      }
   }
}
