package foxtrot.workers;

import foxtrot.AbstractWorkerThread;
import foxtrot.Task;

public class DefaultWorkerThread extends AbstractWorkerThread implements Runnable {
   private static final boolean debug = false;
   private Thread thread;
   private DefaultWorkerThread.Link current;

   public void start() {
      if (this.thread != null && this.thread.isAlive()) {
         this.stop();
      }

      this.thread = new Thread(this, this.getThreadName());
      this.thread.setDaemon(true);
      this.thread.start();
   }

   protected String getThreadName() {
      return "Foxtrot Default Worker Thread";
   }

   private void stop() {
      this.thread.interrupt();
   }

   public boolean isAlive() {
      return this.thread == null ? false : this.thread.isAlive();
   }

   public boolean isWorkerThread() {
      return Thread.currentThread() == this.thread;
   }

   public void postTask(Task t) {
      synchronized (this) {
         if (this.hasTasks()) {
            DefaultWorkerThread.Link item = this.current;

            while (item.next != null) {
               item = item.next;
            }

            item.next = new DefaultWorkerThread.Link(t);
         } else {
            this.current = new DefaultWorkerThread.Link(t);
            this.notifyAll();
         }
      }
   }

   protected Task takeTask() throws InterruptedException {
      synchronized (this) {
         while (!this.hasTasks()) {
            this.wait();
         }

         Task t = this.current.task;
         this.current = this.current.next;
         return t;
      }
   }

   private boolean hasTasks() {
      synchronized (this) {
         return this.current != null;
      }
   }

   protected boolean isThreadInterrupted() {
      return this.thread.isInterrupted();
   }

   public void run() {
      while (!this.isThreadInterrupted()) {
         try {
            Task t = this.takeTask();
            this.runTask(t);
         } catch (InterruptedException var2) {
            break;
         }
      }
   }

   private static class Link {
      private DefaultWorkerThread.Link next;
      private Task task;

      private Link(Task task) {
         this.task = task;
      }
   }
}
