package amp.powerboard.clientapi.command;

import amp.powerboard.clientapi.common.exception.CConnectionException;
import amp.powerboard.clientapi.common.exception.CDataFormatException;
import amp.powerboard.clientapi.common.exception.CInvalidUserException;
import amp.powerboard.clientapi.common.exception.CMaxUserExceededException;
import amp.powerboard.clientapi.common.exception.CNotLoggedException;
import amp.powerboard.clientapi.common.exception.CParamMissingException;
import amp.powerboard.clientapi.common.exception.CSecurityException;
import amp.powerboard.clientapi.common.exception.CUserAlreadyLoggedException;
import amp.powerboard.clientapi.event.CEventDispatcher;
import amp.powerboard.clientapi.event.CEventGenerator;
import amp.powerboard.clientapi.event.IDataEventHandler;
import amp.powerboard.clientapi.event.IDataListener;
import amp.powerboard.clientapi.event.IReportEventHandler;
import amp.powerboard.clientapi.event.IStatusEventHandler;
import amp.powerboard.clientapi.event.IStatusListener;
import amp.powerboard.clientapi.net.CMsgOutputStream;
import amp.powerboard.clientapi.net.CSecureSocket;
import amp.powerboard.clientapi.security.CCryptoKey;
import java.io.IOException;
import java.net.InetAddress;

public class CCommandHandler implements ISendInterface {
   private CEventDispatcher evtDispatcher;
   private CSecureSocket secSocket;
   public byte[] mbox_mp_recmd = null;
   public byte[] mbox_mp_con = null;
   public String mboxLoginName = null;
   private CCommandListenerThread cmdListenerThread;
   private String platform;
   private String subPlatform;

   public CCommandHandler() {
      this.evtDispatcher = new CEventDispatcher();
   }

   public CCommandHandler(String var1) {
      this.platform = var1;
      this.evtDispatcher = new CEventDispatcher();
   }

   public void sendCommand(CCommand var1) throws CParamMissingException, CConnectionException, CSecurityException, CNotLoggedException, CDataFormatException {
      if (var1 == null) {
         throw new CParamMissingException();
      } else {
         try {
            var1.fillStream(new CMsgOutputStream(this.secSocket.getOutputStream(), var1.getOpcode()));
         } catch (IOException var3) {
            throw new CConnectionException("Data cannot be send over the Network,Connection Failed");
         }
      }
   }

   public void login(
      int var1,
      byte var2,
      InetAddress var3,
      int var4,
      String var5,
      int var6,
      byte[] var7,
      String var8,
      CCryptoKey var9,
      CCryptoKey var10,
      int var11,
      boolean var12,
      String var13,
      String var14,
      String var15
   ) throws CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, IOException {
      if (var13.indexOf("_APP") != -1 && var2 == 3) {
         var5 = this.mboxLoginName;
      }

      this.secSocket = new CSecureSocket(var1, var2, var3, var4, var5, var6, var7, var8, var9, var10, var11, var13, var14, var15, this.mbox_mp_recmd, this);
      this.cmdListenerThread = new CCommandListenerThread(this.secSocket.getInputStream(), new CEventGenerator(this.evtDispatcher, var13, var14), var12);
      this.startThread();
   }

   public void login(InetAddress var1, int var2, int var3, int var4, int var5, byte var6, String var7, boolean var8) throws CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, IOException {
      this.secSocket = new CSecureSocket(var1, var2, var3, var4, var5, var6, var7);
      this.cmdListenerThread = new CCommandListenerThread(
         this.secSocket.getInputStream(), new CEventGenerator(this.evtDispatcher, var7, this.subPlatform), var8
      );
      this.startThread();
   }

   public byte[] fetchMbox_admin_cmd() {
      return this.secSocket.mbox_admin_cmd;
   }

   public byte[] fetchMbox_admin_recmd() {
      return this.secSocket.mbox_admin_recmd;
   }

   public byte[] fetchMbox_admin_con() {
      return this.secSocket.mbox_admin_con;
   }

   public byte[] fetchMbox_mp_con() {
      return this.mbox_mp_con;
   }

   public String fetchMbox_login_name() {
      return this.mboxLoginName;
   }

   private void startThread() {
      if (this.cmdListenerThread != null) {
         this.cmdListenerThread.start();
      }
   }

   public IDataEventHandler getIDataEventHandler() {
      return this.evtDispatcher;
   }

   public IStatusEventHandler getIStatusEventHandler() {
      return this.evtDispatcher;
   }

   public IReportEventHandler getIReportEventHandler() {
      return this.evtDispatcher;
   }

   public void save(boolean var1) throws CConnectionException, CSecurityException {
   }

   public void releaseResources() {
      try {
         if (this.cmdListenerThread != null) {
            this.cmdListenerThread.releaseResources();
            if (this.cmdListenerThread.isAlive()) {
               this.cmdListenerThread.stop();
            }

            this.cmdListenerThread = null;
         }
      } catch (Exception var3) {
      }

      try {
         if (this.secSocket != null) {
            this.secSocket.close();
            this.secSocket = null;
         }
      } catch (IOException var2) {
      }

      if (this.evtDispatcher != null) {
         this.evtDispatcher.releaseResources();
         this.evtDispatcher = null;
      }
   }

   public IDataListener[] getDataListeners() {
      return this.evtDispatcher.getDataListeners();
   }

   public IStatusListener[] getStatusListeners() {
      return this.evtDispatcher.getStatusListeners();
   }

   public void commit(boolean var1) throws CConnectionException, CSecurityException {
   }

   public InetAddress getLocalAddress() {
      InetAddress var1 = null;

      try {
         var1 = this.secSocket.getLocalAddress();
      } catch (Exception var3) {
         var1 = null;
      }

      return var1;
   }
}
