package amp.powerboard.clientapi.console;

import amp.powerboard.clientapi.command.CBreak;
import amp.powerboard.clientapi.command.CNewMaster;
import amp.powerboard.clientapi.command.ISendInterface;
import amp.powerboard.clientapi.common.exception.CConnectionException;
import amp.powerboard.clientapi.common.exception.CDataException;
import amp.powerboard.clientapi.common.exception.CInvalidUserException;
import amp.powerboard.clientapi.common.exception.CMaxUserExceededException;
import amp.powerboard.clientapi.common.exception.CNotLoggedException;
import amp.powerboard.clientapi.common.exception.CNotMasterException;
import amp.powerboard.clientapi.common.exception.CSecurityException;
import amp.powerboard.clientapi.common.exception.CUserAlreadyLoggedException;
import amp.powerboard.clientapi.event.CClientListEvent;
import amp.powerboard.clientapi.event.CDataEvent;
import amp.powerboard.clientapi.event.CReportEvent;
import amp.powerboard.clientapi.event.CStatusEvent;
import amp.powerboard.clientapi.event.IConsoleEventHandler;
import amp.powerboard.clientapi.event.IConsoleListener;
import amp.powerboard.clientapi.event.IDataEventHandler;
import amp.powerboard.clientapi.event.IDataListener;
import amp.powerboard.clientapi.event.IReportEventHandler;
import amp.powerboard.clientapi.event.IReportListener;
import amp.powerboard.clientapi.event.IStatusEventHandler;
import amp.powerboard.clientapi.event.IStatusListener;
import amp.powerboard.clientapi.net.CSecureSocket;
import amp.powerboard.clientapi.security.CCryptoKey;
import amp.powerboard.clientapi.security.CMd5;
import amp.powerboard.clientapi.security.CXorKey;
import amp.powerboard.clientapi.services.IBoxInterface;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Hashtable;
import java.util.Vector;

public class CConsoleHandler implements IDataListener, IReportListener, IStatusListener, IConsoleEventHandler, ISendConsole {
   private CSecureSocket secConnection;
   private OutputStream secureOut;
   private InputStream secureInput;
   private IDataEventHandler dataEventhandler;
   private IStatusEventHandler statusEventhandler;
   private IReportEventHandler reportEventhandler;
   private CConsoleListenerThread consoleListener;
   private ISendInterface sendInterface;
   private Hashtable boxData = null;
   private String userName;
   private boolean isMaster;
   private boolean waitingMasterAck;
   private boolean breakResponsestate;
   private Vector consoleListeners;
   private CXorKey inKey = new CXorKey(55);
   private CXorKey outKey = new CXorKey(55);

   public CConsoleHandler(
      ISendInterface var1,
      IStatusEventHandler var2,
      IReportEventHandler var3,
      IDataEventHandler var4,
      String var5,
      int var6,
      String var7,
      String var8,
      int var9,
      IBoxInterface var10,
      CCryptoKey var11,
      CCryptoKey var12,
      int var13,
      String var14,
      String var15,
      String var16,
      byte[] var17
   ) throws CInvalidUserException, CUserAlreadyLoggedException, CMaxUserExceededException, InternalError, IOException, UnknownHostException {
      this.sendInterface = var1;
      this.statusEventhandler = var2;
      this.reportEventhandler = var3;
      this.dataEventhandler = var4;
      this.boxData = var10.getBoxProperty();
      String var18 = (String)this.boxData.get("ChallengeId");
      int var19 = Integer.parseInt(var18);
      Object var20 = null;
      String var21 = (String)this.boxData.get("IPAddress");
      var20 = InetAddress.getByName(var21);
      String var22 = (String)this.boxData.get("Challenge");
      byte[] var23 = new byte[var22.length() / 2];

      for (int var24 = 0; var24 < var23.length; var24++) {
         var23[var24] = (byte)Integer.parseInt(var22.substring(var24 * 2, var24 * 2 + 2), 16);
      }

      byte[] var25 = new byte[var8.length()];
      var8.getBytes(0, var8.length(), var25, 0);
      CMd5 var26 = new CMd5();
      var26.update(var25);
      byte[] var27 = var26.digest();
      this.dataEventhandler.addDataListener(this);
      this.statusEventhandler.addStatusListener(this);
      this.dataEventhandler.addDataListener(this);
      this.statusEventhandler.addStatusListener(this);
      this.secConnection = new CSecureSocket(
         var6, (byte)2, (InetAddress)var20, var9, var7, var19, var23, var8, var11, var12, var13, var14, var15, var16, var17, null
      );
      this.consoleListener = new CConsoleListenerThread(this.secConnection.getInputStream(), this);
      this.secureOut = this.secConnection.getOutputStream();
      this.secureInput = this.secConnection.getInputStream();
      this.isMaster = false;
      this.waitingMasterAck = true;
      this.breakResponsestate = true;
      this.userName = var5;
      this.consoleListener.start();
      this.consoleListeners = new Vector();
   }

   public CConsoleHandler(
      ISendInterface var1,
      IStatusEventHandler var2,
      IReportEventHandler var3,
      IDataEventHandler var4,
      String var5,
      int var6,
      IBoxInterface var7,
      int var8,
      int var9,
      int var10,
      String var11,
      String var12
   ) throws CInvalidUserException, CUserAlreadyLoggedException, CMaxUserExceededException, InternalError, IOException, UnknownHostException {
      this.sendInterface = var1;
      this.statusEventhandler = var2;
      this.reportEventhandler = var3;
      this.dataEventhandler = var4;
      this.boxData = var7.getBoxProperty();
      Object var13 = null;
      var13 = InetAddress.getLocalHost();
      this.dataEventhandler.addDataListener(this);
      this.statusEventhandler.addStatusListener(this);
      this.dataEventhandler.addDataListener(this);
      this.statusEventhandler.addStatusListener(this);
      this.secConnection = new CSecureSocket((InetAddress)var13, var6, var8, var9, var10, (byte)2, var11);
      this.consoleListener = new CConsoleListenerThread(this.secConnection.getInputStream(), this);
      this.secureOut = this.secConnection.getOutputStream();
      this.secureInput = this.secConnection.getInputStream();
      this.isMaster = true;
      this.waitingMasterAck = false;
      this.breakResponsestate = true;
      this.userName = var5;
      this.consoleListener.start();
      this.consoleListeners = new Vector();
   }

   private void secureWrite(byte[] var1, int var2, int var3) throws IOException {
      int var4 = 0;
      byte[] var6 = new byte[(var3 - var2) * 2 + 2];

      for (int var5 = var2; var5 < var3; var5++) {
         if (var1[var5] == -1) {
            var6[var4++] = -1;
         }

         var6[var4++] = var1[var5];
      }

      while (!this.breakResponsestate) {
         try {
            Thread.sleep(100L);
         } catch (InterruptedException var8) {
         }
      }

      this.secureOut.write(var6, 0, var4);
      this.secureOut.flush();
   }

   public synchronized void addConsoleListener(IConsoleListener var1) {
      if (this.consoleListeners.indexOf(var1) == -1) {
         this.consoleListeners.addElement(var1);
      }
   }

   public synchronized void removeConsoleListener(IConsoleListener var1) {
      if (this.consoleListeners.indexOf(var1) != -1) {
         this.consoleListeners.removeElement(var1);
      }
   }

   public void commandDataArrived(CDataEvent var1) {
      if (this.waitingMasterAck && var1.getOpcode() == 1503) {
         CClientListEvent var4 = (CClientListEvent)var1;
         int var2 = var4.getMasterIndex();
         String[] var3 = var4.getListOfClients();
         if (var2 == 0) {
            this.isMaster = false;
         } else if (var3[var2 - 1].equals(this.userName)) {
            this.isMaster = true;
         } else {
            this.isMaster = false;
         }
      }
   }

   public void commandStatusArrived(CStatusEvent var1) {
      if (var1.getOpcode() == 3000) {
         this.breakResponsestate = true;
      }
   }

   public void commandReportArrived(CReportEvent var1) {
   }

   public void send(byte var1) throws CNotMasterException, IOException {
      if (this.isMaster) {
         this.secureOut = this.secConnection.getOutputStream();
         byte[] var2 = new byte[]{var1};
         this.secureWrite(var2, 0, 1);
      } else {
         throw new CNotMasterException();
      }
   }

   public void send(byte[] var1) throws CNotMasterException, IOException {
      if (this.isMaster) {
         this.secureWrite(var1, 0, var1.length);
      } else {
         throw new CNotMasterException();
      }
   }

   public void send(String var1) throws CNotMasterException, IOException {
      if (this.isMaster) {
         this.secureOut = this.secConnection.getOutputStream();
         byte[] var2 = var1.getBytes();
         this.secureWrite(var2, 0, var2.length);
      } else {
         throw new CNotMasterException();
      }
   }

   public synchronized void fireBytesArrived(byte[] var1, int var2) {
      int var3 = this.consoleListeners.size();

      for (int var4 = 0; var4 < var3; var4++) {
         IConsoleListener var5 = (IConsoleListener)this.consoleListeners.elementAt(var4);
         var5.bytesArrived(var1, var2);
      }
   }

   public void becomeMaster() throws CSecurityException, CNotLoggedException, CConnectionException {
      if (!this.isMaster) {
         CNewMaster var1 = new CNewMaster();

         try {
            var1.setProperty("LOCK_REQUIRED", false);
         } catch (CDataException var4) {
         }

         try {
            this.sendInterface.sendCommand(var1);
         } catch (CDataException var3) {
         }

         this.waitingMasterAck = true;
      }
   }

   public void sendBreak() throws CSecurityException, CNotLoggedException, CConnectionException {
      if (this.isMaster) {
         CBreak var1 = new CBreak();

         try {
            var1.setProperty("LOCK_REQUIRED", false);
         } catch (Exception var5) {
         }

         try {
            this.sendInterface.sendCommand(var1);
         } catch (Exception var4) {
         }

         this.breakResponsestate = false;
      } else {
         try {
            this.becomeMaster();
         } catch (Exception var3) {
         }
      }
   }

   public void closeConsole() throws IOException {
      if (this.dataEventhandler != null) {
         this.dataEventhandler.removeDataListener(this);
      }

      if (this.secureOut != null) {
         this.secureOut.close();
         this.secureOut = null;
      }

      if (this.secureInput != null) {
         this.secureInput.close();
         this.secureInput = null;
      }

      if (this.secConnection != null) {
         this.secConnection.close();
         this.secConnection = null;
      }

      if (this.consoleListener != null) {
         this.consoleListener.releaseResources();
         this.consoleListener = null;
      }
   }

   public void setPaused(boolean var1) {
      this.consoleListener.setPaused(var1);
   }
}
