package amp.powerboard.clientapi.services;

import amp.powerboard.clientapi.command.CCommand;
import amp.powerboard.clientapi.command.CCommandHandler;
import amp.powerboard.clientapi.command.CEcho;
import amp.powerboard.clientapi.command.CGetConfigLock;
import amp.powerboard.clientapi.command.CInitialise;
import amp.powerboard.clientapi.command.CLoginInfo;
import amp.powerboard.clientapi.command.CReleaseConfigLock;
import amp.powerboard.clientapi.command.CReset;
import amp.powerboard.clientapi.command.CSetNetwork;
import amp.powerboard.clientapi.command.CSetUser;
import amp.powerboard.clientapi.command.ISendInterface;
import amp.powerboard.clientapi.common.CConst;
import amp.powerboard.clientapi.common.exception.CBoxUnInitialisedException;
import amp.powerboard.clientapi.common.exception.CConfigNotSavedException;
import amp.powerboard.clientapi.common.exception.CConnectionException;
import amp.powerboard.clientapi.common.exception.CDataException;
import amp.powerboard.clientapi.common.exception.CDataFormatException;
import amp.powerboard.clientapi.common.exception.CInvalidUserException;
import amp.powerboard.clientapi.common.exception.CMaxUserExceededException;
import amp.powerboard.clientapi.common.exception.CNotLoggedException;
import amp.powerboard.clientapi.common.exception.CParamMissingException;
import amp.powerboard.clientapi.common.exception.CRoleMismatchException;
import amp.powerboard.clientapi.common.exception.CSecurityException;
import amp.powerboard.clientapi.common.exception.CUserAlreadyLoggedException;
import amp.powerboard.clientapi.event.CClientListEvent;
import amp.powerboard.clientapi.event.CConfigLockEvent;
import amp.powerboard.clientapi.event.CDataEvent;
import amp.powerboard.clientapi.event.CFatalErrorEvent;
import amp.powerboard.clientapi.event.CGetCertStateEvent;
import amp.powerboard.clientapi.event.CGetCertificateEvent;
import amp.powerboard.clientapi.event.CGetDataComAndSystemEvent;
import amp.powerboard.clientapi.event.CGetHWMonitoringEvent;
import amp.powerboard.clientapi.event.CGetIPACLListEvent;
import amp.powerboard.clientapi.event.CGetModemStatusEvent;
import amp.powerboard.clientapi.event.CGetNetworkEvent;
import amp.powerboard.clientapi.event.CGetPingMonitoringEvent;
import amp.powerboard.clientapi.event.CGetRadClientEvent;
import amp.powerboard.clientapi.event.CGetSMTPServerEvent;
import amp.powerboard.clientapi.event.CGetSNMPAgentEvent;
import amp.powerboard.clientapi.event.CGetSubscriptionsEvent;
import amp.powerboard.clientapi.event.CGetTimeEvent;
import amp.powerboard.clientapi.event.CGetUserEvent;
import amp.powerboard.clientapi.event.CGetUserListEvent;
import amp.powerboard.clientapi.event.CInternalCertStateEvent;
import amp.powerboard.clientapi.event.CInternalCertificateEvent;
import amp.powerboard.clientapi.event.CInternalDataComAndSystemEvent;
import amp.powerboard.clientapi.event.CInternalEvent;
import amp.powerboard.clientapi.event.CInternalHWMonitoringEvent;
import amp.powerboard.clientapi.event.CInternalIPACLListEvent;
import amp.powerboard.clientapi.event.CInternalModemEvent;
import amp.powerboard.clientapi.event.CInternalNetworkEvent;
import amp.powerboard.clientapi.event.CInternalPingMonitoringEvent;
import amp.powerboard.clientapi.event.CInternalRadClientEvent;
import amp.powerboard.clientapi.event.CInternalResetEvent;
import amp.powerboard.clientapi.event.CInternalSMTPServerEvent;
import amp.powerboard.clientapi.event.CInternalSNMPAgentEvent;
import amp.powerboard.clientapi.event.CInternalStatusEvent;
import amp.powerboard.clientapi.event.CInternalSubscriptionEvent;
import amp.powerboard.clientapi.event.CInternalTimeEvent;
import amp.powerboard.clientapi.event.CInternalUserEvent;
import amp.powerboard.clientapi.event.CInternalUserInfoEvent;
import amp.powerboard.clientapi.event.CInternalUserListEvent;
import amp.powerboard.clientapi.event.CLoginInfoEvent;
import amp.powerboard.clientapi.event.CLogoutEvent;
import amp.powerboard.clientapi.event.CResetEvent;
import amp.powerboard.clientapi.event.CStatusEvent;
import amp.powerboard.clientapi.event.CUpgradeReportEvent;
import amp.powerboard.clientapi.event.CUserInfoEvent;
import amp.powerboard.clientapi.event.IDataEventHandler;
import amp.powerboard.clientapi.event.IDataListener;
import amp.powerboard.clientapi.event.IReportEventHandler;
import amp.powerboard.clientapi.event.IStatusEventHandler;
import amp.powerboard.clientapi.event.IStatusListener;
import amp.powerboard.clientapi.security.CCryptoKey;
import amp.powerboard.clientapi.security.CMd5;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

public class CCommandService implements ISendInterface, IDataListener, IStatusListener {
   IBoxInterface bIf = null;
   public CCommandHandler cmdHandler = null;
   private Hashtable portNumberToNameMap = null;
   String pform = null;
   String subPlatform = null;
   private CValidator userRoleValidator = null;
   private int userRole = -1;
   private Vector configCommandVector = null;
   private InetAddress iPAddress = null;
   private InetAddress localIPAddress = null;
   private String userName = null;
   private String loginName = null;
   private String userPassword = null;
   private String challengeParameter = null;
   private byte[] hashedPassword = null;
   private byte[] challenge = null;
   private String[] clientList = null;
   private int boxState = 0;
   private int clientId = 0;
   private boolean configIsLocked = false;
   private boolean isLogged = false;
   private boolean lockIsAsked = false;
   private boolean upgradeCalled = false;
   private boolean configIsModified = false;
   private boolean connectionIsActive = true;
   private boolean resetCalled = false;
   private boolean commitCalled = false;
   private int releaseLockParam = 0;
   private int reqOperation = 0;
   private int lockCount = 0;
   private Hashtable boxProperty = null;
   private Hashtable initParameters = null;
   private CInternalEvent internEvent = null;
   private String lockerName = null;

   public CCommandService(IBoxInterface var1) {
      this.bIf = var1;
      this.cmdHandler = new CCommandHandler(this.pform);
      this.getIDataEventHandler().addDataListener(this);
      this.getIStatusEventHandler().addStatusListener(this);
      this.configCommandVector = new Vector(6, 6);
   }

   public void sendCommand(CCommand var1) throws CParamMissingException, CSecurityException, CConnectionException, CNotLoggedException, CDataFormatException {
      if (!this.isLogged) {
         throw new CNotLoggedException();
      } else if (this.upgradeCalled) {
         throw new CSecurityException("Upgrading the Box,Try after Upgrading Finished");
      } else if (this.cmdHandler == null) {
         throw new CSecurityException("Connection to Box Closed,Try Again by Reloading");
      } else if (!this.hasRights(var1) && !this.pform.equals("RX_SHIM")) {
         throw new CRoleMismatchException();
      } else {
         if (!var1.isLockRequired()) {
            this.cmdHandler.sendCommand(var1);
         } else if (this.configIsLocked) {
            if (this.configCommandVector.indexOf(var1) != -1) {
               this.configCommandVector.removeElement(var1);
            }

            this.cmdHandler.sendCommand(var1);
         } else if (this.lockIsAsked) {
            if (this.configCommandVector.indexOf(var1) == -1) {
               this.configCommandVector.addElement(var1);
            }
         } else {
            if (this.configCommandVector.indexOf(var1) == -1) {
               this.configCommandVector.addElement(var1);
            }

            this.askForConfigLock();
            this.lockIsAsked = true;
         }
      }
   }

   public void login(
      int var1,
      String var2,
      String var3,
      int var4,
      IBoxInterface var5,
      boolean var6,
      CCryptoKey var7,
      CCryptoKey var8,
      int var9,
      boolean var10,
      String var11,
      String var12,
      String var13
   ) throws CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, IOException, CBoxUnInitialisedException {
      this.boxProperty = var5.getBoxProperty();
      this.boxState = Integer.parseInt((String)this.boxProperty.get("BoxState"));
      this.setBoxDetails(var2, var3);
      if (this.boxState == 1) {
         throw new CBoxUnInitialisedException();
      } else {
         if (var6) {
            this.cmdHandler
               .login(var1, (byte)3, this.iPAddress, var4, this.loginName, this.clientId, this.challenge, var3, var7, var8, var9, var10, var11, var12, var13);
         } else {
            this.cmdHandler
               .login(var1, (byte)1, this.iPAddress, var4, this.loginName, this.clientId, this.challenge, var3, var7, var8, var9, var10, var11, var12, var13);
         }

         if (var11.indexOf("_APP") != -1) {
            this.loginName = this.fetchMbox_LoginName();
         }

         this.isLogged = true;
         this.getLoginInfo();
         this.localIPAddress = this.cmdHandler.getLocalAddress();
      }
   }

   public void login(IBoxInterface var1, int var2, boolean var3, String var4, int var5, int var6, int var7, boolean var8) throws CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, IOException, CBoxUnInitialisedException {
      this.boxProperty = var1.getBoxProperty();
      this.iPAddress = InetAddress.getLocalHost();
      this.pform = var4;
      this.cmdHandler.login(this.iPAddress, var2, var5, var6, var7, (byte)1, var4, var8);
      this.isLogged = true;
      this.localIPAddress = this.cmdHandler.getLocalAddress();
   }

   private void setBoxDetails(String var1, String var2) throws UnknownHostException {
      this.loginName = var1;
      this.userPassword = var2;
      String var3 = (String)this.boxProperty.get("ChallengeId");
      this.clientId = Integer.parseInt(var3);
      String var4 = (String)this.boxProperty.get("IPAddress");
      this.iPAddress = InetAddress.getByName(var4);
      this.challengeParameter = (String)this.boxProperty.get("Challenge");
      this.challenge = new byte[this.challengeParameter.length() / 2];

      for (int var5 = 0; var5 < this.challenge.length; var5++) {
         this.challenge[var5] = (byte)Integer.parseInt(this.challengeParameter.substring(var5 * 2, var5 * 2 + 2), 16);
      }

      byte[] var6 = new byte[var2.length()];
      var2.getBytes(0, var2.length(), var6, 0);
      CMd5 var7 = new CMd5();
      var7.update(var6);
      this.hashedPassword = var7.digest();
   }

   public void commandDataArrived(CDataEvent var1) {
      int var2 = var1.getOpcode();
      switch (var2) {
         case 2:
         case 17:
            this.configIsModified = false;
            this.configIsLocked = false;
            this.lockCount = 0;
            this.lockIsAsked = false;
            break;
         case 13:
            CLoginInfoEvent var6 = (CLoginInfoEvent)var1;
            this.userName = var6.getUserName();
            this.portNumberToNameMap = var6.getPortNumberToNameMap();
            if (var6.getUserRight() == 1) {
               this.userRoleValidator = new CAdminValidator();
               this.userRole = 1;
            } else if (var6.getUserRight() == 0) {
               this.userRoleValidator = new COperatorValidator();
               this.userRole = 0;
            } else {
               this.userRoleValidator = new CObserverValidator();
               this.userRole = 2;
            }

            this.userRoleValidator.setUser(var6.getUserName());
            break;
         case 14:
            CUpgradeReportEvent var16 = (CUpgradeReportEvent)var1;
            int var4 = var16.getpercentage();
            if (var4 > 100) {
               this.upgradeCalled = false;
            }
            break;
         case 15:
            CConfigLockEvent var7 = (CConfigLockEvent)var1;
            this.lockIsAsked = false;
            if (var7.getmessageStatus() == 14) {
               this.configIsLocked = false;
               this.lockCount = 0;
               this.lockerName = var7.getLockerName();
               if (this.resetCalled) {
                  this.resetCalled = false;
                  CResetEvent var17 = new CResetEvent(
                     "You are going to Reboot without saving the Configuration;The config was modified by  " + this.lockerName,
                     this.lockerName,
                     this.configIsLocked,
                     this.clientList,
                     14
                  );
                  this.fireDataEvent(var17);
               } else {
                  Enumeration var18 = this.configCommandVector.elements();

                  while (var18.hasMoreElements()) {
                     CCommand var9 = (CCommand)var18.nextElement();

                     try {
                        if (var9.isFetchCommand()) {
                           this.cmdHandler.sendCommand(var9);
                        } else {
                           CStatusEvent var10 = new CStatusEvent(var9.getOpcode(), 17, 0, this.configIsLocked, this.lockerName, 0);
                           this.fireStatusEvent(var10);
                        }

                        this.configCommandVector.removeElement(var9);
                     } catch (Exception var14) {
                        var14.printStackTrace();
                     }
                  }
               }
            } else {
               this.configIsLocked = true;
               this.lockerName = this.userName;
               if (this.resetCalled) {
                  this.resetCalled = false;
                  CResetEvent var19 = new CResetEvent("The following users will be disconnected", this.lockerName, this.configIsLocked, this.clientList, 223);
                  this.fireDataEvent(var19);
               } else if (this.boxState == 1) {
                  try {
                     CSetUser var20 = new CSetUser(this.pform);
                     var20.setProperty("USER_ID", 0);
                     var20.setProperty("LOCK_REQUIRED", true);
                     var20.setProperty("LOGIN", (String)this.initParameters.get(CConst.BOX_INIT_LOGIN));
                     String var22 = (String)this.initParameters.get(CConst.BOX_INIT_CAPABILITY);
                     int var24 = Integer.parseInt(var22.trim());
                     var20.setProperty("CAPABILITY", var24);
                     var20.setProperty("USER_NAME", (String)this.initParameters.get(CConst.BOX_INIT_USER_NAME));
                     var20.setProperty("USER_INFO", (String)this.initParameters.get(CConst.BOX_INIT_USER_INFO));
                     var20.setProperty("PASSWORD", (String)this.initParameters.get(CConst.BOX_INIT_PASSWORD));
                     if (!this.pform.equals("DC") && !this.pform.equals("HP")) {
                        var20.setProperty("NUMPORTS", (Integer)this.initParameters.get(CConst.BOX_INIT_NUMPORTS));
                        var20.setProperty("PORTS", (int[])this.initParameters.get(CConst.BOX_INIT_PORTS));
                     }

                     var20.setProperty("LOCK_REQUIRED", false);
                     this.sendCommand(var20);
                  } catch (Exception var13) {
                  }
               } else {
                  Enumeration var21 = this.configCommandVector.elements();

                  while (var21.hasMoreElements()) {
                     CCommand var23 = (CCommand)var21.nextElement();

                     try {
                        this.sendCommand(var23);
                        this.configCommandVector.removeElement(var23);
                     } catch (Exception var12) {
                        var12.printStackTrace();
                     }
                  }
               }
            }
            break;
         case 222:
            CInternalResetEvent var8 = (CInternalResetEvent)var1;
            if (var8.getResetStatus() == 0) {
               this.resetCalled = true;
            }
         case 22:
         case 56:
         case 99:
         case 111:
         case 122:
         case 255:
         case 277:
         case 299:
         case 366:
         case 388:
         case 400:
         case 444:
         case 455:
         case 477:
         case 499:
         case 600:
            this.createAndFireEvents(var1);
            if (this.resetCalled) {
               try {
                  this.releaseResources();
               } catch (Exception var11) {
               }
            }
            break;
         case 1503:
            CClientListEvent var5 = (CClientListEvent)var1;
            this.clientList = var5.getListOfClients();
            break;
         case 4000:
            this.internEvent = (CInternalEvent)var1;
            this.connectionIsActive = false;

            try {
               CEcho var3 = new CEcho();
               var3.setProperty("REQUEST", 18);
               var3.setProperty("LOCK_REQUIRED", false);
               this.sendCommand(var3);
            } catch (Exception var15) {
               var15.printStackTrace();
            }
      }
   }

   public void commandStatusArrived(CStatusEvent var1) {
      CStatusEvent var4;
      CInternalStatusEvent var2 = (CInternalStatusEvent)var1;
      int var3 = var2.getRealOpcode();
      var4 = new CStatusEvent(var3, var2.getStatus(), var2.getReqOperation(), this.configIsLocked, this.lockerName, 0);
      label285:
      switch (var3) {
         case 3:
            int var17 = var1.getStatus();
            switch (var17) {
               case 0:
                  this.upgradeCalled = true;
                  break label285;
               case 1:
               case 2:
               case 3:
               case 4:
               case 5:
               case 6:
               case 7:
               case 8:
               case 9:
               case 10:
               case 11:
               case 12:
               case 13:
               default:
                  this.upgradeCalled = false;
                  break label285;
            }
         case 4:
            int var55 = var1.getStatus();

            try {
               if (var55 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var46) {
            }
            break;
         case 8:
            int var54 = var1.getStatus();
            switch (var54) {
               case 0:
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     try {
                        CSetNetwork var8 = new CSetNetwork();
                        var8.setProperty("HOST_NAME", (String)this.initParameters.get(CConst.BOX_INIT_HOST_NAME));
                        var8.setProperty("IP_ADDRESS", (String)this.initParameters.get(CConst.BOX_INIT_IP_ADDRESS));
                        var8.setProperty("LOCK_REQUIRED", true);
                        var8.setProperty("SUBNET", (String)this.initParameters.get(CConst.BOX_INIT_SUBNET));
                        var8.setProperty("GATEWAY", (String)this.initParameters.get(CConst.BOX_INIT_GATEWAY));
                        Integer var56 = (Integer)this.initParameters.get(CConst.BOX_INIT_PORT_ADDRESS);
                        var8.setProperty("PORT_ADDRESS", var56);
                        var8.setProperty("TERMINAL_TYPE", (String)this.initParameters.get(CConst.BOX_INIT_TERMINAL_TYPE));
                        if (!this.pform.equals("HP")) {
                           Integer var57 = (Integer)this.initParameters.get(CConst.BOX_INIT_USE_SSL);
                           int var7 = var57;
                           var8.setProperty("USE_SSL", var57);
                           if (var7 == 1) {
                              byte[] var58 = this.bIf.getPrime1();
                              var8.setProperty("PRIME1", var58);
                              byte[] var60 = this.bIf.getPrime2();
                              var8.setProperty("PRIME2", var60);
                           } else {
                              byte[] var59 = new byte[32];
                              var8.setProperty("PRIME1", var59);
                              byte[] var61 = new byte[32];
                              var8.setProperty("PRIME2", var61);
                           }
                        }

                        if (this.pform.equals("DC") || this.pform.equals("HP")) {
                           var8.setProperty("DEVICE_NAME", (String)this.initParameters.get(CConst.BOX_INIT_DEVICE_NAME));
                        }

                        this.sendCommand(var8);
                     } catch (Exception var50) {
                     }
                  }
               case 1:
               case 2:
               case 3:
               case 4:
               case 5:
               case 6:
               case 7:
               case 8:
               case 9:
               case 10:
               case 11:
               case 12:
               case 13:
               case 14:
               case 15:
               case 16:
               case 17:
               default:
                  break label285;
            }
         case 10:
            int var18 = var1.getStatus();
            switch (var18) {
               case 0:
                  this.configIsModified = true;
               case 8:
               default:
                  break label285;
            }
         case 11:
            int var16 = var1.getStatus();

            try {
               if (var16 == 0) {
                  this.configIsModified = true;
               }
            } catch (Exception var38) {
            }
            break;
         case 16:
            int var5 = var1.getStatus();
            if (var5 == 0) {
               this.lockIsAsked = false;
               switch (this.releaseLockParam) {
                  case 1:
                     this.configIsLocked = false;
                     this.configIsModified = false;
                     this.lockCount = 0;
                     break;
                  case 2:
                     this.configIsModified = false;
                     this.configIsLocked = false;
                     this.lockCount = 0;
                     this.lockerName = null;
                     CStatusEvent var51;
                     if (this.commitCalled) {
                        var51 = new CStatusEvent(51, 0, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                     } else {
                        var51 = new CStatusEvent(5, 0, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                     }

                     var4 = var51;
                     this.commitCalled = false;
                     this.releaseLockParam = 0;
                     break;
                  case 3:
                     try {
                        this.releaseConfigLock(4);
                     } catch (Exception var49) {
                     }

                     this.commitCalled = false;
                     break;
                  case 4:
                     this.configIsModified = false;
                     this.configIsLocked = false;
                     this.lockCount = 0;
                     if (this.boxState == 1) {
                        try {
                           this.releaseResources();
                        } catch (Exception var48) {
                           var48.printStackTrace();
                        }
                     } else {
                        this.lockerName = null;
                        CStatusEvent var6;
                        if (this.commitCalled) {
                           var6 = new CStatusEvent(51, 0, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                        } else {
                           var6 = new CStatusEvent(5, 0, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                        }

                        var4 = var6;
                        this.releaseLockParam = 0;
                     }

                     this.commitCalled = false;
               }
            } else if (var5 == 14) {
               this.configIsLocked = false;
               this.lockCount = 0;
               switch (this.releaseLockParam) {
                  case 1:
                  case 2:
                  case 3:
                  case 4:
                     CStatusEvent var52;
                     if (this.commitCalled) {
                        var52 = new CStatusEvent(51, 14, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                     } else {
                        var52 = new CStatusEvent(5, 14, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                     }

                     var4 = var52;
                     this.commitCalled = false;
                  default:
                     this.releaseLockParam = 0;
               }
            } else if (var5 == 15 && this.releaseLockParam == 3) {
               try {
                  CStatusEvent var53;
                  if (this.commitCalled) {
                     var53 = new CStatusEvent(51, 0, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                  } else {
                     var53 = new CStatusEvent(5, 15, this.reqOperation, this.configIsLocked, this.lockerName, this.releaseLockParam);
                  }

                  var4 = var53;
               } catch (Exception var47) {
               }
            }

            this.commitCalled = false;
            break;
         case 21:
            int var15 = var1.getStatus();

            try {
               if (var15 == 0) {
               }
            } catch (Exception var39) {
            }
            break;
         case 23:
            int var11 = var1.getStatus();

            try {
               if (var11 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var43) {
            }
            break;
         case 24:
            int var12 = var1.getStatus();

            try {
               if (var12 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var42) {
            }
            break;
         case 26:
            int var9 = var1.getStatus();

            try {
               if (var9 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var45) {
            }
            break;
         case 28:
            int var10 = var1.getStatus();

            try {
               if (var10 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var44) {
            }
            break;
         case 30:
            int var19 = var1.getStatus();

            try {
               if (var19 == 0) {
               }
            } catch (Exception var37) {
            }
            break;
         case 31:
            int var20 = var1.getStatus();

            try {
               if (var20 == 0) {
               }
            } catch (Exception var36) {
            }
            break;
         case 32:
            int var21 = var1.getStatus();

            try {
               if (var21 == 0) {
               }
            } catch (Exception var35) {
            }
            break;
         case 33:
            int var22 = var1.getStatus();

            try {
               if (var22 == 0) {
               }
            } catch (Exception var34) {
            }
            break;
         case 34:
            int var25 = var1.getStatus();

            try {
               if (var25 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var31) {
            }
            break;
         case 35:
            int var26 = var1.getStatus();

            try {
               if (var26 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var30) {
            }
            break;
         case 37:
            int var24 = var1.getStatus();

            try {
               if (var24 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var32) {
            }
            break;
         case 39:
            int var23 = var1.getStatus();

            try {
               if (var23 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var33) {
            }
            break;
         case 43:
         case 46:
         case 48:
         case 50:
         case 61:
         case 62:
            int var27 = var1.getStatus();

            try {
               if (var27 == 0) {
                  this.configIsModified = true;
                  if (this.boxState == 1) {
                     this.releaseConfigLock(4);
                     this.releaseLockParam = 4;
                  }
               }
            } catch (Exception var29) {
            }
            break;
         case 1505:
            if (var1.getStatus() != 18) {
               this.connectionIsActive = true;
            } else {
               CFatalErrorEvent var28 = new CFatalErrorEvent(this.internEvent.getData());
               this.fireDataEvent(var28);
            }
            break;
         case 4500:
            int var13 = var1.getStatus();

            try {
               if (var13 == 0) {
               }
            } catch (Exception var41) {
            }
            break;
         case 4502:
            int var14 = var1.getStatus();

            try {
               if (var14 == 0) {
               }
            } catch (Exception var40) {
            }
      }

      this.fireStatusEvent(var4);
   }

   public IDataEventHandler getIDataEventHandler() {
      return this.cmdHandler.getIDataEventHandler();
   }

   public IStatusEventHandler getIStatusEventHandler() {
      return this.cmdHandler.getIStatusEventHandler();
   }

   public IReportEventHandler getIReportEventHandler() {
      return this.cmdHandler.getIReportEventHandler();
   }

   private boolean hasRights(CCommand var1) {
      return this.userRoleValidator == null ? false : this.userRoleValidator.isOperationValid(var1);
   }

   private void askForConfigLock() {
      CGetConfigLock var1 = new CGetConfigLock();

      try {
         var1.setProperty("LOCK_REQUIRED", false);
      } catch (Exception var4) {
      }

      try {
         this.cmdHandler.sendCommand(var1);
      } catch (Exception var3) {
         this.fireDataEvent(new CFatalErrorEvent("Command cannot be send to the Box"));
      }
   }

   private void releaseConfigLock(int var1) {
      CReleaseConfigLock var2 = new CReleaseConfigLock();
      this.releaseLockParam = var1;
      if (this.commitCalled) {
         switch (this.releaseLockParam) {
            case 1:
            case 2:
               this.reqOperation = 24;
               break;
            case 3:
            case 4:
               this.reqOperation = 23;
         }
      } else {
         switch (this.releaseLockParam) {
            case 1:
            case 2:
               this.reqOperation = 22;
               break;
            case 3:
            case 4:
               this.reqOperation = 21;
         }
      }

      try {
         var2.setProperty("SAVE_STATUS", this.releaseLockParam);
         var2.setProperty("LOCK_REQUIRED", false);
      } catch (Exception var5) {
      }

      try {
         this.cmdHandler.sendCommand(var2);
      } catch (Exception var4) {
         this.fireDataEvent(new CFatalErrorEvent("Lock cannot be Released"));
      }
   }

   public void releaseResources() throws CConfigNotSavedException {
      if (this.configIsModified) {
         throw new CConfigNotSavedException();
      } else {
         this.fireDataEvent(new CLogoutEvent("You have been logged off."));
         if (this.configCommandVector != null) {
            this.configCommandVector.removeAllElements();
            this.configCommandVector = null;
         }

         if (this.cmdHandler != null) {
            this.cmdHandler.releaseResources();
         }

         this.cmdHandler = null;
         this.setToNull();
      }
   }

   private void getLoginInfo() {
      CLoginInfo var1 = new CLoginInfo();

      try {
         var1.setProperty("USER_NAME", this.loginName);
         var1.setProperty("LOCK_REQUIRED", false);
      } catch (CDataException var4) {
      }

      try {
         this.cmdHandler.sendCommand(var1);
      } catch (Exception var3) {
         this.fireDataEvent(new CFatalErrorEvent("Command cannot be send to the Box"));
      }
   }

   public void save(boolean var1) throws CSecurityException {
      if (var1) {
         if (this.configIsModified) {
            this.releaseConfigLock(3);
         } else {
            if (!this.configIsLocked) {
               throw new CSecurityException(20, "Config Lock is not Obtained.");
            }

            this.releaseConfigLock(1);
         }
      } else if (this.configIsModified) {
         this.releaseConfigLock(2);
      } else {
         this.releaseConfigLock(1);
      }
   }

   public void commit(boolean var1) throws CSecurityException {
      this.commitCalled = true;
      if (var1) {
         if (this.configIsModified) {
            this.releaseConfigLock(4);
         } else {
            if (!this.configIsLocked) {
               throw new CSecurityException(20, "Config Lock is not Obtained.");
            }

            this.releaseConfigLock(1);
         }
      } else if (this.configIsModified) {
         this.releaseConfigLock(2);
      } else {
         this.releaseConfigLock(1);
      }
   }

   public int getUserRole() {
      return this.userRole;
   }

   public String getUserName() {
      return this.userName;
   }

   public void initialiseBox(Hashtable var1, IBoxInterface var2, CCryptoKey var3, CCryptoKey var4, int var5, boolean var6, String var7, String var8) throws UnknownHostException, CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, IOException, CSecurityException, CNotLoggedException {
      this.pform = var7;
      byte var9 = 0;
      this.boxProperty = var2.getBoxProperty();
      this.boxState = Integer.parseInt((String)this.boxProperty.get("BoxState"));
      this.initParameters = var1;
      this.setBoxDetails("prospero", "prospero");
      this.cmdHandler
         .login(
            var9,
            (byte)1,
            this.iPAddress,
            23,
            this.loginName,
            this.clientId,
            this.challenge,
            this.userPassword,
            var3,
            var4,
            var5,
            var6,
            this.pform,
            this.subPlatform,
            var8
         );
      this.userRoleValidator = new CAdminValidator();
      this.userRole = 1;
      this.isLogged = true;
      CInitialise var10 = new CInitialise();

      try {
         var10.setProperty("DATA_LENGTH", 8);
         var10.setProperty("LOGIN_NAME", "prospero");
      } catch (Exception var15) {
      }

      try {
         this.sendCommand(var10);
      } catch (CConnectionException var13) {
      } catch (CDataException var14) {
      }
   }

   public void incLockRequestCount() {
      this.lockCount++;
   }

   public void decLockRequestCount() {
      this.lockCount--;
      if (this.lockCount < 1 && this.configIsLocked && !this.configIsModified) {
         try {
            this.save(false);
         } catch (Exception var2) {
            var2.printStackTrace();
         }
      }

      if (this.lockCount < 0) {
         this.lockCount = 0;
      }
   }

   private void createAndFireEvents(CDataEvent var1) {
      int var2 = var1.getOpcode();
      Object var3 = null;
      switch (var2) {
         case 22:
            CInternalUserListEvent var6 = (CInternalUserListEvent)var1;
            CGetUserListEvent var7 = new CGetUserListEvent(this.configIsLocked, this.lockerName);
            var7.setUserListData(var6);
            var3 = var7;
            break;
         case 56:
            CInternalNetworkEvent var12 = (CInternalNetworkEvent)var1;
            CGetNetworkEvent var13 = new CGetNetworkEvent(this.configIsLocked, this.lockerName);
            var13.setNeworkData(var12);
            var3 = var13;
            break;
         case 99:
            CInternalUserEvent var8 = (CInternalUserEvent)var1;
            CGetUserEvent var9 = new CGetUserEvent(this.configIsLocked, this.lockerName);
            var9.setUserData(var8);
            var3 = var9;
            break;
         case 111:
            CInternalUserInfoEvent var4 = (CInternalUserInfoEvent)var1;
            CUserInfoEvent var5 = new CUserInfoEvent(this.configIsLocked, this.lockerName);
            var5.setUserInfoData(var4);
            var3 = var5;
            break;
         case 122:
            CInternalDataComAndSystemEvent var10 = (CInternalDataComAndSystemEvent)var1;
            CGetDataComAndSystemEvent var11 = new CGetDataComAndSystemEvent(this.configIsLocked, this.lockerName);
            var11.setDataComAndSystem(var10);
            var3 = var11;
            break;
         case 222:
            this.resetCalled = true;
            CInternalResetEvent var26 = (CInternalResetEvent)var1;
            CResetEvent var27 = new CResetEvent(var26.getResetReport(), this.lockerName, this.configIsLocked, this.clientList, var26.getResetStatus());
            var3 = var27;
            break;
         case 255:
            CInternalIPACLListEvent var24 = (CInternalIPACLListEvent)var1;
            CGetIPACLListEvent var25 = new CGetIPACLListEvent(this.configIsLocked, this.lockerName);
            var25.setIPACLListData(var24);
            var3 = var25;
            break;
         case 277:
            CInternalHWMonitoringEvent var14 = (CInternalHWMonitoringEvent)var1;
            CGetHWMonitoringEvent var15 = new CGetHWMonitoringEvent(this.configIsLocked, this.lockerName);
            var15.setHWMonitoringData(var14);
            var3 = var15;
            break;
         case 299:
            CInternalPingMonitoringEvent var16 = (CInternalPingMonitoringEvent)var1;
            CGetPingMonitoringEvent var17 = new CGetPingMonitoringEvent(this.configIsLocked, this.lockerName);
            var17.setPingMonitoringData(var16);
            var3 = var17;
            break;
         case 366:
            CInternalSubscriptionEvent var18 = (CInternalSubscriptionEvent)var1;
            CGetSubscriptionsEvent var19 = new CGetSubscriptionsEvent(this.configIsLocked, this.lockerName);
            var19.setSubscriptionData(var18);
            var3 = var19;
            break;
         case 388:
            CInternalSMTPServerEvent var20 = (CInternalSMTPServerEvent)var1;
            CGetSMTPServerEvent var21 = new CGetSMTPServerEvent(this.configIsLocked, this.lockerName);
            var21.setSMTPServerData(var20);
            var3 = var21;
            break;
         case 400:
            CInternalSNMPAgentEvent var22 = (CInternalSNMPAgentEvent)var1;
            CGetSNMPAgentEvent var23 = new CGetSNMPAgentEvent(this.configIsLocked, this.lockerName);
            var23.setSNMPAgentData(var22);
            var3 = var23;
            break;
         case 444:
            CInternalCertificateEvent var28 = (CInternalCertificateEvent)var1;
            CGetCertificateEvent var29 = new CGetCertificateEvent(this.configIsLocked, this.lockerName);
            var29.setCertificateData(var28);
            var3 = var29;
            break;
         case 455:
            CInternalCertStateEvent var36 = (CInternalCertStateEvent)var1;
            CGetCertStateEvent var37 = new CGetCertStateEvent(this.configIsLocked, this.lockerName);
            var37.setCertStateData(var36);
            var3 = var37;
            break;
         case 477:
            CInternalTimeEvent var34 = (CInternalTimeEvent)var1;
            CGetTimeEvent var35 = new CGetTimeEvent(this.configIsLocked, this.lockerName);
            var35.setTimeData(var34);
            var3 = var35;
            break;
         case 499:
            CInternalRadClientEvent var32 = (CInternalRadClientEvent)var1;
            CGetRadClientEvent var33 = new CGetRadClientEvent(this.configIsLocked, this.lockerName);
            var33.setRadClientData(var32);
            var3 = var33;
            break;
         case 600:
            CInternalModemEvent var30 = (CInternalModemEvent)var1;
            CGetModemStatusEvent var31 = new CGetModemStatusEvent(this.configIsLocked, this.lockerName);
            var31.setModemStatusData(var30);
            var3 = var31;
      }

      if (var3 != null) {
         this.fireDataEvent((CDataEvent)var3);
      }
   }

   public boolean isReadyForUpgrade() {
      return !this.configIsModified;
   }

   public void forcedLogout() {
      this.fireDataEvent(new CLogoutEvent("You have been logged off."));
      this.configCommandVector.removeAllElements();
      this.configCommandVector = null;
      this.cmdHandler.releaseResources();
      this.cmdHandler = null;
      this.userRoleValidator = null;
      this.setToNull();
   }

   private void fireStatusEvent(CStatusEvent var1) {
      IStatusListener[] var2 = this.cmdHandler.getStatusListeners();

      for (int var3 = 0; var3 < var2.length; var3++) {
         IStatusListener var4 = var2[var3];
         if (!(var4 instanceof CCommandService)) {
            var4.commandStatusArrived(var1);
         }
      }
   }

   private void fireDataEvent(CDataEvent var1) {
      IDataListener[] var2 = this.cmdHandler.getDataListeners();

      for (int var3 = 0; var3 < var2.length; var3++) {
         IDataListener var4 = var2[var3];
         if (!(var4 instanceof CCommandService)) {
            var4.commandDataArrived(var1);
         }
      }
   }

   public void confirmReset() {
      if (this.configIsLocked) {
         CResetEvent var1 = new CResetEvent(
            "You are going to Reboot without saving the Configuration;The config was modified by  " + this.userName,
            this.lockerName,
            this.configIsLocked,
            this.clientList,
            14
         );
         this.fireDataEvent(var1);
      } else if (this.lockIsAsked) {
         this.resetCalled = true;
      } else {
         this.askForConfigLock();
         this.resetCalled = true;
      }
   }

   public void reset() {
      try {
         CReset var1 = new CReset();
         var1.setProperty("LOCK_REQUIRED", false);
         var1.setProperty("USER_NAME", this.getUserName());
         this.sendCommand(var1);
      } catch (Exception var2) {
      }
   }

   public void cancelReset() {
      if (this.configIsLocked) {
         try {
            if (!this.configIsModified && this.lockCount == 0) {
               this.releaseConfigLock(1);
            }
         } catch (Exception var2) {
         }
      }
   }

   public String[] getUserList() {
      return this.clientList;
   }

   public Hashtable getPortNumberToNameMap() {
      return this.portNumberToNameMap;
   }

   private void setToNull() {
      this.bIf = null;
      this.cmdHandler = null;
      this.userRoleValidator = null;
      this.userRole = -1;
      this.configCommandVector = null;
      this.iPAddress = null;
      this.localIPAddress = null;
      this.userName = null;
      this.loginName = null;
      this.userPassword = null;
      this.challengeParameter = null;
      this.hashedPassword = null;
      this.challenge = null;
      this.clientList = null;
      this.boxState = 0;
      this.clientId = 0;
      this.configIsLocked = false;
      this.isLogged = false;
      this.lockIsAsked = false;
      this.upgradeCalled = false;
      this.configIsModified = false;
      this.connectionIsActive = false;
      this.resetCalled = false;
      this.commitCalled = false;
      this.releaseLockParam = 0;
      this.reqOperation = 0;
      this.lockCount = 0;
      this.boxProperty = null;
      this.initParameters = null;
      this.internEvent = null;
      this.lockerName = null;
   }

   public String getLocalIPAddress() {
      return this.localIPAddress.toString();
   }

   public byte[] fetchMbox_mp_con() {
      return this.cmdHandler.fetchMbox_mp_con();
   }

   public byte[] fetchMbox_admin_cmd() {
      return this.cmdHandler.fetchMbox_admin_cmd();
   }

   public byte[] fetchMbox_admin_recmd() {
      return this.cmdHandler.fetchMbox_admin_recmd();
   }

   public byte[] fetchMbox_admin_con() {
      return this.cmdHandler.fetchMbox_admin_con();
   }

   public String fetchMbox_LoginName() {
      return this.cmdHandler.fetchMbox_login_name();
   }
}
