package amp.powerboard.clientapi.services;

import amp.powerboard.clientapi.command.ISendInterface;
import amp.powerboard.clientapi.common.exception.CAlreadyLoggedException;
import amp.powerboard.clientapi.common.exception.CBoxUnInitialisedException;
import amp.powerboard.clientapi.common.exception.CConfigNotSavedException;
import amp.powerboard.clientapi.common.exception.CConsoleAlreadyConnectedException;
import amp.powerboard.clientapi.common.exception.CInvalidUserException;
import amp.powerboard.clientapi.common.exception.CMaxUserExceededException;
import amp.powerboard.clientapi.common.exception.CNotLoggedException;
import amp.powerboard.clientapi.common.exception.CSecurityException;
import amp.powerboard.clientapi.common.exception.CUserAlreadyLoggedException;
import amp.powerboard.clientapi.console.CConsoleHandler;
import amp.powerboard.clientapi.event.IDataEventHandler;
import amp.powerboard.clientapi.event.IReportEventHandler;
import amp.powerboard.clientapi.event.IStatusEventHandler;
import amp.powerboard.clientapi.security.CKeyInstantiator;
import amp.powerboard.clientapi.security.PrimeThread;
import java.awt.Component;
import java.awt.Frame;
import java.io.DataInputStream;
import java.io.IOException;
import java.net.URL;
import java.net.UnknownHostException;
import java.util.Hashtable;

public class CSWCService implements IBoxInterface {
   private CConsoleHandler conHandler = null;
   int conCount = 0;
   private CCommandService cmdService = null;
   private Hashtable boxProperty = null;
   private Hashtable portNumberToNameMap = null;
   private String platform = "SC_AMP";
   private String deviceName = "<none>";
   private String login = null;
   private String password = null;
   private String iPAddress = null;
   private String htmlString = null;
   private boolean bBoxPropertySet = false;
   private boolean isAlreadyLoggedIn = false;
   private CKeyInstantiator keyInstantiator = null;
   private int iPortAddress;
   byte[] prime1 = new byte[32];
   byte[] prime2 = new byte[32];
   PrimeThread primeThread = null;
   boolean bPrimeThreadCalled = false;
   int SessionId = 0;
   private Frame parentFrame = null;
   private String subPlatform = "default";

   public CSWCService() {
      this.cmdService = new CCommandService(this);
      this.boxProperty = new Hashtable(10);
   }

   public void setParentFrame(Component var1) {
      for (Object var2 = var1; var2 != null; var2 = var2.getParent()) {
         if (var2 instanceof Frame) {
            this.parentFrame = (Frame)var2;
            return;
         }
      }

      this.parentFrame = null;
   }

   public Frame getParentFrame() {
      return this.parentFrame;
   }

   public void disposeParentFrame() {
      this.parentFrame.dispose();
      this.parentFrame = null;
   }

   public void login(int var1, String var2, String var3) throws IOException, CUserAlreadyLoggedException, CAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, CBoxUnInitialisedException {
      if (this.isAlreadyLoggedIn) {
         throw new CAlreadyLoggedException();
      } else {
         this.login = var2;
         this.password = var3;
         if (this.boxProperty == null || this.boxProperty.isEmpty()) {
            this.htmlString = this.connectAndGetHTML();
            this.boxProperty = this.getBoxProperty();
            this.initTasks();
         }

         if (this.cmdService == null) {
            this.cmdService = new CCommandService(this);
         }

         boolean var4 = this.SSLProduct();
         if (this.platform.equals("RX_SHIM")) {
            int var5 = this.getSessionId();
            int var6 = this.getDeviceId();
            int var7 = this.getChannelId();
            this.cmdService.login(this, this.iPortAddress, false, this.platform, var5, var6, var7, var4);
         } else {
            this.cmdService
               .login(
                  var1,
                  var2,
                  var3,
                  this.iPortAddress,
                  this,
                  false,
                  this.keyInstantiator.getCommandDecryptKey(),
                  this.keyInstantiator.getCommandEncryptKey(),
                  this.getSessionId(),
                  var4,
                  this.platform,
                  this.subPlatform,
                  this.deviceName
               );
         }

         this.isAlreadyLoggedIn = true;
      }
   }

   public void reLogin(int var1, String var2, String var3) throws IOException, CAlreadyLoggedException, CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, CBoxUnInitialisedException {
      if (this.isAlreadyLoggedIn) {
         throw new CAlreadyLoggedException();
      } else {
         this.login = var2;
         this.password = var3;
         if (this.boxProperty == null || this.boxProperty.isEmpty()) {
            this.htmlString = this.connectAndGetHTML();
            this.boxProperty = this.getBoxProperty();
            this.initTasks();
         }

         if (this.cmdService == null) {
            this.cmdService = new CCommandService(this);
         }

         this.cmdService
            .login(
               var1,
               var2,
               var3,
               this.iPortAddress,
               this,
               true,
               this.keyInstantiator.getCommandDecryptKey(),
               this.keyInstantiator.getCommandEncryptKey(),
               this.getSessionId(),
               this.SSLProduct(),
               this.platform,
               this.subPlatform,
               this.deviceName
            );
         this.isAlreadyLoggedIn = true;
      }
   }

   public void setIPAddress(String var1) {
      this.iPAddress = var1;
   }

   public String localIPAddress() {
      return this.cmdService != null ? this.cmdService.getLocalIPAddress() : null;
   }

   public CConsoleHandler accessConsole(int var1) throws CNotLoggedException, CConsoleAlreadyConnectedException, CUserAlreadyLoggedException, CMaxUserExceededException, InternalError, IOException, CInvalidUserException {
      if (!this.isAlreadyLoggedIn) {
         throw new CNotLoggedException();
      } else if (this.conHandler == null) {
         if (this.platform.indexOf("_APP") != -1) {
            this.login = this.cmdService.fetchMbox_LoginName();
         }

         if (this.platform.equals("RX_SHIM")) {
            this.conHandler = new CConsoleHandler(
               this.cmdService,
               this.getIStatusEventHandler(),
               this.getIReportEventHandler(),
               this.getIDataEventHandler(),
               this.getUserName(),
               this.iPortAddress,
               this,
               this.getSessionId(),
               this.getDeviceId(),
               this.getChannelId(),
               this.platform,
               this.deviceName
            );
         } else {
            this.conHandler = new CConsoleHandler(
               this.cmdService,
               this.getIStatusEventHandler(),
               this.getIReportEventHandler(),
               this.getIDataEventHandler(),
               this.getUserName(),
               var1,
               this.login,
               this.password,
               this.iPortAddress,
               this,
               this.keyInstantiator.getConsoleDecryptKey(),
               this.keyInstantiator.getConsoleEncryptKey(),
               this.getSessionId(),
               this.platform,
               this.subPlatform,
               this.deviceName,
               this.cmdService.fetchMbox_mp_con()
            );
         }

         this.conCount++;
         return this.conHandler;
      } else {
         this.conCount++;
         return this.conHandler;
      }
   }

   public void closeConsole() throws IOException, Exception {
      if (this.conHandler != null) {
         this.conCount--;
         if (this.conCount <= 0) {
            this.conHandler.closeConsole();
            this.conHandler = null;
         }
      }
   }

   public ISendInterface getISendInterface() {
      return this.cmdService;
   }

   public IDataEventHandler getIDataEventHandler() {
      return this.cmdService.getIDataEventHandler();
   }

   public IStatusEventHandler getIStatusEventHandler() {
      return this.cmdService.getIStatusEventHandler();
   }

   public IReportEventHandler getIReportEventHandler() {
      return this.cmdService.getIReportEventHandler();
   }

   public void writeBoxProperty(Hashtable var1) {
      this.boxProperty = var1;
      this.bBoxPropertySet = true;
      this.initTasks();
   }

   private void initTasks() {
      Object var1 = this.boxProperty.get("PortAddress");
      String var2 = (String)var1;
      var2.trim();

      try {
         this.iPortAddress = Integer.parseInt(var2);
      } catch (NumberFormatException var6) {
         System.err.println("CSWCService : PortAddress:..." + var2 + "..." + var6.toString());
      }

      this.setIPAddress((String)this.boxProperty.get("IPAddress"));
      var1 = this.boxProperty.get("DeviceName");
      if (var1 != null) {
         this.deviceName = (String)var1;
      }

      var1 = this.boxProperty.get("Platform");
      if (var1 != null) {
         this.platform = (String)var1;
      }

      var1 = this.boxProperty.get("SubPlatform");
      if (var1 != null) {
         this.subPlatform = (String)var1;
      } else {
         this.subPlatform = this.platform;
      }

      String var3 = null;

      try {
         var1 = this.boxProperty.get("RC4Key");
         var3 = (String)var1;
         this.keyInstantiator = new CKeyInstantiator(var3);
      } catch (Exception var5) {
         this.keyInstantiator = new CKeyInstantiator(var3);
      }

      String var4 = (String)this.boxProperty.get("SESSION_ID");
      if (var4 == null) {
         this.SessionId = 0;
      } else {
         this.SessionId = Integer.parseInt(var4);
      }

      if (this.isFirstTimeLogin()) {
         this.generatePrimeKeys();
      }
   }

   public void setHTMLString(String var1) {
      this.htmlString = var1;
      this.boxProperty = this.getBoxProperty();
      this.initTasks();
   }

   public Hashtable getBoxProperty() {
      if (this.boxProperty != null && !this.boxProperty.isEmpty()) {
         return this.boxProperty;
      } else {
         this.boxProperty = new Hashtable(10);
         String var1;
         if ((var1 = this.getProperty("Platform")) != null) {
            this.boxProperty.put("Platform", var1);
            this.platform = var1;
         }

         if ((var1 = this.getProperty("ChallengeId")) != null) {
            this.boxProperty.put("ChallengeId", var1);
         }

         if ((var1 = this.getProperty("Challenge")) != null) {
            this.boxProperty.put("Challenge", var1);
         }

         if ((var1 = this.getProperty("Product")) != null) {
            this.boxProperty.put("Product", var1);
         }

         if ((var1 = this.getProperty("BoxState")) != null) {
            this.boxProperty.put("BoxState", var1);
         }

         if ((var1 = this.getProperty("IPAddress")) != null) {
            this.boxProperty.put("IPAddress", var1);
         }

         if (this.iPAddress != null) {
            this.boxProperty.put("IPAddress", this.iPAddress);
         }

         if ((var1 = this.getProperty("PortAddress")) != null) {
            this.boxProperty.put("PortAddress", var1);
         }

         if ((var1 = this.getProperty("RC4Key")) != null) {
            this.boxProperty.put("RC4Key", var1);
         }

         if ((var1 = this.getProperty("TerminalType")) != null) {
            this.boxProperty.put("TerminalType", var1);
         }

         if ((var1 = this.getProperty("UseFrame")) != null) {
            this.boxProperty.put("UseFrame", var1);
         }

         if ((var1 = this.getProperty("MenuBar")) != null) {
            this.boxProperty.put("MenuBar", var1);
         }

         if ((var1 = this.getProperty("Title")) != null) {
            this.boxProperty.put("Title", var1);
         }

         if ((var1 = this.getProperty("ScrollBar")) != null) {
            this.boxProperty.put("ScrollBar", var1);
         }

         if ((var1 = this.getProperty("SubTitle")) != null) {
            this.boxProperty.put("SubTitle", var1);
         }

         if ((var1 = this.getProperty("Version")) != null) {
            this.boxProperty.put("Version", var1);
         }

         if ((var1 = this.getProperty("DeviceName")) != null) {
            this.boxProperty.put("DeviceName", var1);
            this.deviceName = var1;
         }

         if ((var1 = this.getProperty("USERNAME")) != null) {
            this.boxProperty.put("USERNAME", var1);
         }

         if ((var1 = this.getProperty("SessionId")) != null) {
            this.boxProperty.put("SESSION_ID", var1);
         }

         if ((var1 = this.getProperty("PortNumber")) != null) {
            this.boxProperty.put("PortNumber", var1);
         }

         if ((var1 = this.getProperty("SubPlatform")) != null) {
            this.boxProperty.put("SubPlatform", var1);
            this.subPlatform = var1;
         }

         this.bBoxPropertySet = true;
         return this.boxProperty;
      }
   }

   private String getProperty(String var1) {
      String var2 = null;

      try {
         int var3 = this.htmlString.indexOf(var1 + " ");
         if (var3 > -1) {
            var2 = this.htmlString.substring(var3);
            var2 = var2.substring(0, var2.indexOf(">") + 1);
            if (var2.indexOf("\"") != -1) {
               var2 = var2.substring(var2.indexOf("\"") + 1, var2.lastIndexOf("\""));
            } else {
               int var4 = var2.indexOf("=") + 1;
               int var5 = var2.indexOf(">");
               var2 = var2.substring(var4, var5);
            }
         }
      } catch (Exception var6) {
      }

      return var2 == null ? null : var2.trim();
   }

   private String connectAndGetHTML() throws IOException {
      String var1 = "http://" + this.iPAddress + ":" + "80" + "/";
      if (this.platform.equals("SC_AMP")) {
         var1 = var1 + "indexApp.htm";
      } else if (this.platform.equals("CEREBUS_X16") || this.platform.equals("CEREBUS_X16+") || this.platform.equals("CEREBUS_X32+")) {
         var1 = var1 + "app/app0/indexApp.htm";
      }

      URL var2 = new URL(var1);
      DataInputStream var3 = new DataInputStream(var2.openStream());
      StringBuffer var4 = new StringBuffer();

      int var7;
      do {
         int var5 = var3.available();
         byte[] var6 = new byte[var5];
         var7 = var3.read(var6);
         String var8 = new String(var6);
         var4.append(var8);
      } while (var7 != -1);

      return var4.toString();
   }

   public void logOut() throws IOException, CConfigNotSavedException {
      if (this.cmdService != null) {
         this.cmdService.releaseResources();
         if (this.conHandler != null) {
            this.conHandler.closeConsole();
            this.conHandler = null;
         }

         this.cmdService = null;
         this.isAlreadyLoggedIn = false;
         this.boxProperty = null;
      }
   }

   public int getUserRole() {
      return this.cmdService.getUserRole();
   }

   public String getUserName() {
      return this.cmdService.getUserName();
   }

   public String getLogin() {
      return this.login;
   }

   public void initialiseBox(Hashtable var1) throws UnknownHostException, CUserAlreadyLoggedException, CInvalidUserException, CMaxUserExceededException, IOException, CSecurityException, CNotLoggedException {
      this.cmdService
         .initialiseBox(
            var1,
            this,
            this.keyInstantiator.getCommandDecryptKey(),
            this.keyInstantiator.getCommandEncryptKey(),
            this.getSessionId(),
            this.SSLProduct(),
            this.platform,
            this.deviceName
         );
   }

   public void confirmReset() {
      this.cmdService.confirmReset();
   }

   public void reset() {
      this.cmdService.reset();
   }

   public void cancelReset() {
      this.cmdService.cancelReset();
   }

   public boolean SSLProduct() {
      if (!this.bBoxPropertySet) {
         System.err.println("Warning: Calling CSWCService.isSSLVersion() before boxProperty is set.");
         return false;
      } else if (this.platform.equals("CONSOLE_MANAGER")) {
         String var3 = (String)this.boxProperty.get("RC4Key");
         return var3 == null ? false : var3.length() >= 10;
      } else if (this.platform.equals("RX_SHIM")) {
         return false;
      } else {
         String var1 = (String)this.boxProperty.get("Product");
         var1 = var1.trim();
         return var1 == null ? false : var1.compareTo("SCSSL") == 0;
      }
   }

   public boolean SSLEnabled() {
      if (!this.bBoxPropertySet) {
         System.err.println("Warning: Calling CSWCService.isSSLEnabled() before boxProperty is set.");
         return false;
      } else {
         Object var1 = this.boxProperty.get("RC4Key");
         return var1 != null;
      }
   }

   public void generatePrimeKeys() {
      if (!this.bPrimeThreadCalled) {
         this.primeThread = new PrimeThread(this.prime1, this.prime2);
         this.primeThread.setPriority(1);
         this.primeThread.start();
         this.bPrimeThreadCalled = true;
      }
   }

   public byte[] getPrime1() {
      if (!this.bPrimeThreadCalled) {
         this.generatePrimeKeys();
      }

      if (this.primeThread != null && this.primeThread.isAlive()) {
         try {
            this.primeThread.join();
            this.primeThread = null;
         } catch (InterruptedException var2) {
            System.err.println("" + var2);
         }
      }

      return this.prime1;
   }

   public byte[] getPrime2() {
      if (!this.bPrimeThreadCalled) {
         this.generatePrimeKeys();
      }

      if (this.primeThread != null && this.primeThread.isAlive()) {
         try {
            this.primeThread.join();
            this.primeThread = null;
         } catch (InterruptedException var2) {
            System.err.println("" + var2);
         }
      }

      return this.prime2;
   }

   public boolean isFirstTimeLogin() {
      Object var1 = this.boxProperty.get("BoxState");
      String var2 = (String)var1;
      if (var2 != null && var2.length() != 0) {
         var2.trim();
         boolean var4 = false;

         try {
            int var3 = Integer.parseInt(var2);
            if (var3 == 1) {
               var4 = true;
            }
         } catch (NumberFormatException var6) {
            System.err.println("BoxState:..." + var2 + "..." + var6.toString());
         }

         return var4;
      } else {
         return false;
      }
   }

   public void incLockRequestCount() {
      this.cmdService.incLockRequestCount();
   }

   public void decLockRequestCount() {
      this.cmdService.decLockRequestCount();
   }

   public boolean isReadyForUpgrade() {
      return this.cmdService.isReadyForUpgrade();
   }

   public void forcedLogout() {
      try {
         if (this.conHandler != null) {
            this.conHandler.closeConsole();
            this.conHandler = null;
         }

         if (this.cmdService != null) {
            this.cmdService.forcedLogout();
            this.cmdService = null;
            this.isAlreadyLoggedIn = false;
            this.boxProperty = null;
         }
      } catch (Exception var2) {
      }
   }

   public int getSessionId() {
      return this.SessionId;
   }

   public String[] getUserList() {
      return this.cmdService.getUserList();
   }

   public Hashtable getPortNumberToNameMap() {
      return this.cmdService.getPortNumberToNameMap();
   }

   public String getPlatform() {
      return this.platform;
   }

   public String getDeviceName() {
      return this.deviceName;
   }

   public byte[] fetchMbox_admin_cmd() {
      return this.cmdService.fetchMbox_admin_cmd();
   }

   public byte[] fetchMbox_admin_recmd() {
      return this.cmdService.fetchMbox_admin_recmd();
   }

   public byte[] fetchMbox_admin_con() {
      return this.cmdService.fetchMbox_admin_con();
   }

   public String getSubPlatform() {
      return this.subPlatform;
   }

   public int getDeviceId() {
      int var1 = -1;
      String var2 = (String)this.boxProperty.get("DeviceId");
      if (var2 != null) {
         try {
            var1 = Integer.parseInt(var2);
         } catch (NumberFormatException var4) {
         }
      }

      return var1;
   }

   public int getChannelId() {
      int var1 = -1;
      String var2 = (String)this.boxProperty.get("ChannelId");
      if (var2 != null) {
         try {
            var1 = Integer.parseInt(var2);
         } catch (NumberFormatException var4) {
         }
      }

      return var1;
   }
}
