package amp.powerboard.swing;

import amp.powerboard.utils.PbResource;
import amp.powerboard.utils.SpringUtilities;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Frame;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Hashtable;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.plaf.basic.BasicOptionPaneUI.ButtonAreaLayout;

public class DialogSetup extends JDialog {
   StateManager stateManager;
   String[] relayNames;
   String[] relayStatus;
   String[] relayFeedback;
   OutletTextField[] outletNames;
   String errorMessage;
   Hashtable changeList = new Hashtable(10);
   Hashtable nameChangeList = new Hashtable(20);
   int cycleTime;
   int numRelays;
   private JPanel configPanel;
   private JPanel buttonPane;
   private JPanel panelRelay;
   JTextField textFieldUnitId = new JTextField(20);
   JTextField textFieldAlarm = new JTextField(10);
   private static String dialogTitle = PbResource.getString("ConfigDialog.title");
   private static String[] options = new String[]{PbResource.getString("ConfigDialog.okLabel"), PbResource.getString("ConfigDialog.cancelLabel")};
   private String validationErrMsg = PbResource.getString("ValidationErrorMessage");

   public DialogSetup(Frame var1) {
      super(var1, dialogTitle, true);
      this.getContentPane().setLayout(new BorderLayout());
      JOptionPane.setRootFrame(var1);
      this.configPanel = new JPanel(new SpringLayout());
      this.configPanel.setBackground(Color.lightGray);
      JPanel var2 = new JPanel();
      JLabel var3 = new JLabel("", 4);
      JLabel var4 = new JLabel("", 4);
      JLabel var5 = new JLabel("", 4);
      new JLabel("", 4);
      var2.setLayout(new SpringLayout());
      var3.setText(PbResource.getString("UnitIdLabel.name"));
      var3.setFont(new Font("Dialog", 1, 12));
      var3.setLabelFor(this.textFieldUnitId);
      this.textFieldUnitId.setMaximumSize(this.textFieldUnitId.getPreferredSize());
      var2.add(var3);
      var2.add(this.textFieldUnitId);
      var2.add(Box.createVerticalGlue());
      var4.setText(PbResource.getString("AlarmThreshHoldLabel.name"));
      var4.setFont(new Font("Dialog", 1, 12));
      this.textFieldAlarm.setMaximumSize(this.textFieldAlarm.getPreferredSize());
      var4.setLabelFor(this.textFieldAlarm);
      var2.add(var4);
      var2.add(this.textFieldAlarm);
      var5.setText("Amps");
      var5.setFont(new Font("Dialog", 1, 12));
      var2.add(var5);
      SpringUtilities.makeCompactGrid(var2, 2, 3, 6, 6, 10, 4);
      this.panelRelay = new JPanel();
      this.panelRelay.setLayout(new SpringLayout());
      String var7 = PbResource.getString("RelayPanel.name");
      this.panelRelay.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var7), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      this.configPanel.add(var2);
      this.configPanel.add(this.panelRelay);
      SpringUtilities.makeCompactGrid(this.configPanel, 2, 1, 6, 6, 4, 4);
      JButton var8 = new JButton(options[0]);
      JButton var9 = new JButton(options[1]);
      DialogSetup.ButtonActionListener var10 = new DialogSetup.ButtonActionListener();
      var8.addActionListener(var10);
      var9.addActionListener(var10);
      this.getRootPane().setDefaultButton(var8);
      this.buttonPane = new JPanel();
      this.buttonPane.setLayout(new ButtonAreaLayout(true, 6));
      this.buttonPane.setBorder(BorderFactory.createEmptyBorder(0, 10, 10, 10));
      this.buttonPane.add(var8);
      this.buttonPane.add(var9);
      this.getContentPane().add(this.configPanel, "Center");
      this.getContentPane().add(this.buttonPane, "South");
      this.setResizable(false);
      this.setCursor(PbResource.getDefaultCursor());
   }

   public DialogSetup(StateManager var1, String var2, boolean var3) {
      this(var1.getFrame());
      this.stateManager = var1;
      this.fillFields();
      this.pack();
      Dimension var4 = Toolkit.getDefaultToolkit().getScreenSize();
      int var5 = this.getSize().width;
      int var6 = this.getSize().height;
      this.setLocation(var5 / 2, var6 / 2);
   }

   void fillFields() {
      this.textFieldUnitId.setText(this.stateManager.getUnitId());
      this.textFieldAlarm.setText("" + this.stateManager.getAlarmThreshold());
      this.relayNames = this.stateManager.getRelayStatus().getRelayNames();
      this.outletNames = new OutletTextField[this.stateManager.getNumOutlets()];
      JLabel[] var1 = new JLabel[this.stateManager.getNumOutlets()];
      byte var2 = 4;
      int var4 = this.stateManager.getNumOutlets();
      if (var4 == 8) {
         var2 = 2;
      } else if (var4 == 12) {
         var2 = 3;
      } else if (var4 == 18 || var4 == 20) {
         var2 = 4;
      }

      int var3 = var4 / var2;
      if (var4 % var2 > 0) {
         var3++;
      }

      int var5 = 0;

      for (int var6 = 0; var6 < var2; var6++) {
         JPanel var7 = new JPanel(new SpringLayout());

         for (int var8 = 0; var8 < var3; var8++) {
            if (var5 < var4) {
               String var9 = this.relayNames[var5];
               this.outletNames[var5] = new OutletTextField();
               this.outletNames[var5].setText(var9);
               var1[var5] = new JLabel("" + (var5 + 1));
               var1[var5].setHorizontalAlignment(4);
               var1[var5].setLabelFor(this.outletNames[var5]);
               var7.add(var1[var5]);
               var7.add(this.outletNames[var5]);
            } else {
               JLabel var11 = new JLabel();
               JTextField var10 = new JTextField();
               var11.setVisible(false);
               var10.setVisible(false);
               var7.add(var11);
               var7.add(var10);
            }

            var5++;
         }

         SpringUtilities.makeCompactGrid(var7, var7.getComponentCount() / 2, 2, 0, 0, 4, 0);
         this.panelRelay.add(var7);
      }

      SpringUtilities.makeCompactGrid(this.panelRelay, 1, var2, 20, 6, 20, 0);
   }

   private boolean isConfigChanged() {
      boolean var1 = false;

      for (int var2 = 0; var2 < this.relayNames.length; var2++) {
         if (!this.relayNames[var2].equals(this.outletNames[var2].getText())) {
            var1 = true;
            this.nameChangeList.put("" + (var2 + 1), this.outletNames[var2].getText());
         }
      }

      if (!this.stateManager.getUnitId().equals(this.textFieldUnitId.getText())) {
         var1 = true;
         this.changeList.put("5", this.textFieldUnitId.getText());
      }

      if (this.stateManager.getAlarmThreshold() != new Float(this.textFieldAlarm.getText())) {
         var1 = true;
         this.changeList.put("6", this.textFieldAlarm.getText());
      }

      return var1;
   }

   private boolean isConfigValid() {
      try {
         float var1 = new Float(this.textFieldAlarm.getText());
         return true;
      } catch (NumberFormatException var2) {
         this.errorMessage = PbResource.getString("InvalidConfigErrorMessage");
         JOptionPane.showMessageDialog(this.stateManager.getFrame(), this.errorMessage, PbResource.getString("ValidationErrorMessage.title"), 0);
         this.textFieldAlarm.setCaretPosition(this.textFieldAlarm.getText().length());
         return false;
      }
   }

   boolean validateOutletNames() {
      boolean var1 = true;

      for (int var2 = 0; var2 < this.outletNames.length; var2++) {
         if (this.outletNames[var2].getText().indexOf(".") != -1
            || this.outletNames[var2].getText().indexOf("(") != -1
            || this.outletNames[var2].getText().indexOf(")") != -1
            || this.outletNames[var2].getText().indexOf(":") != -1) {
            this.errorMessage = this.validationErrMsg;
            var1 = false;
            break;
         }
      }

      return var1;
   }

   class ButtonActionListener implements ActionListener {
      public void actionPerformed(ActionEvent var1) {
         JButton var2 = (JButton)var1.getSource();
         if (var2.getText().equalsIgnoreCase(DialogSetup.options[0])) {
            DialogSetup.this.setCursor(PbResource.getWaitCursor());
            boolean var3 = DialogSetup.this.isConfigValid();
            boolean var4 = DialogSetup.this.validateOutletNames();
            if (var3 && var4) {
               if (DialogSetup.this.isConfigChanged()) {
                  DialogSetup.this.stateManager.save(DialogSetup.this.changeList, DialogSetup.this.nameChangeList);
               }

               DialogSetup.this.setVisible(false);
               DialogSetup.this.dispose();
            } else {
               JOptionPane.showMessageDialog(
                  DialogSetup.this.stateManager.getFrame(), DialogSetup.this.errorMessage, PbResource.getString("ValidationErrorMessage.title"), 0
               );
               DialogSetup.this.setCursor(PbResource.getDefaultCursor());
            }
         } else {
            DialogSetup.this.setVisible(false);
            DialogSetup.this.dispose();
         }
      }
   }
}
