package amp.powerboard.swing;

import amp.powerboard.clientapi.console.CConsoleHandler;
import amp.powerboard.clientapi.event.CClientListEvent;
import amp.powerboard.clientapi.event.CDataEvent;
import amp.powerboard.clientapi.event.CLoginInfoEvent;
import amp.powerboard.clientapi.event.IConsoleListener;
import amp.powerboard.clientapi.event.IDataListener;
import amp.powerboard.component.AcpSwcService;
import amp.powerboard.component.Constants;
import amp.powerboard.component.PowerboardInterface;
import amp.powerboard.component.RelayConfig;
import amp.powerboard.component.RelayStatus;
import amp.powerboard.component.SystemStatus;
import amp.powerboard.utils.PbResource;
import java.awt.Component;
import java.awt.Frame;
import java.util.Enumeration;
import java.util.Hashtable;
import javaclientlib.clientlib.ISerialStream;
import javax.swing.JOptionPane;

public class StateManager implements IDataListener, IConsoleListener {
   public static final long TIMEOUT = 1800000L;
   public static final int UNIDENTIFIED_MODE = 0;
   public static final int LOGOUT_MODE = 2;
   public static final int ACTION_MODE = 3;
   public static final int PULSE_MODE = 4;
   public static final int REFRESH_MODE = 5;
   public static final int SETUP_MODE = 6;
   public static final int SAVE_MODE = 7;
   public static final int NO_COMMAND = 0;
   public static final int LOGOUT_COMMAND = 2;
   public static final int ACTION_COMMAND = 3;
   public static final int PULSE_COMMAND = 4;
   public static final int SETUP_COMMAND = 5;
   public static final int FIND_COMMAND = 6;
   static final byte SEVEN_BITS_MASK = 127;
   static final byte EIGHT_BITS_MASK = -1;
   byte controlMask = 127;
   boolean master = false;
   boolean wasMaster = false;
   boolean requestForMaster = false;
   boolean warned = false;
   boolean confirmationDisabled = true;
   boolean enableDebug = false;
   boolean dataArrived = false;
   int userRole;
   int users = 0;
   int cycleTime;
   int relays;
   long timer = 0L;
   int numOutlets = 20;
   float alarmThreshold;
   int mode = 0;
   int lastCommand = 0;
   String userName = null;
   String masterName = null;
   String baudRate;
   String parityData;
   String unitMode;
   String unitId = "";
   String lastId = "NONE";
   String title = "PowerBoard";
   private String platform;
   String bytes = "";
   String password;
   String command;
   Hashtable changeList = new Hashtable(10);
   Hashtable nameChangeList = new Hashtable(20);
   private AcpSwcService swcService = null;
   private CConsoleHandler consoleHandler;
   private ISerialStream serialStream;
   private Powerboard powerboard = new Powerboard(this.title, this);
   PowerboardInterface applet;
   RelayStatus relayStatus;
   SystemStatus systemStatus;
   RelayConfig relayConfig;
   DialogSetup setup;

   public StateManager() {
      JOptionPane.setRootFrame(this.powerboard.getFrame());
   }

   public void writeSwcService(AcpSwcService var1) {
      this.swcService = var1;
      this.swcService.getIDataEventHandler().addDataListener(this);
   }

   public AcpSwcService readSwcService() {
      return this.swcService;
   }

   public void setSerialStream(ISerialStream var1) {
      this.serialStream = var1;
      this.master = true;
      this.mode = 5;
      this.lastCommand = 6;
   }

   public ISerialStream getSerialStream() {
      return this.serialStream;
   }

   public void setPassword(String var1) {
      this.timer = System.currentTimeMillis() + 1800000L;
      this.password = var1;
   }

   public void setPlatform(String var1) {
      this.platform = var1;
   }

   public String getPlatform() {
      return this.platform;
   }

   public void setTitle(String var1) {
      this.title = var1;
   }

   public Component getPowerboardUI() {
      return this.powerboard.getPowerboardUI();
   }

   public void setPowerboardInterface(PowerboardInterface var1) {
      this.powerboard.setPowerboardAppletInterface(var1);
      this.applet = var1;
   }

   public void commandDataArrived(CDataEvent var1) {
      switch (var1.getOpcode()) {
         case 13:
            CLoginInfoEvent var2 = (CLoginInfoEvent)var1;
            if (this.userName == null) {
               this.userName = var2.getUserName();
               if (this.masterName != null) {
                  if (this.masterName.equals(this.userName)) {
                     this.master = true;
                  } else {
                     this.master = false;
                  }

                  if (!this.masterName.equals(this.userName)) {
                     this.wasMaster = false;
                  } else {
                     this.wasMaster = true;
                  }
               }
            }

            this.swcService.getIDataEventHandler().removeDataListener(this);
            this.swcService.getIDataEventHandler().addDataListener(this);
            break;
         case 1503:
            CClientListEvent var3 = (CClientListEvent)var1;
            int var4 = var3.getMasterIndex();
            String[] var5 = var3.getListOfClients();
            this.users = var5.length;
            if (this.powerboard != null) {
               this.powerboard.updateUsers(var5.length);
            }

            if (var4 != 0) {
               this.masterName = var5[var4 - 1];
               if (this.userName != null) {
                  if (this.masterName.equals(this.userName)) {
                     this.master = true;
                     if (this.userRole != 2 && !this.warned) {
                        this.warned = true;
                        this.refresh();
                     }
                  } else {
                     this.master = false;
                     JOptionPane.showMessageDialog(
                        this.getFrame(), PbResource.getString("PbAccessErrorMessage"), PbResource.getString("PbConnectionErrorMessage.title"), 0
                     );
                     System.out.println("\nAnother user is operating on the PowerBoard.");
                  }

                  if (!var5[var4 - 1].equals(this.userName)) {
                     this.wasMaster = false;
                  } else {
                     this.wasMaster = true;
                  }
               }
            } else if (var4 == 0) {
               if (this.wasMaster) {
                  this.master = false;
               }

               this.wasMaster = false;
            }

            if (this.requestForMaster) {
               this.requestForMaster = false;
            }

            this.swcService.getIDataEventHandler().removeDataListener(this);
            this.swcService.getIDataEventHandler().addDataListener(this);
      }
   }

   public void connect(int var1) {
      try {
         this.consoleHandler = this.swcService.accessConsole(var1);
         this.consoleHandler.addConsoleListener(this);
         this.userRole = this.swcService.getUserRole();
         if (this.swcService.getPlatform().equals("RX_SHIM")) {
            this.master = true;
            this.refresh();
         }
      } catch (Exception var3) {
         System.out.println("Exception: " + var3.toString());
      }
   }

   public void bytesArrived(byte[] var1, int var2) {
      for (int var3 = 0; var3 < var2; var3++) {
         var1[var3] &= this.controlMask;
      }

      this.bytes = this.bytes + new String(var1, 0, var2);
      String var4 = this.getCompleteMessage();
      if (var4 != null) {
         if (this.enableDebug) {
            System.out.println(var4);
         }

         this.parseData(var4);
      }
   }

   private String getCompleteMessage() {
      int var1 = this.bytes.indexOf(Constants.PROMPT_MENU_8);
      int var2 = this.bytes.indexOf(Constants.PROMPT_MENU_12);
      int var3 = this.bytes.indexOf(Constants.PROMPT_MENU_18);
      int var4 = this.bytes.indexOf(Constants.PROMPT_MENU_20);
      int var5 = this.bytes.indexOf(Constants.PROMPT_ENTER);
      int var6 = this.bytes.indexOf(Constants.PROMPT_ENTER_1);
      int var7 = this.bytes.indexOf(Constants.PROMPT_SAVE);
      int var8 = this.bytes.indexOf(Constants.PROMPT_REQUEST);
      int var9 = this.bytes.indexOf(Constants.PROMPT_UNIT_ID);
      int var10 = this.bytes.indexOf(Constants.PROMPT_ENABLE);
      int var11 = this.bytes.indexOf(Constants.PROMPT_DISABLE);
      int var12 = this.bytes.indexOf(Constants.ID_TURN_OFF);
      int var13 = this.bytes.indexOf(Constants.ID_TURN_ON);
      int var14 = -1;
      int var15 = 0;
      if (var1 != -1) {
         var14 = var1;
         var15 = Constants.PROMPT_MENU_8.length();
      } else if (var2 != -1) {
         var14 = var2;
         var15 = Constants.PROMPT_MENU_12.length();
      } else if (var3 != -1) {
         var14 = var3;
         var15 = Constants.PROMPT_MENU_18.length();
      } else if (var4 != -1) {
         var14 = var4;
         var15 = Constants.PROMPT_MENU_20.length();
      } else if (var5 != -1) {
         var14 = var5;
         var15 = Constants.PROMPT_ENTER.length();
      } else if (var6 != -1) {
         var14 = var6;
         var15 = Constants.PROMPT_ENTER_1.length();
      } else if (var7 != -1) {
         var14 = var7;
         var15 = Constants.PROMPT_SAVE.length();
      } else if (var8 != -1) {
         var14 = var8;
         var15 = Constants.PROMPT_REQUEST.length();
      } else if (var9 != -1) {
         var14 = var9;
         var15 = Constants.PROMPT_UNIT_ID.length();
      } else if (var10 != -1) {
         var14 = var10;
         var15 = Constants.PROMPT_ENABLE.length();
      } else if (var11 != -1) {
         var14 = var11;
         var15 = Constants.PROMPT_DISABLE.length();
      } else if (var12 != -1) {
         var14 = var12;
         int var16 = this.bytes.indexOf("?");
         var15 = var16 - var12 + 1;
      } else if (var13 != -1) {
         var14 = var13;
         int var17 = this.bytes.indexOf("?");
         var15 = var17 - var13 + 1;
      }

      if (var14 != -1) {
         String var18 = this.bytes.substring(0, var14 + var15);
         if (var14 + var15 == this.bytes.length()) {
            this.bytes = "";
         } else {
            this.bytes = this.bytes.substring(var14 + var15);
         }

         this.dataArrived = true;
         return var18;
      } else {
         return null;
      }
   }

   void parseData(String var1) {
      if (this.enableDebug) {
         System.out.println("swing statemanager -- Mode: " + this.mode + "\tlastCommand: " + this.lastCommand);
      }

      if (var1.indexOf(Constants.ID_MAIN_8) != -1
         || var1.indexOf(Constants.ID_MAIN_12) != -1
         || var1.indexOf(Constants.ID_MAIN_18) != -1
         || var1.indexOf(Constants.ID_MAIN_20) != -1) {
         if (this.enableDebug) {
            System.out.println("ID_MAIN");
         }

         switch (this.mode) {
            case 0:
               this.relayStatus = new RelayStatus(var1);
               this.numOutlets = this.relayStatus.getNumOutlets();
               this.systemStatus = new SystemStatus(var1);
               this.unitId = this.systemStatus.getUnitId();
               if (this.powerboard != null) {
                  if (!this.powerboard.isInitialized()) {
                     this.powerboard.initUI(this.numOutlets);
                  }

                  this.powerboard.updateUI(this.relayStatus, this.systemStatus);
               }
            case 1:
            case 2:
            case 4:
            default:
               break;
            case 3:
               if (this.command != null) {
                  try {
                     this.send(this.command);
                     this.command = null;
                  } catch (Exception var4) {
                     System.out.println("$ Exception: " + var4.toString());
                  }
               } else {
                  this.relayStatus = new RelayStatus(var1);
                  this.systemStatus = new SystemStatus(var1);
                  this.unitId = this.systemStatus.getUnitId();
                  this.powerboard.updateUI(this.relayStatus, this.systemStatus);
                  this.mode = 0;
               }
               break;
            case 5:
               if (this.lastCommand == 6) {
                  if (this.confirmationDisabled) {
                     this.relayStatus = new RelayStatus(var1);
                     this.systemStatus = new SystemStatus(var1);
                     this.unitId = this.systemStatus.getUnitId();
                     this.numOutlets = this.relayStatus.getNumOutlets();
                     if (this.powerboard != null && !this.powerboard.isInitialized()) {
                        this.powerboard.initUI(this.numOutlets);
                     }

                     if (this.userRole != 2) {
                        this.powerboard.enableAll(true);
                     }

                     if ((this.swcService == null || !this.swcService.getPlatform().equals("RX_SHIM"))
                        && (this.serialStream == null || !this.getPlatform().equalsIgnoreCase(Constants.PLATFORM_JAVARRC))) {
                        if (!this.powerboard.isVisible()) {
                           this.powerboard.getContentPane().add(this.powerboard.getPowerboardUI());
                           this.powerboard.setVisible(true);
                        }
                     } else {
                        this.applet.addStateManager();
                     }

                     if (this.powerboard != null) {
                        this.powerboard.updateUI(this.relayStatus, this.systemStatus);
                     }

                     this.mode = 0;
                  } else {
                     this.send("config\r");
                  }
               }
               break;
            case 6:
            case 7:
               if (this.enableDebug) {
                  System.out.println("SETUP/SAVE MODE: ");
               }

               switch (this.lastCommand) {
                  case 2:
                     this.relayStatus = new RelayStatus(var1);
                     this.systemStatus = new SystemStatus(var1);
                     this.unitId = this.systemStatus.getUnitId();
                     this.powerboard.updateUI(this.relayStatus, this.systemStatus);
                     this.mode = 0;
                     break;
                  case 6:
                     this.lastCommand = 5;
                     this.send("config\r");
               }
         }
      }

      if (var1.indexOf(Constants.ID_SETUP) != -1) {
         if (this.enableDebug) {
            System.out.println("ID_SETUP");
         }

         switch (this.mode) {
            case 2:
               this.mode = 0;
               this.subMenuExit();
            case 3:
            case 4:
            default:
               break;
            case 5:
               if (!this.confirmationDisabled) {
                  this.send("3\r");
               } else {
                  this.send("\r");
               }
               break;
            case 6:
               if (this.lastCommand == 5) {
                  this.send("6\r");
               } else {
                  this.subMenuExit();
               }
               break;
            case 7:
               if (this.changeList.size() > 0) {
                  if (this.changeList.containsKey("5")) {
                     this.send("5\r");
                  } else if (this.changeList.containsKey("6")) {
                     this.send("6\r");
                  }
               } else if (this.nameChangeList.size() > 0) {
                  this.send("2\r");
               } else {
                  this.lastCommand = 2;
                  this.subMenuExit();
               }
         }
      }

      if (var1.indexOf(Constants.PROMPT_UNIT_ID) != -1) {
         if (this.enableDebug) {
            System.out.println("PROMPT_UNIT_ID");
         }

         switch (this.mode) {
            case 7:
               if (this.changeList.containsKey("5")) {
                  this.send(this.changeList.get("5") + "\r");
                  this.changeList.remove("5");
               }
         }
      }

      if (var1.indexOf(Constants.PROMPT_REQUEST) != -1 && var1.indexOf(Constants.ID_CONTROL_FEATURES) != -1) {
         if (this.enableDebug) {
            System.out.println("ID_CONTROL_FEATURES");
         }

         switch (this.mode) {
            case 7:
               if (this.nameChangeList.size() > 0) {
                  Enumeration var2 = this.nameChangeList.keys();
                  if (var2.hasMoreElements()) {
                     String var3 = (String)var2.nextElement();
                     this.command = (String)this.nameChangeList.get(var3);
                     this.send(var3 + "\r");
                     this.nameChangeList.remove(var3);
                     this.powerboard.setDefaultCursor();
                  }
               } else {
                  this.lastCommand = 2;
                  this.subMenuExit();
               }
         }
      }

      if (var1.indexOf(Constants.ID_CURRENT_OUTLET) != -1) {
         switch (this.mode) {
            case 7:
               this.lastId = Constants.ID_CURRENT_OUTLET;
         }
      }

      if (var1.indexOf(Constants.ID_ALARM) != -1) {
         if (this.enableDebug) {
            System.out.println("ID_ALARM");
         }

         switch (this.mode) {
            case 6:
               this.alarmThreshold = new Float(
                  var1.substring(var1.indexOf(Constants.ID_ALARM) + Constants.ID_ALARM.length(), var1.indexOf(Constants.ST_AMPS)).trim()
               );
               if (this.setup != null) {
                  this.setup.dispose();
                  this.setup = null;
               }

               this.powerboard.setDefaultCursor();
               this.setup = new DialogSetup(this, "Config", false);
               this.setup.setVisible(true);
               break;
            case 7:
               this.lastId = Constants.ID_ALARM;
         }
      }

      if (var1.indexOf(Constants.PROMPT_ENTER_1) != -1) {
         if (this.enableDebug) {
            System.out.println("Prompt Enter 1");
         }

         switch (this.mode) {
            case 7:
               this.send(this.changeList.get("6") + "\r");
               this.changeList.remove("6");
               this.lastId = "NONE";
         }
      }

      if (var1.indexOf(Constants.PROMPT_ENTER) != -1) {
         if (this.enableDebug) {
            System.out.println("Prompt Enter");
         }

         switch (this.mode) {
            case 7:
               if (this.command != null) {
                  this.send(this.command + "\r");
                  this.command = null;
                  this.lastId = "NONE";
               }
         }
      }

      if (var1.indexOf(Constants.PROMPT_SAVE) != -1) {
         if (this.enableDebug) {
            System.out.println("Prompt Y/N");
         }

         switch (this.mode) {
            case 7:
               this.send("Y\r");
         }
      }

      if (var1.indexOf(Constants.PROMPT_ENABLE) != -1) {
         if (this.enableDebug) {
            System.out.println("PROMPT_ENABLE");
         }

         switch (this.mode) {
            case 5:
               this.confirmationDisabled = true;
               this.send("N\r");
         }
      }

      if (var1.indexOf(Constants.PROMPT_DISABLE) != -1) {
         if (this.enableDebug) {
            System.out.println("PROMPT_DISABLE");
         }

         switch (this.mode) {
            case 5:
               this.confirmationDisabled = true;
               this.send("Y\r");
         }
      }

      if (var1.indexOf(Constants.ID_TURN_OFF) != -1) {
         this.send("Y\r");
      }

      if (var1.indexOf(Constants.ID_TURN_ON) != -1) {
         this.send("Y\r");
      }
   }

   void findState() {
      try {
         this.lastCommand = 6;
         this.dataArrived = false;
         this.send("\r");
      } catch (Exception var2) {
         System.out.println("Exception: " + var2.toString());
      }
   }

   void subMenuExit() {
      try {
         this.send("\r");
      } catch (Exception var2) {
         System.out.println("Exception: " + var2.toString());
      }
   }

   void mainLogout() {
      try {
         this.send("\r");
      } catch (Exception var2) {
         System.out.println("Exception: " + var2.toString());
      }
   }

   void login() {
   }

   public void sendOff(int var1) {
      this.powerboard.setWaitCursor();
      this.command = "Off " + var1 + "\r";
      String[] var2 = this.relayStatus.getRelayNames();
      StringBuffer var3 = new StringBuffer(PbResource.getString("PowerConfirmOffMessage.text"));
      var3.append(var2[var1 - 1]);
      int var4 = JOptionPane.showOptionDialog(this.getFrame(), var3.toString(), PbResource.getString("PowerConfirmOffMessage.title"), 0, -1, null, null, null);
      this.setConfirmation(var4 == 0);
   }

   public void sendOn(int var1) {
      try {
         this.powerboard.updateStatus("Ready to toggle relay ...");
         this.powerboard.setWaitCursor();
         this.mode = 3;
         this.command = null;
         if (this.master) {
            this.send("On " + var1 + "\r");
         } else {
            try {
               this.requestForMaster = true;
               this.consoleHandler.becomeMaster();
            } catch (Exception var3) {
               System.out.println("$ Could not become master - exception: " + var3.toString());
            }
         }
      } catch (Exception var4) {
         System.out.println("Exception: " + var4.toString());
      }
   }

   void sendPulse(String var1) {
      this.powerboard.updateStatus("Ready to pulse relay ...");
      this.mode = 4;
      this.command = var1;
      if (this.master) {
         this.findState();
      } else {
         try {
            this.requestForMaster = true;
            this.consoleHandler.becomeMaster();
         } catch (Exception var3) {
            System.out.println("$ Could not become master - exception: " + var3.toString());
         }
      }
   }

   void refresh() {
      this.powerboard.updateStatus("Ready to get status ...");
      this.mode = 5;
      this.command = null;
      if (this.master) {
         this.findState();
         int var1 = 60;
         System.out.print("Connecting .");

         for (; !this.dataArrived && var1 > 0; var1--) {
            try {
               System.out.print(".");
               Thread.sleep(100L);
            } catch (InterruptedException var4) {
               System.out.println("Timer interrupted");
            }
         }

         if (!this.dataArrived) {
            System.out.println("\nConnection to power strip timed out.");
            JOptionPane.showMessageDialog(
               this.getFrame(), PbResource.getString("PbConnectionErrorMessage"), PbResource.getString("PbConnectionErrorMessage.title"), 0
            );
         }
      } else {
         try {
            this.requestForMaster = true;
            this.consoleHandler.becomeMaster();
         } catch (Exception var3) {
            System.out.println("$ Could not become master - exception: " + var3.toString());
         }
      }
   }

   void send(String var1) {
      try {
         if (this.getPlatform().equalsIgnoreCase(Constants.PLATFORM_JAVARRC)) {
            if (this.serialStream != null) {
               byte[] var2 = var1.getBytes();
               this.serialStream.serialOut(var2.length, var2);
            }
         } else if (this.consoleHandler != null) {
            this.consoleHandler.send(var1);
         }
      } catch (Exception var3) {
         if (this.mode != 0) {
            this.powerboard.updateStatus("Ready");
            JOptionPane.showMessageDialog(
               this.getFrame(), PbResource.getString("UserInterruptMessage.text"), PbResource.getString("UserInterruptMessage.title"), 0
            );
            this.mode = 0;
         }
      }
   }

   public void readSetupData() {
      this.powerboard.setWaitCursor();
      this.powerboard.updateStatus("Ready to get setup data ...");
      this.mode = 6;
      if (this.master) {
         this.findState();
      } else {
         try {
            this.requestForMaster = true;
            this.consoleHandler.becomeMaster();
         } catch (Exception var2) {
            System.out.println("$ Could not become master - exception: " + var2.toString());
         }
      }
   }

   public void save(Hashtable var1, Hashtable var2) {
      this.changeList = var1;
      this.nameChangeList = var2;
      if (var1.size() > 0 || var2.size() > 0) {
         this.powerboard.updateStatus("Ready to save setup data ...");
         this.powerboard.setWaitCursor();
         this.mode = 7;
         if (this.master) {
            this.findState();
         } else {
            try {
               this.requestForMaster = true;
               this.consoleHandler.becomeMaster();
            } catch (Exception var4) {
               System.out.println("$ Could not become master - exception: " + var4.toString());
            }
         }
      } else if (this.enableDebug) {
         System.out.println("No changes to save.");
      }
   }

   public void closeAll() {
      if (this.setup != null) {
         this.setup.setVisible(false);
         this.setup.dispose();
         this.setup = null;
      }

      if (this.powerboard != null) {
         this.powerboard.dispose();
         this.powerboard = null;
      }
   }

   public void cancelLogin() {
      this.mode = 0;
   }

   public Frame getFrame() {
      return this.powerboard.getFrame();
   }

   public void setConfirmation(boolean var1) {
      if (var1) {
         try {
            this.powerboard.updateStatus("Ready to toggle relay ...");
            this.powerboard.setWaitCursor();
            this.mode = 3;
            if (this.master) {
               this.send(this.command);
               this.command = null;
            } else {
               try {
                  this.requestForMaster = true;
                  this.consoleHandler.becomeMaster();
               } catch (Exception var3) {
                  System.out.println("$ Could not become master - exception: " + var3.toString());
               }
            }
         } catch (Exception var4) {
            System.out.println("Exception: " + var4.toString());
         }
      } else {
         this.powerboard.setDefaultCursor();
         this.command = null;
      }
   }

   public int getNumOutlets() {
      return this.numOutlets;
   }

   public float getAlarmThreshold() {
      return this.alarmThreshold;
   }

   public String getUnitId() {
      return this.unitId;
   }

   public RelayStatus getRelayStatus() {
      return this.relayStatus;
   }
}
