package com.raritan.plaf;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import javax.swing.AbstractButton;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import javax.swing.border.Border;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.metal.MetalButtonUI;
import javax.swing.plaf.metal.MetalComboBoxButton;

public class RaritanButtonUI extends MetalButtonUI implements MouseListener {
   protected Border border = null;
   protected final Color colorTopUp = new Color(227, 225, 202);
   protected final Color colorTopDown = new Color(219, 216, 199);
   protected Color colorCenterUp = new Color(216, 213, 196);
   protected Color colorCenterDown = new Color(205, 202, 185);
   protected Color colorBottomUp = new Color(203, 200, 183);
   protected Color colorBottomDown = new Color(201, 198, 181);
   protected Color bgFirstOver = new Color(222, 220, 197);
   protected Color bgSecondOver = new Color(180, 177, 162);
   protected Color bgFirstPressedBack = new Color(219, 217, 202);
   protected Color bgSecondPressedBack = new Color(149, 148, 130);
   protected Color bgPressedBackLine = new Color(211, 210, 192);
   protected Color bgFirstPressed = new Color(180, 176, 164);
   protected Color bgSecondPressed = new Color(227, 222, 200);
   protected Color toolBarBorderLight = new Color(255, 254, 255);
   protected Color toolBarBorderDark = new Color(55, 53, 54);

   public static ComponentUI createUI(JComponent var0) {
      return new RaritanButtonUI();
   }

   @Override
   public void installUI(JComponent var1) {
      super.installUI(var1);
      var1.addMouseListener(this);
   }

   @Override
   public void update(Graphics var1, JComponent var2) {
      super.update(var1, var2);
   }

   @Override
   public void uninstallUI(JComponent var1) {
      super.uninstallUI(var1);
      var1.removeMouseListener(this);
   }

   @Override
   public void paint(Graphics var1, JComponent var2) {
      if (!(var2 instanceof MetalComboBoxButton)) {
         if (var2.getParent() instanceof JToolBar) {
            if (var2.getClientProperty("mouseIn") != null) {
               var1.setColor(RaritanLookAndFeel.BASE_BACKGROUND);
               var1.fillRect(0, 0, var2.getWidth(), var2.getHeight());
               var1.setColor(this.toolBarBorderLight);
               var1.drawLine(0, 0, var2.getWidth(), 0);
               var1.drawLine(0, 0, 0, var2.getHeight() - 2);
               var1.setColor(this.toolBarBorderDark);
               var1.drawLine(1, var2.getHeight() - 1, var2.getWidth(), var2.getHeight() - 1);
               var1.drawLine(var2.getWidth() - 1, 0, var2.getWidth() - 1, var2.getHeight());
            }
         } else if (var2.isOpaque()) {
            if (var2.getClientProperty("mouseIn") == null) {
               Rectangle var3 = null;
               var3 = var2.getBounds();
               var3.x = 0;
               var3.y = 0;
               var3.height /= 3;
               RaritanGradientDrawer.paintGradiendRect(var1, var3, this.colorTopUp, this.colorTopDown, true);
               var3 = var2.getBounds();
               var3.x = 0;
               var3.y = var3.height / 3;
               var3.height /= 3;
               RaritanGradientDrawer.paintGradiendRect(var1, var3, this.colorCenterUp, this.colorCenterDown, true);
               var3 = var2.getBounds();
               var3.x = 0;
               var3.y = var3.height / 3 * 2;
               var3.height /= 3;
               RaritanGradientDrawer.paintGradiendRect(var1, var3, this.colorBottomUp, this.colorBottomDown, true);
            } else {
               RaritanGradientDrawer.paintDefaultGradient(var1, var2, this.bgFirstOver, this.bgSecondOver);
            }
         }
      }

      super.paint(var1, var2);
   }

   @Override
   protected void paintFocus(Graphics var1, AbstractButton var2, Rectangle var3, Rectangle var4, Rectangle var5) {
      super.paintFocus(var1, var2, var3, var4, var5);
   }

   @Override
   protected void paintButtonPressed(Graphics var1, AbstractButton var2) {
      if (!(var2 instanceof MetalComboBoxButton)) {
         if (var2.getParent() instanceof JToolBar) {
            var1.setColor(RaritanLookAndFeel.BASE_BACKGROUND);
            var1.fillRect(0, 0, var2.getWidth(), var2.getHeight());
            var1.setColor(this.toolBarBorderDark);
            var1.drawLine(0, 0, var2.getWidth() - 2, 0);
            var1.drawLine(0, 0, 0, var2.getHeight());
            var1.setColor(this.toolBarBorderLight);
            var1.drawLine(1, var2.getHeight() - 1, var2.getWidth(), var2.getHeight() - 1);
            var1.drawLine(var2.getWidth() - 1, 1, var2.getWidth() - 1, var2.getHeight());
         } else {
            Rectangle var3 = null;
            RaritanGradientDrawer.paintDefaultGradient(var1, var2, this.bgFirstPressedBack, this.bgSecondPressedBack);
            var1.setColor(this.bgPressedBackLine);
            var1.drawLine(0, var2.getHeight() - 3, var2.getWidth(), var2.getHeight() - 3);
            var3 = var2.getBounds();
            var3.x = 2;
            var3.y = 2;
            var3.width = var2.getWidth() - 6;
            var3.height = var2.getHeight() - 5;
            RaritanGradientDrawer.paintGradiendRect(var1, var3, this.bgFirstPressed, this.bgSecondPressed, true);
         }
      }
   }

   @Override
   public void mouseClicked(MouseEvent var1) {
   }

   @Override
   public void mouseEntered(MouseEvent var1) {
      JComponent var2 = (JComponent)var1.getComponent();
      var2.putClientProperty("mouseIn", "TRUE");
      var2.repaint();
   }

   @Override
   public void mouseExited(MouseEvent var1) {
      JComponent var2 = (JComponent)var1.getComponent();
      var2.putClientProperty("mouseIn", null);
      var2.repaint();
   }

   @Override
   public void mousePressed(MouseEvent var1) {
   }

   @Override
   public void mouseReleased(MouseEvent var1) {
   }
}
