package com.raritan.plaf;

import java.awt.Graphics;
import java.awt.Point;
import java.awt.event.MouseEvent;
import javax.swing.JComponent;
import javax.swing.MenuElement;
import javax.swing.MenuSelectionManager;
import javax.swing.event.MenuKeyEvent;
import javax.swing.event.MenuKeyListener;
import javax.swing.event.MouseInputListener;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicMenuItemUI;

public class RaritanMenuItemUI extends BasicMenuItemUI implements MouseInputListener, MenuKeyListener {
   private MenuKeyListener basicMenuKeyListener = null;

   public static ComponentUI createUI(JComponent var0) {
      return new RaritanMenuItemUI();
   }

   @Override
   public void installUI(JComponent var1) {
      super.installUI(var1);
      var1.addMouseListener(this);
   }

   @Override
   public void update(Graphics var1, JComponent var2) {
      super.update(var1, var2);
   }

   @Override
   public void uninstallUI(JComponent var1) {
      super.uninstallUI(var1);
      var1.removeMouseListener(this);
   }

   @Override
   public void paint(Graphics var1, JComponent var2) {
      super.paint(var1, var2);
   }

   @Override
   protected MouseInputListener createMouseInputListener(JComponent var1) {
      return null;
   }

   @Override
   public void mouseClicked(MouseEvent var1) {
   }

   @Override
   public void mouseEntered(MouseEvent var1) {
      MenuSelectionManager var2 = MenuSelectionManager.defaultManager();
      int var3 = var1.getModifiers();
      if ((var3 & 28) != 0) {
         MenuSelectionManager.defaultManager().processMouseEvent(var1);
      } else {
         var2.setSelectedPath(this.getPath());
      }
   }

   @Override
   public void mouseExited(MouseEvent var1) {
      MenuSelectionManager var2 = MenuSelectionManager.defaultManager();
      int var3 = var1.getModifiers();
      if ((var3 & 28) != 0) {
         MenuSelectionManager.defaultManager().processMouseEvent(var1);
      } else {
         MenuElement[] var4 = var2.getSelectedPath();
         if (var4.length > 1 && var4[var4.length - 1] == this.menuItem) {
            MenuElement[] var5 = new MenuElement[var4.length - 1];
            int var6 = 0;

            for (int var7 = var4.length - 1; var6 < var7; var6++) {
               var5[var6] = var4[var6];
            }

            var2.setSelectedPath(var5);
         }
      }
   }

   @Override
   public void mousePressed(MouseEvent var1) {
   }

   @Override
   public void mouseReleased(MouseEvent var1) {
      if (this.menuItem.isEnabled()) {
         MenuSelectionManager var2 = MenuSelectionManager.defaultManager();
         Point var3 = var1.getPoint();
         if (var3.x >= 0 && var3.x < this.menuItem.getWidth() && var3.y >= 0 && var3.y < this.menuItem.getHeight()) {
            this.doClick(var2);
         } else {
            var2.processMouseEvent(var1);
         }
      }
   }

   @Override
   public void mouseDragged(MouseEvent var1) {
   }

   @Override
   public void mouseMoved(MouseEvent var1) {
   }

   @Override
   protected MenuKeyListener createMenuKeyListener(JComponent var1) {
      this.basicMenuKeyListener = super.createMenuKeyListener(var1);
      return this;
   }

   @Override
   public void menuKeyPressed(MenuKeyEvent var1) {
      MenuElement[] var2 = MenuSelectionManager.defaultManager().getSelectedPath();
      if (var2.length == 1 && (var1.getKeyCode() == 38 || var1.getKeyCode() == 224 || var1.getKeyCode() == 40 || var1.getKeyCode() == 225)) {
         boolean var3 = var1.getKeyCode() == 38 || var1.getKeyCode() == 224;
         MenuElement[] var4 = var2[0].getSubElements();
         if (var4 != null) {
            MenuElement var5 = this.getNextElement(var4, var3);
            if (var5 != null) {
               MenuElement[] var6 = new MenuElement[]{var2[0], var5};
               MenuSelectionManager.defaultManager().setSelectedPath(var6);
               var1.consume();
            }
         }
      }

      if (!var1.isConsumed() && this.basicMenuKeyListener != null) {
         this.basicMenuKeyListener.menuKeyPressed(var1);
      }
   }

   @Override
   public void menuKeyReleased(MenuKeyEvent var1) {
      if (this.basicMenuKeyListener != null) {
         this.basicMenuKeyListener.menuKeyReleased(var1);
      }
   }

   @Override
   public void menuKeyTyped(MenuKeyEvent var1) {
      if (this.basicMenuKeyListener != null) {
         this.basicMenuKeyListener.menuKeyTyped(var1);
      }
   }

   private MenuElement getNextElement(MenuElement[] var1, boolean var2) {
      MenuElement var3 = null;
      int var4 = var1.length;
      int var5 = 0;
      byte var6 = 1;
      if (var2) {
         var5 = var1.length - 1;
         var6 = -1;
      }

      int var7 = var5;

      for (byte var8 = 0; var8 < var4; var7 += var6) {
         if (var1[var7].getComponent().isEnabled()) {
            var3 = var1[var7];
            break;
         }
      }

      return var3;
   }
}
