package com.raritan.plaf;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Insets;
import java.awt.LayoutManager;
import java.awt.LayoutManager2;
import java.awt.Rectangle;
import java.io.File;
import java.io.Serializable;
import java.net.MalformedURLException;
import java.net.URL;
import javax.swing.ImageIcon;
import javax.swing.JApplet;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JLayeredPane;
import javax.swing.JRootPane;

public class RaritanRootPane extends JRootPane {
   private static final long serialVersionUID = 4952638827039480408L;
   private Component parentComponent;
   private JLabel lblOnTop;

   public RaritanRootPane(JFrame var1) {
      this.parentComponent = var1;
      RaritanRootPane.BianorImageIconRow var2 = new RaritanRootPane.BianorImageIconRow();
      this.lblOnTop = new JLabel(var2);
      this.layeredPane.add(this.lblOnTop, JLayeredPane.FRAME_CONTENT_LAYER);
   }

   public RaritanRootPane(JApplet var1) throws Exception {
      this.parentComponent = var1;
   }

   @Override
   protected LayoutManager createRootLayout() {
      return new RaritanRootPane.BianorRootLayout();
   }

   public void destroy() {
      this.parentComponent = null;
   }

   protected class BianorImageIconRow extends ImageIcon {
      private static final long serialVersionUID = 8826545708174652071L;
      private ImageIcon leftImage;
      private ImageIcon centerImage;
      private ImageIcon rightImage;

      public BianorImageIconRow() {
      }

      public BianorImageIconRow(ImageIcon var2, ImageIcon var3, ImageIcon var4) {
         this.leftImage = var2;
         this.centerImage = var3;
         this.rightImage = var4;
      }

      @Override
      public int getIconHeight() {
         return this.checkLoaded() ? Math.max(this.leftImage.getIconHeight(), Math.max(this.centerImage.getIconHeight(), this.rightImage.getIconHeight())) : 0;
      }

      @Override
      public int getIconWidth() {
         return this.checkLoaded() ? this.leftImage.getIconWidth() + this.centerImage.getIconWidth() + this.rightImage.getIconWidth() : 0;
      }

      @Override
      public synchronized void paintIcon(Component var1, Graphics var2, int var3, int var4) {
         if (this.checkLoaded()) {
            int var5 = this.leftImage.getIconWidth();
            int var6 = this.leftImage.getIconWidth();
            var2.drawImage(this.leftImage.getImage(), 0, var4, var5, this.getIconHeight(), var1);
            var2.drawImage(this.centerImage.getImage(), var5, var4, var1.getWidth() - var5 - var6, this.getIconHeight(), var1);
            var2.drawImage(this.rightImage.getImage(), var1.getWidth() - var6 - var5, var4, var6 + var5, this.getIconHeight(), var1);
         }
      }

      private boolean checkLoaded() {
         if (this.leftImage == null || this.rightImage == null || this.centerImage == null) {
            try {
               this.leftImage = new ImageIcon(this.getImage("logo_head.gif"));
               this.centerImage = new ImageIcon(this.getImage("tile_head.gif"));
               this.rightImage = new ImageIcon(this.getImage("rrc_head.gif"));
            } catch (Throwable var2) {
               return false;
            }
         }

         return false;
      }

      private URL getIconBase() {
         if (RaritanRootPane.this.parentComponent instanceof JFrame) {
            try {
               File var1 = new File("com/raritan/rrc/resources/images/");
               return var1.toURL();
            } catch (MalformedURLException var2) {
               return null;
            }
         } else if (RaritanRootPane.this.parentComponent instanceof JApplet) {
            try {
               return new URL(((JApplet)RaritanRootPane.this.parentComponent).getCodeBase(), "com/raritan/rrc/resources/images/");
            } catch (MalformedURLException var3) {
               return null;
            }
         } else {
            return null;
         }
      }

      private Image getImage(String var1) {
         if (RaritanRootPane.this.parentComponent instanceof JApplet) {
            JApplet var4 = (JApplet)RaritanRootPane.this.parentComponent;
            return var4.getImage(this.getIconBase(), var1);
         } else {
            try {
               URL var2 = new URL(this.getIconBase(), var1);
               return RaritanRootPane.this.parentComponent.getToolkit().createImage(var2);
            } catch (MalformedURLException var3) {
               return null;
            }
         }
      }
   }

   protected class BianorRootLayout implements LayoutManager2, Serializable {
      private static final long serialVersionUID = -3983711617301191539L;

      @Override
      public Dimension preferredLayoutSize(Container var1) {
         Insets var5 = RaritanRootPane.this.getInsets();
         Dimension var2;
         if (RaritanRootPane.this.contentPane != null) {
            var2 = RaritanRootPane.this.contentPane.getPreferredSize();
         } else {
            var2 = var1.getSize();
         }

         Dimension var3;
         if (RaritanRootPane.this.menuBar != null && RaritanRootPane.this.menuBar.isVisible()) {
            var3 = RaritanRootPane.this.menuBar.getPreferredSize();
         } else {
            var3 = new Dimension(0, 0);
         }

         Dimension var4;
         if (RaritanRootPane.this.lblOnTop != null) {
            var4 = RaritanRootPane.this.lblOnTop.getPreferredSize();
         } else {
            var4 = new Dimension(0, 0);
         }

         return new Dimension(
            Math.max(Math.max(var2.width, var3.width), var4.width) + var5.left + var5.right, var2.height + var3.height + var4.height + var5.top + var5.bottom
         );
      }

      @Override
      public Dimension minimumLayoutSize(Container var1) {
         Insets var5 = RaritanRootPane.this.getInsets();
         Dimension var2;
         if (RaritanRootPane.this.contentPane != null) {
            var2 = RaritanRootPane.this.contentPane.getMinimumSize();
         } else {
            var2 = var1.getSize();
         }

         Dimension var3;
         if (RaritanRootPane.this.menuBar != null && RaritanRootPane.this.menuBar.isVisible()) {
            var3 = RaritanRootPane.this.menuBar.getMinimumSize();
         } else {
            var3 = new Dimension(0, 0);
         }

         Dimension var4;
         if (RaritanRootPane.this.lblOnTop != null) {
            var4 = RaritanRootPane.this.lblOnTop.getMinimumSize();
         } else {
            var4 = new Dimension(0, 0);
         }

         return new Dimension(
            Math.max(Math.max(var2.width, var3.width), var4.width) + var5.left + var5.right, var2.height + var3.height + var4.height + var5.top + var5.bottom
         );
      }

      @Override
      public Dimension maximumLayoutSize(Container var1) {
         Insets var5 = RaritanRootPane.this.getInsets();
         Dimension var3;
         if (RaritanRootPane.this.menuBar != null && RaritanRootPane.this.menuBar.isVisible()) {
            var3 = RaritanRootPane.this.menuBar.getMaximumSize();
         } else {
            var3 = new Dimension(0, 0);
         }

         Dimension var4;
         if (RaritanRootPane.this.lblOnTop != null) {
            var4 = RaritanRootPane.this.lblOnTop.getMinimumSize();
         } else {
            var4 = new Dimension(0, 0);
         }

         Dimension var2;
         if (RaritanRootPane.this.contentPane != null) {
            var2 = RaritanRootPane.this.contentPane.getMaximumSize();
         } else {
            var2 = new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE - var5.top - var5.bottom - var3.height - 1);
         }

         return new Dimension(
            Math.min(Math.min(var2.width, var3.width), var4.width) + var5.left + var5.right, var2.height + var3.height + var4.height + var5.top + var5.bottom
         );
      }

      @Override
      public void layoutContainer(Container var1) {
         Rectangle var2 = var1.getBounds();
         Insets var3 = RaritanRootPane.this.getInsets();
         int var4 = 0;
         int var5 = var2.width - var3.right - var3.left;
         int var6 = var2.height - var3.top - var3.bottom;
         if (RaritanRootPane.this.layeredPane != null) {
            RaritanRootPane.this.layeredPane.setBounds(var3.left, var3.top, var5, var6);
         }

         if (RaritanRootPane.this.glassPane != null) {
            RaritanRootPane.this.glassPane.setBounds(var3.left, var3.top, var5, var6);
         }

         if (RaritanRootPane.this.lblOnTop != null) {
            Dimension var7 = RaritanRootPane.this.lblOnTop.getPreferredSize();
            RaritanRootPane.this.lblOnTop.setBounds(0, var4, var5, var7.height);
            var4 += var7.height;
         }

         if (RaritanRootPane.this.menuBar != null && RaritanRootPane.this.menuBar.isVisible()) {
            Dimension var8 = RaritanRootPane.this.menuBar.getPreferredSize();
            RaritanRootPane.this.menuBar.setBounds(0, var4, var5, var8.height);
            var4 += var8.height;
         }

         if (RaritanRootPane.this.contentPane != null) {
            RaritanRootPane.this.contentPane.setBounds(0, var4, var5, var6 - var4);
         }
      }

      @Override
      public void addLayoutComponent(String var1, Component var2) {
      }

      @Override
      public void removeLayoutComponent(Component var1) {
      }

      @Override
      public void addLayoutComponent(Component var1, Object var2) {
      }

      @Override
      public float getLayoutAlignmentX(Container var1) {
         return 0.0F;
      }

      @Override
      public float getLayoutAlignmentY(Container var1) {
         return 0.0F;
      }

      @Override
      public void invalidateLayout(Container var1) {
      }
   }
}
