package com.raritan.plaf;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.ActionMap;
import javax.swing.InputMap;
import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.SwingUtilities;
import javax.swing.TransferHandler;
import javax.swing.UIManager;
import javax.swing.plaf.ActionMapUIResource;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicTableUI;
import javax.swing.table.TableCellEditor;

public class RaritanTableUI extends BasicTableUI {
   public static ComponentUI createUI(JComponent var0) {
      return new RaritanTableUI();
   }

   @Override
   protected void installKeyboardActions() {
      ActionMap var1 = this.getThisActionMap();
      SwingUtilities.replaceUIActionMap(this.table, var1);
      InputMap var2 = this.getThisInputMap(1);
      SwingUtilities.replaceUIInputMap(this.table, 1, var2);
   }

   InputMap getThisInputMap(int var1) {
      if (var1 == 1) {
         InputMap var2 = (InputMap)UIManager.get("Table.ancestorInputMap");
         InputMap var3;
         if (!this.table.getComponentOrientation().isLeftToRight() && (var3 = (InputMap)UIManager.get("Table.ancestorInputMap.RightToLeft")) != null) {
            var3.setParent(var2);
            return var3;
         } else {
            return var2;
         }
      } else {
         return null;
      }
   }

   ActionMap getThisActionMap() {
      ActionMap var1 = (ActionMap)UIManager.get("Table.actionMap");
      if (var1 == null) {
         var1 = this.createThisActionMap();
         if (var1 != null) {
            UIManager.getLookAndFeelDefaults().put("Table.actionMap", var1);
         }
      }

      return var1;
   }

   ActionMap createThisActionMap() {
      ActionMapUIResource var1 = new ActionMapUIResource();
      var1.put("selectNextColumn", new RaritanTableUI.NavigationalAction(1, 0, false, false, false));
      var1.put("selectPreviousColumn", new RaritanTableUI.NavigationalAction(-1, 0, false, false, false));
      var1.put("selectNextRow", new RaritanTableUI.NavigationalAction(0, 1, false, false, false));
      var1.put("selectPreviousRow", new RaritanTableUI.NavigationalAction(0, -1, false, false, false));
      var1.put("selectNextColumnExtendSelection", new RaritanTableUI.NavigationalAction(1, 0, false, true, false));
      var1.put("selectPreviousColumnExtendSelection", new RaritanTableUI.NavigationalAction(-1, 0, false, true, false));
      var1.put("selectNextRowExtendSelection", new RaritanTableUI.NavigationalAction(0, 1, false, true, false));
      var1.put("selectPreviousRowExtendSelection", new RaritanTableUI.NavigationalAction(0, -1, false, true, false));
      var1.put("scrollUpChangeSelection", new RaritanTableUI.PagingAction(false, false, true, false));
      var1.put("scrollDownChangeSelection", new RaritanTableUI.PagingAction(false, true, true, false));
      var1.put("selectFirstColumn", new RaritanTableUI.PagingAction(false, false, false, true));
      var1.put("selectLastColumn", new RaritanTableUI.PagingAction(false, true, false, true));
      var1.put("scrollUpExtendSelection", new RaritanTableUI.PagingAction(true, false, true, false));
      var1.put("scrollDownExtendSelection", new RaritanTableUI.PagingAction(true, true, true, false));
      var1.put("selectFirstColumnExtendSelection", new RaritanTableUI.PagingAction(true, false, false, true));
      var1.put("selectLastColumnExtendSelection", new RaritanTableUI.PagingAction(true, true, false, true));
      var1.put("selectFirstRow", new RaritanTableUI.PagingAction(false, false, true, true));
      var1.put("selectLastRow", new RaritanTableUI.PagingAction(false, true, true, true));
      var1.put("selectFirstRowExtendSelection", new RaritanTableUI.PagingAction(true, false, true, true));
      var1.put("selectLastRowExtendSelection", new RaritanTableUI.PagingAction(true, true, true, true));
      var1.put("selectNextColumnCell", new RaritanTableUI.NavigationalAction(1, 0, true, false, true));
      var1.put("selectPreviousColumnCell", new RaritanTableUI.NavigationalAction(-1, 0, true, false, true));
      var1.put("selectNextRowCell", new RaritanTableUI.NavigationalAction(0, 1, true, false, true));
      var1.put("selectPreviousRowCell", new RaritanTableUI.NavigationalAction(0, -1, true, false, true));
      var1.put("selectAll", new RaritanTableUI.SelectAllAction());
      var1.put("cancel", new RaritanTableUI.CancelEditingAction());
      var1.put("startEditing", new RaritanTableUI.StartEditingAction());
      var1.put("tabNext", new RaritanTableUI.TabNextAction());
      var1.put("tabPrevious", new RaritanTableUI.TabPreviousAction());
      var1.put(TransferHandler.getCutAction().getValue("Name"), TransferHandler.getCutAction());
      var1.put(TransferHandler.getCopyAction().getValue("Name"), TransferHandler.getCopyAction());
      var1.put(TransferHandler.getPasteAction().getValue("Name"), TransferHandler.getPasteAction());
      if (this.table.getComponentOrientation().isLeftToRight()) {
         var1.put("scrollLeftChangeSelection", new RaritanTableUI.PagingAction(false, false, false, false));
         var1.put("scrollRightChangeSelection", new RaritanTableUI.PagingAction(false, true, false, false));
         var1.put("scrollLeftExtendSelection", new RaritanTableUI.PagingAction(true, false, false, false));
         var1.put("scrollRightExtendSelection", new RaritanTableUI.PagingAction(true, true, false, false));
      } else {
         var1.put("scrollLeftChangeSelection", new RaritanTableUI.PagingAction(false, true, false, false));
         var1.put("scrollRightChangeSelection", new RaritanTableUI.PagingAction(false, false, false, false));
         var1.put("scrollLeftExtendSelection", new RaritanTableUI.PagingAction(true, true, false, false));
         var1.put("scrollRightExtendSelection", new RaritanTableUI.PagingAction(true, false, false, false));
      }

      return var1;
   }

   private static class CancelEditingAction extends AbstractAction {
      private static final long serialVersionUID = -3449118993873310245L;

      private CancelEditingAction() {
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         var2.removeEditor();
      }
   }

   private static class NavigationalAction extends AbstractAction {
      private static final long serialVersionUID = 6394247547613967826L;
      protected int dx;
      protected int dy;
      protected boolean toggle;
      protected boolean extend;
      protected boolean inSelection;
      protected int anchorRow;
      protected int anchorColumn;
      protected int leadRow;
      protected int leadColumn;

      protected NavigationalAction(int var1, int var2, boolean var3, boolean var4, boolean var5) {
         this.dx = var1;
         this.dy = var2;
         this.toggle = var3;
         this.extend = var4;
         this.inSelection = var5;
      }

      private int clipToRange(int var1, int var2, int var3) {
         return Math.min(Math.max(var1, var2), var3 - 1);
      }

      private void moveWithinTableRange(JTable var1, int var2, int var3, boolean var4) {
         if (var4) {
            this.leadRow = this.clipToRange(this.leadRow + var3, 0, var1.getRowCount());
            this.leadColumn = this.clipToRange(this.leadColumn + var2, 0, var1.getColumnCount());
         } else {
            this.anchorRow = this.clipToRange(this.anchorRow + var3, 0, var1.getRowCount());
            this.anchorColumn = this.clipToRange(this.anchorColumn + var2, 0, var1.getColumnCount());
         }
      }

      private int selectionSpan(ListSelectionModel var1) {
         return var1.getMaxSelectionIndex() - var1.getMinSelectionIndex() + 1;
      }

      private int compare(int var1, ListSelectionModel var2) {
         return this.compare(var1, var2.getMinSelectionIndex(), var2.getMaxSelectionIndex() + 1);
      }

      private int compare(int var1, int var2, int var3) {
         return var1 < var2 ? -1 : (var1 >= var3 ? 1 : 0);
      }

      private boolean moveWithinSelectedRange(JTable var1, int var2, int var3, boolean var4) {
         ListSelectionModel var5 = var1.getSelectionModel();
         ListSelectionModel var6 = var1.getColumnModel().getSelectionModel();
         int var7 = this.anchorRow + var3;
         int var8 = this.anchorColumn + var2;
         int var11 = this.selectionSpan(var5);
         int var12 = this.selectionSpan(var6);
         boolean var13 = var11 * var12 > 1;
         int var9;
         int var10;
         if (var13) {
            var9 = this.compare(var7, var5);
            var10 = this.compare(var8, var6);
         } else {
            var11 = var1.getRowCount();
            var12 = var1.getColumnCount();
            var9 = this.compare(var7, 0, var11);
            var10 = this.compare(var8, 0, var12);
         }

         this.anchorRow = var7 - var11 * var9;
         this.anchorColumn = var8 - var12 * var10;
         return !var4 ? this.moveWithinSelectedRange(var1, var9, var10, true) : var13;
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         ListSelectionModel var3 = var2.getSelectionModel();
         this.anchorRow = var3.getAnchorSelectionIndex();
         this.leadRow = var3.getLeadSelectionIndex();
         ListSelectionModel var4 = var2.getColumnModel().getSelectionModel();
         this.anchorColumn = var4.getAnchorSelectionIndex();
         this.leadColumn = var4.getLeadSelectionIndex();
         if (!var2.isEditing() || var2.getCellEditor().stopCellEditing()) {
            if (!this.inSelection) {
               this.moveWithinTableRange(var2, this.dx, this.dy, this.extend);
               if (!this.extend) {
                  var2.changeSelection(this.anchorRow, this.anchorColumn, false, this.extend);
               } else {
                  var2.changeSelection(this.leadRow, this.leadColumn, false, this.extend);
               }
            } else if (this.moveWithinSelectedRange(var2, this.dx, this.dy, false)) {
               var2.changeSelection(this.anchorRow, this.anchorColumn, true, true);
            } else {
               var2.changeSelection(this.anchorRow, this.anchorColumn, false, false);
            }
         }
      }
   }

   private static class PagingAction extends RaritanTableUI.NavigationalAction {
      private static final long serialVersionUID = 1199054984536998883L;
      private boolean forwards;
      private boolean vertically;
      private boolean toLimit;

      private PagingAction(boolean var1, boolean var2, boolean var3, boolean var4) {
         super(0, 0, false, var1, false);
         this.forwards = var2;
         this.vertically = var3;
         this.toLimit = var4;
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         if (this.toLimit) {
            if (this.vertically) {
               int var3 = var2.getRowCount();
               this.dx = 0;
               this.dy = this.forwards ? var3 : -var3;
            } else {
               int var8 = var2.getColumnCount();
               this.dx = this.forwards ? var8 : -var8;
               this.dy = 0;
            }
         } else {
            if (!(var2.getParent().getParent() instanceof JScrollPane)) {
               return;
            }

            Dimension var9 = var2.getParent().getSize();
            ListSelectionModel var4 = this.vertically ? var2.getSelectionModel() : var2.getColumnModel().getSelectionModel();
            int var5 = this.extend ? var4.getLeadSelectionIndex() : var4.getAnchorSelectionIndex();
            if (this.vertically) {
               Rectangle var6 = var2.getCellRect(var5, 0, true);
               var6.y = var6.y + (this.forwards ? var9.height : -var9.height);
               this.dx = 0;
               int var7 = var2.rowAtPoint(var6.getLocation());
               if (var7 == -1 && this.forwards) {
                  var7 = var2.getRowCount();
               }

               this.dy = var7 - var5;
            } else {
               Rectangle var10 = var2.getCellRect(0, var5, true);
               var10.x = var10.x + (this.forwards ? var9.width : -var9.width);
               int var11 = var2.columnAtPoint(var10.getLocation());
               if (var11 == -1 && this.forwards) {
                  var11 = var2.getColumnCount();
               }

               this.dx = var11 - var5;
               this.dy = 0;
            }
         }

         super.actionPerformed(var1);
      }
   }

   private static class SelectAllAction extends AbstractAction {
      private static final long serialVersionUID = -2793523430798554295L;

      private SelectAllAction() {
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         var2.selectAll();
      }
   }

   private static class StartEditingAction extends AbstractAction {
      private static final long serialVersionUID = 4291641785422799756L;

      private StartEditingAction() {
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         if (!var2.hasFocus()) {
            TableCellEditor var8 = var2.getCellEditor();
            if (var8 == null || var8.stopCellEditing()) {
               var2.requestFocus();
            }
         } else {
            ListSelectionModel var3 = var2.getSelectionModel();
            int var4 = var3.getAnchorSelectionIndex();
            ListSelectionModel var5 = var2.getColumnModel().getSelectionModel();
            int var6 = var5.getAnchorSelectionIndex();
            var2.editCellAt(var4, var6);
            Component var7 = var2.getEditorComponent();
            if (var7 != null) {
               var7.requestFocus();
            }
         }
      }
   }

   private static class TabNextAction extends AbstractAction {
      private static final long serialVersionUID = -3868790363838289292L;

      private TabNextAction() {
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         var2.transferFocus();
      }
   }

   private static class TabPreviousAction extends AbstractAction {
      private static final long serialVersionUID = 6582574981741021581L;

      private TabPreviousAction() {
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         JTable var2 = (JTable)var1.getSource();
         var2.transferFocusBackward();
      }
   }
}
