package com.raritan.protocol.browser.spi;

import com.raritan.protocol.browser.BrowserEvent;
import com.raritan.protocol.browser.BrowserEventHandler;
import com.raritan.protocol.browser.HintAddress;
import com.raritan.protocol.csc.RRCDeviceInfo;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.util.Util;
import java.io.IOException;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.SocketException;
import java.net.SocketTimeoutException;
import java.net.UnknownHostException;
import java.util.Collection;
import java.util.Collections;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javaclientlib.utils.RRCLogger;
import javaclientlib.utils.XMLParser;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class Browser implements com.raritan.protocol.browser.Browser {
   protected static final int SEND_PING_INTERVAL = 1000;
   private List listeners = new LinkedList();
   private Map activeDevices = new HashMap();
   private Map hintAddresses = new HashMap();
   private Map pingHintAddresses = new HashMap();
   private Browser.WorkerThread worker = null;
   private boolean browseLocalNetwork = true;
   private int queryInterval = 10;
   private int removeInterval = 100;
   private int defaultDiscoveryPort = 5000;
   private boolean refresh = false;
   private final Browser.BroadcastState broadcastState = new Browser.BroadcastState();
   private RRCScreenContext scrContext;
   private Set devicesNotToBeRefreshed = new HashSet();
   private DNSLookupHelper dnsLookupHelper = new DNSLookupHelper(this);

   private RRCDeviceInfoEx populateDevice(String var1, DatagramPacket var2) {
      RRCDeviceInfoEx var3 = new RRCDeviceInfoEx(var2.getSocketAddress(), -1L);
      InetAddress var4 = var2.getAddress();
      var3.setPort(var2.getPort());
      boolean var5 = var4 instanceof Inet6Address && var4.isLinkLocalAddress();

      try {
         XMLParser var6 = new XMLParser();
         Document var7 = var6.getDocument(var1);
         if (var7 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "XML document is empty");
            }

            return null;
         }

         Element var8 = var7.getDocumentElement();
         Object var28 = null;
         NodeList var9 = var8.getElementsByTagName("Device");
         if (var9 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device>");
            }

            return null;
         }

         if (var9.getLength() > 1 && RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "No <Device> length");
         }

         Element var10 = (Element)var9.item(0);
         String var11 = var10.getAttribute("Type");
         String var12 = var10.getAttribute("Model");
         String var13 = var10.getAttribute("Version");
         String var14 = var10.getAttribute("ProductName");
         String var15 = var10.getAttribute("id");
         if (null != var12) {
            var3.setModel("Model");
         }

         if (null != var11) {
            var3.setType(var11);
         }

         if (null != var13) {
            var3.setClusterId(var13);
         }

         if (null != var14) {
            var3.setProductName(var14);
         }

         var3.setDeviceID(var15);
         NodeList var16 = var10.getElementsByTagName("Name");
         String var17 = "";
         if (var16 != null && var16.getLength() != 0 && var16.item(0).getFirstChild() != null) {
            Node var18 = var16.item(0).getFirstChild();
            var17 = var18.getNodeValue();
            if (var17 == null || var17.trim().length() == 0) {
               return null;
            }
         }

         var3.setName(var17);
         if (var5) {
            NodeList var29 = var10.getElementsByTagName("IPAddress_v6");
            InetAddress var19 = null;
            if (var29.getLength() > 0) {
               String var20 = XMLParser.getTextContent(var29.item(0));
               if (var20 != null) {
                  try {
                     var19 = InetAddress.getByName(var20);
                  } catch (UnknownHostException var22) {
                  }
               }
            }

            if (var19 == null) {
               return null;
            }

            var3.setInetAddress(var19);
         } else {
            var3.setInetAddress(var4);
         }

         NodeList var30 = var10.getElementsByTagName("Hostname");
         if (var30.getLength() > 0) {
            var3.setDnsName(XMLParser.getTextContent(var30.item(0)));
         }

         String var31 = this.dnsLookupHelper.getDNSName(var3.getInetAddress());
         if (var31 != null) {
            var3.setDnsName(var31);
         }
      } catch (NumberFormatException var23) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var23.getMessage());
         }
      } catch (DOMException var24) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var24.getMessage());
         }
      } catch (IOException var25) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var25.getMessage());
         }
      } catch (SAXException var26) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var26.getMessage());
         }
      } catch (ParserConfigurationException var27) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var27.getMessage());
         }
      }

      return var3;
   }

   @Override
   public synchronized void start() {
      if (this.worker == null) {
         this.worker = new Browser.WorkerThread(this);
         this.worker.startWorker();
         this.dnsLookupHelper.startLookupThread();
      }
   }

   @Override
   public synchronized void stop() {
      this.clearActiveDevices();
      this.removeAllHintAddresses();
      if (this.worker != null) {
         try {
            this.worker.stopWorker();
         } catch (InterruptedException var2) {
            if (RRCLogger.logEnabled) {
               RRCLogger.logException(var2);
            }
         }

         this.worker = null;
      }

      this.dnsLookupHelper.stopLookupThread();
   }

   @Override
   public synchronized boolean isRunning() {
      return this.worker != null;
   }

   @Override
   public void addHandler(BrowserEventHandler var1) {
      if (var1 != null) {
         synchronized (this.listeners) {
            if (!this.listeners.contains(var1)) {
               this.listeners.add(var1);
            }
         }

         Enumeration var5 = this.getActiveDevices();

         while (var5 != null && var5.hasMoreElements()) {
            this._notifyListener(var1, new BrowserEventImpl(1, (RRCDeviceInfo)var5.nextElement()));
         }
      }
   }

   @Override
   public void removeHandler(BrowserEventHandler var1) {
      if (var1 != null) {
         synchronized (this.listeners) {
            this.listeners.remove(var1);
         }
      }
   }

   @Override
   public void removeAllHandlers() {
      synchronized (this.listeners) {
         this.listeners.clear();
      }
   }

   private void _notifyListener(BrowserEventHandler var1, BrowserEvent var2) {
      synchronized (this.listeners) {
         if (!this.listeners.contains(var1)) {
            return;
         }
      }

      if (var1 != null) {
         try {
            var1.notify(this, var2);
         } catch (Throwable var5) {
            RRCLogger.log(300, 128, var5, "Exception in browser notification");
         }
      }
   }

   private void _notifyListeners(BrowserEvent var1) {
      Object var2 = null;
      synchronized (this.listeners) {
         var2 = new LinkedList(this.listeners);
      }

      for (BrowserEventHandler var4 : var2) {
         this._notifyListener(var4, var1);
      }
   }

   @Override
   public Enumeration getActiveDevices() {
      Object var1 = null;
      synchronized (this.activeDevices) {
         var1 = new LinkedList(this.activeDevices.values());
      }

      return Collections.enumeration((Collection)var1);
   }

   @Override
   public Enumeration getActiveDevicesByName(String var1) {
      if (var1 != null && var1.trim().length() != 0) {
         LinkedList var2 = new LinkedList();
         synchronized (this.activeDevices) {
            for (RRCDeviceInfo var5 : this.activeDevices.values()) {
               if (var5.getName().equalsIgnoreCase(var1)) {
                  var2.add(var5);
               }
            }
         }

         return Collections.enumeration(var2);
      } else {
         return Collections.enumeration(Collections.EMPTY_LIST);
      }
   }

   @Override
   public Enumeration getActiveDevicesByHost(String var1) throws UnknownHostException {
      InetAddress[] var2 = InetAddress.getAllByName(var1);
      LinkedList var3 = new LinkedList();
      synchronized (this.activeDevices) {
         for (RRCDeviceInfoEx var6 : this.activeDevices.values()) {
            if (var6.getSocketAddress() instanceof InetSocketAddress) {
               for (int var7 = 0; var7 < var2.length; var7++) {
                  if (var2[var7].equals(((InetSocketAddress)var6.getSocketAddress()).getAddress())) {
                     var3.add(var6);
                     break;
                  }
               }
            }
         }
      }

      return Collections.enumeration(var3);
   }

   private void _onReceivePing(RRCDeviceInfoEx var1) {
      boolean var2 = false;
      synchronized (this.activeDevices) {
         if (this.activeDevices.containsKey(var1.getSocketAddress())) {
            var1 = (RRCDeviceInfoEx)this.activeDevices.get(var1.getSocketAddress());
         } else {
            var2 = true;
            this.activeDevices.put(var1.getSocketAddress(), var1);
            RRCLogger.log(300, 128, "Adding deivce " + var1.getName() + " [" + var1.getHost() + "]");
         }
      }

      var1.lastPingTime = System.currentTimeMillis();
      Object var6 = null;
      if (var2) {
         var6 = new BrowserEventImpl(1, var1);
         this._notifyListeners((BrowserEvent)var6);
      } else {
         var6 = new BrowserEventImpl(3, var1);
         this._notifyListeners((BrowserEvent)var6);
      }
   }

   private void _removeDevice(RRCDeviceInfoEx var1) {
      synchronized (this.activeDevices) {
         var1 = (RRCDeviceInfoEx)this.activeDevices.remove(var1.getSocketAddress());
      }

      if (var1 != null) {
         BrowserEventImpl var6 = new BrowserEventImpl(2, var1);
         this._notifyListeners(var6);
      }
   }

   private void _checkForExpiration() {
      long var1 = System.currentTimeMillis();
      Enumeration var3 = this.getActiveDevices();

      while (var3.hasMoreElements()) {
         RRCDeviceInfoEx var4 = (RRCDeviceInfoEx)var3.nextElement();
         if (var1 - var4.lastPingTime >= this.removeInterval * 1000) {
            RRCLogger.log(300, 128, "Removing device " + var4.getName() + " [" + var4.getHost() + "]");
            this._removeDevice(var4);
         }
      }
   }

   public void clearActiveDevices() {
      synchronized (this.activeDevices) {
         this.activeDevices.clear();
      }
   }

   @Override
   public void addDNSHint(String var1, int var2) {
      this.dnsLookupHelper.addDNS(var1, var2);
   }

   @Override
   public void removeDNSHint(String var1) {
      this.dnsLookupHelper.removeDNS(var1);
   }

   @Override
   public void addHintAddress(HintAddress var1) throws UnknownHostException {
      HintAddressEx var2 = new HintAddressEx(var1);
      if (!var2.getAddress().isAnyLocalAddress()) {
         synchronized (this.hintAddresses) {
            if (this.hintAddresses.containsKey(var2)) {
               return;
            }
         }

         var2.getAddress();
         synchronized (this.hintAddresses) {
            this.hintAddresses.put(var2, var2);
         }
      }
   }

   @Override
   public void removeHintAddress(HintAddress var1) {
      synchronized (this.hintAddresses) {
         this.hintAddresses.remove(var1);
      }
   }

   @Override
   public void removeAllHintAddresses() {
      synchronized (this.hintAddresses) {
         this.hintAddresses.clear();
      }
   }

   @Override
   public Enumeration getAllHintAddresses() {
      Object var1 = null;
      synchronized (this.hintAddresses) {
         var1 = new LinkedList(this.hintAddresses.values());
      }

      return Collections.enumeration((Collection)var1);
   }

   @Override
   public void browseLocalNetwork(boolean var1) {
      this.browseLocalNetwork = var1;
   }

   @Override
   public boolean isBrowseLocalNetwork() {
      return this.browseLocalNetwork;
   }

   @Override
   public void setQueryInterval(int var1) {
      if (var1 >= 0) {
         this.queryInterval = var1;
      }
   }

   @Override
   public int getQueryInterval() {
      return this.queryInterval;
   }

   @Override
   public void setRemoveInterval(int var1) {
      if (var1 >= 0) {
         this.removeInterval = var1;
      }
   }

   @Override
   public int getRemoveInterval() {
      return this.removeInterval;
   }

   @Override
   public synchronized int getDefaultDiscoveryPort() {
      return this.defaultDiscoveryPort;
   }

   @Override
   public synchronized void setDefaultDiscoveryPort(int var1) {
      if (var1 > 0) {
         this.defaultDiscoveryPort = var1;
      }
   }

   private synchronized boolean isRefresh() {
      return this.refresh;
   }

   public synchronized void refreshDevices(Set var1) {
      this.devicesNotToBeRefreshed.addAll(var1);
      this.refresh = true;
   }

   private synchronized Set getRefreshDevices() {
      HashSet var1 = new HashSet(this.devicesNotToBeRefreshed);
      this.devicesNotToBeRefreshed.clear();
      this.refresh = false;
      return var1;
   }

   private void processUpdateDevices(Set var1) {
      if (this.scrContext.getCreateProfileBy() != 3) {
         Map var2 = null;
         synchronized (this.activeDevices) {
            var2 = new HashMap(this.activeDevices);
         }

         Iterator var4 = var1.iterator();

         while (var4.hasNext()) {
            var2.remove(((RRCDeviceInfoEx)var4.next()).getSocketAddress());
         }

         var4 = var2.values().iterator();

         while (var4.hasNext()) {
            this._removeDevice((RRCDeviceInfoEx)var4.next());
         }
      }
   }

   public void stopBroadcastAndUpdateDevices(Set var1) {
      this.broadcastState.stopBroadcastAndUpdateDevices(var1);
   }

   public void setBroadcastEnabled() {
      this.broadcastState.setBroadcastEnabled();
   }

   public RRCDeviceInfo pingHintAddress(HintAddress var1, long var2) throws UnknownHostException, InterruptedException {
      HintAddressEx var4 = new HintAddressEx(var1);
      var4.getAddress();
      synchronized (this.pingHintAddresses) {
         HintAddressEx var6 = (HintAddressEx)this.pingHintAddresses.get(var4);
         if (var6 != null) {
            var4 = var6;
         } else {
            this.pingHintAddresses.put(var4, var4);
         }
      }

      if (var2 <= 500L) {
         var2 = 500L;
      }

      InterruptedException var14 = null;
      synchronized (var4) {
         try {
            var4.wait(var2);
         } catch (InterruptedException var11) {
            var14 = var11;
         }
      }

      synchronized (this.pingHintAddresses) {
         this.pingHintAddresses.remove(var4);
      }

      if (var14 != null) {
         throw var14;
      } else {
         return var4.getPingResult();
      }
   }

   public void setScreenContext(RRCScreenContext var1) {
      this.scrContext = var1;
   }

   private class BroadcastState {
      private boolean broadcastEnabled = false;
      private Set devicesNotToBeUpdatedOnStopBroadcast = new HashSet();

      private BroadcastState() {
      }

      public boolean waitTillBroadcastEnabled() {
         boolean var1 = false;
         if (!this.isBroadcastEnabled()) {
            Browser.this.processUpdateDevices(this.getDevicesNotToBeUpdated());
            var1 = true;
         }

         synchronized (this) {
            while (!this.isBroadcastEnabled()) {
               try {
                  this.wait();
               } catch (InterruptedException var5) {
               }
            }

            return var1;
         }
      }

      public synchronized boolean isBroadcastEnabled() {
         return this.broadcastEnabled;
      }

      public synchronized void setBroadcastEnabled() {
         this.broadcastEnabled = true;
         this.notifyAll();
      }

      public synchronized void stopBroadcastAndUpdateDevices(Set var1) {
         this.devicesNotToBeUpdatedOnStopBroadcast.clear();
         this.devicesNotToBeUpdatedOnStopBroadcast.addAll(var1);
         this.broadcastEnabled = false;
      }

      private synchronized Set getDevicesNotToBeUpdated() {
         HashSet var1 = new HashSet(this.devicesNotToBeUpdatedOnStopBroadcast);
         this.devicesNotToBeUpdatedOnStopBroadcast.clear();
         return var1;
      }
   }

   protected class WorkerThread extends Thread {
      protected static final boolean debug = false;
      protected static final int RECEIVE_TIMEOUT = 30000;
      protected static final int RECEIVE_BUFFER_SIZE = 100000;
      protected final byte[] CSC_Discover = new byte[]{0, 0, 0, 20, 60, 67, 83, 67, 95, 68, 105, 115, 99, 111, 118, 101, 114, 47, 62, 0};
      protected Browser browser = null;
      protected boolean isRunning = false;

      protected WorkerThread(Browser var2) {
         super("Raritan.Protocol.Browser.WorkerThread");
         this.setDaemon(true);
         this.browser = var2;
      }

      protected void startWorker() {
         if (!this.isRunning()) {
            this.start();
         }
      }

      protected void stopWorker() throws InterruptedException {
         if (this.isRunning()) {
            this.isRunning = false;
            this.interrupt();
            this.join();
         }
      }

      protected boolean isRunning() {
         return this.isRunning;
      }

      @Override
      public void run() {
         this.isRunning = true;
         DatagramSocket var1 = null;
         DatagramPacket var2 = null;
         DatagramPacket var3 = null;
         long var4 = 0L;
         var2 = new DatagramPacket(this.CSC_Discover, this.CSC_Discover.length);
         var2.setPort(this.browser.getDefaultDiscoveryPort());
         byte[] var6 = new byte[1024];
         var3 = new DatagramPacket(var6, var6.length);

         try {
            var1 = new DatagramSocket();
            var1.setReceiveBufferSize(100000);
         } catch (SocketException var45) {
            RRCLogger.logException(var45);
            this.isRunning = false;
            return;
         }

         do {
            boolean var7 = Browser.this.broadcastState.waitTillBroadcastEnabled();
            this.browser._checkForExpiration();
            long var8 = System.currentTimeMillis();
            synchronized (this.browser.pingHintAddresses) {
               for (HintAddressEx var12 : this.browser.pingHintAddresses.values()) {
                  if (var8 - var12.getPingTime() > 1000L) {
                     var12.setPingTime(var8);

                     try {
                        var2.setAddress(var12.inetAddress);
                        var2.setPort(var12.port);
                        var1.send(var2);
                     } catch (UnknownHostException var32) {
                        RRCLogger.logException(var32);
                     } catch (IOException var33) {
                        RRCLogger.logException(var33);
                     }
                  }
               }
            }

            if (Browser.this.broadcastState.isBroadcastEnabled() && (var7 || Browser.this.isRefresh() || var8 - var4 >= this.browser.queryInterval * 1000)) {
               if (Browser.this.isRefresh()) {
                  Browser.this.processUpdateDevices(Browser.this.getRefreshDevices());
               }

               var4 = var8;
               Enumeration var10 = this.browser.getAllHintAddresses();

               while (var10.hasMoreElements()) {
                  HintAddressEx var52 = (HintAddressEx)var10.nextElement();
                  if (var52.inetAddress instanceof Inet4Address
                     || var52.inetAddress instanceof Inet6Address
                        && Util.isIPV6Supported()
                        && Browser.this.scrContext.getAppSettings().isIPv6NetworkingEnabled()) {
                     try {
                        var2.setAddress(var52.inetAddress);
                        var2.setPort(var52.port);
                        var1.send(var2);
                     } catch (UnknownHostException var43) {
                        RRCLogger.logException(var43);
                     } catch (IOException var44) {
                        RRCLogger.logException(var44);
                     }
                  }
               }

               if (this.browser.browseLocalNetwork) {
                  try {
                     InetAddress var53 = InetAddress.getByName("255.255.255.255");
                     var2.setAddress(var53);
                     var2.setPort(this.browser.getDefaultDiscoveryPort());
                     var1.send(var2);
                  } catch (UnknownHostException var41) {
                     RRCLogger.logException(var41);
                  } catch (IOException var42) {
                     RRCLogger.logException(var42);
                  }

                  if (Util.isIPV6Supported() && Browser.this.scrContext.getAppSettings().isIPv6NetworkingEnabled()) {
                     try {
                        InetAddress var54 = InetAddress.getByName("FF02::1");
                        var2.setAddress(var54);
                        var2.setPort(this.browser.getDefaultDiscoveryPort());
                        var1.send(var2);
                     } catch (UnknownHostException var39) {
                        RRCLogger.logException(var39);
                     } catch (IOException var40) {
                        RRCLogger.logException(var40);
                     }
                  }
               }
            }

            long var50 = System.currentTimeMillis();

            while (Browser.this.broadcastState.isBroadcastEnabled() && var50 - var8 <= 30000L && !Browser.this.isRefresh()) {
               try {
                  var1.setSoTimeout(500);
                  var1.receive(var3);
                  byte[] var55 = var3.getData();
                  String var13 = new String(var55);
                  String var14 = var13.substring(4, var13.indexOf("</CSC_Info>")) + "</CSC_Info>";
                  RRCDeviceInfoEx var15 = Browser.this.populateDevice(var14, var3);
                  if (var15 != null) {
                     this.browser._onReceivePing(var15);
                  }
               } catch (SocketException var34) {
                  RRCLogger.logException(var34);
               } catch (SocketTimeoutException var35) {
               } catch (IOException var36) {
                  RRCLogger.logException(var36);
               } catch (Exception var37) {
                  RRCLogger.logException(var37);
               } finally {
                  var50 = System.currentTimeMillis();
               }
            }
         } while (this.isRunning);

         var1.disconnect();
         var1.close();
         this.isRunning = false;
      }
   }
}
