package com.raritan.protocol.browser.spi;

import com.raritan.protocol.browser.BrowserEvent;
import com.raritan.protocol.browser.BrowserEventHandler;
import com.raritan.protocol.csc.RRCDeviceInfo;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class BrowserByName implements BrowserEventHandler {
   private final Map deviceMap = Collections.synchronizedMap(new HashMap());
   private final BrowserEventHandler handler;
   private final Set deviceNames = Collections.synchronizedSet(new HashSet());

   public BrowserByName(com.raritan.protocol.browser.Browser var1, BrowserEventHandler var2) {
      this.handler = var2;
      var1.addHandler(this);
   }

   @Override
   public void notify(com.raritan.protocol.browser.Browser var1, BrowserEvent var2) {
      RRCDeviceInfo var3 = var2.getDeviceInfo();
      String var4 = var3.getHost();
      switch (var2.getType()) {
         case 1:
            synchronized (this) {
               if (this.deviceMap.put(var4, var3) == null) {
                  this.fireListener(1, var3, var1);
               }
               break;
            }
         case 2:
            if (this.deviceMap.remove(var4) != null) {
               this.fireListener(2, var3, var1);
            }
         case 3:
      }
   }

   public synchronized boolean addBrowseByName(String var1) {
      String var2 = var1.toLowerCase();
      this.deviceNames.add(var2);
      return this.isDeviceAlive(var2);
   }

   public void removeBrowseByName(String var1) {
      String var2 = var1.toLowerCase();
      this.deviceNames.remove(var2);
   }

   private boolean isDeviceAlive(String var1) {
      for (RRCDeviceInfo var3 : this.deviceMap.values()) {
         if (var3.getName().equalsIgnoreCase(var1)) {
            return true;
         }
      }

      return false;
   }

   private void fireListener(int var1, RRCDeviceInfo var2, com.raritan.protocol.browser.Browser var3) {
      if (this.deviceNames.contains(var2.getName().toLowerCase())) {
         BrowserEventImpl var4 = new BrowserEventImpl(var1, var2);
         this.handler.notify(var3, var4);
      }
   }

   public synchronized void clearDeviceMap() {
      this.deviceMap.clear();
   }

   public static void main(String[] var0) throws Exception {
      Browser var1 = new Browser();
      BrowserByName var2 = new BrowserByName(var1, new BrowserEventHandler() {
         @Override
         public void notify(com.raritan.protocol.browser.Browser var1, BrowserEvent var2x) {
            System.out.println("Type : " + var2x.getType() + " : " + var2x);
         }
      });
      var1.start();

      while (true) {
         BufferedReader var3 = new BufferedReader(new InputStreamReader(System.in));
         System.out.println("Waiting for Input : add | del name");
         String var4 = var3.readLine();
         if (var4.startsWith("add")) {
            var4 = var4.substring(4);
            System.out.println(var2.addBrowseByName(var4));
         } else if (var4.startsWith("del")) {
            var4 = var4.substring(4);
            var2.removeBrowseByName(var4);
         }
      }
   }
}
