package com.raritan.protocol.browser.spi;

import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.UnknownHostException;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Set;
import java.util.Vector;
import javaclientlib.utils.RRCLogger;

public class DNSLookupHelper {
   private final HashMap nameToIPSet = new HashMap();
   private final HashMap ipToName = new HashMap();
   private final Vector lookupQueue = new Vector(10);
   private final com.raritan.protocol.browser.Browser browser;
   private boolean keepLooking;
   private DNSLookupHelper.LookupThread lookupThread = new DNSLookupHelper.LookupThread();

   public DNSLookupHelper(com.raritan.protocol.browser.Browser var1) {
      this.browser = var1;
   }

   public void addDNS(String var1, int var2) {
      DNSLookupHelper.LookupEntry var3 = new DNSLookupHelper.LookupEntry(var1, var2);
      this.lookupQueue.add(var3);
      synchronized (this.lookupQueue) {
         this.lookupQueue.notifyAll();
      }
   }

   public synchronized void removeDNS(String var1) {
      String var2 = var1.toLowerCase();
      Set var3 = (Set)this.nameToIPSet.remove(var2);
      if (var3 != null) {
         for (InetSocketAddress var5 : var3) {
            this.browser.removeHintAddress(new HintAddressEx(var5.getAddress().getHostAddress(), var5.getPort()));
         }
      }
   }

   public synchronized void refresh() {
      this.ipToName.clear();
   }

   public synchronized String getDNSName(InetAddress var1) {
      return (String)this.ipToName.get(var1);
   }

   public void startLookupThread() {
      this.keepLooking = true;
      this.lookupThread.start();
   }

   public void stopLookupThread() {
      this.keepLooking = false;
      this.lookupThread.interrupt();
   }

   class LookupEntry {
      private String dnsName;
      private int port;

      public LookupEntry(String var2, int var3) {
         this.dnsName = var2;
         this.port = var3;
      }
   }

   class LookupThread extends Thread {
      public LookupThread() {
         super("DNSLookupHelper.LookupThread");
         this.setDaemon(true);
         RRCLogger.log(300, 128, "DNSLookupHelper.LookupThread started");
      }

      @Override
      public void run() {
         while (DNSLookupHelper.this.keepLooking) {
            synchronized (DNSLookupHelper.this.lookupQueue) {
               while (DNSLookupHelper.this.lookupQueue.size() <= 0) {
                  try {
                     DNSLookupHelper.this.lookupQueue.wait();
                  } catch (InterruptedException var4) {
                     RRCLogger.logException(var4);
                  }
               }
            }

            this.findAndAddDNSDevice();
         }

         RRCLogger.log(300, 128, "DNSLookupHelper.LookupThread Stopped");
      }

      private void findAndAddDNSDevice() {
         DNSLookupHelper.LookupEntry var1 = (DNSLookupHelper.LookupEntry)DNSLookupHelper.this.lookupQueue.remove(0);
         String var2 = var1.dnsName.toLowerCase();
         InetAddress[] var3 = this.lookup(var2);
         synchronized (DNSLookupHelper.this) {
            if (var3 == null) {
               DNSLookupHelper.this.nameToIPSet.put(var2, Collections.EMPTY_SET);
               RRCLogger.log(300, 128, "DNSLookupHelper.LookupThread.findDNSDevice() : " + var2 + " lookup() returned NULL");
            } else {
               HashSet var5 = new HashSet();

               for (int var6 = 0; var6 < var3.length; var6++) {
                  DNSLookupHelper.this.ipToName.put(var3[var6], var1.dnsName);
                  var5.add(new InetSocketAddress(var3[var6], var1.port));
                  RRCLogger.log(300, 128, "DNSLookupHelper.LookupThread.findDNSDevice() : " + var3[var6]);
               }

               DNSLookupHelper.this.nameToIPSet.put(var2, var5);
            }
         }

         if (var3 != null) {
            for (int var10 = 0; var10 < var3.length; var10++) {
               try {
                  DNSLookupHelper.this.browser.addHintAddress(new HintAddressEx(var3[var10].getHostAddress(), var1.port));
               } catch (UnknownHostException var8) {
               }
            }
         }
      }

      private InetAddress[] lookup(String var1) {
         try {
            return InetAddress.getAllByName(var1);
         } catch (UnknownHostException var3) {
            return null;
         }
      }
   }
}
