package com.raritan.rrc.components.serialconsole;

import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

public class ConfigDialog extends JDialog implements ActionListener {
   private static final long serialVersionUID = -2348764668297525927L;
   private static final String CMD_OK = "CMD_OK";
   private static final String CMD_CANCEL = "CMD_CANCEL";
   private static final int HALF_BRIGHT = 1;
   private static final int FULL_BRIGHT = 0;
   private Terminal terminal;
   private StatusBar statusBar;
   private JLabel lblCodeSet;
   private JRadioButton rbtASCII;
   private JRadioButton rbt88591;
   private JRadioButton rbt885915;
   private ButtonGroup groupCodeSet;
   private JLabel lblCursorType;
   private JRadioButton rbtHalfBrightBox;
   private JRadioButton rbtFullBrightBox;
   private ButtonGroup groupCursorType;
   private JButton btnOk;
   private JButton btnCancel;

   public ConfigDialog(Frame var1) {
      super(var1);
      this.setDefaultCloseOperation(2);
      this.getContentPane().setLayout(new GridBagLayout());
      this.initComponents();
      this.pack();
      this.setSize(320, 170);
      this.setLocationRelativeTo(this.getParent());
      this.setResizable(false);
   }

   public ConfigDialog(Frame var1, boolean var2) {
      this(var1);
      this.setModal(var2);
   }

   ConfigDialog(StatusBar var1, Terminal var2) {
      this(JOptionPane.getFrameForComponent(var2), "Settings", true);
      this.terminal = var2;
      this.statusBar = var1;
      if (var2.getCodeSet().equals("ISO 8859-15 (Latin-9)")) {
         this.rbt885915.setSelected(true);
      } else if (var2.getCodeSet().equals("ISO 8859-1 (Latin-1)")) {
         this.rbt88591.setSelected(true);
      } else {
         this.rbtASCII.setSelected(true);
      }

      if (var2.getCursorType() == 0) {
         this.rbtFullBrightBox.setSelected(true);
      } else {
         this.rbtHalfBrightBox.setSelected(true);
      }
   }

   public ConfigDialog(Frame var1, String var2, boolean var3) {
      this(var1, var3);
      this.setTitle(var2);
   }

   private void initComponents() {
      this.lblCodeSet = new JLabel("Code Set:", 2);
      this.getContentPane().add(this.lblCodeSet, new GridBagConstraints(0, 0, 1, 1, 0.5, 0.0, 10, 2, new Insets(4, 4, 4, 4), 0, 0));
      this.lblCursorType = new JLabel("Cursor Type:", 2);
      this.getContentPane().add(this.lblCursorType, new GridBagConstraints(1, 0, 1, 1, 0.5, 0.0, 10, 2, new Insets(4, 4, 4, 4), 0, 0));
      this.rbtASCII = new JRadioButton("US ASCII (True VT100)");
      this.getContentPane().add(this.rbtASCII, new GridBagConstraints(0, 1, 1, 1, 0.5, 0.0, 10, 2, new Insets(4, 4, 2, 4), 0, 0));
      this.rbtHalfBrightBox = new JRadioButton("Line Cursor");
      this.getContentPane().add(this.rbtHalfBrightBox, new GridBagConstraints(1, 1, 1, 1, 0.5, 0.0, 10, 2, new Insets(4, 4, 2, 4), 0, 0));
      this.rbt88591 = new JRadioButton("ISO 8859-1 (Latin-1)");
      this.getContentPane().add(this.rbt88591, new GridBagConstraints(0, 2, 1, 1, 0.5, 0.0, 10, 2, new Insets(2, 4, 2, 4), 0, 0));
      this.rbtFullBrightBox = new JRadioButton("Block Cursor");
      this.getContentPane().add(this.rbtFullBrightBox, new GridBagConstraints(1, 2, 1, 1, 0.5, 0.0, 10, 2, new Insets(2, 4, 2, 4), 0, 0));
      this.rbt885915 = new JRadioButton("ISO 8859-15 (Latin-9)");
      this.getContentPane().add(this.rbt885915, new GridBagConstraints(0, 3, 1, 1, 0.5, 0.0, 10, 2, new Insets(2, 4, 2, 4), 0, 0));
      this.groupCodeSet = new ButtonGroup();
      this.groupCodeSet.add(this.rbtASCII);
      this.groupCodeSet.add(this.rbt88591);
      this.groupCodeSet.add(this.rbt885915);
      this.groupCursorType = new ButtonGroup();
      this.groupCursorType.add(this.rbtHalfBrightBox);
      this.groupCursorType.add(this.rbtFullBrightBox);
      JPanel var1 = new JPanel();
      var1.setLayout(new GridLayout(1, 0, 4, 4));
      this.btnOk = new JButton("OK");
      this.btnOk.setActionCommand("CMD_OK");
      this.btnOk.addActionListener(this);
      var1.add(this.btnOk);
      this.btnCancel = new JButton("Cancel");
      this.btnCancel.setActionCommand("CMD_CANCEL");
      this.btnCancel.addActionListener(this);
      var1.add(this.btnCancel);
      this.getContentPane().add(var1, new GridBagConstraints(0, 4, 2, 1, 1.0, 0.0, 15, 0, new Insets(4, 4, 4, 4), 0, 0));
   }

   void changeConfiguration() {
      String var1 = this.rbtASCII.isSelected() ? this.rbtASCII.getText() : (this.rbt88591.isSelected() ? this.rbt88591.getText() : this.rbt885915.getText());
      String var2 = this.rbtFullBrightBox.isSelected() ? this.rbtFullBrightBox.getText() : this.rbtHalfBrightBox.getText();
      if (var2 != null && var2.indexOf("Line") != -1) {
         this.terminal.setCursorType(1);
      } else {
         this.terminal.setCursorType(0);
      }

      if (!var1.equals(this.terminal.getCodeSet())) {
         this.terminal.setCodeSet(var1);
         this.terminal.initEmulator();
         this.terminal.saveConfig();
      }

      this.terminal.vdu.reDraw();
      this.dispose();
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      String var2 = var1.getActionCommand();
      if (var2.equals("CMD_OK")) {
         this.changeConfiguration();
      } else if (var2.equals("CMD_CANCEL")) {
         this.dispose();
      }
   }
}
