package com.raritan.rrc.components.serialconsole;

import com.raritan.rrc.util.CircBuffer;
import com.raritan.rrc.util.StringUtils;
import java.awt.AWTEvent;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.KeyEventDispatcher;
import java.awt.KeyboardFocusManager;
import java.awt.Toolkit;
import java.awt.datatransfer.Clipboard;
import java.awt.datatransfer.ClipboardOwner;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.StringSelection;
import java.awt.datatransfer.Transferable;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.awt.event.ComponentEvent;
import java.awt.event.ComponentListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.event.WindowEvent;
import java.io.File;
import java.util.ArrayList;
import java.util.Hashtable;
import javaclientlib.clientlib.TRSerialStream;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.event.InternalFrameEvent;
import javax.swing.event.InternalFrameListener;

public class Terminal
   extends JPanel
   implements InternalFrameListener,
   ActionListener,
   AdjustmentListener,
   ComponentListener,
   KeyListener,
   MouseListener,
   FocusListener,
   MouseMotionListener,
   ClipboardOwner {
   public static final String CODESET_USASCII = "US ASCII (True VT100)";
   public static final String CODESET_ISO_8859_1 = "ISO 8859-1 (Latin-1)";
   public static final String CODESET_ISO_8859_15 = "ISO 8859-15 (Latin-9)";
   private static final int ROWS = 24;
   private static final int BUFFER_SIZE = 5002;
   private static final int PORT_NUMBER = 23;
   private static final String KEY_INSERT = "\u001b[4h";
   private static final String KEY_REMOVE = "\u001b[6h";
   private static final String KEY_HOME = "\u001b[H";
   private static final String KP_0 = "\u001bOp";
   private static final String KP_1 = "\u001bOq";
   private static final String KP_2 = "\u001bOr";
   private static final String KP_3 = "\u001bOs";
   private static final String KP_4 = "\u001bOt";
   private static final String KP_5 = "\u001bOu";
   private static final String KP_6 = "\u001bOv";
   private static final String KP_7 = "\u001bOw";
   private static final String KP_8 = "\u001bOx";
   private static final String KP_9 = "\u001bOy";
   private static final String KP_MINUS = "\u001bOm";
   private static final String KP_COMMA = "\u001bOl";
   private static final String KP_PERIOD = "\u001bOn";
   private static final String PF1 = "\u001bOP";
   private static final String PF2 = "\u001bOQ";
   private static final String PF3 = "\u001bOR";
   private static final String PF4 = "\u001bOS";
   private static final int OFF = 0;
   private static final int ON = 1;
   private static final long serialVersionUID = 2580990810031856951L;
   private static final int MAX_BUFFER_SIZE = 1024;
   private static final int EVENT_BYTE_ID = 32456;
   StatusBar statusBar;
   VDU vdu;
   FileLogger fileLogger;
   private CircBuffer historyBuffer;
   private KeyEventDispatcher keyEventDisp;
   private int autoRepeat = 1;
   private boolean keyReleased = true;
   private TRSerialStream serialStream;
   private JMenu menuConfigure;
   private JMenuItem menuitemEmulator;
   private JMenuItem menuitemSelect;
   private JMenuItem menuitemCopy;
   private JMenuItem menuitemPaste;
   private JMenuItem menuitemBreak;
   private JMenuItem menuitemHistory;
   private JMenuItem menuitemStartLogging;
   private JMenuItem menuitemStopLogging;
   private ArrayList menuList;
   private JScrollBar scrollbar;
   private ConfigDialog configDialog;
   private int columnSize;
   private int bufferSize = 5002;
   private int portNo = 23;
   private int cursorType = 1;
   private Emulator emulator;
   private boolean altKey = false;
   private boolean ctrlKey = false;
   private boolean shiftKey = false;
   private Font genFont;
   private boolean logging = false;
   private Clipboard systemClipboard;
   private String clipboardData;
   private boolean rightClicked = false;
   private boolean admin = false;
   private boolean diagnostic = false;
   private String codeSet = "US ASCII (True VT100)";
   private ConfigManager configManager;

   public Terminal(TRSerialStream var1, boolean var2, boolean var3) {
      this.enableEvents(32456L);
      this.serialStream = var1;
      this.admin = var2;
      this.diagnostic = var3;
      this.historyBuffer = new CircBuffer(1024);
      this.setLayout(new BorderLayout());
      this.addComponentListener(this);
      this.menuList = new ArrayList();
      this.menuConfigure = new JMenu("Emulator");
      this.menuConfigure.setOpaque(false);
      this.menuitemEmulator = new JMenuItem("Settings...");
      this.menuitemEmulator.addActionListener(this);
      this.menuConfigure.add(this.menuitemEmulator);
      this.menuList.add(this.menuitemEmulator);
      this.menuConfigure.addSeparator();
      this.menuitemBreak = new JMenuItem("Get Write Access");
      this.menuitemHistory = new JMenuItem("History");
      this.menuitemHistory.addActionListener(this);
      this.menuConfigure.add(this.menuitemHistory);
      this.menuList.add(this.menuitemHistory);
      this.menuConfigure.addSeparator();
      this.menuitemCopy = new JMenuItem("Copy");
      this.menuitemCopy.setEnabled(false);
      this.menuitemCopy.addActionListener(this);
      this.menuConfigure.add(this.menuitemCopy);
      this.menuList.add(this.menuitemCopy);
      this.menuitemPaste = new JMenuItem("Paste");
      this.menuitemPaste.addActionListener(this);
      this.menuConfigure.add(this.menuitemPaste);
      this.menuList.add(this.menuitemPaste);
      this.menuitemSelect = new JMenuItem("Select All Text");
      this.menuitemSelect.addActionListener(this);
      this.menuConfigure.add(this.menuitemSelect);
      this.menuList.add(this.menuitemSelect);
      this.menuConfigure.addSeparator();
      this.menuitemStartLogging = new JMenuItem("Start Logging...");
      this.menuitemStartLogging.addActionListener(this);
      this.menuConfigure.add(this.menuitemStartLogging);
      this.menuList.add(this.menuitemStartLogging);
      this.menuitemStopLogging = new JMenuItem("Stop Logging");
      this.menuitemStopLogging.addActionListener(this);
      this.menuitemStopLogging.setEnabled(false);
      this.menuConfigure.add(this.menuitemStopLogging);
      this.menuList.add(this.menuitemStopLogging);
      this.scrollbar = new JScrollBar(1, 0, 1, 0, this.bufferSize - 24 + 1);
      this.scrollbar.setUnitIncrement(1);
      this.scrollbar.setBlockIncrement(3);
      this.scrollbar.setMaximum(14);
      this.scrollbar.addAdjustmentListener(this);
      this.scrollbar.setEnabled(false);
      this.addKeyListener(this);
      this.statusBar = new StatusBar();
      this.vdu = new VDU(this);
      this.vdu.addKeyListener(this);
      this.add(this.vdu, "Center");
      this.add(this.scrollbar, "East");
      if (!var2 && !var3) {
         this.add(this.statusBar, "South");
      }

      this.vdu.addMouseListener(this);
      this.vdu.addMouseMotionListener(this);
      this.vdu.addFocusListener(this);
      Font var4 = this.vdu.getFont();
      int var5 = var4.getSize();
      this.genFont = new Font("Monospaced", 0, var5);
      this.setFont(this.genFont);
      this.configManager = new ConfigManager();
      Hashtable var6 = this.configManager.readConfig();
      if (var6 != null && var6.get("CodeSet") != null) {
         this.setCodeSet((String)var6.get("CodeSet"));
      }

      this.fileLogger = new FileLogger();
      this.initEmulator();
   }

   void fireBytesArrived(byte[] var1) {
      Terminal.ByteEvent var2 = new Terminal.ByteEvent(this, 32456, var1);
      this.getToolkit().getSystemEventQueue().postEvent(var2);
   }

   @Override
   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof Terminal.ByteEvent) {
         if (this.emulator != null) {
            this.emulator.preProcessByte(((Terminal.ByteEvent)var1).b);
         }
      } else {
         super.processEvent(var1);
      }
   }

   public static int adjustedFontSize(int var0) {
      int var1 = var0;
      JPanel var2 = new JPanel();

      for (int var3 = var2.getFontMetrics(new Font("Monospaced", 0, var0)).getHeight();
         var3 > var0 + 4;
         var3 = var2.getFontMetrics(new Font("Monospaced", 0, var1)).getHeight()
      ) {
         var1 -= 2;
      }

      return var1;
   }

   public boolean isAdmin() {
      return this.admin;
   }

   public boolean isDiagnostic() {
      return this.diagnostic;
   }

   boolean isAltKey() {
      return this.altKey;
   }

   boolean isCtrlKey() {
      return this.ctrlKey;
   }

   boolean isShiftKey() {
      return this.shiftKey;
   }

   void setThumbPosition(int var1) {
      this.scrollbar.setValue(var1);
      this.scrollbar.removeAdjustmentListener(this);
      if (var1 >= this.scrollbar.getMaximum()) {
         this.scrollbar.setMaximum(this.scrollbar.getMaximum() + 1);
      }

      this.scrollbar.addAdjustmentListener(this);
   }

   void enableScrollbar() {
      this.scrollbar.setEnabled(true);
   }

   public int getCursorType() {
      return this.cursorType;
   }

   public void setCursorType(int var1) {
      this.cursorType = var1;
      this.vdu.setCursorType(var1);
   }

   int getColumnSize() {
      return this.columnSize;
   }

   void setBufferSize(int var1) {
      this.bufferSize = var1;
      this.vdu.adjustBuffer(var1);
   }

   int getBufferSize() {
      return this.bufferSize;
   }

   void setColumnSize(int var1) {
      this.columnSize = var1;
      this.vdu.setRightMargin(var1);
   }

   void setPortNo(int var1) {
      this.portNo = var1;
   }

   int getPortNo() {
      return this.portNo;
   }

   void setAutoRepeat(int var1) {
      this.autoRepeat = var1;
   }

   public String getCodeSet() {
      return this.codeSet;
   }

   public void setCodeSet(String var1) {
      this.codeSet = var1;
      this.statusBar.setStatus(var1.substring(0, var1.indexOf("(")).trim());
   }

   public Emulator getEmulator() {
      return this.emulator;
   }

   public VDU getVDU() {
      return this.vdu;
   }

   public void saveConfig() {
      Hashtable var1 = new Hashtable();
      var1.put("CodeSet", this.codeSet);
      this.configManager.writeConfig(var1);
   }

   public void initEmulator() {
      if (this.codeSet.equals("ISO 8859-15 (Latin-9)")) {
         this.emulator = new VT100_8859_15Emulator(this);
      } else if (this.codeSet.equals("ISO 8859-1 (Latin-1)")) {
         this.emulator = new VT100_8859_1Emulator(this);
      } else {
         this.emulator = new VT100Emulator(this);
      }

      this.vdu.setVisible(true);
      this.statusBar.setStatus(this.codeSet.substring(0, this.codeSet.indexOf("(")).trim(), "", "");
   }

   void callWhenExit() {
      this.emulator = null;

      try {
         this.serialStream.stopSerialStream();
         this.serialStream = null;
      } catch (Exception var2) {
      }
   }

   void resetTerminal() {
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      if (var1.getActionCommand() == "Settings...") {
         this.doSettings();
      } else if (var1.getActionCommand() == "Select All Text") {
         this.doSelectAll();
      } else if (var1.getActionCommand() == "History") {
         this.doShowHistory();
      } else if (var1.getActionCommand() == "Start Logging...") {
         this.doStartLogging();
      } else if (var1.getActionCommand() == "Stop Logging") {
         this.doStopLogging();
      } else if (var1.getActionCommand() == "Copy") {
         this.doCopy();
      } else if (var1.getActionCommand() == "Paste") {
         this.doPaste();
      }
   }

   @Override
   public void adjustmentValueChanged(AdjustmentEvent var1) {
      this.vdu.scrollRows(var1.getValue());
   }

   @Override
   public void keyPressed(KeyEvent var1) {
      this.requestFocus();
      if (this.emulator != null && !var1.isControlDown() && var1.isActionKey()) {
         this.write(var1.getKeyCode());
      }

      if (this.emulator != null && !var1.isActionKey() && (var1.getKeyCode() == 127 || var1.getKeyCode() == 27)) {
         this.write(var1.getKeyChar());
         this.keyReleased = false;
      }

      this.shiftKey = var1.isShiftDown();
      var1.consume();
   }

   @Override
   public void keyReleased(KeyEvent var1) {
      this.requestFocus();
      if (var1.isAltDown()) {
         this.altKey = true;
      } else {
         this.altKey = false;
      }

      if (var1.isControlDown()) {
         this.ctrlKey = true;
      } else {
         this.ctrlKey = false;
      }

      if (var1.isShiftDown()) {
         this.shiftKey = true;
      } else {
         this.shiftKey = false;
      }

      if (var1.getKeyCode() == 80 && var1.isAltDown()) {
         this.write("|");
      }

      if (var1.isControlDown() && var1.getKeyCode() == 119) {
         this.emulator.sendAnswerBack();
      }

      if (this.vdu.hasSelection() && var1.isControlDown() && var1.getKeyCode() == 67) {
         try {
            if (this.getSystemClipboard() != null && !this.clipboardData.equals("")) {
               StringSelection var2 = new StringSelection(this.clipboardData);
               this.systemClipboard.setContents(var2, this);
            }
         } catch (Exception var7) {
         }
      }

      if (this.rightClicked && var1.isControlDown() && var1.getKeyCode() == 86 && this.getSystemClipboard() != null) {
         Transferable var8 = this.systemClipboard.getContents(this);
         if (var8 != null) {
            Object var3 = null;

            try {
               var3 = (String)var8.getTransferData(DataFlavor.stringFlavor);
            } catch (Exception var6) {
               var3 = null;
            }

            if (var3 != null) {
               this.write((String)var3);
               if (this.vdu.hasSelection()) {
                  try {
                     this.vdu.deselectText();
                     this.menuitemCopy.setEnabled(false);
                  } catch (Exception var5) {
                  }
               }
            }
         }
      }

      this.keyReleased = true;
      if (this.rightClicked) {
         this.rightClicked = false;
      }
   }

   @Override
   public void keyTyped(KeyEvent var1) {
      if (var1.getKeyChar() == '\t') {
         var1.consume();
      } else {
         if (this.emulator != null && !var1.isActionKey()) {
            if ((var1.getKeyChar() == '\r' || var1.getKeyChar() == '\n') && !var1.isControlDown()) {
               if (this.emulator.sendcrlf == 1) {
                  this.write("\r\n");
               } else {
                  this.write("\r");
               }
            } else if (this.emulator.keypadMode != 1
               || (var1.getKeyCode() < 95 || var1.getKeyCode() > 105) && var1.getKeyCode() != 109 && var1.getKeyCode() != 110 && var1.getKeyCode() != 188) {
               if (!var1.isAltDown() && var1.getKeyCode() != 17 && var1.getKeyCode() != 18 && var1.getKeyCode() != 16 && this.keyReleased) {
                  if (!this.vdu.hasSelection() && !this.rightClicked) {
                     this.write(var1.getKeyChar());
                  }

                  if (this.autoRepeat == 0) {
                     this.keyReleased = false;
                  }
               }
            } else {
               this.write(var1.getKeyCode());
            }
         }
      }
   }

   void setMyFont(String var1) {
      Dimension var2 = this.vdu.getSize();
      this.setMyFont(var1, var2.width, var2.height);
   }

   void setMyFont(String var1, int var2, int var3) {
      Font var4 = this.vdu.getFont();
      int var5 = var4.getSize();
      byte var7 = 80;
      byte var8 = 24;
      byte var9 = 10;
      byte var10 = 15;
      int var11 = var2 - var9;
      int var12 = var3 - var10;
      if (var11 >= var7 && var12 >= var8) {
         boolean var13 = true;
         boolean var14 = false;
         boolean var15 = false;
         int var16 = 0;
         int var17 = 0;
         FontMetrics var18 = null;

         while (var13) {
            var4 = new Font("Monospaced", 0, var5);
            this.vdu.setFont(var4);
            var18 = this.vdu.getFontMetrics(var4);
            var16 = var7 * var18.charWidth('W');
            var17 = var8 * var18.getHeight();
            int var19 = var11 - var16;
            int var20 = var12 - var17;
            if (var14 && var15) {
               var13 = false;
            } else if (var19 > 0 && var20 > 0) {
               if (var14) {
                  var13 = false;
               } else {
                  var15 = true;
                  var5++;
               }
            } else if ((var19 < 0 || var20 < 0) && var5 > 2) {
               var5--;
               var14 = true;
            } else {
               var13 = false;
            }
         }

         this.vdu.getImagesForDouble();
      }
   }

   void write(int var1) {
      switch (var1) {
         case 36:
            this.write("\u001b[H");
            break;
         case 37:
            this.write(this.emulator.keyLeft);
            break;
         case 38:
            this.write(this.emulator.keyUp);
            break;
         case 39:
            this.write(this.emulator.keyRight);
            break;
         case 40:
            this.write(this.emulator.keyDown);
            break;
         case 96:
            this.write("\u001bOp");
            break;
         case 97:
            this.write("\u001bOq");
            break;
         case 98:
            this.write("\u001bOr");
            break;
         case 99:
            this.write("\u001bOs");
            break;
         case 100:
            this.write("\u001bOt");
            break;
         case 101:
            this.write("\u001bOu");
            break;
         case 102:
            this.write("\u001bOv");
            break;
         case 103:
            this.write("\u001bOw");
            break;
         case 104:
            this.write("\u001bOx");
            break;
         case 105:
            this.write("\u001bOy");
            break;
         case 109:
            this.write("\u001bOm");
            break;
         case 110:
            this.write("\u001bOn");
            break;
         case 112:
            if (!this.altKey) {
               this.write("\u001bOP");
            }
            break;
         case 113:
            if (!this.altKey) {
               this.write("\u001bOQ");
            }
            break;
         case 114:
            if (!this.altKey) {
               this.write("\u001bOR");
            }
            break;
         case 115:
            if (!this.altKey) {
               this.write("\u001bOS");
            }
            break;
         case 118:
            if (!this.altKey) {
               this.write("\n");
            }
            break;
         case 119:
            if (!this.altKey) {
               try {
                  this.serialStream.sendSunBreak();
               } catch (Exception var3) {
                  var3.printStackTrace();
               }
            }
            break;
         case 123:
            if (!this.altKey) {
               this.write(10);
            }
            break;
         case 155:
            this.write("\u001b[4h");
            break;
         case 188:
            this.write("\u001bOl");
      }
   }

   void write(char var1) {
      try {
         this.historyBuffer.writeBulk(new char[]{var1}, 1);
         boolean var2 = this.serialStream.serialOut(1, new byte[]{(byte)var1});
      } catch (Exception var3) {
      }
   }

   void write(byte[] var1) {
      try {
         this.historyBuffer.writeBulk(new String(var1).toCharArray(), var1.length);
         boolean var2 = this.serialStream.serialOut(var1.length, var1);
      } catch (Exception var3) {
      }
   }

   void write(String var1) {
      byte[] var2 = var1.getBytes();
      this.write(var2);
   }

   @Override
   public void componentHidden(ComponentEvent var1) {
   }

   @Override
   public void componentMoved(ComponentEvent var1) {
   }

   @Override
   public void componentResized(ComponentEvent var1) {
   }

   @Override
   public void componentShown(ComponentEvent var1) {
   }

   public void windowActivated(WindowEvent var1) {
   }

   public void windowClosed(WindowEvent var1) {
   }

   public void windowClosing(WindowEvent var1) {
   }

   public void windowDeactivated(WindowEvent var1) {
   }

   public void windowDeiconified(WindowEvent var1) {
   }

   public void windowIconified(WindowEvent var1) {
   }

   public void windowOpened(WindowEvent var1) {
   }

   @Override
   public void mouseClicked(MouseEvent var1) {
   }

   @Override
   public void mouseEntered(MouseEvent var1) {
   }

   @Override
   public void mouseExited(MouseEvent var1) {
   }

   @Override
   public void mousePressed(MouseEvent var1) {
      if (this.vdu.hasSelection()) {
         try {
            this.vdu.deselectText();
         } catch (Exception var4) {
         }
      }

      try {
         this.vdu.setSelectionStart(var1.getX(), var1.getY());
      } catch (Exception var3) {
      }
   }

   @Override
   public void mouseReleased(MouseEvent var1) {
      try {
         this.vdu.setSelectionEnd(var1.getX(), var1.getY());
         this.setClipboard(this.vdu.getSelectedText());
      } catch (Exception var3) {
      }

      if (var1.isPopupTrigger()) {
         this.rightClicked = true;
         this.setClipboard("");
      } else {
         this.rightClicked = false;
      }
   }

   @Override
   public void mouseDragged(MouseEvent var1) {
      try {
         this.vdu.updateSelection(var1.getX(), var1.getY());
      } catch (Exception var3) {
      }
   }

   @Override
   public void mouseMoved(MouseEvent var1) {
   }

   private void setClipboard(String var1) {
      if (var1.equals("")) {
         this.menuitemCopy.setEnabled(false);
      } else {
         this.menuitemCopy.setEnabled(true);
         this.clipboardData = var1;
      }
   }

   @Override
   public void focusGained(FocusEvent var1) {
      this.keyEventDisp = new KeyEventDispatcher() {
         int step = 1;

         @Override
         public boolean dispatchKeyEvent(KeyEvent var1) {
            if (var1.getKeyCode() == 9) {
               this.step = ++this.step % 2;
               if (this.step == 0) {
                  if (Terminal.this.shiftKey) {
                     Terminal.this.write(38);
                  } else {
                     Terminal.this.write(var1.getKeyChar());
                  }
               }

               var1.consume();
               return true;
            } else {
               return false;
            }
         }
      };
      KeyboardFocusManager.getCurrentKeyboardFocusManager().addKeyEventDispatcher(this.keyEventDisp);
   }

   @Override
   public void focusLost(FocusEvent var1) {
      KeyboardFocusManager.getCurrentKeyboardFocusManager().removeKeyEventDispatcher(this.keyEventDisp);
   }

   public void dispose() {
   }

   public void produceImages(int var1) {
      Font var2 = this.vdu.getFont();
      Font var3 = new Font("Monospaced", 0, var1);
      this.vdu.setFont(var3);
      FontMetrics var4 = this.vdu.getFontMetrics(var3);
      int var5 = var4.getHeight();
      int var6 = var4.charWidth('W');
      int var7 = var4.getDescent();
      this.vdu.setBackground(Color.black);
      this.vdu.setForeground(Color.lightGray);
      Image var8 = this.vdu.createImage(var6 * 100, var5 * 8);
      Graphics var9 = var8.getGraphics();

      for (int var10 = 32; var10 < 128; var10++) {
         var9.drawString("" + (char)var10, (var10 - 32) * var6, var5 - var7);
      }

      for (int var11 = 161; var11 < 256; var11++) {
         var9.drawString("" + (char)var11, (var11 - 160) * var6, var5 * 2 - var7);
      }

      for (int var12 = 32; var12 < 128; var12++) {
         var9.drawString("" + (char)var12, (var12 - 32) * var6, var5 * 3 - var7);
      }

      for (int var13 = 161; var13 < 256; var13++) {
         var9.drawString("" + (char)var13, (var13 - 160) * var6, var5 * 4 - var7);
      }

      for (int var14 = 96; var14 <= 101; var14++) {
         this.vdu.decSpl.drawGlyph(var9, (char)var14, (var14 - 95) * var6, var5 * 4 - var7, var6, var5);
      }

      for (int var15 = 104; var15 <= 124; var15++) {
         this.vdu.decSpl.drawGlyph(var9, (char)var15, (var15 - 95) * var6, var5 * 4 - var7, var6, var5);
      }

      for (int var16 = 96; var16 <= 101; var16++) {
         this.vdu.decSpl.drawGlyph(var9, (char)var16, (var16 - 95) * var6, var5 * 5 - var7, var6, var5);
      }

      for (int var17 = 104; var17 <= 124; var17++) {
         this.vdu.decSpl.drawGlyph(var9, (char)var17, (var17 - 95) * var6, var5 * 5 - var7, var6, var5);
      }

      if (var1 == 13) {
         this.vdu.setImage13(var8);
      } else {
         this.vdu.setImage10(var8);
      }

      this.vdu.setFont(var2);
   }

   @Override
   public void lostOwnership(Clipboard var1, Transferable var2) {
   }

   private Clipboard getSystemClipboard() {
      if (this.systemClipboard == null) {
         this.systemClipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
      }

      return this.systemClipboard;
   }

   public void doSettings() {
      this.configDialog = new ConfigDialog(this.statusBar, this);
      this.configDialog.setVisible(true);
   }

   public void doSelectAll() {
      if (this.vdu.hasSelection()) {
         try {
            this.vdu.deselectText();
         } catch (Exception var3) {
         }
      }

      try {
         this.setClipboard(this.vdu.selectAllText());
      } catch (Exception var2) {
      }
   }

   public void doStartLogging() {
      this.logging = this.fileLogger.startLogging();
      this.emulator.setLogging(this.logging);
      this.statusBar.setLoggingStatus(this.logging);
      if (this.logging) {
         this.menuitemStartLogging.setEnabled(false);
         this.menuitemStopLogging.setEnabled(true);
      }

      this.requestFocus();
   }

   public boolean doStartLogging(File var1) {
      this.logging = this.fileLogger.startLogging(var1);
      this.emulator.setLogging(this.logging);
      this.statusBar.setLoggingStatus(this.logging);
      if (this.logging) {
         this.menuitemStartLogging.setEnabled(false);
         this.menuitemStopLogging.setEnabled(true);
      }

      this.requestFocus();
      return this.logging;
   }

   public void doStopLogging() {
      boolean var1 = this.fileLogger.stopLogging();
      if (var1) {
         this.logging = false;
         this.emulator.setLogging(this.logging);
         this.statusBar.setLoggingStatus(this.logging);
         this.menuitemStopLogging.setEnabled(false);
         this.menuitemStartLogging.setEnabled(true);
      } else {
         new MessageBox("Logging", "Could not stop logging.", false).showMessage();
      }
   }

   public void doCopy() {
      try {
         if (this.getSystemClipboard() != null && !this.clipboardData.equals("")) {
            StringSelection var1 = new StringSelection(this.clipboardData);
            this.systemClipboard.setContents(var1, this);
         }
      } catch (Exception var2) {
      }
   }

   public void doPaste() {
      if (this.getSystemClipboard() != null) {
         Transferable var1 = this.systemClipboard.getContents(this);
         if (var1 != null) {
            Object var2 = null;

            try {
               var2 = (String)var1.getTransferData(DataFlavor.stringFlavor);
            } catch (Exception var5) {
               var2 = null;
            }

            if (var2 != null) {
               this.write((String)var2);
               if (this.vdu.hasSelection()) {
                  try {
                     this.vdu.deselectText();
                     this.menuitemCopy.setEnabled(false);
                  } catch (Exception var4) {
                  }
               }
            }
         }
      }
   }

   @Override
   public void internalFrameActivated(InternalFrameEvent var1) {
   }

   @Override
   public void internalFrameClosed(InternalFrameEvent var1) {
   }

   @Override
   public void internalFrameClosing(InternalFrameEvent var1) {
      int var2 = JOptionPane.showConfirmDialog(this, "Are you sure that you want to exit this console window?", "Exit console", 0, -1);
      if (var2 == 0) {
         ;
      }
   }

   @Override
   public void internalFrameDeactivated(InternalFrameEvent var1) {
   }

   @Override
   public void internalFrameDeiconified(InternalFrameEvent var1) {
   }

   @Override
   public void internalFrameIconified(InternalFrameEvent var1) {
   }

   @Override
   public void internalFrameOpened(InternalFrameEvent var1) {
   }

   @Override
   public void requestFocus() {
      super.requestFocus();
      this.vdu.requestFocus();
   }

   public boolean isLogging() {
      return this.logging;
   }

   public CircBuffer getHistoryBuffer() {
      return this.historyBuffer;
   }

   public void doShowHistory() {
      byte[] var1 = new byte[16384];
      this.getHistoryBuffer().readHistory(var1);
      String var2 = StringUtils.trim(new String(var1));
      this.emulator.setWritingHistoryBufferOn(true);
      this.emulator.preProcessByte(var1);
      this.emulator.setWritingHistoryBufferOn(false);
   }

   public void setSerialStream(TRSerialStream var1) {
      this.serialStream = var1;
   }

   void writeFromHistory(char var1) {
      try {
         boolean var2 = this.serialStream.serialOut(1, new byte[]{(byte)var1});
      } catch (Exception var3) {
      }
   }

   void writeFromHistory(byte[] var1) {
      try {
         boolean var2 = this.serialStream.serialOut(var1.length, var1);
      } catch (Exception var3) {
      }
   }

   void writeFromHistory(String var1) {
      byte[] var2 = var1.getBytes();
      this.writeFromHistory(var2);
   }

   public void onFinalize() {
      this.historyBuffer = null;
      this.emulator = null;
      this.statusBar = null;
      this.vdu.onFinalize();
      this.vdu = null;
   }

   private static class ByteEvent extends AWTEvent {
      private static final long serialVersionUID = -1322966874491550736L;
      private byte[] b;

      ByteEvent(Object var1, int var2, byte[] var3) {
         super(var1, var2);
         this.b = var3;
      }
   }
}
