package com.raritan.rrc.components.serialconsole;

class VT100Emulator extends Emulator {
   private static final int STATE_ASCII = 0;
   private static final int STATE_ESCAPE = 1;
   private static final int STATE_CSI = 2;
   private static final int STATE_G0 = 3;
   private static final int STATE_G1 = 4;
   private static final int STATE_MODE = 5;
   private static final int STATE_FILL = 6;
   private static final int SCROLL_UP = 1;
   private static final int SCROLL_DOWN = 2;
   private static final int NORMAL = 0;
   private static final int BOLD = 1;
   private static final int UNDERLINE = 4;
   private static final int BLINK = 5;
   private static final int REVERSE = 7;
   private static final int BOLD_UNDERLINE = 14;
   private static final int BOLD_BLINK = 15;
   private static final int BOLD_REVERSE = 17;
   private static final int UNDERLINE_BLINK = 45;
   private static final int BLINK_REVERSE = 57;
   private static final int REVERSE_UNDERLINE = 74;
   private static final int BOLD_UNDERLINE_BLINK = 145;
   private static final int BOLD_BLINK_REVERSE = 157;
   private static final int BOLD_REVERSE_UNDERLINE = 174;
   private static final int UNDERLINE_BLINK_REVERSE = 457;
   private static final int BOLD_UNDERLINE_BLINK_REVERSE = 1457;
   private static final int DARK_BACKGROUND = 0;
   private static final int LIGHT_BACKGROUND = 1;
   private static final int INSERT = 1;
   private static final int REPLACE = 0;
   private static final int ON = 1;
   private static final int OFF = 0;
   private static final int ORIGIN_ABSOLUTE = 0;
   private static final int ORIGIN_RELATIVE = 1;
   private static final int ASCII_SET = 1;
   private static final int DECSPL_SET = 2;
   private static final char NUL = '\u0000';
   private static final char ET = '\u0003';
   private static final char ENQ = '\u0005';
   private static final char BEL = '\u0007';
   private static final char BS = '\b';
   private static final char HT = '\t';
   private static final char LF = '\n';
   private static final char VT = '\u000b';
   private static final char FF = '\f';
   private static final char CR = '\r';
   private static final char SO = '\u000e';
   private static final char SI = '\u000f';
   private static final char DC1 = '\u0011';
   private static final char DC3 = '\u0013';
   private static final char CAN = '\u0018';
   private static final char SUB = '\u001a';
   private static final char ESC = '\u001b';
   private static final char FS = '\u001c';
   private static final char DEL = '\u007f';
   private static final char CSI = '\u009b';
   private static final int MAX_ARGS = 10;
   private static final byte SEVEN_BITS_MASK = 127;
   private static final byte EIGHT_BITS_MASK = -1;
   private byte controlMask = 127;
   private int terminalState = 0;
   private int[] cmdArguments = new int[10];
   private int currentArgument = 0;
   private int rMargin = 80;
   private byte[] tabSettings = new byte[this.rMargin + 1];
   private int saveCursorRow = 0;
   private int saveCursorCol = 0;
   private int saveAttributes;
   private char saveGraphicsLeft;
   private char saveGraphicsRight;
   private char saveG0;
   private char saveG1;
   private int currCursorRow = 1;
   private int currCursorCol = 1;
   private int bMargin = 24;
   private int tMargin = 1;

   VT100Emulator(Terminal var1) {
      super(var1);
   }

   void setControlMask(byte var1) {
      this.controlMask = var1;
   }

   void resetState() {
      for (int var1 = 0; var1 < 10; var1++) {
         this.cmdArguments[var1] = 0;
      }

      this.currentArgument = 0;
      this.terminalState = 0;
   }

   @Override
   void processByte(byte var1) {
      char var2 = (char)(var1 & 127);
      if (this.checkChar(var2)) {
         if (!this.writingHistoryBufferOn) {
            if (var2 == '\n') {
               this.terminal.vdu.putChar("\r");
            }

            this.terminal.vdu.putChar(var2);
         }

         if (this.softScroll && var2 == '\n') {
            this.terminal.vdu.reDraw();
         }
      } else {
         this.doChar(var2);
         if (this.needRedraw) {
            this.terminal.vdu.reDraw();
            this.needRedraw = false;
         }
      }

      if (this.writingHistoryBufferOn) {
         if (var2 == '\r') {
            if (this.sendcrlf == 1) {
               this.terminal.writeFromHistory("\r\n");
            } else {
               this.terminal.writeFromHistory("\r");
            }
         } else {
            this.terminal.writeFromHistory(var2);
         }
      }
   }

   @Override
   boolean checkChar(char var1) {
      if (this.terminalState == 0
         && var1 != 27
         && var1 != 155
         && var1 != 11
         && var1 != '\f'
         && var1 != 14
         && var1 != 15
         && var1 != 17
         && var1 != 19
         && var1 != 24
         && var1 != 26
         && var1 != 127
         && var1 != 5
         && var1 != 28
         && var1 != 3) {
         return true;
      } else {
         if (var1 == 24 || var1 == 26 || var1 == 27) {
            this.resetState();
         }

         return false;
      }
   }

   @Override
   void doChar(char var1) {
      if (var1 == 27) {
         this.resetState();
      }

      label358:
      switch (this.terminalState) {
         case 0:
            if (var1 == 11 || var1 == '\f') {
               this.terminal.vdu.putChar('\n');
            } else if (var1 == 14) {
               this.terminal.vdu.setGraphicsLeft(this.graphicsDesignator[1]);
            } else if (var1 == 15) {
               this.terminal.vdu.setGraphicsLeft(this.graphicsDesignator[0]);
            } else if (var1 == 27) {
               this.terminalState = 1;
            } else if (var1 == 155) {
               this.terminalState = 2;
            }
            break;
         case 1:
            switch (var1) {
               case '#':
                  this.terminalState = 6;
                  break label358;
               case '(':
                  this.terminalState = 3;
                  break label358;
               case ')':
                  this.terminalState = 4;
                  break label358;
               case '7':
                  this.saveCursorRow = this.terminal.vdu.getCursorRow();
                  this.saveCursorCol = this.terminal.vdu.getCursorCol();
                  this.saveAttributes = this.terminal.vdu.getFontStyle();
                  this.saveGraphicsLeft = this.terminal.vdu.getGraphicsLeft();
                  this.saveGraphicsRight = this.terminal.vdu.getGraphicsRight();
                  this.saveG0 = this.graphicsDesignator[0];
                  this.saveG1 = this.graphicsDesignator[1];
                  this.terminalState = 0;
                  break label358;
               case '8':
                  this.terminal.vdu.setCursorPosition(this.saveCursorRow, this.saveCursorCol);
                  this.terminal.vdu.setFontStyle(this.saveAttributes);
                  this.terminal.vdu.setGraphicsLeft(this.saveGraphicsLeft);
                  this.terminal.vdu.setGraphicsRight(this.saveGraphicsRight);
                  this.graphicsDesignator[0] = this.saveG0;
                  this.graphicsDesignator[1] = this.saveG1;
                  this.terminalState = 0;
                  break label358;
               case '=':
                  this.keypadMode = 1;
                  this.terminalState = 0;
                  break label358;
               case '>':
                  this.keypadMode = 0;
                  this.terminalState = 0;
                  break label358;
               case 'D':
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  if (this.currCursorRow >= this.bMargin) {
                     this.currCursorRow = this.bMargin;
                     this.terminal.vdu.insertLine(1, 1);
                  } else {
                     this.currCursorRow++;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case 'E':
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = 1;
                  if (this.currCursorRow >= this.bMargin) {
                     this.currCursorRow = this.bMargin;
                     this.terminal.vdu.insertLine(1, 1);
                  } else {
                     this.currCursorRow++;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case 'H':
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  this.tabSettings[this.currCursorCol] = 1;
                  this.terminalState = 0;
                  break label358;
               case 'I':
                  this.terminalState = 0;
                  break label358;
               case 'M':
                  this.tMargin = this.terminal.vdu.getTopMargin();
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  if (this.currCursorRow > this.tMargin && this.currCursorRow < this.bMargin) {
                     this.currCursorRow--;
                  } else {
                     this.currCursorRow = this.tMargin;
                     this.terminal.vdu.insertLine(1, 2);
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case '[':
                  this.terminalState = 2;
                  break label358;
               case 'c':
                  this.terminal.vdu.setFontStyle(0);
                  this.terminal.vdu.setCursorPosition(1, 1);
                  this.terminal.vdu.screenClearEntire();
                  this.terminalState = 0;
                  break label358;
               default:
                  this.terminalState = 1;
                  break label358;
            }
         case 2:
            switch (var1) {
               case '\b':
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol--;
                  if (this.currCursorCol < 1) {
                     this.currCursorCol = 1;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
               case '\t':
               case '\n':
               case '\u000b':
               case '\f':
               case '\r':
               case '\u000e':
               case '\u000f':
               case '\u0010':
               case '\u0011':
               case '\u0012':
               case '\u0013':
               case '\u0014':
               case '\u0015':
               case '\u0016':
               case '\u0017':
               case '\u0018':
               case '\u0019':
               case '\u001a':
               case '\u001b':
               case '\u001c':
               case '\u001d':
               case '\u001e':
               case '\u001f':
               case ' ':
               case '!':
               case '"':
               case '#':
               case '$':
               case '%':
               case '&':
               case '\'':
               case '(':
               case ')':
               case '*':
               case '+':
               case ',':
               case '-':
               case '.':
               case '/':
               case ':':
               case '<':
               case '=':
               case '>':
               case '@':
               case 'G':
               case 'I':
               case 'N':
               case 'O':
               case 'Q':
               case 'R':
               case 'S':
               case 'T':
               case 'U':
               case 'V':
               case 'W':
               case 'X':
               case 'Y':
               case 'Z':
               case '[':
               case '\\':
               case ']':
               case '^':
               case '_':
               case '`':
               case 'a':
               case 'b':
               case 'd':
               case 'e':
               case 'i':
               case 'j':
               case 'k':
               case 'o':
               case 'p':
               default:
                  break label358;
               case '0':
               case '1':
               case '2':
               case '3':
               case '4':
               case '5':
               case '6':
               case '7':
               case '8':
               case '9':
                  this.cmdArguments[this.currentArgument] = this.cmdArguments[this.currentArgument] * 10 + var1 - 48;
                  break label358;
               case ';':
                  this.currentArgument++;
                  this.cmdArguments[this.currentArgument] = 0;
                  break label358;
               case '?':
                  this.terminalState = 5;
                  break label358;
               case 'A':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  this.tMargin = this.terminal.vdu.getTopMargin();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorRow--;
                  } else {
                     this.currCursorRow = this.currCursorRow - this.cmdArguments[0];
                  }

                  if (this.currCursorRow < this.tMargin) {
                     this.currCursorRow = this.tMargin;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case 'B':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorRow++;
                  } else {
                     this.currCursorRow = this.currCursorRow + this.cmdArguments[0];
                  }

                  if (this.currCursorRow > this.bMargin) {
                     this.currCursorRow = this.bMargin;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case 'C':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorCol++;
                  } else {
                     this.currCursorCol = this.currCursorCol + this.cmdArguments[0];
                  }

                  if (this.currCursorCol > this.terminal.vdu.getRightMargin()) {
                     this.currCursorCol = this.terminal.vdu.getRightMargin();
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case 'D':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorCol--;
                  } else {
                     this.currCursorCol = this.currCursorCol - this.cmdArguments[0];
                  }

                  if (this.currCursorCol < 1) {
                     this.currCursorCol = 1;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  break label358;
               case 'E':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorRow++;
                  } else {
                     this.currCursorRow = this.currCursorRow + this.cmdArguments[0];
                  }

                  if (this.currCursorRow > this.bMargin) {
                     this.currCursorRow = this.bMargin;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, 1);
                  this.terminalState = 0;
                  break label358;
               case 'F':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorRow--;
                  } else {
                     this.currCursorRow = this.currCursorRow - this.cmdArguments[0];
                  }

                  if (this.currCursorRow < this.tMargin) {
                     this.currCursorRow = this.tMargin;
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, 1);
                  this.terminalState = 0;
                  break label358;
               case 'H':
               case 'f':
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  this.rMargin = this.terminal.vdu.getRightMargin();
                  this.tMargin = this.terminal.vdu.getTopMargin();
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  if (this.cmdArguments[0] == 0) {
                     this.currCursorRow = 1;
                     this.currCursorCol = 1;
                  } else {
                     this.currCursorRow = this.cmdArguments[0];
                     this.currCursorCol = this.cmdArguments[1];
                  }

                  this.terminal.vdu.setCursorPosition(this.currCursorRow, this.currCursorCol);
                  this.terminalState = 0;
                  this.needRedraw = true;
                  break label358;
               case 'J':
                  if (this.cmdArguments[0] == 0) {
                     this.terminal.vdu.screenClearEOD();
                  } else if (this.cmdArguments[0] == 1) {
                     this.terminal.vdu.screenClearBOD();
                  } else if (this.cmdArguments[0] == 2) {
                     this.terminal.vdu.screenClearEntire();
                  }

                  this.terminalState = 0;
                  break label358;
               case 'K':
                  if (this.cmdArguments[0] == 0) {
                     this.terminal.vdu.screenClearEOL();
                  } else if (this.cmdArguments[0] == 1) {
                     this.terminal.vdu.screenClearBOL();
                  } else if (this.cmdArguments[0] == 2) {
                     this.terminal.vdu.screenClearLine();
                  }

                  this.terminalState = 0;
                  break label358;
               case 'L':
                  if (this.cmdArguments[0] != 0) {
                     this.terminal.vdu.insertLine(this.cmdArguments[0], 2);
                  } else {
                     this.terminal.vdu.insertLine(1, 2);
                  }

                  this.terminalState = 0;
                  break label358;
               case 'M':
                  if (this.cmdArguments[0] != 0) {
                     this.terminal.vdu.deleteLine(this.cmdArguments[0]);
                  } else {
                     this.terminal.vdu.deleteLine(1);
                  }

                  this.terminalState = 0;
                  break label358;
               case 'P':
                  this.currCursorRow = this.terminal.vdu.getCursorRow();
                  this.currCursorCol = this.terminal.vdu.getCursorCol();
                  if (this.cmdArguments[0] != 0) {
                     this.terminal.vdu.deleteChars(this.currCursorRow, this.cmdArguments[0]);
                  } else {
                     this.terminal.vdu.deleteChars(this.currCursorRow, 1);
                  }

                  this.terminalState = 0;
                  break label358;
               case 'c':
                  try {
                     this.terminal.write("\u001b[?1;1c");
                  } catch (Exception var7) {
                  }

                  this.terminalState = 0;
                  break label358;
               case 'g':
                  switch (this.cmdArguments[0]) {
                     case 0:
                        this.currCursorCol = this.terminal.vdu.getCursorCol();
                        this.tabSettings[this.currCursorCol] = 0;
                        break;
                     case 3:
                        this.rMargin = this.terminal.vdu.getRightMargin();
                        this.tabSettings = new byte[this.rMargin + 1];
                  }

                  this.terminalState = 0;
                  break label358;
               case 'h':
                  if (this.cmdArguments[0] == 4) {
                     this.terminal.vdu.setInsertReplace(1);
                  } else if (this.cmdArguments[0] == 20) {
                     this.sendcrlf = 1;
                  }

                  this.terminalState = 0;
                  break label358;
               case 'l':
                  if (this.cmdArguments[0] == 4) {
                     this.terminal.vdu.setInsertReplace(0);
                  } else if (this.cmdArguments[0] == 20) {
                     this.sendcrlf = 0;
                  }

                  this.terminalState = 0;
                  break label358;
               case 'm':
                  int var2 = 0;
                  boolean var3 = false;
                  if (this.currentArgument == 0 && this.cmdArguments[0] != 0) {
                     var2 = this.terminal.vdu.getFontStyle();
                  }

                  for (int var4 = 0; var4 <= this.currentArgument; var4++) {
                     if (this.cmdArguments[var4] != 5) {
                        if (this.cmdArguments[var4] == 0 || this.cmdArguments[var4] == 1 || this.cmdArguments[var4] == 4 || this.cmdArguments[var4] == 7) {
                           var2 = var2 * 10 + this.cmdArguments[var4];
                        }
                     } else {
                        var3 = true;
                     }

                     if (this.cmdArguments[var4] == 0) {
                        var2 = 0;
                        var3 = false;
                     }

                     switch (var2) {
                        case 0:
                           this.terminal.vdu.setFontStyle(0);
                           this.terminalState = 0;
                           break;
                        case 1:
                           this.terminal.vdu.setFontStyle(1);
                           this.terminalState = 0;
                           break;
                        case 4:
                           this.terminal.vdu.setFontStyle(4);
                           this.terminalState = 0;
                           break;
                        case 7:
                           this.terminal.vdu.setFontStyle(7);
                           this.terminalState = 0;
                           break;
                        case 14:
                        case 41:
                           this.terminal.vdu.setFontStyle(14);
                           this.terminalState = 0;
                           break;
                        case 15:
                        case 51:
                           this.terminal.vdu.setFontStyle(15);
                           this.terminalState = 0;
                           break;
                        case 17:
                        case 71:
                           this.terminal.vdu.setFontStyle(17);
                           this.terminalState = 0;
                           break;
                        case 45:
                        case 54:
                           this.terminal.vdu.setFontStyle(45);
                           this.terminalState = 0;
                           break;
                        case 47:
                        case 74:
                           this.terminal.vdu.setFontStyle(74);
                           this.terminalState = 0;
                           break;
                        case 57:
                        case 75:
                           this.terminal.vdu.setFontStyle(57);
                           this.terminalState = 0;
                           break;
                        case 145:
                        case 154:
                        case 415:
                        case 451:
                        case 514:
                        case 541:
                           this.terminal.vdu.setFontStyle(145);
                           this.terminalState = 0;
                           break;
                        case 147:
                        case 174:
                        case 417:
                        case 471:
                        case 714:
                        case 741:
                           this.terminal.vdu.setFontStyle(174);
                           this.terminalState = 0;
                           break;
                        case 157:
                        case 175:
                        case 517:
                        case 571:
                        case 715:
                        case 751:
                           this.terminal.vdu.setFontStyle(157);
                           this.terminalState = 0;
                           break;
                        case 457:
                        case 475:
                        case 547:
                        case 574:
                        case 745:
                        case 754:
                           this.terminal.vdu.setFontStyle(457);
                           this.terminalState = 0;
                           break;
                        case 1457:
                           this.terminal.vdu.setFontStyle(1457);
                           this.terminalState = 0;
                     }
                  }

                  if (var3) {
                     var2 = this.terminal.vdu.getFontStyle();
                     var2 += 30000;
                     this.terminal.vdu.setFontStyle(var2);
                     var3 = false;
                  }
                  break label358;
               case 'n':
                  if (this.cmdArguments[0] == 5) {
                     try {
                        this.terminal.write("\u001b[0n");
                     } catch (Exception var6) {
                        this.terminal.vdu.putChar("\r\n " + var6.toString());
                     }
                  }

                  if (this.cmdArguments[0] == 6) {
                     try {
                        this.currCursorRow = this.terminal.vdu.getCursorRow();
                        this.currCursorCol = this.terminal.vdu.getCursorCol();
                        this.terminal.write("\u001b[" + this.currCursorRow + ";" + this.currCursorCol + "R");
                     } catch (Exception var5) {
                        this.terminal.vdu.putChar("\r\n " + var5.toString());
                     }
                  }

                  this.terminalState = 0;
                  break label358;
               case 'q':
                  this.terminalState = 0;
                  break label358;
               case 'r':
                  this.tMargin = this.terminal.vdu.getTopMargin();
                  this.bMargin = this.terminal.vdu.getBottomMargin();
                  if (this.cmdArguments[0] != 0) {
                     if (this.cmdArguments[0] < this.cmdArguments[1]) {
                        this.tMargin = this.cmdArguments[0];
                        this.bMargin = this.cmdArguments[1];
                        this.terminal.vdu.setScrollRegion(this.tMargin, this.bMargin);
                        this.terminalState = 0;
                     }
                  } else {
                     this.tMargin = 1;
                     this.bMargin = 24;
                     this.terminal.vdu.setScrollRegion(this.tMargin, this.bMargin);
                     this.terminalState = 0;
                  }
                  break label358;
            }
         case 3:
            switch (var1) {
               case '0':
                  this.graphicsDesignator[0] = var1;
                  this.terminalState = 0;
                  break label358;
               case 'B':
                  this.graphicsDesignator[0] = var1;
                  this.terminalState = 0;
               default:
                  break label358;
            }
         case 4:
            switch (var1) {
               case '0':
                  this.graphicsDesignator[1] = var1;
                  this.terminalState = 0;
                  break label358;
               case 'B':
                  this.graphicsDesignator[1] = var1;
                  this.terminalState = 0;
               default:
                  break label358;
            }
         case 5:
            switch (var1) {
               case '0':
               case '1':
               case '2':
               case '3':
               case '4':
               case '5':
               case '6':
               case '7':
               case '8':
               case '9':
                  this.cmdArguments[this.currentArgument] = this.cmdArguments[this.currentArgument] * 10 + var1 - 48;
                  break label358;
               case 'h':
                  switch (this.cmdArguments[0]) {
                     case 1:
                        this.keyUp = "\u001bOA";
                        this.keyDown = "\u001bOB";
                        this.keyRight = "\u001bOC";
                        this.keyLeft = "\u001bOD";
                        this.terminalState = 0;
                        break label358;
                     case 2:
                        this.terminalState = 0;
                        break label358;
                     case 3:
                        this.terminal.vdu.setRightMargin(132);
                        this.terminal.vdu.reSetSettings();
                        this.terminalState = 0;
                        break label358;
                     case 4:
                        this.softScroll = true;
                        this.terminalState = 0;
                        break label358;
                     case 5:
                        this.terminalState = 0;
                        this.terminal.vdu.setBackgroundColor(1);
                        break label358;
                     case 6:
                        this.terminal.vdu.setOriginMode(1);
                        this.terminalState = 0;
                        break label358;
                     case 7:
                        this.terminalState = 0;
                        this.terminal.vdu.setAutoWrap(1);
                        break label358;
                     case 8:
                        this.terminal.setAutoRepeat(1);
                        this.terminalState = 0;
                        break label358;
                     case 9:
                        this.terminalState = 0;
                        break label358;
                     case 10:
                     case 11:
                     default:
                        this.terminalState = 0;
                        break label358;
                     case 12:
                        this.terminalState = 0;
                        break label358;
                  }
               case 'l':
                  switch (this.cmdArguments[0]) {
                     case 1:
                        this.keyUp = "\u001b[A";
                        this.keyDown = "\u001b[B";
                        this.keyRight = "\u001b[C";
                        this.keyLeft = "\u001b[D";
                        this.terminalState = 0;
                        break label358;
                     case 2:
                        this.terminalState = 0;
                        break label358;
                     case 3:
                        this.terminalState = 0;
                        this.terminal.vdu.setRightMargin(80);
                        this.terminal.vdu.reSetSettings();
                        break label358;
                     case 4:
                        this.softScroll = false;
                        this.terminalState = 0;
                        break label358;
                     case 5:
                        this.terminalState = 0;
                        this.terminal.vdu.setBackgroundColor(0);
                        break label358;
                     case 6:
                        this.terminal.vdu.setOriginMode(0);
                        this.terminalState = 0;
                        break label358;
                     case 7:
                        this.terminalState = 0;
                        this.terminal.vdu.setAutoWrap(0);
                        break label358;
                     case 8:
                        this.terminal.setAutoRepeat(0);
                        this.terminalState = 0;
                        break label358;
                     case 9:
                        this.terminalState = 0;
                        break label358;
                     case 10:
                     case 11:
                     default:
                        this.terminalState = 0;
                        break label358;
                     case 12:
                        this.terminalState = 0;
                  }
               default:
                  break label358;
            }
         case 6:
            switch (var1) {
               case '3':
                  this.terminal.vdu.setLineAttribute(2);
                  this.terminal.vdu.reDraw();
                  break;
               case '4':
                  this.terminal.vdu.setLineAttribute(3);
                  this.terminal.vdu.reDraw();
                  break;
               case '5':
                  this.terminal.vdu.setLineAttribute(0);
                  this.terminal.vdu.reDraw();
                  break;
               case '6':
                  this.terminal.vdu.setLineAttribute(1);
                  this.terminal.vdu.reDraw();
               case '7':
               default:
                  break;
               case '8':
                  this.terminal.vdu.fillWithE();
            }

            this.terminalState = 0;
      }

      if (var1 == 24 || var1 == 26) {
         this.resetState();
      } else if (var1 == 5) {
         this.sendAnswerBack();
      }
   }
}
