package com.raritan.rrc.data;

import com.raritan.rrc.ui.MPCScanFrame;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.ErrorHandlerImpl;
import com.raritan.rrc.util.DeviceComparator;
import com.raritan.rrc.util.StringUtils;
import com.raritan.rrc.util.TR_NOTIFY_MSG_CACHE;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import java.beans.PropertyChangeListener;
import java.beans.PropertyVetoException;
import java.io.File;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Vector;
import java.util.Map.Entry;
import javaclientlib.clientlib.ITRConnection;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.tr.TRSRVR_SERVER_ID;
import javaclientlib.utils.RRCLogger;
import javax.swing.event.SwingPropertyChangeSupport;

public abstract class Device extends Component implements ITRConnection {
   public static final String IP_REACH_TYPE = "IP-Reach";
   public static final String PARAGON_TYPE = "Paragon";
   public static final String KVMSWITCH_TYPE = "KVMSwitch";
   public static final String KVMSWITCH_MODEL = "KVMSwitch";
   public static final String SX_TYPE = "SX";
   public static final String KX2_TYPE = "Dominion_KX2";
   public static final String POWERSTRIP_TYPE = "PowerStrip";
   public static final String BLADE_CHASSIS_TYPE = "BladeChassis";
   public static final String BLADE_CHASSIS_MODEL = "BladeChassis";
   public static final String TIER_DEVICE_TYPE = "TierDevice";
   public static final String VIRTUAL_BLADE_CHASSIS_TYPE = "VirtualBladeChassis";
   public static final String PORT_GROUP_TYPE = "PortGroup";
   public static final String MULTI_MONITOR_PORT_TYPE = "MultiMonitorPort";
   public static final String DKX_MODEL = "DKX";
   public static final String TR36X_MODEL = "TR36x";
   public static final String TR01_MODEL = "TR01";
   public static final String RX440_MODEL = "RX440";
   public static final String RX880_MODEL = "RX880";
   public static final String COMPUSWITCH_MODEL = "CompuSwitch";
   public static final String UMT832_MODEL = "UMT832";
   public static final String UMT1664_MODEL = "UMT1664";
   public static final String PCR8_MODEL = "PCR8";
   public static final String PCS12_MODEL = "PCS12";
   public static final String PCS20_MODEL = "PCS20";
   public static final String DISCONNECTED_STATE = "AVAILABLE";
   public static final String CONNECTED_STATE = "CONNECTED";
   public static final String UNAVAILABLE_STATE = "UNAVAILABLE";
   public static final String PROFILED_STATE = "PROFILED";
   public static final String NO_PROFILE_STATE = "NOT_PROFILED";
   public static final String MODEM_PROFILE_STATE = "MODEM_PROFILED";
   public static final String DEVICE_CONNECTED = "DEVICE_CONNECTED";
   public static final String DEVICE_AUTHENTICATED = "DEVICE_AUTHENTICATED";
   public static final String DEVICE_CONNECTION_LOST = "DEVICE_CONNECTION_LOST";
   public static final String DEVICE_DISCONNECTED = "DEVICE_DISCONNECTED";
   public static final String DEVICE_PORTS_ADDED = "DEVICE_PORTS_ADD";
   public static final String DEVICE_PORTS_REMOVE = "DEVICE_PORTS_REMOVE";
   public static final String DEVICE_PORT_VIEW_ADD = "DEVICE_PORT_VIEW_ADD";
   public static final String DEVICE_PORT_VIEW_REMOVE = "DEVICE_PORT_VIEW_REMOVE";
   public static final String DEVICE_STATE_CHANGED = "DEVICE_STATE_CHANGED";
   public static final String DEVICE_NAME_CHANGED = "DEVICE_NAME_CHANGED";
   public static final String DEVICE_PROFILE_STATE_CHANGED = "DEVICE_PROFILE_STATE_CHANGED";
   public static final String DEVICE_ACTIVATED = "DEVICE_ACTIVATED";
   public static final String DEVICE_SELECTED = "DEVICE_SELECTED";
   public static final String DEVICE_DESELECTED = "DEVICE_DESELECTED";
   public static final int UNAVAILABLE = 0;
   public static final int AVAILABLE = 1;
   public static final int BUSY = 2;
   public static final int INACTIVE = 0;
   public static final int ACTIVE = 1;
   private String uniquePortId;
   boolean virtual = false;
   public static final int SORT_ActiveDevice = 1;
   public static final int SORT_ActiveChannel = 2;
   public static final int SORT_InactiveDevice = 3;
   public static final int SORT_Available = 4;
   public static final int SORT_Unavailable = 5;
   public static final int SORT_Unequipped = 6;
   public static final int SORT_Admin = 7;
   public static final int SORT_Diagnostics = 8;
   public static final int SORT_URL = 9;
   public static final int SORT_TYPE_CHANNEL = 0;
   public static final int SORT_TYPE_NAME = 1;
   public static final int SORT_TYPE_STATUS = 2;
   private static final String[] ENUM_DEVICE_TYPES = new String[]{"IP-Reach", "Paragon", "KVMSwitch", "SX", "PowerStrip"};
   private static final String[] ENUM_MODEL_TYPES = new String[]{
      "DKX", "TR36x", "TR01", "RX440", "RX880", "CompuSwitch", "UMT1664", "UMT832", "PCR8", "PCS12", "PCS20"
   };
   private static final String[] ENUM_STATES = new String[]{"AVAILABLE", "CONNECTED", "UNAVAILABLE"};
   protected ArrayList arrEvenMsg = null;
   protected DevicePreferences devPrefs = null;
   protected DeviceConnector connector;
   protected SwingPropertyChangeSupport deviceListeners = new SwingPropertyChangeSupport(this);
   protected ScreenContext scrContext = null;
   private String name;
   protected String description;
   private String dnsName;
   protected boolean profiled = false;
   protected boolean isModemProfiled = false;
   private String id = "0";
   private String rdmId = "";
   private long ipPort;
   private String deviceType;
   private String deviceModel = "";
   private boolean rootDevice;
   private volatile boolean connected;
   private String state = "AVAILABLE";
   private boolean active;
   private String notifyMsg;
   private DeviceSecurity security;
   protected RaritanPropertyResourceBundle bundle;
   private KvmPort activeKvmPort;
   private String kvmSwitchId;
   private boolean kvmSwitchEnabled;
   private boolean cancelLogin = false;
   private ArrayList addressList = new ArrayList();
   private static int sortType = 0;
   private int colorCalibSpeed = 60000;
   private DeviceView deviceView;
   private int isGhostingEnabled;
   private String rdmSessionId = null;
   private String rdmSessionKey = null;
   private Map appletParameters = null;
   private DeviceComparator comparator = new DeviceComparator();
   private DeviceHandlerInterface handler;
   private LinkedHashMap<VirtualBladeChassis, Vector<String>> portsWithGroupsMap;
   private MultiMonitorPortHandler multiMonitorHandler = new MultiMonitorPortHandler();
   private int upgradeDuration = 20;
   private File rscFileHandle;
   private boolean requireRSAAcceptance = false;
   private boolean rsaEnabled = false;
   private boolean rsaAccepted = false;
   private boolean scanSupported = false;
   private boolean doNotshowErrorAgain = false;
   private String statusToolTip = "";
   private String availabilityToolTip = "";
   private int rdmStatAvailable = -1;
   private int status;
   public static final int STATAVAILABLE_AVAILABLE = 0;
   public static final int STATAVAILABLE_OCCUPIED = 1;
   public static final int STATAVAILABLE_BUSY = 2;
   public static final int STATAVAILABLE_UNAVAILABLE = 3;
   public static final int STATAVAILABLE_INACCESSIBLE = 4;

   public boolean isDoNotshowErrorAgain() {
      return this.doNotshowErrorAgain;
   }

   public void setDoNotshowErrorAgain(boolean var1) {
      this.doNotshowErrorAgain = var1;
   }

   public void showCommunicationError(String var1, String var2) {
      RRCLogger.log(200, "Received Communication Error:" + var1 + " Showing Popup:" + this.isDoNotshowErrorAgain());
      RaritanDesktopPane var3 = (RaritanDesktopPane)((RRCScreenContext)this.scrContext).getPanelMediator().getParent();
      if (!this.isDoNotshowErrorAgain()) {
         boolean var4 = ErrorHandlerImpl.getInstance().showErrorWithOptionToRemember(var3, var1, var2);
         this.setDoNotshowErrorAgain(var4);
      }
   }

   public void setUpgradeDuration(int var1) {
      this.upgradeDuration = var1;
   }

   public int getUpgradeDuration() {
      return this.upgradeDuration;
   }

   public Device() {
      this(null);
   }

   public Device(ScreenContext var1) {
      this.scrContext = var1;
      if (this.scrContext != null) {
         this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      }
   }

   private boolean isType(String var1) {
      return var1.equals(this.deviceModel);
   }

   public boolean isModelKX() {
      return this.isType("DKX");
   }

   public static boolean isFixedSortPos(int var0) {
      return var0 == 7 || var0 == 8 || var0 == 9;
   }

   public int getColorCalibSpeed() {
      return this.colorCalibSpeed;
   }

   public void setColorCalibSpeed(int var1) {
      this.colorCalibSpeed = var1;
   }

   public void setName(String var1) {
      String var2 = this.name;
      this.name = var1;
      this.firePropertyChange("DEVICE_STATE_CHANGED", null, null);
      this.firePropertyChange("DEVICE_NAME_CHANGED", var2, var1);
      DeviceTreeController.getInstance((RRCScreenContext)this.scrContext).treeNodeChanged(this);
   }

   public String getName() {
      return this.name;
   }

   public void setId(String var1) {
      if (StringUtils.notNullOrEmpty(var1)) {
         this.id = var1;
      }
   }

   public String getId() {
      return this.id;
   }

   public void setRdmId(String var1) {
      if (StringUtils.notNullOrEmpty(var1)) {
         this.rdmId = var1;
      }
   }

   public String getRdmId() {
      return this.rdmId;
   }

   private final String getIPAddress() {
      return this.addressList.size() > 0 ? ((InetAddress)this.addressList.get(0)).getHostAddress() : "";
   }

   public String getIPAddressStringNoPhone() {
      return this.getIPAddress();
   }

   public void setIPPort(long var1) {
      this.ipPort = var1;
   }

   public long getIPPort() {
      if (this.isProfiled()) {
         this.getDevPrefs().getPort();
      }

      return this.ipPort;
   }

   public int getHttpsPort() {
      return this.isProfiled() ? this.getDevPrefs().getHttpsPort() : ((RRCScreenContext)this.getContext()).getAppSettings().getDefaultHttpsPort();
   }

   public void setDeviceType(String var1) {
      if (StringUtils.findInStringArray(var1, ENUM_DEVICE_TYPES)) {
         this.deviceType = var1;
      }
   }

   public String getDeviceType() {
      return this.deviceType;
   }

   public void setGhostMode(int var1) {
      this.isGhostingEnabled = var1;
   }

   public int getGhostMode() {
      return this.isGhostingEnabled;
   }

   public String getDeviceClass() {
      return "";
   }

   public void setDeviceModel(String var1) {
      this.deviceModel = var1;
   }

   public String getDeviceModel() {
      return this.deviceModel;
   }

   public void setRootDevice(boolean var1) {
      this.rootDevice = var1;
   }

   public boolean isRootDevice() {
      return this.rootDevice;
   }

   @Override
   public boolean isConnected() {
      return this.connected;
   }

   @Override
   public void setConnected(boolean var1) {
      this.connected = var1;
   }

   public boolean isActive() {
      return this.active;
   }

   public void setActive(boolean var1) {
      this.active = var1;
      if (this.active) {
         this.firePropertyChange("DEVICE_ACTIVATED", null, null);
      }
   }

   public boolean isProfiled() {
      return this.profiled;
   }

   public void setProfiled(boolean var1) {
      this.profiled = var1;
      this.firePropertyChange("DEVICE_STATE_CHANGED", null, null);
   }

   public void setState(String var1) {
      if (StringUtils.findInStringArray(var1, ENUM_STATES) && !var1.equals(this.state)) {
         String var2 = this.state;
         this.state = var1;
         this.firePropertyChange("DEVICE_STATE_CHANGED", var2, this.state);
         DeviceTreeController.getInstance((RRCScreenContext)this.scrContext).treeNodeChanged(this);
      } else {
         DeviceTreeController.getInstance((RRCScreenContext)this.scrContext).treeNodeChanged(this);
      }
   }

   public String getState() {
      return this.state;
   }

   public abstract String getViewName();

   public void setConnectionId(String var1) {
      if (StringUtils.notNullOrEmpty(var1)) {
         this.id = var1;
      }
   }

   public String getConnectionId() {
      return this.id;
   }

   public int getSortType() {
      return sortType;
   }

   public void setSortType(int var1) {
      sortType = var1;
   }

   @Override
   public boolean login(TRSRVR_SERVER_ID var1, TRLIB_USERINFO var2, boolean var3) {
      return false;
   }

   public TRLIB_USERINFO login() {
      return null;
   }

   @Override
   public boolean loginChallenge(int var1, byte[] var2, byte[] var3) {
      return false;
   }

   @Override
   public void notify(int var1, int var2) {
   }

   @Override
   public void connect() {
   }

   @Override
   public void disconnect() {
      try {
         Map var1 = this.getChildren();
         if (var1 != null) {
            synchronized (var1) {
               Iterator var3 = var1.keySet().iterator();

               while (var3.hasNext()) {
                  Device var4 = (Device)var1.get(var3.next());
                  String var5 = null;
                  if (var4 instanceof BladeChassis) {
                     BladeChassis var6 = (BladeChassis)var4;
                     if (var6 != null) {
                        Map var7 = var6.getChildren();
                        if (var7 != null) {
                           synchronized (var7) {
                              Iterator var9 = var7.keySet().iterator();

                              while (var9.hasNext()) {
                                 Device var10 = (Device)var7.get(var9.next());
                                 if (var10 != null) {
                                    var5 = var10.getPortKey();
                                    if (var10.isConnected()) {
                                       var10.disconnect();
                                    }
                                 }
                              }
                           }
                        }
                     }
                  } else if (var4 != null) {
                     var5 = var4.getPortKey();
                     if (var4.isConnected()) {
                        var4.disconnect();
                     }
                  }

                  this.clearEntriesInVMMaps(var5);
               }
            }

            this.arrEvenMsg = null;
         }

         this.setState("AVAILABLE");
      } finally {
         this.rscFileHandle = null;
         if (this.scrContext != null) {
            MPCScanFrame var14 = ((RRCScreenContext)this.scrContext).getScanFrame();
            if (var14 != null && var14.getConnectedDeviceId().equals(this.getId())) {
               try {
                  var14.setClosed(true);
               } catch (PropertyVetoException var21) {
               }
            }

            if (((RRCScreenContext)this.scrContext).getSelectedPort() == null) {
               ((RRCScreenContext)this.scrContext).resetDesktopFocus();
            }
         }
      }

      if (this.portsWithGroupsMap != null) {
         this.portsWithGroupsMap.clear();
         this.portsWithGroupsMap = null;
      }

      this.requireRSAAcceptance = false;
      this.rsaEnabled = false;
      this.rsaAccepted = false;
      this.doNotshowErrorAgain = false;
   }

   private void clearEntriesInVMMaps(String var1) {
      if (var1 != null) {
         if (this.scrContext != null) {
            if (this.scrContext.getVirtualMediaImageMap() != null && this.scrContext.getVirtualMediaImageMap().containsKey(var1)) {
               this.scrContext.getVirtualMediaImageMap().remove(var1);
               RRCLogger.log(300, 4, "Removing PortKey from VirtualMediaImageMap:" + var1);
            }

            if (this.scrContext.getVirtualMediaLocalMap() != null && this.scrContext.getVirtualMediaLocalMap().containsKey(var1)) {
               this.scrContext.getVirtualMediaLocalMap().remove(var1);
               RRCLogger.log(300, 4, "Removing PortKey from VirtualMediaLocalMap:" + var1);
            }
         } else {
            RRCLogger.log(300, 4, "ScreenContext is NULL in Device while Disconnecting");
         }
      }
   }

   public synchronized DeviceConnector getDeviceConnector() {
      return this.connector;
   }

   public synchronized void setDeviceConnector(DeviceConnector var1) {
      this.connector = var1;
   }

   private boolean isListenerAdded(PropertyChangeListener var1) {
      boolean var2 = false;
      PropertyChangeListener[] var3 = this.deviceListeners.getPropertyChangeListeners();

      for (int var4 = 0; var4 < var3.length; var4++) {
         if (var3[var4].getClass().getName().equalsIgnoreCase(var1.getClass().getName())) {
            var2 = true;
            break;
         }
      }

      return var2;
   }

   public void addPropertyChangeListener(PropertyChangeListener var1) {
      boolean var2 = this.isListenerAdded(var1);
      if (!var2) {
         this.deviceListeners.addPropertyChangeListener(var1);
      }
   }

   public void addPropertyChangeListener(String var1, PropertyChangeListener var2) {
      boolean var3 = this.isListenerAdded(var2);
      if (!var3) {
         this.deviceListeners.addPropertyChangeListener(var1, var2);
      }
   }

   public void firePropertyChange(String var1, Object var2, Object var3) {
      this.deviceListeners.firePropertyChange(var1, var2, var3);
   }

   protected void displayDeviceStatus(int var1) {
      this.notifyMsg = this.getNotifyMessage(var1);
      this.setNotifyMsg(this.notifyMsg);
   }

   protected void addNotifyMessage(int var1) {
      if (this.arrEvenMsg == null) {
         this.arrEvenMsg = new ArrayList();
      }

      if (!this.arrEvenMsg.contains(new Integer(var1))) {
         this.arrEvenMsg.add(new Integer(var1));
      }
   }

   protected void printMsg(int var1) {
      if (this.scrContext != null) {
         this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
         if (this.bundle != null) {
            String var2 = this.bundle.getString("error.unknown");
            this.scrContext.getLogger().logTextInfo("[" + getActiveNameIP(this, var2) + "]: " + this.bundle.getMessage("Device.message" + var1, var1));
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel())
               .setTextLabel("[" + getActiveNameIP(this, var2) + "]: " + this.bundle.getMessage("Device.message" + var1, var1));
         } else {
            this.scrContext.getLogger().logTextInfo("[" + this.getNameIP() + "]: TR Event" + var1);
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel("[" + this.getNameIP() + "]:  TR Event" + var1);
         }
      }
   }

   public String getNotifyMessage(int var1) {
      StringBuffer var2 = new StringBuffer();
      this.notifyMsg = TR_NOTIFY_MSG_CACHE.getNotifyMessage(var1);
      var2.append(" " + (this.notifyMsg == null ? String.valueOf(var1) : this.notifyMsg));
      return var2.toString();
   }

   public String getNotifyMsg() {
      return this.notifyMsg;
   }

   public void setNotifyMsg(String var1) {
      this.notifyMsg = var1;
   }

   public boolean isModemProfiled() {
      return this.isModemProfiled;
   }

   public void setModemProfiled(boolean var1) {
      this.isModemProfiled = var1;
   }

   public DevicePreferences getDevPrefs() {
      return this.devPrefs;
   }

   public void setDevPrefs(DevicePreferences var1) {
      this.devPrefs = var1;
   }

   public ScreenContext getContext() {
      return this.scrContext;
   }

   public void setContext(ScreenContext var1) {
      this.scrContext = var1;
   }

   public void setDevView(DeviceView var1) {
      this.deviceView = var1;
   }

   public boolean hasFocus() {
      return this.deviceView != null && this.deviceView.hasFocus();
   }

   public DeviceSecurity getSecurity() {
      return this.security;
   }

   public void setSecurity(DeviceSecurity var1) {
      this.security = var1;
   }

   public ArrayList getArrEvenMsg() {
      return this.arrEvenMsg;
   }

   public void setArrEvenMsg(ArrayList var1) {
      this.arrEvenMsg = var1;
   }

   public String getDescription() {
      return StringUtils.notNullOrEmpty(this.description) ? this.description : this.name;
   }

   public void setDescription(String var1) {
      this.description = var1;
   }

   public void setActiveKvmPort(KvmPort var1) {
      if (var1 != null && this.activeKvmPort != null) {
         this.activeKvmPort.setActive(false);
         this.activeKvmPort.disconnect();
      }

      this.activeKvmPort = var1;
      if (this.activeKvmPort != null && !this.activeKvmPort.isActive()) {
         this.activeKvmPort.setActive(true);
      }
   }

   public Port getActiveKvmPort() {
      return this.activeKvmPort;
   }

   public void enableKvmSwitch(boolean var1) {
      this.kvmSwitchEnabled = var1;
   }

   public boolean isKvmSwitch() {
      return this.kvmSwitchEnabled;
   }

   public void setKvmSwitchId(String var1) {
      this.kvmSwitchId = var1;
   }

   public String getKvmSwitchId() {
      return this.kvmSwitchId;
   }

   public void setPortStatus(int var1, int var2) {
      this.rdmStatAvailable = var2;
      if (var1 == 0) {
         if (var2 == 0) {
            this.status = 0;
            this.statusToolTip = "Down";
            this.availabilityToolTip = "Idle";
         } else if (var2 == 1) {
            this.status = 2;
            this.statusToolTip = "Down";
            this.availabilityToolTip = "Connected";
         } else if (var2 == 2) {
            this.status = 2;
            this.statusToolTip = "Down";
            this.availabilityToolTip = "Busy";
         } else if (var2 == 3) {
            this.status = 2;
            this.statusToolTip = "Down";
            this.availabilityToolTip = "Unavailable";
         } else if (var2 == 4) {
            this.status = 2;
            this.statusToolTip = "Down";
            this.availabilityToolTip = "All Channels In Use";
         } else {
            this.status = 0;
            this.statusToolTip = "Down";
            this.availabilityToolTip = "Idle";
         }
      }

      if (var1 == 1) {
         if (var2 == 0) {
            this.status = 1;
            this.statusToolTip = "Up";
            this.availabilityToolTip = "Idle";
         } else if (var2 == 1) {
            this.status = 2;
            this.statusToolTip = "Up";
            this.availabilityToolTip = "Connected";
         } else if (var2 == 2) {
            this.status = 2;
            this.statusToolTip = "Up";
            this.availabilityToolTip = "Busy";
         } else if (var2 == 3) {
            this.status = 2;
            this.statusToolTip = "Up";
            this.availabilityToolTip = "Unavailable";
         } else if (var2 == 4) {
            this.status = 1;
            this.statusToolTip = "Up";
            this.availabilityToolTip = "All Channels In Use";
         } else {
            this.status = 1;
            this.statusToolTip = "Up";
            this.availabilityToolTip = "Idle";
         }
      }

      if (var1 == 0) {
         this.setState("UNAVAILABLE");
      } else if (this.isConnected()) {
         this.setState("CONNECTED");
      } else {
         this.setState("AVAILABLE");
      }

      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "Port.setPortStatus(int, int) [" + this.toString() + ", " + this.getName() + "], " + this.status);
      }
   }

   public int getRdmStatAvailable() {
      return this.rdmStatAvailable;
   }

   public String getStatusToolTip() {
      return this.statusToolTip;
   }

   public String getAvailabilityToolTip() {
      return this.availabilityToolTip;
   }

   public void setToolTipText() {
      if (this.isConnected()) {
         this.statusToolTip = "Connected";
      } else {
         this.statusToolTip = "Not Connected";
      }

      if (this.status == 1) {
         this.availabilityToolTip = "Available";
      }

      if (this.status == 0) {
         this.availabilityToolTip = "Unavailable";
      }

      if (this.status == 2) {
         this.availabilityToolTip = "Busy";
      }
   }

   public int getStatus() {
      return this.status;
   }

   public void setPortStatus(String var1) {
      int var2 = Integer.parseInt(var1);
      if (var2 >= 0 && var2 <= 2) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "Port.setPortStatus(String) [" + this.toString() + ", " + this.getName() + "], " + var1);
         }

         this.status = var2;
         this.setToolTipText();
         this.setPortStatus(var2);
      }
   }

   public void setPortStatus(int var1) {
      if (var1 >= 0 && var1 <= 2) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "Port.setPortStatus(int) [" + this.toString() + ", " + this.getName() + "], " + var1);
         }

         this.status = var1;
         this.setToolTipText();
         if (var1 == 0) {
            this.setState("UNAVAILABLE");
         } else if (this.isConnected()) {
            this.setState("CONNECTED");
         } else {
            this.setState("AVAILABLE");
         }
      }
   }

   public BladeChassis getBladeChassisByTargetDeviceId(String var1) {
      Map var2 = this.getChildren();
      if (var2 != null) {
         Iterator var3 = var2.keySet().iterator();
         Object var4 = null;

         while (var3.hasNext()) {
            Object var5 = var3.next();
            if (var5 != null) {
               var5 = var2.get(var5);
               if (var5 != null && var5 instanceof BladeChassis) {
                  BladeChassis var6 = (BladeChassis)var5;
                  if (var6 != null && var6.getId().equals(var1)) {
                     return var6;
                  }
               }
            }
         }
      }

      return null;
   }

   public Port getPortByTargetDeviceId(String var1) {
      Map var2 = this.getChildren();
      if (var2 != null) {
         Iterator var3 = var2.keySet().iterator();
         Port var4 = null;

         while (var3.hasNext()) {
            Object var5 = var3.next();
            if (var5 != null) {
               var5 = var2.get(var5);
               if (var5 != null) {
                  if (var5 instanceof Port) {
                     var4 = (Port)var5;
                     if (var4 != null && var4.getTargetDeviceId().equals(var1)) {
                        return var4;
                     }
                  } else if (var5 instanceof Paragon) {
                     Paragon var6 = (Paragon)var5;
                     var4 = var6.getPortByTargetDeviceId(var1);
                     if (var4 != null) {
                        return var4;
                     }
                  } else if (var5 instanceof BladeChassis || var5 instanceof VirtualBladeChassis) {
                     BladeChassis var11 = (BladeChassis)var5;
                     var4 = var11.getPortByTargetDeviceId(var1);
                     if (var4 != null) {
                        return var4;
                     }
                  }
               }
            }
         }
      }

      return null;
   }

   public String getBladeChassisForDeviceId(String var1) {
      Map var2 = this.getChildren();
      if (var2 != null) {
         Iterator var3 = var2.keySet().iterator();
         Object var4 = null;

         while (var3.hasNext()) {
            Object var5 = var3.next();
            if (var5 != null) {
               var5 = var2.get(var5);
               if (var5 != null && var5 instanceof BladeChassis) {
                  var4 = (BladeChassis)var5;
                  if (var4 != null && ((BladeChassis)var4).getConnectionId().equals(var1)) {
                     return ((BladeChassis)var4).getId();
                  }
               }
            }
         }
      }

      return null;
   }

   public String getIP() {
      String var1 = null;
      if (this.isProfiled() && !this.isModemProfiled()) {
         switch (this.getDevPrefs().getFindBy()) {
            case 0:
               var1 = new String(StringUtils.formatString(this.getDevPrefs().getIp()));
               break;
            case 1:
               var1 = this.getIPAddress();
               if ("".equals(var1)) {
                  var1 = null;
                  RRCLogger.log(300, 4, "Unable to get IP for device named " + this.getDevPrefs().getName());
               }
               break;
            case 2:
               try {
                  var1 = new String(InetAddress.getByName(this.getDevPrefs().getDnsName()).getHostAddress());
               } catch (UnknownHostException var3) {
                  var1 = null;
                  RRCLogger.log(300, 4, "Unknown Host Exception when connecting to " + this.getDevPrefs().getDnsName());
               }
               break;
            default:
               RRCLogger.log(100, 4, "Unable to determine IP Address of device: " + this.getName());
         }
      } else {
         var1 = this.getIPAddress();
      }

      return var1;
   }

   public String getNameIP() {
      String var1 = this.getIP();
      if (var1 == null) {
         if (this.bundle == null) {
            this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
         }

         var1 = this.bundle.getString("error.unknownHostname");
      }

      return (StringUtils.formatString(this.name) + " " + var1).trim();
   }

   public boolean isCancelLogin() {
      return this.cancelLogin;
   }

   public void setCancelLogin(boolean var1) {
      this.cancelLogin = var1;
   }

   public void sort(int var1) {
      sortType = var1;
      this.comparator.setSortType(var1);
      Map var2 = this.getChildren();
      if (var2 != null) {
         synchronized (var2) {
            if (var2.entrySet() != null) {
               ArrayList var4 = new ArrayList(var2.entrySet());
               Collections.sort(var4, this.comparator);
               Iterator var5 = var4.iterator();
               LinkedHashMap var6 = new LinkedHashMap();
               int var7 = 0;

               while (var5.hasNext()) {
                  var7++;
                  Device var8 = (Device)((Entry)var5.next()).getValue();
                  String var9 = "";
                  if (var8 instanceof Port) {
                     var9 = ((Port)var8).getTargetDeviceId();
                  } else if (!(var8 instanceof BladeChassis) && !(var8 instanceof VirtualBladeChassis)) {
                     var9 = Integer.toString(var7);
                  } else {
                     var8.sort(this.getSortType());
                  }

                  var6.put((var8.getName() + var9).toLowerCase(), var8);
               }

               this.addChildren(var6);
               var6.clear();
               Object var12 = null;
            }
         }
      }
   }

   public DeviceHandlerInterface getHandler() {
      return this.handler;
   }

   public void setHandler(DeviceHandlerInterface var1) {
      this.handler = var1;
   }

   public String getRdmSessionId() {
      return this.rdmSessionId;
   }

   public void setRdmSessionId(String var1) {
      this.rdmSessionId = var1;
   }

   public String getRdmSessionKey() {
      return this.rdmSessionKey;
   }

   public void setRdmSessionKey(String var1) {
      this.rdmSessionKey = var1;
   }

   public Map<String, String> getAppletParameters() {
      return this.appletParameters;
   }

   public void setAppletParameters(Map<String, String> var1) {
      this.appletParameters = var1;
   }

   public DeviceView getDeviceView() {
      return this.deviceView;
   }

   public void setDeviceView(DeviceView var1) {
      this.deviceView = var1;
   }

   public File getRscFileHandle() {
      return this.rscFileHandle;
   }

   public void setRscFileHandle(File var1) {
      this.rscFileHandle = var1;
   }

   public void setAddressList(List var1) {
      this.addressList.clear();
      this.addressList.addAll(var1);
   }

   public List getAddressList() {
      return new ArrayList(this.addressList);
   }

   public String getDnsName() {
      return this.dnsName;
   }

   public void setDnsName(String var1) {
      this.dnsName = var1;
   }

   public static String getNameIP(Device var0, String var1) {
      String var2 = var0.getName();
      String var3 = "";
      if (var0.isProfiled()) {
         DevicePreferences var4 = var0.getDevPrefs();
         switch (var4.getConnectionType()) {
            case 1:
               var2 = var4.getPhone();
               var3 = getIP(var0);
               break;
            case 2:
               switch (var4.getFindBy()) {
                  case 0:
                     var3 = var4.getIp();
                     break;
                  case 1:
                     var2 = var4.getName();
                     var3 = getIP(var0);
                     break;
                  case 2:
                     var3 = var4.getDnsName();
               }
         }
      } else {
         var3 = getIP(var0);
      }

      if (var2 == null || "".equals(var2)) {
         var2 = var1;
      }

      return var2 + " " + var3;
   }

   private static String getIP(Device var0) {
      List var1 = var0.getAddressList();
      return var1.size() > 0 ? ((InetAddress)var1.get(0)).getHostAddress() : "";
   }

   private static String getActiveNameIP(Device var0, String var1) {
      DeviceConnector var2 = var0.getDeviceConnector();
      Object var3 = null;
      if (var2 != null && (var3 = var2.getInetAddress()) != null) {
         String var4 = var0.getName();
         if (var0.isProfiled()) {
            DevicePreferences var5 = var0.getDevPrefs();
            switch (var5.getConnectionType()) {
               case 1:
                  var4 = var5.getPhone();
                  break;
               case 2:
                  switch (var5.getFindBy()) {
                     case 1:
                        var4 = var5.getName();
                  }
            }
         }

         if (var4 == null || "".equals(var4)) {
            var4 = var1;
         }

         return var4 + " " + var3.getHostAddress();
      } else {
         return getNameIP(var0, var1);
      }
   }

   public abstract String getPortKey();

   public void setUniquePortId(String var1) {
      this.uniquePortId = var1;
   }

   public String getUniquePortId() {
      return this.uniquePortId;
   }

   public void showGroupView(boolean var1) {
      Map var2 = this.getChildren();
      new Vector();
      new Vector();
      if (var1) {
         if (this.portsWithGroupsMap != null && this.portsWithGroupsMap.size() > 0) {
            for (Object var6 : this.portsWithGroupsMap.keySet()) {
               VirtualBladeChassis var7 = (VirtualBladeChassis)var6;
               if (var7.getBaseDevice() == this) {
                  if (var6 != null) {
                     Vector var8 = this.portsWithGroupsMap.get(var6);

                     for (int var9 = 0; var9 < var8.size(); var9++) {
                        String var10 = (String)var8.get(var9);
                        Port var11 = this.getPortByTargetDeviceId(var10);
                        this.remove(var11, var11.getName() + var11.getTargetDeviceId());
                        var7.add(var11, var11.getName() + var11.getTargetDeviceId());
                     }
                  }

                  this.add(var7, var7.getName() + var7.getId());
                  this.firePropertyChange("DEVICE_PORTS_ADD", null, null);
               }
            }
         }
      } else {
         this.showWithoutGroups();
      }

      DeviceTreeController.getInstance().sort(this.getSortType());
   }

   public void showWithoutGroups() {
      Map var1 = this.getChildren();
      Vector var2 = new Vector();
      Vector var3 = new Vector();
      if (var1 != null) {
         for (Object var5 : var1.keySet()) {
            if (var5 != null) {
               var5 = var1.get(var5);
               if (var5 != null && var5 instanceof VirtualBladeChassis) {
                  VirtualBladeChassis var6 = (VirtualBladeChassis)var5;
                  Map var7 = var6.getChildren();
                  if (var7 != null && var7.size() > 0) {
                     for (Object var9 : var7.keySet()) {
                        if (var9 != null) {
                           Object var10 = var7.get(var9.toString());
                           if (var10 != null && var10 instanceof Port) {
                              Port var11 = (Port)var10;
                              var3.add(var11);
                           }
                        }
                     }

                     if (var6.hasChildren()) {
                        var6.removeChildren();
                     }

                     var2.add(var6);
                  }
               }
            }
         }

         for (int var13 = 0; var13 < var3.size(); var13++) {
            Port var15 = (Port)var3.get(var13);
            this.add(var15, var15.getName() + var15.getTargetDeviceId());
         }

         for (int var14 = 0; var14 < var2.size(); var14++) {
            VirtualBladeChassis var16 = (VirtualBladeChassis)var2.get(var14);
            this.remove(var16, var16.getName());
         }

         this.firePropertyChange("DEVICE_PORTS_REMOVE", null, null);
      }
   }

   public Map getPortsWithGroupMap() {
      return this.portsWithGroupsMap;
   }

   public void setVbcWithPortsMap(LinkedHashMap<VirtualBladeChassis, Vector<String>> var1) {
      this.portsWithGroupsMap = var1;
   }

   public void setMultiMonitorPorts(List<MultiMonitorPort> var1) {
      this.multiMonitorHandler = new MultiMonitorPortHandler(var1);
   }

   public void setMultiMonitorPorts(MultiMonitorPort var1) {
      this.multiMonitorHandler = new MultiMonitorPortHandler(var1);
   }

   public MultiMonitorPortHandler getMultiMonitorPortHandler() {
      return this.multiMonitorHandler;
   }

   public boolean isVirtual() {
      return this.virtual;
   }

   public void setVirtual(Boolean var1) {
      this.virtual = var1;
   }

   public void setRSAEnabled(boolean var1) {
      this.rsaEnabled = var1;
   }

   public boolean isRSAEnabled() {
      return this.rsaEnabled;
   }

   public void setRSAAcceptance(boolean var1) {
      this.requireRSAAcceptance = var1;
   }

   public boolean isRSAAcceptance() {
      return this.requireRSAAcceptance;
   }

   public void setRSAAccepted(boolean var1) {
      this.rsaAccepted = var1;
   }

   public boolean isRSAAccepted() {
      return this.rsaAccepted;
   }

   public boolean isScanSupported() {
      return this.scanSupported;
   }

   public void setScanSupported(boolean var1) {
      this.scanSupported = var1;
   }

   public void setScreenContext(ScreenContext var1) {
      this.scrContext = var1;
   }
}
