package com.raritan.rrc.data;

import com.raritan.rrc.ui.commands.ShowChangePasswordCommand;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.ScreenContext;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.InetAddress;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLEncoder;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import javaclientlib.clientlib.TRConnection;
import javaclientlib.tr.TRLIB_COMM;
import javaclientlib.tr.TRLIB_REFERRAL_COMM;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.tr.TRSRVR_SERVER_ID;
import javaclientlib.utils.RRCLogger;
import javax.swing.SwingUtilities;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class DeviceConnector extends TRConnection {
   private static final int PORT_STATUS_CHANGED = 84;
   private static final int DEVICE_CHANGED = 65;
   private static final int RDM_EC_PATH_STATUS_CHANGED = 164;
   private static final int PORT_CHANGED = 81;
   private static final int DEVICE_COMM_FAILED = 79;
   private static final String GET_SESSION_ID = "<Session><GetSessionID/></Session>";
   private Device device;
   private TRLIB_USERINFO userInfo;
   private boolean authFailed = false;
   private static final int sleepTime = 200;
   private boolean wrongAuth = false;
   private boolean bIsCSCReferral = false;
   private String CCURL = null;
   private String CCconnID = null;
   private boolean CCPowerControl = false;
   private DevicePreferences devprefs = null;
   private boolean writePrefsToCC = false;
   public boolean usePrefsFromCC = false;
   public boolean usePowerControlFromCC = false;
   private boolean isPIISCPort = false;
   private HashMap ccParamsMap;
   private ScreenContext scrContext;
   private boolean noResponseFromIP = false;

   public DeviceConnector(Device var1, TRLIB_USERINFO var2) {
      this.device = var1;
      this.userInfo = var2;
   }

   public DeviceConnector(Device var1, TRLIB_USERINFO var2, ScreenContext var3) {
      this.device = var1;
      this.userInfo = var2;
      this.scrContext = var3;
   }

   @Override
   public boolean login(TRSRVR_SERVER_ID var1, TRLIB_USERINFO var2, boolean var3) {
      if (var3) {
         this.notify(1008, 0);
      }

      TRLIB_USERINFO var4 = this.login();
      if (var4 == null) {
         return false;
      } else {
         var2.setName(var4.getName());
         var2.setPassword(var4.getPassword());
         return true;
      }
   }

   private TRLIB_USERINFO login() {
      return this.device != null ? this.device.login() : null;
   }

   @Override
   public boolean loginChallenge(int var1, byte[] var2, byte[] var3) {
      return this.device != null ? this.device.loginChallenge(var1, var2, var3) : false;
   }

   @Override
   public void notify(int var1, int var2) {
      if (!this.updateActive) {
         if (this.device != null) {
            switch (var1) {
               case 1001:
                  this.device.addNotifyMessage(var1);
                  break;
               case 1002:
               case 1003:
               case 1004:
               case 1005:
               case 1009:
               case 1011:
               case 1013:
               case 1014:
               case 1015:
               case 1017:
               case 1019:
               case 1021:
               case 1022:
               case 1023:
               case 1024:
               case 1025:
               case 1027:
               case 1028:
               case 1029:
               case 1030:
               case 1031:
               case 1032:
               case 1033:
               case 1034:
               case 1035:
               case 1036:
               case 1037:
               case 1038:
               case 1039:
               default:
                  this.authFailed = true;
                  this.device.printMsg(var1);
                  this.device.addNotifyMessage(var1);
                  this.device.disconnect();
                  break;
               case 1006:
                  this.authFailed = false;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1007:
                  if (!this.device.isCancelLogin()) {
                     this.authFailed = false;
                     this.device.setConnected(true);
                     this.device.addNotifyMessage(var1);
                  }
                  break;
               case 1008:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1010:
                  this.authFailed = true;
                  this.device.disconnect();
                  this.device.printMsg(var1);
                  this.device.addNotifyMessage(var1);
                  break;
               case 1012:
                  this.authFailed = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1016:
                  this.device.printMsg(var1);
                  break;
               case 1018:
                  this.authFailed = true;
                  this.device.printMsg(var1);
                  this.device.addNotifyMessage(var1);
                  break;
               case 1020:
                  this.authFailed = true;
                  ((IPReach)this.device).disconnect(this.wrongAuth);
                  this.wrongAuth = false;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1026:
                  this.authFailed = true;
                  this.device.addNotifyMessage(var1);
                  SwingUtilities.invokeLater(new Runnable() {
                     @Override
                     public void run() {
                        ShowChangePasswordCommand var1x = new ShowChangePasswordCommand(DeviceConnector.this.device.getContext());
                        if (var1x.isExecutable()) {
                           CommandResult var2x = var1x.execute();
                           if (!var2x.isSuccess() && var2x.hasErrorDescription()) {
                              var1x.handleCommandResultErrorDescription(var2x);
                           } else {
                              var1x.handleCommandResult(var2x);
                              DeviceConnector.this.device.getContext().getPanelMediator().showPanel(var1x.getContext());
                           }
                        }
                     }
                  });
                  break;
               case 1040:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1041:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1042:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1043:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1044:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1045:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1046:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1047:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1048:
                  this.authFailed = true;
                  this.wrongAuth = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1049:
                  this.authFailed = true;
                  this.device.addNotifyMessage(var1);
                  break;
               case 1050:
                  this.setNoResponseFromIP(true);
            }
         }
      }
   }

   @Override
   public void event(byte[] var1) {
      try {
         String var2 = new String(var1).trim();
         int var3 = var2.indexOf("<e ");
         int var4 = var2.indexOf("</e>");
         var2 = var2.substring(var3, var4 + 4);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "RSP Proc:new EVENT::  " + var2);
         }

         Document var6 = getXmlParserInstance().getDocument(var2.trim());
         if (var6 == null) {
            return;
         }

         Element var7 = var6.getDocumentElement();
         Object var47 = null;
         Object var8 = null;
         var8 = var7.getAttribute("ec").trim();
         if (StringUtils.notNullOrEmpty((String)var8)) {
            int var9 = Integer.parseInt((String)var8);
            Object var10 = null;
            Object var11 = null;
            String var12 = null;
            NodeList var13 = null;
            Element var14 = null;
            NodeList var15 = null;
            Element var16 = null;
            NodeList var17 = null;
            Element var18 = null;
            Object var19 = null;
            Object var20 = null;
            switch (var9) {
               case 65:
                  NodeList var79 = var7.getElementsByTagName("n");
                  if (var79 != null && var79.getLength() != 0) {
                     String var80 = var79.item(0).getTextContent();
                     if (var80.equals(this.device.getRdmId())) {
                        NodeList var82 = var7.getElementsByTagName("Name");
                        if (this.device != null && var82 != null && var82.getLength() > 0) {
                           Node var83 = var82.item(0);
                           String var85 = var83.getTextContent();
                           this.device.setName(var85);
                           break;
                        }

                        return;
                     }

                     if (var80.startsWith("PG_") && this.device instanceof IPReach) {
                        ((IPReach)this.device).updateDevice(true);
                        break;
                     }

                     return;
                  }

                  return;
               case 79:
                  NodeList var84 = var7.getElementsByTagName("n");
                  if (var84 != null && var84.getLength() != 0) {
                     String var86 = var84.item(0).getTextContent();
                     var13 = var7.getElementsByTagName("d");
                     if (var13 != null && var13.getLength() != 0) {
                        var14 = (Element)var13.item(0);
                        var15 = var14.getElementsByTagName("Device");
                        if (var15 != null && var15.getLength() != 0) {
                           NodeList var28 = var7.getElementsByTagName("Name");
                           String var29 = "Blade Chassis";
                           if (this.device != null && var28 != null && var28.getLength() > 0) {
                              Node var30 = var28.item(0);
                              var29 = var30.getTextContent();
                           }

                           NodeList var87 = var7.getElementsByTagName("Message");
                           String var31 = "";
                           if (this.device != null && var87 != null && var87.getLength() > 0) {
                              Node var32 = var87.item(0);
                              var31 = var32.getTextContent();
                           }

                           String var88 = this.device.getBladeChassisForDeviceId(var86);
                           BladeChassis var33 = this.device.getBladeChassisByTargetDeviceId(var88);
                           if (var33 != null) {
                              var33.setContext(this.device.getContext());
                              var33.showCommunicationError(var29, var31);
                           }
                           break;
                        }

                        return;
                     }

                     return;
                  }

                  return;
               case 81:
                  var10 = var7.getElementsByTagName("n");
                  if (var10 != null && var10.getLength() != 0) {
                     var11 = var10.item(0).getFirstChild();
                     if (var11 != null) {
                        if (StringUtils.nullOrEmpty(var11.getNodeValue())) {
                           return;
                        }

                        var12 = var11.getNodeValue().trim();
                     }

                     var13 = var7.getElementsByTagName("d");
                     if (var13 != null && var13.getLength() != 0) {
                        var14 = (Element)var13.item(0);
                        var15 = var14.getElementsByTagName("Device");
                        if (var15 != null && var15.getLength() != 0) {
                           var16 = (Element)var15.item(0);
                           var17 = var16.getElementsByTagName("Port");
                           if (var17 != null && var17.getLength() != 0) {
                              int var34 = 0;
                              var18 = (Element)var17.item(0);
                              NamedNodeMap var35 = var18.getAttributes();
                              if (var35 != null) {
                                 Node var36 = var35.getNamedItem("Ghost");
                                 if (var36 != null) {
                                    String var37 = var36.getNodeValue();

                                    try {
                                       var34 = Integer.parseInt(var37);
                                    } catch (Exception var42) {
                                    }
                                 }
                              }

                              NodeList var89 = var18.getElementsByTagName("Name");
                              if (var89 != null && var89.getLength() != 0) {
                                 String var90 = "";
                                 Node var38 = var89.item(0).getFirstChild();
                                 if (var38 != null) {
                                    var90 = var38.getNodeValue().trim();
                                 }

                                 String var39 = "";
                                 if (var35 != null) {
                                    Node var40 = var35.getNamedItem("Type");
                                    if (var40 != null) {
                                       var39 = var40.getNodeValue();
                                    }
                                 }

                                 if (StringUtils.notNullOrEmpty(var12)) {
                                    if (var12.startsWith("FG")) {
                                       var12 = var12.substring(2);
                                    }

                                    Port var91 = this.device.getPortByTargetDeviceId("//*[@id=" + var12 + "]");
                                    if (var91 != null) {
                                       var91.setGhostMode(var34);
                                       var91.setName(var90);
                                       if (var39 != null) {
                                          var91.setPortType(var39);
                                       }
                                    } else if (var39.equals("BladeChassis")
                                       || "PortGroup".equals(var39)
                                       || "VirtualBladeChassis".equals(var39)
                                       || "KVMSwitch".equals(var39)) {
                                       BladeChassis var41 = this.device.getBladeChassisByTargetDeviceId("//*[@id=" + var12 + "]");
                                       if (var41 != null) {
                                          var41.setName(var90);
                                       }
                                    }
                                 }
                                 break;
                              }

                              return;
                           }

                           return;
                        }

                        return;
                     }

                     return;
                  }

                  return;
               case 84:
                  var10 = var7.getElementsByTagName("n");
                  if (var10 != null && var10.getLength() != 0) {
                     var11 = var10.item(0).getFirstChild();
                     if (var11 != null) {
                        if (StringUtils.nullOrEmpty(var11.getNodeValue())) {
                           return;
                        }

                        var12 = var11.getNodeValue().trim();
                     }

                     var13 = var7.getElementsByTagName("d");
                     if (var13 != null && var13.getLength() != 0) {
                        var14 = (Element)var13.item(0);
                        var15 = var14.getElementsByTagName("Device");
                        if (var15 != null && var15.getLength() != 0) {
                           var16 = (Element)var15.item(0);
                           var17 = var16.getElementsByTagName("Port");
                           if (var17 != null && var17.getLength() != 0) {
                              var18 = (Element)var17.item(0);
                              String var21 = var18.getAttribute("Type").trim();
                              var19 = var18.getAttribute("Status").trim();
                              var20 = var18.getAttribute("StatAvailable").trim();
                              if (StringUtils.notNullOrEmpty((String)var19)) {
                                 int var22 = Integer.parseInt((String)var19);
                                 if (StringUtils.notNullOrEmpty(var12)) {
                                    if (var12.startsWith("Ser_")) {
                                       var12 = var12.substring(4);
                                    }

                                    Port var23 = this.device.getPortByTargetDeviceId("//*[@id=" + var12 + "]");
                                    if (var23 != null) {
                                       if (StringUtils.notNullOrEmpty((String)var20)) {
                                          var23.setPortStatus(var22, Integer.parseInt((String)var20));
                                       } else {
                                          var23.setPortStatus(var22);
                                       }
                                    } else {
                                       BladeChassis var81 = this.device.getBladeChassisByTargetDeviceId("//*[@id=" + var12 + "]");
                                       if (var81 != null) {
                                          if (var81.isConnected()) {
                                          }

                                          var81.setPortStatus(var22, Integer.parseInt((String)var20));
                                       }
                                    }
                                 }
                              }
                              break;
                           }

                           return;
                        }

                        return;
                     }

                     return;
                  }

                  return;
               case 164:
                  var10 = var7.getElementsByTagName("n");
                  if (var10 != null && var10.getLength() != 0) {
                     var11 = var10.item(0).getFirstChild();
                     if (var11 != null) {
                        if (StringUtils.nullOrEmpty(var11.getNodeValue())) {
                           return;
                        }

                        var12 = var11.getNodeValue().trim();
                     }

                     var13 = var7.getElementsByTagName("d");
                     if (var13 != null && var13.getLength() != 0) {
                        var14 = (Element)var13.item(0);
                        var15 = var14.getElementsByTagName("Device");
                        if (var15 != null && var15.getLength() != 0) {
                           var16 = (Element)var15.item(0);
                           var17 = var16.getElementsByTagName("Port");
                           if (var17 != null && var17.getLength() != 0) {
                              var18 = (Element)var17.item(0);
                              NodeList var24 = var18.getElementsByTagName("Path");
                              if (var24 != null && var24.getLength() != 0) {
                                 Element var25 = (Element)var24.item(0);
                                 var19 = var25.getAttribute("Status").trim();
                                 if (StringUtils.notNullOrEmpty((String)var19)) {
                                    int var26 = Integer.parseInt((String)var19);
                                    if (StringUtils.notNullOrEmpty(var12)) {
                                       if (var12.startsWith("FG")) {
                                          var12 = var12.substring(2);
                                       }

                                       Port var27 = this.device == null ? null : this.device.getPortByTargetDeviceId("//*[@id=" + var12 + "]");
                                       if (var27 != null) {
                                          var27.setPortStatus(var26);
                                       }

                                       return;
                                    }
                                 }

                                 return;
                              }

                              return;
                           }

                           return;
                        }

                        return;
                     }

                     return;
                  }

                  return;
            }
         }
      } catch (NumberFormatException var43) {
         RRCLogger.logException(var43);
      } catch (DOMException var44) {
         RRCLogger.logException(var44);
      } catch (Exception var45) {
         RRCLogger.logException(var45);
      }
   }

   public boolean resetTR() {
      DeviceConnector var1 = this.device.getDeviceConnector();
      String var2 = "<System><Restart/></System>";
      String var3 = "<System><Restart></Restart></System>";
      return var3.equalsIgnoreCase(var1.databaseRequest(var2));
   }

   @Override
   public boolean disConnect() {
      boolean var1 = super.disConnect();
      this.interrupt();
      return var1;
   }

   public boolean getAuthFailed() {
      return this.authFailed;
   }

   public Device connect(String var1, int var2) {
      try {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "DeviceConnector.Connect XML: " + var1);
         }

         Document var3 = getXmlParserInstance().getDocument(var1);
         if (var3 == null) {
            return null;
         }

         this.ccParamsMap = new HashMap();
         Element var4 = var3.getDocumentElement();
         Object var55 = null;
         NodeList var5 = var4.getElementsByTagName("Device");
         if (var5 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device>");
            }

            return null;
         }

         if (var5.getLength() > 1) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device> length");
            }

            return null;
         }

         Node var6 = var5.item(0);
         NamedNodeMap var7 = var6.getAttributes();
         if (var7 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device> attributes");
            }

            return null;
         }

         Object var8 = null;
         Node var9 = var7.getNamedItem("ID");
         if (var9 != null) {
            var8 = var9.getNodeValue();
         }

         Object var10 = null;
         Node var11 = var7.getNamedItem("Name");
         if (var11 != null) {
            var10 = var11.getNodeValue();
            this.ccParamsMap.put("name", var10);
         }

         InetAddress var12 = null;
         Object var13 = null;
         Node var14 = var7.getNamedItem("HostName");
         if (var14 != null) {
            var13 = var14.getNodeValue();
            var12 = InetAddress.getByName((String)var13);
         } else {
            Node var15 = var7.getNamedItem("IPAddress");
            if (var15 != null) {
               String var16 = var15.getNodeValue();
               long var17 = Long.parseLong(var16);
               String var19 = TRConnection.long2IPString(var17);
               var12 = InetAddress.getByName(var19);
            }
         }

         this.ccParamsMap.put("IPAddress", var12.getHostAddress());
         String var59 = "";
         Node var61 = var7.getNamedItem("Model");
         if (var61 != null) {
            var59 = var61.getNodeValue();
            this.ccParamsMap.put("Model", var59);
            if (var59.toUpperCase().equals("P2SC")) {
               this.isPIISCPort = true;
            }
         }

         String var62 = null;
         Node var18 = var7.getNamedItem("SessionID");
         if (var18 != null) {
            var62 = var18.getNodeValue();
            this.ccParamsMap.put("SessionID", var62);
         }

         String var63 = null;
         Node var20 = var7.getNamedItem("SessionKey");
         if (var20 != null) {
            var63 = var20.getNodeValue();
            this.ccParamsMap.put("SessionKey", var63);
         }

         String var21 = null;
         Node var22 = var7.getNamedItem("ConnectionID");
         if (var22 != null) {
            var21 = var22.getNodeValue();
            this.ccParamsMap.put("ConnectionID", var21);
         }

         String var23 = null;
         Node var24 = var7.getNamedItem("ConnectionIDHTTPS");
         if (var24 != null) {
            var23 = var24.getNodeValue();
            this.ccParamsMap.put("ConnectionIDHTTPS", var23);
         }

         Object var25 = null;
         Node var26 = var7.getNamedItem("useSSLInProxy");
         if (var26 != null) {
            var25 = var26.getNodeValue();
            this.ccParamsMap.put("useSSLInProxy", var25);
         }

         int var27 = 0;
         Node var28 = var7.getNamedItem("TCPPort");
         if (var28 != null) {
            var27 = Integer.parseInt(var28.getNodeValue());
            this.ccParamsMap.put("TCPPort", var28.getNodeValue());
         }

         Object var29 = null;
         Node var30 = var7.getNamedItem("Access");
         if (var30 != null) {
            var29 = var30.getNodeValue();
            this.ccParamsMap.put("Access", var29);
         }

         Object var31 = null;
         Node var32 = var7.getNamedItem("VirtualMedia");
         if (var32 != null) {
            var31 = var32.getNodeValue();
            RRCLogger.log(300, 4, "VM permission from CC:" + var31);
            if (var31 != null && !var31.equals("")) {
               if (var31.toLowerCase().equals("read-write")) {
                  var31 = "w";
               } else if (var31.toLowerCase().equals("read-only")) {
                  var31 = "r";
               } else {
                  var31 = "n";
               }
            }

            RRCLogger.log(300, 4, "VM permission from CC after parsing:" + var31);
            this.ccParamsMap.put("VirtualMedia", var31);
         }

         Node var33 = var7.getNamedItem("MultiMonitorLaunch");
         if (var33 != null) {
            MPCUtil.setCCMultiMonitorLaunch(Boolean.valueOf(var33.getNodeValue()));
         }

         NodeList var34 = var4.getElementsByTagName("Port");
         if (var34 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No ports");
            }

            return null;
         }

         Node var35 = null;
         String var36 = null;
         Object var37 = null;
         int var38 = 0;

         for (int var39 = 0; var38 < var34.getLength(); var38++) {
            var35 = var34.item(var38);
            NamedNodeMap var40 = var35.getAttributes();
            if (var40 == null) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(300, 4, "No port attrs");
               }

               return null;
            }

            String var41 = null;
            String var42 = null;
            Node var43 = var40.getNamedItem("ID");
            if (var43 != null) {
               var41 = var43.getNodeValue();
            }

            if (var38 == 0) {
               if (var41 == null) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "No port id attr");
                  }

                  return null;
               }

               var36 = var41;
               this.ccParamsMap.put("ID", var41);
            }

            Node var44 = var40.getNamedItem("Class");
            if (var44 != null) {
               var42 = var44.getNodeValue();
            }

            if (var38 == 0) {
               if (var42 == null) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "No class");
                  }

                  return null;
               }

               Node var45 = var40.getNamedItem("MonitorIndex");
               Node var46 = var40.getNamedItem("MonitorHPosition");
               Node var47 = var40.getNamedItem("MonitorVPosition");
               if (var45 != null) {
                  this.ccParamsMap.put("MonitorIndex", var45.getNodeValue());
               }

               if (var46 != null) {
                  this.ccParamsMap.put("MonitorHPosition", var46.getNodeValue());
               }

               if (var47 != null) {
                  this.ccParamsMap.put("MonitorVPosition", var47.getNodeValue());
               }
            }

            if (var41 != null && var38 != 0 && "KVM".equals(var42)) {
               this.ccParamsMap.put("ID." + ++var39, var41);
               Node var70 = var40.getNamedItem("SessionID");
               Node var71 = var40.getNamedItem("SessionKey");
               Node var72 = var40.getNamedItem("ConnectionID");
               Node var48 = var40.getNamedItem("ConnectionIDHTTPS");
               if (var70 != null && var71 != null) {
                  this.ccParamsMap.put("SessionID." + var39, var70.getNodeValue());
                  this.ccParamsMap.put("SessionKey." + var39, var71.getNodeValue());
               }

               if (var72 != null) {
                  this.ccParamsMap.put("ConnectionID." + var39, var72.getNodeValue());
               } else if (var21 != null) {
                  this.ccParamsMap.put("ConnectionID." + var39, var21);
               }

               if (var48 != null) {
                  this.ccParamsMap.put("ConnectionIDHTTPS." + var39, var48.getNodeValue());
               } else if (var23 != null) {
                  this.ccParamsMap.put("ConnectionIDHTTPS." + var39, var23);
               }

               Node var49 = var40.getNamedItem("MonitorIndex");
               Node var50 = var40.getNamedItem("MonitorHPosition");
               Node var51 = var40.getNamedItem("MonitorVPosition");
               if (var49 != null) {
                  this.ccParamsMap.put("MonitorIndex." + var39, var49.getNodeValue());
               }

               if (var50 != null) {
                  this.ccParamsMap.put("MonitorHPosition." + var39, var50.getNodeValue());
               }

               if (var51 != null) {
                  this.ccParamsMap.put("MonitorVPosition." + var39, var51.getNodeValue());
               }
            }
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(
               300,
               4,
               "DeviceConnector.connect(String csc) calling referralConnect: ip "
                  + var12.getHostAddress()
                  + ", tcpPort "
                  + Integer.toString(var27)
                  + ", sessionId "
                  + var62
                  + ", sessionKey "
                  + var63
                  + ", connectionId "
                  + var21
                  + ", portId "
                  + var36
            );
         }

         Object var68 = null;
         NodeList var69 = var4.getElementsByTagName("ConnectionProperties");
         if (var69.getLength() == 1) {
            this.processCCPowerControlProperty(getNamedSubnode(var69.item(0), "Permission"));
            if (!this.isKX2Device()) {
               this.processCCConnProps(var69.item(0), var1);
            }
         }

         if (var2 == 0) {
            return this.referralConnect(var12, var27, var62, var63, var21, var36);
         }

         if (var7.getNamedItem("Type") != null
            && var7.getNamedItem("Type").getNodeValue().equals("Dominion_KX2")
            && this.ccParamsMap.containsKey("ID." + var2)
            && this.ccParamsMap.containsKey("SessionID." + var2)
            && this.ccParamsMap.containsKey("SessionKey." + var2)) {
            this.ccParamsMap.put("multiIdx", "" + var2);
            return this.referralConnect(
               var12,
               var27,
               (String)this.ccParamsMap.get("SessionID." + var2),
               (String)this.ccParamsMap.get("SessionKey." + var2),
               (String)this.ccParamsMap.get("ConnectionID." + var2),
               (String)this.ccParamsMap.get("ID." + var2)
            );
         }

         return null;
      } catch (NumberFormatException var52) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var52, "Number string is not in the correct format ");
         }

         var52.printStackTrace();
      } catch (DOMException var53) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var53, "XML parsing error ");
         }

         var53.printStackTrace();
      } catch (Exception var54) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var54, "General exception ");
         }

         var54.printStackTrace();
      }

      return null;
   }

   public HashMap getConnectionMap() {
      return this.ccParamsMap;
   }

   public DevicePreferences getCCDevPrefs() {
      return this.usePrefsFromCC ? this.devprefs : null;
   }

   public boolean getCCPowerControlPermission() {
      return this.CCPowerControl;
   }

   private boolean setProperties(String[] var1, String[] var2, String var3) {
      boolean var4 = false;
      if (this.CCURL.startsWith("https://")) {
         var4 = true;
      }

      try {
         StringBuffer var5 = new StringBuffer();
         var5.append("ConnectionId").append("=").append(var3);

         for (int var6 = 0; var6 < var1.length; var6++) {
            var5.append("&");
            var5.append(var1[var6]);
            var5.append("=");
            var5.append(URLEncoder.encode(var2[var6], "UTF-8"));
         }

         URL var7 = null;
         HttpURLConnection var8 = null;
         var7 = new URL(this.CCURL);
         var8 = (HttpURLConnection)var7.openConnection();
         var8.setDoInput(true);
         var8.setDoOutput(true);
         var8.setRequestMethod("POST");
         var8.setRequestProperty("Content-type", "application/x-www-form-urlencoded");
         OutputStreamWriter var9 = new OutputStreamWriter(var8.getOutputStream());
         var9.write(var5.toString());
         var9.flush();
         var9.close();
         int var10 = var8.getResponseCode();
         var8.disconnect();
         return var10 == 200;
      } catch (MalformedURLException var11) {
         var11.printStackTrace();
      } catch (IOException var12) {
         var12.printStackTrace();
      }

      return false;
   }

   public boolean isP2scPort() {
      return this.isPIISCPort;
   }

   public void writePrefsToCCnow(DevicePreferences var1) {
      if (this.writePrefsToCC && var1 != null) {
         ByteArrayOutputStream var2 = var1.CCExportPrefs();
         String[] var3 = new String[1];
         String[] var4 = new String[1];
         var3[0] = "preferences";
         String var5 = var2.toString();
         var4[0] = var5.substring(var5.indexOf("<preferences"));
         boolean var6 = this.setProperties(var3, var4, this.CCconnID);
      }
   }

   private static Node getNamedSubnode(Node var0, String var1) {
      if (!var0.hasChildNodes()) {
         return null;
      } else {
         NodeList var2 = var0.getChildNodes();
         int var3 = var2.getLength();

         for (int var4 = 0; var4 < var3; var4++) {
            if (var2.item(var4).getNodeName().equals(var1)) {
               return var2.item(var4);
            }
         }

         return null;
      }
   }

   private static String getNamedAttribute(Node var0, String var1) {
      Node var2 = var0.getAttributes().getNamedItem(var1);
      return var2 != null ? var2.getNodeValue() : null;
   }

   private void processCCConnProps(Node var1, String var2) {
      Object var3 = null;
      Object var4 = null;
      Object var5 = null;
      this.writePrefsToCC = false;
      NodeList var7 = var1.getChildNodes();
      int var8 = var7.getLength();
      if (var8 >= 1) {
         var3 = getNamedSubnode(var1, "Persistence");
         var4 = getNamedSubnode(var1, "Permission");
         var5 = getNamedSubnode(var1, "preferences");
         if (var3 != null) {
            Node var6 = getNamedSubnode((Node)var3, "SetApplicationProperties");
            if (var6 != null) {
               this.CCURL = getNamedAttribute(var6, "url");
               if (this.CCURL != null) {
                  var6 = getNamedSubnode(var6, "param");
                  if (var6 != null) {
                     if (getNamedAttribute(var6, "name").equals("ConnectionID")) {
                        this.CCconnID = getNamedAttribute(var6, "value");
                        this.writePrefsToCC = true;
                        if (var5 != null) {
                           int var9 = var2.indexOf("<preferences");
                           int var10 = var2.indexOf("</preferences>", var9) + 14;
                           String var11 = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><!DOCTYPE preferences SYSTEM \"http://java.sun.com/dtd/preferences.dtd\">"
                              + var2.substring(var9, var10);
                           this.devprefs = new DevicePreferences();
                           this.devprefs.importPreferences("VideoSetting", var11);
                           this.usePrefsFromCC = true;
                        }
                     }
                  }
               }
            }
         }
      }
   }

   private void processCCPowerControlProperty(Node var1) {
      if (var1 != null) {
         String var2 = getNamedAttribute(var1, "PowerControl");
         if (var2 != null) {
            this.CCPowerControl = var2.equals("1") || var2.equalsIgnoreCase("true");
            this.usePowerControlFromCC = true;
         }
      }
   }

   private Device findPortById(Device var1, String var2) {
      try {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "DeviceConnector.findPortById search device " + var1.getName() + ", for port " + var2);
         }

         Iterator var3 = var1.getChildren().keySet().iterator();
         Object var4 = null;
         Object var5 = null;

         while (var3.hasNext()) {
            var4 = (String)var3.next();
            var5 = (Device)var1.getChildren().get(var4);
            if (var5 instanceof Port) {
               Port var10 = (Port)var5;
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(
                     400,
                     4,
                     "device "
                        + var1.getName()
                        + ", findPortById search portId "
                        + var2
                        + ", currentPort.getId() "
                        + var10.getId()
                        + ", currentPort.getId().indexOf(portId) "
                        + var10.getId().indexOf(var2)
                        + " || currentPort.getTargetDeviceId().indexOf(portId) "
                        + var10.getTargetDeviceId().indexOf(var2)
                  );
               }

               if (var10.getId().indexOf(var2) != -1 || var10.getTargetDeviceId().indexOf(var2) != -1) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, var2 + " MATCHES " + var10.getId());
                  }

                  return var10;
               }
            } else if (!(var5 instanceof Paragon) && !(var5 instanceof BladeChassis)) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(400, 4, "NOT Paragon! NOT Port; hasnext " + var3.hasNext());
               }
            } else {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(400, 4, "Paragon! hasnext " + var3.hasNext());
               }

               Device var6 = null;
               if (((Device)var5).hasChildren()) {
                  var6 = this.findPortById((Device)var5, var2);
               }

               if (var6 != null) {
                  return var6;
               }
            }
         }
      } catch (NullPointerException var7) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "NullPointerException Occured in findPortById\n " + var7);
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var7);
         }
      }

      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "findPortById ret null (okay when recursing on tiered devs)!");
      }

      return null;
   }

   private Device referralConnect(InetAddress var1, int var2, String var3, String var4, String var5, String var6) {
      TRLIB_COMM var7 = new TRLIB_COMM();
      if (RRCLogger.logEnabled) {
         RRCLogger.log(
            300,
            4,
            "DeviceConnector.referralConnect sessionID " + var3 + ", sessionKey " + var4 + ", connectionId " + var5 + ", ip addr " + var1.getHostAddress()
         );
      }

      this.bIsCSCReferral = true;
      var7.setInetAddress(var1);
      var7.setConnType(2);
      var7.setFindBy(0);
      var7.setIpPort(var2);
      TRLIB_REFERRAL_COMM var8 = null;
      if (var3 != null && var4 != null) {
         var8 = new TRLIB_REFERRAL_COMM();
         var8.setVersion(1);
         var8.setSessionID(var3.getBytes());
         var8.setSessionKey(var4.getBytes());
         if (var5 != null) {
            var8.setConnectionID(var5.getBytes());
         }
      }

      this.connect(var7, null, null, var8);
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "DeviceConnector.referralConnect connecting...");
      }

      while (!this.isConnected()) {
         try {
            Thread.sleep(200L);
         } catch (InterruptedException var12) {
         }
      }

      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "DeviceConnector.referralConnect ...connected");
      }

      IPReach var9 = new IPReach(this.scrContext);
      var9.setName(this.getServerID().getServerNameString());
      var9.setDeviceConnector(this);
      var9.setAddressList(Arrays.asList(var1));
      this.device = var9;
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "referralConnect authenticating...");
      }

      while (!this.isAuthenticated()) {
         try {
            Thread.currentThread();
            Thread.sleep(200L);
         } catch (InterruptedException var11) {
         }
      }

      var9.setCcLaunch(true);
      if (this.isKX2Device() && !this.isKX101G2Device()) {
         this.device.setHandler(new KX2DeviceHandlerImpl(this.device));
      } else if (this.isKX2Device() && this.isKX101G2Device()) {
         this.device.setHandler(new KX101G2DeviceHandlerImpl(this.device));
      } else if (this.isKX101G1Device()) {
         this.device.setHandler(new KX101G1DeviceHandlerImpl(this.device));
      } else {
         this.device.setHandler(new G1DeviceHandlerImpl(this.device));
      }

      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "referralConnect ...authenticated ? " + this.isAuthenticated());
      }

      var9.updateDevice();
      if (var9.getChildren() == null) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "referralConnect ret null 1");
         }

         return null;
      } else {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "DeviceConnector.referralConnect looking for port by id " + var6);
         }

         Device var10 = this.findPortById(var9, var6);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "DeviceConnector.referralConnect return device " + (var10 == null ? "NULL" : var10.getName()));
         }

         return var10;
      }
   }

   private boolean isCSCReferral() {
      return this.bIsCSCReferral;
   }

   public int getDataIn() {
      return this.iDataIn;
   }

   public int getDataOut() {
      return this.iDataOut;
   }

   public String getUsername() {
      return this.userInfo == null ? null : new String(this.userInfo.getName());
   }

   public String getPassword() {
      return this.userInfo == null ? null : new String(this.userInfo.getPassword());
   }

   public void setUsername(String var1) {
      this.userInfo.setName(var1.getBytes());
   }

   public void setPassword(String var1) {
      this.userInfo.setPassword(var1.getBytes());
   }

   public Device getDevice() {
      return this.device;
   }

   public void setUpdateActive(boolean var1) {
      this.updateActive = var1;
   }

   public String getSessionID() {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "sending databaseRequest for session id");
      }

      String var1 = this.databaseRequest("<Session><GetSessionID/></Session>");
      if (var1 != null) {
         Document var2 = null;

         try {
            var2 = getXmlParserInstance().getDocument(var1);
         } catch (ParserConfigurationException var6) {
         } catch (SAXException var7) {
         } catch (IOException var8) {
         }

         if (var2 != null) {
            Element var3 = var2.getDocumentElement();
            NodeList var4 = var3.getElementsByTagName("SessionID");
            Node var5 = var4.item(0).getFirstChild();
            return var5.getNodeValue();
         }
      }

      return null;
   }

   private synchronized void setNoResponseFromIP(boolean var1) {
      this.noResponseFromIP = var1;
   }

   public synchronized boolean isNoResponseFromIP() {
      return this.noResponseFromIP;
   }

   public InetAddress getInetAddress() {
      TRLIB_COMM var1 = super.getTrlib_comm();
      return var1 != null ? var1.getInetAddress() : null;
   }
}
