package com.raritan.rrc.data;

import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.ui.ScreenContext;
import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Vector;
import javaclientlib.utils.RRCLogger;
import javaclientlib.utils.XMLParser;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class DeviceFactory {
   private static final DeviceFactory INSTANCE = new DeviceFactory();
   private XMLParser xmlParser;
   private PortFactory portFactory;
   public static final String GET_DEVICE = "<Database><Get><Select>/System/Device[@id='%s']</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>";
   public static final String GET_DEVICE_CALIBRATION_DETAILS = "<Database><Get><Select>/System/Device</Select><Nodes> Device </Nodes><SubNodes> Name SerialNo @id @Type @Model @BM @BaseDevice @CalibrationSpeed @ProductCode</SubNodes></Get></Database>";
   private static final String GET_DEVICE_CAPABILITIES = "<Database><Get><Select>/System/Device[@Type='IP-Reach']/DeviceCapabilities</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>";
   private IPReach kxDevice;
   LinkedHashMap<VirtualBladeChassis, Vector<String>> vbcWithPortsMap = new LinkedHashMap<>();
   List<MultiMonitorPort> multiMonitorPorts = new Vector<>();

   private DeviceFactory() {
      this.xmlParser = new XMLParser();
      this.portFactory = PortFactory.getInstance();
   }

   public static DeviceFactory getInstance() {
      return INSTANCE;
   }

   public void updateDevice(Device var1, String var2, ScreenContext var3, boolean var4) throws ParserConfigurationException, SAXException, IOException {
      this.kxDevice = (IPReach)var1;
      this.multiMonitorPorts.clear();
      Document var5 = null;
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 16, "DeviceFactory.updateDevice " + var1.getName() + ", XML:\n" + var2 + "\n\n");
      }

      String var6 = var1.getDeviceConnector()
         .databaseRequest(
            "<Database><Get><Select>/System/Device[@Type='IP-Reach']/DeviceCapabilities</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>"
         );
      if (var6 != null) {
         Document var7 = this.xmlParser.getDocument(var6);
         var5 = this.xmlParser.getDocument(var2);
         if (var5 == null || var7 == null) {
            return;
         }

         String var8 = null;
         String var9 = null;
         String var10 = null;
         Element var11 = var7.getDocumentElement();
         NodeList var12 = var11.getElementsByTagName("DeviceCapabilities");
         Element var13 = (Element)var12.item(0);
         if (var13 != null && var12.getLength() != 0) {
            NodeList var14 = var13.getElementsByTagName("Capability");
            if (var14 != null && var14.getLength() > 0) {
               Element var15 = null;

               for (int var16 = 0; var16 < var14.getLength(); var16++) {
                  var15 = (Element)var14.item(var16);
                  if (var15 != null) {
                     var8 = var15.getAttribute("CapType");
                     var9 = var15.getAttribute("CapID");
                     var10 = var15.getTextContent();
                  }

                  if (var8 != null && var9 != null && var10 != null && var8.equals("FEATURE") && var9.equals("AutoScan")) {
                     if (var10.equals("1")) {
                        var1.setScanSupported(true);
                     } else {
                        var1.setScanSupported(false);
                     }
                  }
               }
            }
         }
      }

      String var18 = var1.getDeviceConnector()
         .databaseRequest(
            "<Database><Get><Select>/System/Device</Select><Nodes> Device </Nodes><SubNodes> Name SerialNo @id @Type @Model @BM @BaseDevice @CalibrationSpeed @ProductCode</SubNodes></Get></Database>"
         );
      if (var18 != null) {
         Document var19 = this.xmlParser.getDocument(var18);
         var5 = this.xmlParser.getDocument(var2);
         if (var5 == null || var19 == null) {
            return;
         }

         Element var21 = var19.getDocumentElement();
         NodeList var22 = var21.getElementsByTagName("Device");
         Element var23 = (Element)var22.item(0);
         String var24 = "";
         if (var23 != null) {
            var24 = var23.getAttribute("CalibrationSpeed");
         }

         int var25 = 60000;
         if (var24 != null && var24.length() > 0) {
            try {
               var25 = Integer.parseInt(var24, 10);
               if (var25 <= 0) {
                  var25 = 60000;
               }
            } catch (NumberFormatException var17) {
               var25 = 60000;
            }
         }

         var1.setColorCalibSpeed(var25);
         if (var23 != null) {
            this.updateDeviceData(var1, var23);
         } else {
            RRCLogger.log(300, 4, "Device Element is NULL.");
         }
      } else {
         RRCLogger.log(300, 4, "Response for GET_DEVICE_CALIBRATION_DETAILS is NULL.");
      }

      if (var5 != null) {
         Element var20 = var5.getDocumentElement();
         this.addDevicePorts(var1, var20, var3, var4);
         var1.sort(var1.getSortType());
      } else {
         RRCLogger.log(300, 4, "Document is NULL.");
      }
   }

   private void updateDeviceData(Device var1, Element var2) {
      String var3 = var2.getAttribute("id").trim();
      String var4 = var2.getAttribute("Type").trim();
      String var5 = var2.getAttribute("Model").trim();
      var1.setRdmId(var3);
      var1.setDeviceType(var4);
      var1.setDeviceModel(var5);
   }

   public void updateDeviceSecurity(Device var1, Element var2) {
      Element var3 = (Element)var2.getElementsByTagName("Security").item(0);
      DeviceSecurity var4 = new DeviceSecurity();
      if (var3 != null) {
         Element var5 = (Element)var3.getElementsByTagName("ConcurrentAccess").item(0);
         Element var6 = (Element)var3.getElementsByTagName("SingleUserLogin").item(0);
         if (var5 != null) {
            var4.setSharedMode(Integer.parseInt(var5.getFirstChild().getNodeValue()));
         }

         if (var6 != null) {
            var4.setSingleUserLogin(this.parseBoolean(var6.getFirstChild().getNodeValue()));
         }
      }

      var1.setSecurity(var4);
   }

   private void addDevicePorts(Device var1, Element var2, ScreenContext var3, boolean var4) throws ParserConfigurationException, SAXException, IOException {
      Object var5 = null;
      NodeList var6 = var2.getElementsByTagName("Port");
      if (var6 != null && var6.getLength() != 0) {
         Element var7 = null;
         NodeList var8 = null;
         Object var9 = null;
         Object var10 = null;

         for (int var11 = 0; var11 < var6.getLength(); var11++) {
            var7 = (Element)var6.item(var11);
            PortFactory.PortOrParagon var12 = this.portFactory.getPortOrParagon(var1, var7, var3, var4);
            Port var13 = var12.getPort();
            Paragon var14 = var12.getParagon();
            if (var13 != null) {
               var13.setDeviceConnector(var1.getDeviceConnector());
               var13.setDevice(var1);
               if (var13.getConnectionId().equals("")) {
                  var1.add(var13, var13.getName() + var13.getId());
               } else {
                  this.addKVMPorts(var1, var13.getConnectionId(), var13.getId(), var3, var4);
                  var1.setVbcWithPortsMap(this.vbcWithPortsMap);
                  var1.setMultiMonitorPorts(this.multiMonitorPorts);
               }

               if (var1.isKvmSwitch() && var13.getDeviceClass().equalsIgnoreCase("KVM")) {
                  var8 = var7.getElementsByTagName("AssociatedOutlet");
                  if (var8 != null && var8.getLength() != 0) {
                     for (int var15 = var8.getLength() - 1; var15 >= 0; var15--) {
                        if (var8.item(var15) != null) {
                           var9 = (Element)var8.item(var15);
                           var5 = var9.getAttribute("ConnID").trim();
                           ((KvmPort)var13).setOutLetPort(true);
                           var13.addOutletId((String)var5);
                        }
                     }
                  }

                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 16, "addDevicePorts device " + var1.getName() + ", port.setId: " + var1.getKvmSwitchId());
                  }

                  var13.setId(var1.getKvmSwitchId());
               }
            } else if (var14 != null) {
               var14.setDeviceConnector(var1.getDeviceConnector());
               var14.setName(this.getParagonName(var14, var14.getConnectionId()));
               var14.setDeviceType("Paragon");
               var1.add(var14, var14.getName() + var11);
            }

            var10 = var7.getAttribute("Connection").trim();
            if (StringUtils.notNullOrEmpty((String)var10)) {
               var1.setConnectionId((String)var10);
               var10 = var7.getAttribute("id").trim();
               var1.setKvmSwitchId((String)var10);
               var1.enableKvmSwitch(true);
            }
         }
      }
   }

   public Node findSubNode(Node var1, String var2) {
      if (var1.getNodeType() != 1) {
         return null;
      } else if (!var1.hasChildNodes()) {
         return null;
      } else {
         NodeList var3 = var1.getChildNodes();

         for (int var4 = 0; var4 < var3.getLength(); var4++) {
            Node var5 = var3.item(var4);
            if (var5.getNodeType() == 1 && var5.getNodeName().equals(var2)) {
               return var5;
            }
         }

         return null;
      }
   }

   private void addKVMPorts(Device var1, String var2, String var3, ScreenContext var4, boolean var5) throws ParserConfigurationException, SAXException, IOException {
      Object var6 = null;
      String var7 = var1.getDeviceConnector()
         .databaseRequest(
            "<Database><Get><Select>/System/Device[@id='%s']</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>".replaceFirst("%s", var2)
         );
      Document var8 = this.xmlParser.getDocument(var7);
      if (var8 != null) {
         Element var9 = var8.getDocumentElement();
         NodeList var10 = var8.getElementsByTagName("DeviceSettings");
         Node var11 = null;
         Node var12 = null;
         Object var13 = null;
         if (var10 != null && var10.getLength() != 0) {
            var11 = var10.item(0);
         }

         if (var11 != null) {
            var12 = this.findSubNode(var11, "Paragon");
         }

         int var15 = 1;
         if (var12 != null) {
            Node var14 = this.findSubNode(var12, "GhostMode");
            if (var14 != null) {
               var15 = Integer.parseInt(var14.getFirstChild().getNodeValue());
            }
         }

         var1.setGhostMode(var15);
         String var16 = "";
         String var17 = "";
         String var18 = "";
         NodeList var19 = var9.getElementsByTagName("Device");
         if (var19 != null && var19.getLength() != 0) {
            Object var20 = null;

            for (int var21 = 0; var21 < var19.getLength(); var21++) {
               var20 = (Element)var19.item(var21);
               var17 = var20.getAttribute("Type").trim();
               var18 = var20.getAttribute("Model").trim();
            }
         }

         NodeList var42 = var9.getElementsByTagName("Port");
         if (var42 != null && var42.getLength() != 0) {
            Object var43 = null;

            for (int var22 = 0; var22 < var42.getLength(); var22++) {
               var43 = (Element)var42.item(var22);
               PortFactory.PortOrParagon var23 = this.portFactory.getPortOrParagon(var1, (Element)var43, var4, var5);
               Port var24 = var23.getPort();
               Paragon var25 = var23.getParagon();
               BladeChassis var26 = var23.getBladeChassis();
               if (var24 != null) {
                  var24.setDeviceConnector(var1.getDeviceConnector());
                  if ((var17.equals("BladeChassis") || var17.equals("KVMSwitch")) && var1.getDeviceConnector().isKX2Device()) {
                     BladeChassis var72 = (BladeChassis)var1;
                     var24.setDevice(var72.getBaseDevice());
                     var24.setParentIndex(var72.getPortIndex());
                     var24.setBladePort(true);
                     var24.setParentBladeChassis(var72);
                  } else if (!var17.equals("VirtualBladeChassis") && !var17.equals("PortGroup")) {
                     var24.setDevice(var1);
                  } else {
                     VirtualBladeChassis var27 = (VirtualBladeChassis)var1;
                     var24.setDevice(var27.getBaseDevice());
                     var24.setParentIndex(var27.getPortIndex());
                     var24.setParentBladeChassis(var27);
                  }

                  if (var24.getConnectionId().equals("")) {
                     if (!var24.getPortType().equals("PowerStrip")) {
                        var1.add(var24, var24.getName() + var24.getId());
                     }
                  } else {
                     this.addKVMPorts(var24, var24.getConnectionId(), var24.getId(), var4, var5);
                  }

                  if (!var24.getPortType().equals("PowerStrip")) {
                     var24.setTargetDeviceId(var24.getId());
                     var24.setId(var3);
                  }
               } else if (var25 != null) {
                  var25.setDeviceConnector(var1.getDeviceConnector());
                  var25.setName(this.getParagonName(var25, var25.getConnectionId()));
                  var25.setDeviceType("Paragon");
                  var1.add(var25, var25.getName() + var22);
                  this.addKVMPorts(var25, var25.getConnectionId(), "", var4, var5);
               } else if (var26 != null) {
                  var26.setDeviceConnector(var1.getDeviceConnector());
                  var26.setHandler(var1.getHandler());
                  if (!var26.isVirtual()) {
                     var1.add(var26, var26.getId());
                     var26.setDeviceType("BladeChassis");
                  } else {
                     var26.setDeviceType("VirtualBladeChassis");
                  }

                  this.addKVMPorts(var26, var26.getConnectionId(), var3, var4, var5);
               }
            }
         }

         NodeList var45 = var9.getElementsByTagName("URL");
         if (var45 != null && var45.getLength() != 0) {
            Element var46 = null;

            for (int var49 = 0; var49 < var45.getLength(); var49++) {
               var46 = (Element)var45.item(var49);
               String var52 = var46.getAttribute("id");
               String var56 = var46.getAttribute("index");
               String var61 = "";
               int var73 = 0;
               NodeList var28 = var46.getElementsByTagName("Enable");
               if (var28 != null && var28.getLength() != 0 && var28.item(0).getFirstChild() != null) {
                  Node var29 = var28.item(0).getFirstChild();
                  var61 = var29.getNodeValue();

                  try {
                     var73 = Integer.parseInt(var61);
                  } catch (NumberFormatException var40) {
                     RRCLogger.log(300, "NumberFormatException occured while parsing <Enable> tag in <URL>:\n", var40);
                     var73 = 0;
                  }
               }

               if (var73 == 1) {
                  URLPort var76 = new URLPort();
                  NodeList var30 = var46.getElementsByTagName("Name");
                  if (var30 != null && var30.getLength() != 0 && var30.item(0).getFirstChild() != null) {
                     Node var31 = var30.item(0).getFirstChild();
                     var61 = var31.getNodeValue();
                     if (StringUtils.nullOrEmpty(var61)) {
                        var61 = "";
                     }

                     var76.setName(var61);
                  }

                  NodeList var78 = var46.getElementsByTagName("Link");
                  if (var78 != null && var78.getLength() != 0 && var78.item(0).getFirstChild() != null) {
                     Node var32 = var78.item(0).getFirstChild();
                     var61 = var32.getNodeValue();
                     if (StringUtils.nullOrEmpty(var61)) {
                        var61 = "";
                     }

                     var76.setLink(var61);
                  }

                  NodeList var79 = var46.getElementsByTagName("Username");
                  if (var79 != null && var79.getLength() != 0 && var79.item(0).getFirstChild() != null) {
                     Node var33 = var79.item(0).getFirstChild();
                     var61 = var33.getNodeValue();
                     if (StringUtils.nullOrEmpty(var61)) {
                        var61 = "";
                     }

                     var76.setUsername(var61);
                  }

                  NodeList var80 = var46.getElementsByTagName("Password");
                  if (var80 != null && var80.getLength() != 0 && var80.item(0).getFirstChild() != null) {
                     Node var34 = var80.item(0).getFirstChild();
                     var61 = var34.getNodeValue();
                     if (StringUtils.nullOrEmpty(var61)) {
                        var61 = "";
                     }

                     var76.setPassword(var61);
                  }

                  NodeList var81 = var46.getElementsByTagName("Usernamefield");
                  if (var81 != null && var81.getLength() != 0 && var81.item(0).getFirstChild() != null) {
                     Node var35 = var81.item(0).getFirstChild();
                     var61 = var35.getNodeValue();
                     if (StringUtils.nullOrEmpty(var61)) {
                        var61 = "";
                     }

                     var76.setUsernameField(var61);
                  }

                  NodeList var82 = var46.getElementsByTagName("Passwordfield");
                  if (var82 != null && var82.getLength() != 0 && var82.item(0).getFirstChild() != null) {
                     Node var36 = var82.item(0).getFirstChild();
                     var61 = var36.getNodeValue();
                     if (StringUtils.nullOrEmpty(var61)) {
                        var61 = "";
                     }

                     var76.setPasswordField(var61);
                  }

                  var76.setDeviceClass("URL");
                  var76.setPortType("URL");
                  var76.setId(var52);
                  var76.setPortIndex(var56);
                  if (var17.equals("BladeChassis") && var18.equals("BladeChassis") || var17.equals("KVMSwitch") && var18.equals("KVMSwitch")) {
                     BladeChassis var83 = (BladeChassis)var1;
                     var76.setDevice(var83.getBaseDevice());
                     var76.setParentIndex(var83.getPortIndex());
                     String var37 = var52;
                     if (var52 != null && !var52.startsWith("//*[@id=")) {
                        StringBuffer var38 = new StringBuffer("//*[@id=");
                        var38.append(var52);
                        var38.append("]");
                        var37 = var38.toString();
                     }

                     var76.setTargetDeviceId(var37);
                     var76.setBladePort(true);
                     var76.setParentBladeChassis(var83);
                  }

                  var1.add(var76, var76.getName() + var76.getId());
               }
            }
         }

         NodeList var48 = var9.getElementsByTagName("AssociatedNode");
         if (var48 != null && var48.getLength() != 0) {
            if (var17.equals("MultiMonitorPort") && var18.equals("MultiMonitorPort")) {
               MultiMonitorPort var51 = new MultiMonitorPort(this.kxDevice);

               for (int var55 = 0; var55 < var48.getLength(); var55++) {
                  Element var60 = (Element)var48.item(var55);

                  try {
                     String var71 = "//*[@id=" + var60.getAttribute("ConnID") + "]";
                     int var74 = Integer.parseInt(var60.getAttribute("MonitorIndex"));
                     int var75 = Integer.parseInt(var60.getAttribute("MonitorHPosition"));
                     int var77 = Integer.parseInt(var60.getAttribute("MonitorVPosition"));
                     var51.addPort(var71, var74, var75, var77);
                  } catch (NumberFormatException var39) {
                  }
               }

               this.multiMonitorPorts.add(var51);
            } else {
               Vector var50 = new Vector();
               Element var53 = null;
               String var57 = "";

               for (int var69 = 0; var69 < var48.getLength(); var69++) {
                  var53 = (Element)var48.item(var69);
                  var57 = var53.getAttribute("ConnID");
                  var57 = "//*[@id=" + var57 + "]";
                  var50.add(var57);
               }

               VirtualBladeChassis var70 = new VirtualBladeChassis(this.kxDevice);
               var70.setId(var1.getId());
               var70.setName(var1.getName());
               var70.setVirtual(true);
               var70.setPortIndex(Integer.toString(((BladeChassis)var1).getPortIndex()));
               this.vbcWithPortsMap.put(var70, var50);
            }
         }
      }
   }

   private String getParagonName(Paragon var1, String var2) throws ParserConfigurationException, SAXException, IOException {
      String var3 = var1.getDeviceConnector()
         .databaseRequest(
            "<Database><Get><Select>/System/Device[@id='%s']</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>".replaceFirst("%s", var2)
         );
      Document var4 = this.xmlParser.getDocument(var3);
      if (var4 == null) {
         return null;
      } else {
         var1.setDocument(var3);
         Element var5 = var4.getDocumentElement();
         NodeList var6 = var5.getElementsByTagName("Name");
         return var6.item(0).getFirstChild().getNodeValue();
      }
   }

   private boolean parseBoolean(String var1) {
      return "true".equals(var1) || "t".equals(var1) || "1".equals(var1);
   }
}
