package com.raritan.rrc.data;

import com.raritan.rrc.util.StringUtils;
import com.raritan.rrc.util.modem.ModemConnector;
import com.raritan.tools.util.Constants;
import com.raritan.tools.util.CryptoException;
import com.raritan.tools.util.StringCryptoUtil;
import java.io.BufferedOutputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.prefs.BackingStoreException;
import java.util.prefs.InvalidPreferencesFormatException;
import java.util.prefs.Preferences;
import javaclientlib.tr.TRSRVR_COMP_PARAMS;
import javaclientlib.utils.RRCLogger;
import nn.pp.ext.devPref.DevicePrefs;
import nn.pp.ext.pref.ApplicationPreferences;

public class DevicePreferences extends DevicePrefs {
   private static final String DESCRIPTION_KEY = "description";
   private static final String CONNECTION_TYPE_KEY = "connectionType";
   private static final String PRODUCT_TYPE_KEY = "productType";
   private static final String FIND_BY_KEY = "findBy";
   private static final String IP_ADDRESS_KEY = "ipAddress";
   private static final String SERVER_NAME_KEY = "serverName";
   private static final String DNS_NAME_KEY = "dnsName";
   private static final String PORT_KEY = "port";
   private static final String HTTPS_PORT_KEY = "httpsPort";
   private static final String PHONE_KEY = "phone";
   private static final String MODEM_KEY = "modem";
   private static final String CONNECTION_SPEED_KEY = "connectionSpeed";
   private static final String COLOR_DEPTH_KEY = "colorDepth";
   private static final String PROGRESSIVE_UPDATE_KEY = "progressiveUpdate";
   private static final String FLOW_CONTROL_KEY = "flowControl";
   private static final String SMOOTHING_KEY = "smoothing";
   private static final String FRAMES_PER_SECOND = "framesPerSecond";
   private static final String SECURITY_KEY = "privateKey";
   private static final String REMEMBER_KEY = "remember";
   private static final String USER_NAME_KEY = "userName";
   private static final String PASSWORD_KEY = "password";
   private static final String DEVICENAME_KEY = "deviceName";
   private String description = "";
   private int connectionType = 2;
   private String productType = "";
   private int findBy = 0;
   private String ip = "0.0.0.0";
   private String name = "";
   private String dnsName = "";
   private int port = Integer.parseInt(Constants.NETWORKCONFIG_DEFAULT_PORT);
   private int httpsPort = new ApplicationPreferences().getDefaultHttpsPort();
   private String phone = "";
   private String modem = "";
   private int connectionSpeed = 0;
   private int colorDepth = 0;
   private boolean progressiveUpdate = false;
   private boolean flowControl = false;
   private int smoothing = 0;
   private int framesPerSecond = 0;
   private String privateKey = "";
   private String confirmKey = "";
   private int rememberOption = 2;
   private String userName = "";
   private String password = "";
   private ModemConnector modemConnector = null;
   private String deviceName = "";
   private static final String unassignedDeviceName = new String();

   public DevicePreferences() {
      this.rootPrefs = Preferences.userRoot().node("/" + javaclientlib.tr.Constants.COMPANY_NAME_NOSPACE + "Devices");
   }

   public String getNodeName() {
      switch (this.getConnectionType()) {
         case 1:
            return this.getPhone();
         case 2:
            switch (this.getFindBy()) {
               case 0:
                  return this.getIp();
               case 1:
                  return this.getName();
               case 2:
                  return this.getDnsName();
               default:
                  return null;
            }
         default:
            return null;
      }
   }

   public static void exportPreferences() {
      Preferences var0 = Preferences.userRoot().node("/" + javaclientlib.tr.Constants.COMPANY_NAME_NOSPACE + "Devices");
      BufferedOutputStream var1 = null;

      try {
         var1 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(FILE_NAME)));
         var0.exportSubtree(var1);
      } catch (FileNotFoundException var15) {
      } catch (IOException var16) {
      } catch (BackingStoreException var17) {
      } finally {
         if (var1 != null) {
            try {
               var1.close();
               Object var19 = null;
            } catch (IOException var14) {
            }
         }
      }
   }

   public ByteArrayOutputStream CCExportPrefs() {
      Preferences var1 = Preferences.userRoot().node("VideoSetting");
      var1.putInt("connectionSpeed", this.connectionSpeed);
      var1.putInt("colorDepth", this.colorDepth);
      var1.putInt("progressiveUpdate", this.progressiveUpdate ? 1 : 0);
      var1.putInt("flowControl", this.flowControl ? 1 : 0);
      var1.putInt("smoothing", this.smoothing);
      var1.putInt("framesPerSecond", this.framesPerSecond);
      ByteArrayOutputStream var2 = new ByteArrayOutputStream();

      try {
         var1.exportSubtree(var2);
         return var2;
      } catch (IOException var8) {
         return var2;
      } catch (BackingStoreException var9) {
         return var2;
      } finally {
         ;
      }
   }

   @Override
   public void exportPreferences(String var1) {
      Preferences var2 = this.rootPrefs.node(var1);
      this.storeToPreferences(var2);
      var2.put("description", this.description);
      var2.putInt("connectionType", this.connectionType);
      var2.put("productType", this.productType);
      var2.putInt("findBy", this.findBy);
      var2.put("ipAddress", this.ip);
      if (this.isPersistDeviceName()) {
         var2.put("deviceName", this.getDeviceName());
      }

      var2.put("serverName", this.getName());
      var2.put("dnsName", this.dnsName);
      var2.putInt("port", this.port);
      var2.putInt("httpsPort", this.httpsPort);
      var2.put("phone", this.phone);
      var2.put("modem", this.modem);
      var2.putInt("connectionSpeed", this.connectionSpeed);
      var2.putInt("colorDepth", this.colorDepth);
      var2.putInt("progressiveUpdate", this.progressiveUpdate ? 1 : 0);
      var2.putInt("flowControl", this.flowControl ? 1 : 0);
      var2.putInt("smoothing", this.smoothing);
      var2.putInt("framesPerSecond", this.framesPerSecond);
      if (StringUtils.notNullOrEmpty(this.privateKey)) {
         try {
            var2.put("privateKey", StringCryptoUtil.encrypt(this.privateKey, "l2Ge0FQQwlu2yGSF+Jh/nZdhntBUEMJb"));
         } catch (CryptoException var26) {
            RRCLogger.logException(var26);
         } catch (IOException var27) {
            RRCLogger.logException(var27);
         }
      } else {
         var2.put("privateKey", "");
      }

      var2.put("userName", this.userName);
      if (StringUtils.notNullOrEmpty(this.password)) {
         try {
            var2.put("password", StringCryptoUtil.encrypt(this.password, "l2Ge0FQQwlu2yGSF+Jh/nZdhntBUEMJb"));
         } catch (CryptoException var24) {
            RRCLogger.logException(var24);
         } catch (IOException var25) {
            RRCLogger.logException(var25);
         }
      } else {
         var2.put("password", "");
      }

      var2.putInt("remember", this.rememberOption);
      BufferedOutputStream var3 = null;

      try {
         var3 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(FILE_NAME)));
         this.rootPrefs.exportSubtree(var3);
      } catch (FileNotFoundException var21) {
      } catch (IOException var22) {
      } catch (BackingStoreException var23) {
      } finally {
         if (var3 != null) {
            try {
               var3.close();
               Object var29 = null;
            } catch (IOException var20) {
            }
         }
      }
   }

   public void importPreferences(String var1, String var2) {
      Object var3 = null;
      var3 = new ByteArrayInputStream(var2.getBytes());
      this.importPreferences(var1, (InputStream)var3, Preferences.userRoot());
   }

   @Override
   protected void importPreferences(String var1, InputStream var2, Preferences var3) {
      Preferences var4 = null;

      try {
         Preferences.importPreferences(var2);
         var4 = var3.node(var1);
         this.description = var4.get("description", "");
         this.connectionType = var4.getInt("connectionType", 2);
         this.productType = var4.get("productType", "");
         this.findBy = var4.getInt("findBy", 0);
         this.ip = var4.get("ipAddress", "0.0.0.0");
         this.name = var4.get("serverName", "");
         this.dnsName = var4.get("dnsName", "");
         this.port = var4.getInt("port", Integer.parseInt(Constants.NETWORKCONFIG_DEFAULT_PORT));
         this.httpsPort = var4.getInt("httpsPort", new ApplicationPreferences().getDefaultHttpsPort());
         this.phone = var4.get("phone", "0");
         this.modem = var4.get("modem", "");
         this.connectionSpeed = var4.getInt("connectionSpeed", 0);
         this.colorDepth = var4.getInt("colorDepth", 0);
         String var5 = var4.get("progressiveUpdate", "false");
         this.progressiveUpdate = var5.equals("1") || var5.equalsIgnoreCase("true");
         var5 = var4.get("flowControl", "false");
         this.flowControl = var5.equals("1") || var5.equalsIgnoreCase("true");
         this.smoothing = var4.getInt("smoothing", 0);
         this.framesPerSecond = var4.getInt("framesPerSecond", 0);
         this.privateKey = var4.get("privateKey", "");
         if (StringUtils.notNullOrEmpty(this.privateKey)) {
            try {
               this.privateKey = StringCryptoUtil.decrypt(this.privateKey, "l2Ge0FQQwlu2yGSF+Jh/nZdhntBUEMJb");
            } catch (CryptoException var23) {
               RRCLogger.logException(var23);
            } catch (IOException var24) {
               RRCLogger.logException(var24);
            }
         }

         this.userName = var4.get("userName", "");
         this.password = var4.get("password", "");
         if (StringUtils.notNullOrEmpty(this.password)) {
            try {
               this.password = StringCryptoUtil.decrypt(this.password, "l2Ge0FQQwlu2yGSF+Jh/nZdhntBUEMJb");
            } catch (CryptoException var21) {
               RRCLogger.logException(var21);
            } catch (IOException var22) {
               RRCLogger.logException(var22);
            }
         }

         this.rememberOption = var4.getInt("remember", 0);
         this.setDeviceName(var4.get("deviceName", unassignedDeviceName));
      } catch (InvalidPreferencesFormatException var25) {
         exportPreferences();
      } catch (IOException var26) {
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var28 = null;
            } catch (IOException var20) {
            }
         }
      }

      if (var4 != null) {
         this.loadValues(var4);
      }
   }

   public static void deleteNode(String var0) {
      Preferences var1 = Preferences.userRoot().node("/" + javaclientlib.tr.Constants.COMPANY_NAME_NOSPACE + "Devices");

      try {
         var1.node(var0).removeNode();
         exportPreferences();
      } catch (BackingStoreException var3) {
      }
   }

   public static String[] returnNodes() {
      importPreferences();
      Preferences var0 = Preferences.userRoot().node("/" + javaclientlib.tr.Constants.COMPANY_NAME_NOSPACE + "Devices");
      String[] var1 = null;

      try {
         var1 = var0.childrenNames();
      } catch (BackingStoreException var3) {
      }

      return var1;
   }

   public static DevicePreferences getNode(String var0) {
      importPreferences();
      Preferences var1 = Preferences.userRoot().node("/" + javaclientlib.tr.Constants.COMPANY_NAME_NOSPACE + "Devices");

      try {
         if (var1.nodeExists(var0)) {
            DevicePreferences var2 = new DevicePreferences();
            var2.importPreferences(var0);
            return var2;
         }
      } catch (BackingStoreException var3) {
      }

      return null;
   }

   protected static File getOrCreateXmlFile(String var0) {
      setComapnyName(javaclientlib.tr.Constants.COMPANY_NAME_NOSPACE);
      return DevicePrefs.getOrCreateXmlFile(var0);
   }

   public TRSRVR_COMP_PARAMS getCompParams() {
      TRSRVR_COMP_PARAMS var1 = new TRSRVR_COMP_PARAMS();
      int var2 = 0;
      if (this.progressiveUpdate) {
         var2 |= 32768;
      } else {
         var2 &= -32769;
      }

      var2 |= 24;
      if (this.flowControl) {
         var2 |= 128;
      } else {
         var2 &= -129;
      }

      var1.setFlags(var2);
      var1.setCCT((short)this.colorDepth);
      var1.setCacheDepth((short)0);
      var1.setCompressMode(2);
      var1.setSpeed(this.connectionSpeed);
      var1.setMinFrameTime(200 / (this.framesPerSecond + 1));
      var1.setMaxFrameTime(0);
      var1.setSmoothing(this.smoothing);
      return var1;
   }

   public int getColorDepth() {
      return this.colorDepth;
   }

   public int getConnectionSpeed() {
      return this.connectionSpeed;
   }

   public int getConnectionType() {
      return this.connectionType;
   }

   public String getProductType() {
      return this.productType;
   }

   public void setProductType(String var1) {
      this.productType = var1;
   }

   public String getDescription() {
      return this.description;
   }

   public String getDnsName() {
      return this.dnsName;
   }

   public int getFindBy() {
      return this.findBy;
   }

   public boolean isFlowControl() {
      return this.flowControl;
   }

   public String getIp() {
      return "".equals(this.ip) ? "0.0.0.0" : this.ip;
   }

   public InetAddress getInetAddess() {
      InetAddress var1 = null;

      try {
         var1 = InetAddress.getByName(this.getIp());
      } catch (UnknownHostException var3) {
         var3.printStackTrace();
      }

      return var1;
   }

   public String getKey() {
      return this.privateKey;
   }

   public String getModem() {
      return this.modem;
   }

   public String getName() {
      return this.isDeviceNameInStore() ? this.getDeviceName() : this.name;
   }

   public String getPhone() {
      return this.phone;
   }

   public int getPort() {
      return this.port;
   }

   public int getHttpsPort() {
      return this.httpsPort;
   }

   public boolean isProgressiveUpdate() {
      return this.progressiveUpdate;
   }

   public int getSmoothing() {
      return this.smoothing;
   }

   public void setColorDepth(int var1) {
      this.colorDepth = var1;
   }

   public void setConnectionSpeed(int var1) {
      this.connectionSpeed = var1;
   }

   public void setConnectionType(int var1) {
      this.connectionType = var1;
   }

   public void setDescription(String var1) {
      this.description = var1;
   }

   public void setDnsName(String var1) {
      this.dnsName = var1;
   }

   public void setFindBy(int var1) {
      this.findBy = var1;
   }

   public void setFlowControl(boolean var1) {
      this.flowControl = var1;
   }

   public void setIp(String var1) {
      if (null != var1 && !"".equals(var1)) {
         this.ip = var1;
      } else {
         this.ip = "0.0.0.0";
      }
   }

   public void setKey(String var1) {
      this.privateKey = var1;
   }

   public void setModem(String var1) {
      this.modem = var1;
   }

   public void setName(String var1) {
      this.setDeviceName(var1);
   }

   public void setPhone(String var1) {
      this.phone = var1;
   }

   public void setPort(int var1) {
      this.port = var1;
   }

   public void setHttpsPort(int var1) {
      this.httpsPort = var1;
   }

   public void setProgressiveUpdate(boolean var1) {
      this.progressiveUpdate = var1;
   }

   public void setSmoothing(int var1) {
      this.smoothing = var1;
   }

   public String getConfirmKey() {
      return this.confirmKey;
   }

   public int getFramesPerSecond() {
      return this.framesPerSecond;
   }

   public void setConfirmKey(String var1) {
      this.confirmKey = var1;
   }

   public String getPassword() {
      return this.password;
   }

   public void setPassword(String var1) {
      this.password = var1;
   }

   public String getUserName() {
      return this.userName;
   }

   public void setUserName(String var1) {
      this.userName = var1;
   }

   public int getRememberOption() {
      return this.rememberOption;
   }

   public void setRememberOption(int var1) {
      this.rememberOption = var1;
   }

   public void setFramesPerSecond(int var1) {
      this.framesPerSecond = var1;
   }

   public void setModemConnector(ModemConnector var1) {
      this.modemConnector = var1;
   }

   public ModemConnector getModemConnector() {
      return this.modemConnector;
   }

   public synchronized String getDeviceName() {
      return this.deviceName;
   }

   public synchronized void setDeviceName(String var1) {
      this.deviceName = var1;
   }

   public boolean isDeviceNameInStore() {
      return this.getDeviceName() != unassignedDeviceName;
   }

   private boolean isPersistDeviceName() {
      return this.getDeviceName() != unassignedDeviceName;
   }
}
