package com.raritan.rrc.data;

import com.raritan.protocol.browser.DeviceNameAddressProvider;
import com.raritan.protocol.browser.TooManyDevicesException;
import com.raritan.rrc.util.StringUtils;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Arrays;
import java.util.List;
import javaclientlib.utils.RRCLogger;

public class FindByBasedAddressSelector implements AddressSelector {
   private IPv6PrefAddressSelector addrSelector;

   public FindByBasedAddressSelector(Device var1, boolean var2, DeviceNameAddressProvider var3) throws UnknownHostException, DeviceUnavailableException, TooManyDevicesException {
      String var4 = null;
      List var5 = null;
      if (var1.isProfiled() && !var1.isModemProfiled()) {
         DevicePreferences var6 = var1.getDevPrefs();
         switch (var6.getFindBy()) {
            case 0:
               var4 = StringUtils.formatString(var6.getIp());
               break;
            case 1:
               List var7 = var3.getAddresses(var6.getDeviceName());
               if (var7.size() == 0) {
                  throw new DeviceUnavailableException("Device Not found", null, var6.getDeviceName());
               }

               var5 = var7;
               break;
            case 2:
               var5 = Arrays.asList(InetAddress.getAllByName(var6.getDnsName()));
               break;
            default:
               RRCLogger.log(100, 4, "find by is not one of ip/name/dns");

               assert false;
         }
      } else {
         var5 = var1.getAddressList();
      }

      if (var5 != null) {
         this.addrSelector = new IPv6PrefAddressSelector(var5, var2);
      } else {
         try {
            this.addrSelector = new IPv6PrefAddressSelector(Arrays.asList(InetAddress.getAllByName(var4)), var2);
         } catch (UnknownHostException var8) {
            assert false;
         }
      }
   }

   @Override
   public InetAddress getNextAddress() throws NoSuitableAddress {
      return this.addrSelector.getNextAddress();
   }

   @Override
   public boolean hasMoreAddress() {
      return this.addrSelector.hasMoreAddress();
   }
}
