package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoSwitchCommand;
import com.raritan.rrc.ui.panes.ViewFactory;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.mediator.PanelMediator;
import java.io.IOException;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import javaclientlib.clientlib.TRConnection;
import javaclientlib.tr.TRCMD_CHANGE_PASSWORD_DATA;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;

public class G1DeviceHandlerImpl extends DeviceHandlerImpl {
   public G1DeviceHandlerImpl(Device var1) {
      this.device = var1;
   }

   @Override
   public void doPostLogin(boolean var1) throws RRCGeneralException {
      RRCLogger.log(300, 4, "G1 Device. No HTTPS Connection made.");
   }

   @Override
   public void showRSA(boolean var1) throws RRCGeneralException, KeyManagementException, NoSuchAlgorithmException, IOException {
   }

   @Override
   public boolean isAbsoluteMouseSupported() {
      return ((RRCScreenContext)this.device.scrContext).getSelectView() != null
         ? ((RRCScreenContext)this.device.scrContext).getSelectView().getAbsoluteMouseSupported()
         : false;
   }

   @Override
   public boolean isIntelligentMouseSupported() {
      return ((RRCScreenContext)this.device.scrContext).getSelectView() != null
         ? ((RRCScreenContext)this.device.scrContext).getSelectView().getIntelligentMouseSupported()
         : false;
   }

   @Override
   public boolean isStandardMouseSupported() {
      return ((RRCScreenContext)this.device.scrContext).getSelectView() != null
         ? ((RRCScreenContext)this.device.scrContext).getSelectView().getStandardMouseSupported()
         : false;
   }

   @Override
   public boolean changePassword(boolean var1, String var2, String var3, String var4) {
      TRCMD_CHANGE_PASSWORD_DATA var5 = new TRCMD_CHANGE_PASSWORD_DATA();
      var5.setOldPassword(var2.getBytes());
      var5.setNewPassword(var3.getBytes());
      return this.device.getDeviceConnector().ChangeUserPassword(var5);
   }

   @Override
   public void doSwitch(DoSwitchCommand var1, CommandResult var2) {
      ArrayList var3 = (ArrayList)((RRCScreenContext)this.device.scrContext).getSelectedDevicesObservable().getComponent();
      KvmPort var4 = (KvmPort)var3.get(0);
      var4.getBaseDevice().setActiveKvmPort(var4);
      var4.connect();
      if (!var4.isConnected()) {
         boolean var5 = false;
         int var6 = TRConnection.getLastError();
         int var7 = var6 & -4096;
         var6 &= 4095;
         if (var6 == 12) {
            if (var7 == 0) {
               var7 = 536875008;
            }

            var2.setIsSuccess(false);
            String var8 = null;
            if (var7 == 536875008) {
               var8 = "TR_ERROR.";
            }

            RaritanPropertyResourceBundle var9 = RaritanResourceBundle.getResourceBundle(this.device.scrContext.getLocale());
            String var10 = var8 + Integer.toString(var6);
            var5 = CommonPopups.showConfirmationDialog(var9.getString(var10 + ".title"), var9.getString(var10 + ".text"), null, this.device.scrContext) == 2;
            if (var5) {
               var4.forceConnection();
               var1.setBusy(false);
            }
         }
      }

      if (!var4.isConnected()) {
         var4.getBaseDevice().setActiveKvmPort(null);
         var1.getTRSRVR_ErrorResult(var2, var4);
      } else {
         var1.getContext().setCommandParameter("ports", var4);
         var2.setIsSuccess(true);
      }
   }

   @Override
   public boolean isWindowMenuItem(Port var1) {
      return true;
   }

   @Override
   public boolean isShowHtmlPortExecutable() {
      Port var1 = (Port)((ArrayList)((RRCScreenContext)this.device.scrContext).getSelectedDevicesObservable().getComponent()).get(0);
      return !var1.isConnected() && ((RRCScreenContext)this.device.scrContext).getPortByKeyObservable(var1) == null;
   }

   @Override
   public boolean isShowSaveActivityLogExecutable() {
      return true;
   }

   @Override
   public boolean isShowSaveDeviceConfigurationExecutable() {
      return true;
   }

   @Override
   public boolean isShowSaveDiagnosticLogExecutable() {
      return true;
   }

   @Override
   public boolean isShowSaveTotalConfigurationExecutable() {
      return false;
   }

   @Override
   public boolean isShowSaveUserConfigurationExecutable() {
      return true;
   }

   @Override
   public String getCommandClassName(String var1) {
      return "com.raritan.rrc.ui.commands.Show" + var1 + "Command";
   }

   @Override
   public AbstractDisplay initializeDeviceView(CommandContext var1, String var2, PanelMediator var3) throws RRCGeneralException {
      if (var2.equals("doSwitchCommand") || var2.equals("showKvmPortCommand")) {
         return ViewFactory.getInstance().getView(this.device.scrContext, "KX_1.X", null);
      } else {
         return var2.equals("showHtmlPortCommand") ? var3.getTarget(var2) : null;
      }
   }

   @Override
   public boolean isRFPRecieveThreadNeeded() {
      return false;
   }

   @Override
   public Port initSerialPort() {
      return new SerialPort();
   }

   @Override
   public void setToolTip(Port var1) {
      var1.setToolTipText();
   }

   @Override
   public void waitBeforeAutoReboot() {
      try {
         Thread.sleep(15000L);
      } catch (InterruptedException var2) {
         RRCLogger.logException(var2);
      }
   }
}
