package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoSwitchCommand;
import com.raritan.rrc.ui.panes.BrowserLaunch;
import com.raritan.rrc.ui.panes.RestrictedServiceAgreementPane;
import com.raritan.rrc.ui.panes.ViewFactory;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.mediator.PanelMediator;
import com.raritan.tools.util.Util;
import java.awt.Frame;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.MalformedURLException;
import java.net.ProtocolException;
import java.net.URLEncoder;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;
import javax.swing.JOptionPane;
import nn.pp.common.KXHttpConnection;

public class G2DeviceHandlerImpl extends DeviceHandlerImpl {
   public G2DeviceHandlerImpl(Device var1) {
      this.device = var1;
   }

   @Override
   public void doPostLogin(boolean var1) throws RRCGeneralException, KeyManagementException, NoSuchAlgorithmException, IOException {
      RRCLogger.log(300, 4, "Starting HTTPS Connection using port:" + this.device.getHttpsPort());
      KXHttpConnection var2 = null;
      DeviceConnector var3 = this.device.getDeviceConnector();
      String var4 = null;
      String var5 = "";
      String var6 = "";
      if (var1) {
         HashMap var7 = var3.getConnectionMap();
         if (var7 != null) {
            var5 = this.getParamValue(var7, "SessionID", true);
            var6 = this.getParamValue(var7, "SessionKey", true);
            var4 = this.getParamValue(var7, "ConnectionIDHTTPS", false);
            RRCLogger.log(300, 4, "RDM SessionId: " + var5);
            RRCLogger.log(300, 4, "RDM Session Key: " + var6);
            this.device.setRdmSessionId(var5);
            this.device.setRdmSessionKey(var6);
         }

         var2 = new KXHttpConnection(
            this.device.getRdmSessionId(),
            this.device.getRdmSessionKey(),
            "https://" + Util.getURLCompatibleIP(var3.getInetAddress(), this.device.getHttpsPort()),
            var1
         );
      } else {
         RRCLogger.log(300, 4, "Not a CCLaunch");
         var2 = new KXHttpConnection(
            var3.getUsername(), var3.getPassword(), "https://" + Util.getURLCompatibleIP(var3.getInetAddress(), this.device.getHttpsPort()), var1
         );
      }

      if (var4 != null) {
         LinkedHashMap var16 = new LinkedHashMap();
         this.device.setAppletParameters(var16);
         RRCLogger.log(300, 4, "Applet Parameters: " + var16);
      } else {
         LinkedHashMap var15 = var2.getAppletParameterMap();
         RRCLogger.log(300, 4, "HTTPS Connection done.");
         if (var15 == null || var15.size() <= 0) {
            RRCScreenContext var17 = (RRCScreenContext)this.device.getContext();
            String var18 = "";
            if (var17 != null) {
               RaritanPropertyResourceBundle var10 = RaritanResourceBundle.getResourceBundle(var17.getLocale());
               var18 = var10.getString("error.connect.port");
            }

            CommonPopups.showCommandResultErrorMessage(var18, null, (RRCScreenContext)this.device.getContext());
            RRCLogger.log(300, 4, "Null applet parameters");
            throw new RRCGeneralException("No applet parameters found");
         }

         this.device.setAppletParameters(var15);
         int var8 = 0;
         int var9 = 0;

         try {
            var8 = new Integer((String)var15.get("banner_display"));
            var9 = new Integer((String)var15.get("banner_req_accept"));
         } catch (NumberFormatException var11) {
            RRCLogger.log(300, 4, "Exception occured while getting Banner enabled data: " + var11);
         }

         this.device.setRSAEnabled(var8 == 1);
         this.device.setRSAAcceptance(var9 == 1);
         RRCLogger.log(300, 4, "Applet Parameters: " + var15);
      }
   }

   @Override
   public void showRSA(boolean var1) throws KeyManagementException, ProtocolException, MalformedURLException, NoSuchAlgorithmException, IOException {
      if (!var1) {
         DeviceConnector var2 = this.device.getDeviceConnector();
         KXHttpConnection var3 = null;
         var3 = new KXHttpConnection(
            var2.getUsername(), var2.getPassword(), "https://" + Util.getURLCompatibleIP(var2.getInetAddress(), this.device.getHttpsPort()), var1
         );
         KXHttpConnection.BannerSettings var4 = var3.getSecurityBannerSettings();
         String var5 = var4.getRsaText();
         String var6 = var4.getRsaTitle();
         if (this.device.isRSAEnabled()) {
            try {
               RRCScreenContext var7 = (RRCScreenContext)this.device.getContext();
               Frame var8 = JOptionPane.getFrameForComponent(var7.getApplication().getContentPane());
               RestrictedServiceAgreementPane var9 = new RestrictedServiceAgreementPane(var8, this.device, var7, var5, var6);
               var9.setLocation(var8.getWidth() / 2, var8.getHeight() / 2);
               var9.setVisible(true);
               if (this.device.isRSAAccepted()) {
                  var3.callSecurityBannerAcceptPage(1);
               } else {
                  var3.callSecurityBannerAcceptPage(0);
               }
            } catch (Exception var10) {
               RRCLogger.log(300, "Exception while showing Restricted Service Agreement:\n", var10);
            }
         }
      }
   }

   @Override
   public boolean changePassword(boolean var1, String var2, String var3, String var4) {
      DeviceConnector var6 = this.device.getDeviceConnector();
      KXHttpConnection var5 = new KXHttpConnection(
         new String(var6.getUsername()),
         new String(var6.getPassword()),
         "https://" + Util.getURLCompatibleIP(var6.getInetAddress(), this.device.getHttpsPort()),
         var1
      );
      boolean var7 = false;
      if (this.device.getRdmSessionId() != null && this.device.getDeviceConnector().isAuthenticated()) {
         var7 = var5.changePwd(null, var2, var3, var4, false);
      } else {
         var7 = var5.changePwd(new String(this.device.getDeviceConnector().objUserInfo.getName()), var2, var3, var4, true);
      }

      if (var7) {
         this.device.getDeviceConnector().setPassword(var3);
      }

      return var7;
   }

   @Override
   public boolean isWindowMenuItem(Port var1) {
      return !(var1 instanceof HtmlPort);
   }

   @Override
   public boolean isShowHtmlPortExecutable() {
      return true;
   }

   @Override
   public boolean isURLPortExecutable() {
      return true;
   }

   @Override
   public boolean isShowSaveActivityLogExecutable() {
      return false;
   }

   @Override
   public boolean isShowSaveDeviceConfigurationExecutable() {
      return false;
   }

   @Override
   public boolean isShowSaveDiagnosticLogExecutable() {
      return false;
   }

   @Override
   public boolean isShowSaveTotalConfigurationExecutable() {
      return true;
   }

   @Override
   public boolean isShowSaveUserConfigurationExecutable() {
      return false;
   }

   @Override
   public String getCommandClassName(String var1) {
      return !var1.equalsIgnoreCase("htmlport") && !var1.equalsIgnoreCase("urlport")
         ? "com.raritan.rrc.ui.commands.ShowKX2" + var1 + "Command"
         : "com.raritan.rrc.ui.commands.Show" + var1 + "Command";
   }

   @Override
   public AbstractDisplay initializeDeviceView(CommandContext var1, String var2, PanelMediator var3) throws RRCGeneralException {
      DeviceConnector var4 = this.device.getDeviceConnector();
      if (!"doSwitch".equals(var1.getCommandParameter("doSwitch")) && !"showKX2KvmPortCommand".equals(var2) && !"showKVMFromScanCommand".equals(var2)) {
         if (var2.equals("showHtmlPortCommand")) {
            String var5 = "";

            try {
               var5 = new String(
                  "https://"
                     + Util.getURLCompatibleIP(var4.getInetAddress(), this.device.getHttpsPort())
                     + "/admin.html?SessionID="
                     + URLEncoder.encode(this.device.getDeviceConnector().getRdmSessionID(), "UTF-8")
                     + "&SessionKey="
                     + URLEncoder.encode(this.device.getDeviceConnector().getRdmSessionKey(), "UTF-8")
               );
            } catch (UnsupportedEncodingException var10) {
               RRCLogger.log(300, 16, "Unsupported Encoding exception when constructing URL to launch admin");
            }

            this.launchUrl(var5);
         } else if (var2.equals("showURLPortCommand")) {
            ArrayList var11 = (ArrayList)((RRCScreenContext)this.device.scrContext).getSelectedDevicesObservable().getComponent();
            URLPort var6 = (URLPort)var11.get(0);
            String var7 = "";
            if (var6 != null) {
               try {
                  var7 = new String(
                     "https://"
                        + Util.getURLCompatibleIP(var4.getInetAddress(), this.device.getHttpsPort())
                        + "/auth_url_connect.asp?SessionID="
                        + URLEncoder.encode(this.device.getDeviceConnector().getRdmSessionID(), "UTF-8")
                        + "&SessionKey="
                        + URLEncoder.encode(this.device.getDeviceConnector().getRdmSessionKey(), "UTF-8")
                        + "&pid="
                        + var6.getParentBladeChassis().getUniquePortId()
                        + "&uid="
                        + var6.getUniquePortId()
                  );
               } catch (UnsupportedEncodingException var9) {
                  RRCLogger.log(300, 16, "Unsupported Encoding exception when constructing URL to launch admin");
               }

               this.launchUrl(var7);
            }
         }

         return null;
      } else {
         RRCLogger.log(300, 1, "Creating new RFBView");
         return ViewFactory.getInstance().getView(this.device.scrContext, "KX_2.0", null);
      }
   }

   private void launchUrl(String var1) {
      if (this.device.scrContext.getApplication().isStandalone()) {
         BrowserLaunch.openURL(var1, null);
      } else {
         BrowserLaunch.openURL(var1, this.device.scrContext.getAppletContext());
      }
   }

   @Override
   public boolean isRFPRecieveThreadNeeded() {
      return true;
   }

   @Override
   public Port initSerialPort() {
      return new G2SerialPort();
   }

   @Override
   public void doSwitch(DoSwitchCommand var1, CommandResult var2) {
      RRCLogger.log(300, 1, "handleCommand(DoSwitchCommand) Started");
      ArrayList var3 = (ArrayList)((RRCScreenContext)this.device.scrContext).getSelectedDevicesObservable().getComponent();
      RFBView var4 = null;
      KvmPort var5 = (KvmPort)var3.get(0);
      KvmPort var6 = (KvmPort)var5.getBaseDevice().getActiveKvmPort();
      if (var6 != null) {
         var4 = (RFBView)var6.getView();
         if (var4 != null) {
            RRCLogger.log(300, 1, "Switch from " + var6.getPortIndex());
            RRCLogger.log(300, 1, "Switch to " + var5.getPortIndex());
            var4.switchKvmPort(var6, var5);
            var2.setIsSuccess(true);
            var1.getContext().setCommandParameter("doSwitch", null);
         } else {
            RRCLogger.log(100, 1, "rfbView is null");
         }
      } else {
         RRCLogger.log(300, 1, "New Connection marked for switching. Switch to " + var5.getPortIndex());
         var5.getBaseDevice().setActiveKvmPort(var5);
         var1.getContext().setCommandParameter("doSwitch", "doSwitch");
      }

      var2.setIsSuccess(true);
      var1.getContext().setCommandParameter("ports", var5);
      RRCLogger.log(300, 1, "handleCommand(DoSwitchCommand) Finished");
   }

   @Override
   public boolean hasColorCalibration(Port var1) {
      RFBView var2 = (RFBView)var1.getView();
      return var2.isColorCalibrationSupported();
   }

   @Override
   public void setToolTip(Port var1) {
   }

   @Override
   public void waitBeforeAutoReboot() {
   }

   @Override
   public boolean showCtrlNumlockCommand(Port var1) {
      if (var1.getView() instanceof RFBView) {
         RFBView var2 = (RFBView)var1.getView();
         return var2.isCimLanguageOptionsSupported();
      } else {
         return true;
      }
   }

   @Override
   public boolean canDoTargetScreenCapture() {
      return true;
   }
}
