package com.raritan.rrc.data;

import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.RSCView;
import com.raritan.tools.util.Util;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.URL;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.jar.JarEntry;
import java.util.jar.JarInputStream;
import java.util.jar.JarOutputStream;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.swing.JApplet;

public class G2SerialPort extends Port {
   private RSCView rscView;

   @Override
   public Stream getStream() {
      return null;
   }

   @Override
   public DeviceView getView() {
      return this.rscView;
   }

   public void setView(RSCView var1) {
      this.rscView = var1;
   }

   @Override
   public void connect() {
      try {
         this.downloadRSCJar();
         this.setConnected(true);
         this.setState("CONNECTED");
         this.firePropertyChange("DEVICE_PORT_VIEW_ADD", null, null);
      } catch (KeyManagementException var2) {
         RRCLogger.logException(var2);
      } catch (NoSuchAlgorithmException var3) {
         RRCLogger.logException(var3);
      } catch (RRCGeneralException var4) {
         RRCLogger.logException(var4);
      } catch (IOException var5) {
         RRCLogger.logException(var5);
      }
   }

   public void downloadRSCJar() throws RRCGeneralException, KeyManagementException, NoSuchAlgorithmException, IOException {
      if (this.device.getRscFileHandle() == null) {
         this.deleteRSCJar();
         File var2 = null;

         try {
            SSLContext var1 = SSLContext.getInstance("SSLv3");
            TrustManager[] var3 = new TrustManager[]{new DummyTrustManager1()};
            var1.init(null, var3, null);
            SSLSocketFactory var4 = var1.getSocketFactory();
            HttpsURLConnection.setDefaultSSLSocketFactory(var4);
            HttpsURLConnection.setDefaultHostnameVerifier(new DummyHostNameVerifier());
            DeviceConnector var5 = this.device.getDeviceConnector();
            String var6 = "https://" + Util.getURLCompatibleIP(var5.getInetAddress(), this.device.getHttpsPort()) + "/RSC.jar";
            URL var7 = new URL(var6);
            HttpsURLConnection var8 = (HttpsURLConnection)var7.openConnection();
            var2 = new File(this.getTempDirPath() + File.separator + this.getRSCJarName());
            JarInputStream var9 = new JarInputStream(var8.getInputStream());
            FileOutputStream var10 = new FileOutputStream(var2);
            JarOutputStream var11 = new JarOutputStream(var10);
            byte[] var12 = new byte[1024];

            JarEntry var13;
            while ((var13 = var9.getNextJarEntry()) != null) {
               var11.putNextEntry(var13);

               while (true) {
                  int var14 = var9.read(var12, 0, var12.length);
                  if (var14 <= 0) {
                     var9.closeEntry();
                     var11.closeEntry();
                     break;
                  }

                  var11.write(var12, 0, var14);
               }
            }

            var11.flush();
            var9.close();
            var11.close();
         } catch (NoSuchAlgorithmException var15) {
            RRCLogger.logException(var15);
         } catch (KeyManagementException var16) {
            RRCLogger.logException(var16);
         } catch (IOException var17) {
            RRCLogger.logException(var17);
         }

         RRCLogger.log(300, 4, "RSC Jar path " + var2.getCanonicalPath());
         this.device.setRscFileHandle(var2);
      } else {
         RRCLogger.log(300, 4, this.getDevice().getRscFileHandle().getCanonicalPath() + " already exists");
      }
   }

   private boolean deleteRSCJar() throws IOException {
      File var1 = new File(this.getTempDirPath() + File.pathSeparator + this.getRSCJarName());
      boolean var2 = true;
      if (var1.exists()) {
         var2 = var1.delete();
         RRCLogger.log(300, 4, "Deleting file " + var1.getCanonicalPath() + " : " + var2);
      }

      return var2;
   }

   private String getTempDirPath() throws IOException {
      File var1 = File.createTempFile("rsc", ".tmp");
      RRCLogger.log(300, 4, "Temp dir path " + var1.getParentFile().getCanonicalPath());
      String var2 = var1.getParentFile().getCanonicalPath();
      var1.delete();
      return var2;
   }

   public String getRSCJarName() {
      DeviceConnector var1 = this.getDevice().getDeviceConnector();
      String var2 = var1.getInetAddress().getHostAddress();
      String var3 = var2.replace(':', '.');
      return "rsc_" + var3 + ".jar";
   }

   @Override
   public void disconnect() {
      if (this.isConnected()) {
         this.setConnected(false);
         this.setActive(false);
         this.setState("AVAILABLE");
         JApplet var1 = this.rscView.getApplet();

         try {
            Method var2 = var1.getClass().getMethod("disconnect", null);
            var2.invoke(var1, null);
         } catch (SecurityException var4) {
            RRCLogger.logException(var4);
         } catch (NoSuchMethodException var5) {
            RRCLogger.logException(var5);
         } catch (IllegalArgumentException var6) {
            RRCLogger.logException(var6);
         } catch (IllegalAccessException var7) {
            RRCLogger.logException(var7);
         } catch (InvocationTargetException var8) {
            RRCLogger.logException(var8);
         }

         super.disconnect();
         this.firePropertyChange("DEVICE_PORT_VIEW_REMOVE", null, null);
         this.setView(null);
         this.setDeviceView(null);
      }
   }
}
