package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.io.IOException;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.utils.RRCLogger;
import javax.swing.SwingUtilities;
import javax.xml.parsers.ParserConfigurationException;
import org.xml.sax.SAXException;

public class IPReach extends Device {
   private ConnectionInfo connInfo;
   public static final String GET_DATABASE = "<Database><Get><Select>/System</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>";
   private static final String GET_DEVICE = "<Database><Get><Select>/System/Device[@Type='IP-Reach']/Port</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>";
   private static final String EVENTS = "<Notify><Subscribe><ID>*</ID><Events>*</Events><Time/><SerialNo/><SubscriptionID/><NodeID/><SendData/></Subscribe></Notify>";
   private int selectedOption = 2;
   private String sessionId = null;
   private String cookie = null;
   private boolean ccLaunch = false;

   public boolean isCcLaunch() {
      return this.ccLaunch;
   }

   public void setCcLaunch(boolean var1) {
      this.ccLaunch = var1;
   }

   public IPReach() {
      this.connInfo = new ConnectionInfo();
   }

   public IPReach(ScreenContext var1) {
      this.setScreenContext(var1);
      this.connInfo = new ConnectionInfo();
   }

   @Override
   public String getDeviceType() {
      return "IP-Reach";
   }

   @Override
   public void setName(String var1) {
      super.setName(var1);
      this.connInfo.setName(var1);
   }

   @Override
   public void setIPPort(long var1) {
      super.setIPPort(var1);
      this.connInfo.getComm().setIpPort((int)var1);
   }

   public ConnectionInfo getConnectionInfo() {
      return this.connInfo;
   }

   @Override
   public String getViewName() {
      return null;
   }

   @Override
   public void disconnect() {
      if (this.isConnected()) {
         if (this.scrContext != null) {
            this.scrContext.getPanelMediator().hideAll();
         }

         this.setConnected(false);
         super.disconnect();
         this.removeChildren();
         this.setState("AVAILABLE");
         if (this.getDevPrefs() != null && this.getDevPrefs().getModemConnector() != null && this.isModemProfiled()) {
            this.getDevPrefs().getModemConnector().rasHangUp();
            this.getDevPrefs().setModemConnector(null);
            this.setState("UNAVAILABLE");
         }

         DeviceConnector var1 = this.getDeviceConnector();
         if (var1 != null) {
            var1.disConnect();
            this.setDeviceConnector(null);
         }

         System.gc();
         this.firePropertyChange("DEVICE_CONNECTION_LOST", null, null);
      }
   }

   public void disconnect(boolean var1) {
      if (this.isConnected()) {
         if (this.scrContext != null) {
            this.scrContext.getPanelMediator().hideAll();
         }

         this.setConnected(false);
         super.disconnect();
         this.removeChildren();
         this.setState("AVAILABLE");
         if (!var1 && this.getDevPrefs() != null && this.getDevPrefs().getModemConnector() != null && this.isModemProfiled()) {
            this.getDevPrefs().getModemConnector().rasHangUp();
            this.getDevPrefs().setModemConnector(null);
            this.setState("UNAVAILABLE");
         }

         DeviceConnector var2 = this.getDeviceConnector();
         if (var2 != null) {
            var2.disConnect();
            this.setDeviceConnector(null);
         }

         if (this.getRdmSessionId() != null) {
            this.setRdmSessionId(null);
         }

         if (this.getRdmSessionKey() != null) {
            this.setRdmSessionKey(null);
         }

         System.gc();
         this.firePropertyChange("DEVICE_CONNECTION_LOST", null, null);
      }
   }

   @Override
   public TRLIB_USERINFO login() {
      return null;
   }

   public void updateDevice() {
      this.updateDevice(false);
   }

   public void updateDevice(final boolean var1) {
      if (SwingUtilities.isEventDispatchThread()) {
         this.addDevice(var1);
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               IPReach.this.addDevice(var1);
            }
         });
      }
   }

   public void addDevice() {
      this.addDevice(false);
   }

   public void addDevice(boolean var1) {
      try {
         DeviceConnector var2 = this.getDeviceConnector();
         String var9 = var2.databaseRequest(
            "<Database><Get><Select>/System/Device[@Type='IP-Reach']/Port</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>"
         );
         if (var9 != null) {
            this.processDatabaseResponse(var9, var1);
         } else {
            RRCLogger.log(300, 4, "xmlresponse for GET_DEVICE is NULL.");
         }

         if (!var1) {
            var2.databaseRequest("<Notify><Subscribe><ID>*</ID><Events>*</Events><Time/><SerialNo/><SubscriptionID/><NodeID/><SendData/></Subscribe></Notify>");
         }
      } catch (ParserConfigurationException var4) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "Parser Configuration Exception in addDevice()\nException Message: " + var4.getMessage());
         }

         if (this.scrContext != null) {
            RaritanPropertyResourceBundle var8 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
            if (var8 != null) {
               CommonPopups.showCommandResultErrorMessage("[" + this.getNameIP() + "]: " + var8.getString("corruptXmlError.message"), null, this.scrContext);
            }
         }

         this.disconnect();
      } catch (SAXException var5) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(
               200, 4, "SAXException in addDevice()\nException Message: " + var5.getMessage() + "\nThis might indicate a problem with the XML string."
            );
         }

         if (this.scrContext != null) {
            RaritanPropertyResourceBundle var7 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
            if (var7 != null) {
               CommonPopups.showCommandResultErrorMessage("[" + this.getNameIP() + "]: " + var7.getString("corruptXmlError.message"), null, this.scrContext);
            }
         }

         this.disconnect();
      } catch (IOException var6) {
         if (this.scrContext != null) {
            RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
            if (var3 != null) {
               CommonPopups.showCommandResultErrorMessage("[" + this.getNameIP() + "]: " + var3.getString("corruptXmlError.message"), null, this.scrContext);
            }
         }

         this.disconnect();
      }
   }

   public void processDatabaseResponse(String var1, boolean var2) throws ParserConfigurationException, SAXException, IOException {
      if (var1 != null) {
         DeviceFactory var3 = DeviceFactory.getInstance();
         if (!this.isCcLaunch()) {
            this.setSortType(((RRCScreenContext)this.scrContext).getAppSettings().getChannelSortMethod());
         }

         var3.updateDevice(this, var1, this.scrContext, var2);
         if (this.hasChildren()) {
            this.firePropertyChange("DEVICE_PORTS_ADD", null, null);
         }

         if (!this.isCcLaunch()) {
            this.showGroupView(((RRCScreenContext)this.scrContext).getAppSettings().isShowGroups());
         }
      }
   }

   @Override
   public void firePropertyChange(String var1, Object var2, Object var3) {
      super.firePropertyChange(var1, var2, var3);
   }

   public int getSelectedOption() {
      return this.isProfiled() && this.getDevPrefs() != null ? this.getDevPrefs().getRememberOption() : this.selectedOption;
   }

   public void setSelectedOption(int var1) {
      this.selectedOption = var1;
      if (this.isProfiled() && this.getDevPrefs() != null) {
         this.getDevPrefs().setRememberOption(this.selectedOption);
      }
   }

   public boolean isAdministrator() {
      DeviceConnector var1 = this.getDeviceConnector();
      if (var1 == null) {
         return false;
      } else if (var1.isKX2Device()) {
         return var1.isAdminUser();
      } else {
         boolean var2 = (var1.getPermissions() & 2L) != 0L;
         boolean var3 = var1.getServerID().getProtocolVersion() > 11;
         boolean var4 = (var1.getServerID().getSecurityFlags() & 1) != 0;
         return var2 && var3 && var4;
      }
   }

   public String getSessionId() {
      return this.sessionId;
   }

   public void setSessionId(String var1) {
      this.sessionId = var1;
   }

   public String getCookie() {
      return this.cookie;
   }

   public void setCookie(String var1) {
      this.cookie = var1;
   }

   @Override
   public String getPortKey() {
      return null;
   }
}
