package com.raritan.rrc.data;

import com.raritan.tools.util.Util;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.List;
import java.util.NoSuchElementException;

public class IPv6PrefAddressSelector implements AddressSelector {
   private final ArrayList inetAddresses;
   private int index = 0;
   private boolean noSuitableAddress = false;
   private final boolean ipv6Enabled;

   public IPv6PrefAddressSelector(List var1, boolean var2) {
      this.inetAddresses = new ArrayList();
      int var3 = var1.size();
      this.ipv6Enabled = var2;
      boolean var4 = false;
      int var5 = 0;
      if (var3 > 0) {
         for (int var6 = 0; var6 < var3; var6++) {
            InetAddress var7 = (InetAddress)var1.get(var6);
            if (var7 instanceof Inet6Address) {
               this.inetAddresses.add(var7);
            }
         }

         var4 = this.inetAddresses.size() == var1.size();
         if (!var4) {
            var5 = this.inetAddresses.size();

            for (int var9 = 0; var9 < var3; var9++) {
               InetAddress var11 = (InetAddress)var1.get(var9);
               if (var11 instanceof Inet4Address) {
                  this.inetAddresses.add(var11);
               }
            }
         }

         boolean var10 = Util.isIPV6Supported();
         if (!var10 || !this.ipv6Enabled) {
            if (var4) {
               this.noSuitableAddress = true;
            } else {
               this.index = var5;
            }
         }
      }
   }

   @Override
   public InetAddress getNextAddress() throws NoSuitableAddress {
      if (this.noSuitableAddress) {
         throw new NoSuitableAddress("No Suitable address", null);
      } else if (!this.hasMoreAddress()) {
         throw new NoSuchElementException("No Such Element");
      } else {
         return (InetAddress)this.inetAddresses.get(this.index++);
      }
   }

   @Override
   public boolean hasMoreAddress() {
      int var1 = this.inetAddresses.size();
      return var1 > 0 && this.index < var1;
   }
}
