package com.raritan.rrc.data;

import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import java.awt.HeadlessException;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.TreeMap;
import java.util.prefs.BackingStoreException;
import java.util.prefs.InvalidPreferencesFormatException;
import java.util.prefs.Preferences;
import javaclientlib.utils.RRCLogger;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class KeyboardMacrosPreferences {
   public static final String ROOT_NODE = "/KeyboardMacros";
   private static final String FILE_NAME = System.getProperty("user.home") != null
      ? System.getProperty("user.home") + System.getProperty("file.separator") + "KeyboardMacros.xml"
      : "KeyboardMacros.xml";
   private static final String TEMP_FILE_NAME = System.getProperty("user.home") != null
      ? System.getProperty("user.home") + System.getProperty("file.separator") + "KeyboardMacrosTemp.xml"
      : "KeyboardMacrosTemp.xml";
   private static final String MACRO_NAME_KEY = "name";
   private static final String HOT_KEY_COMBINATION_KEY = "hotKey";
   private static final String MACRO_SEQUENCE_KEY = "macroSequence";
   private static final int NUMBER_OF_ATTRIBUTES = 3;
   private static final int TIME_DELAY_INTERVAL = 700;
   private static final int TIME_DELAY_CYCLES = 3;
   private Preferences rootPrefs;
   private String macroName = "";
   private int hotKeyCombination = -1;
   private String macroSequence = "";

   public KeyboardMacrosPreferences() {
      this.rootPrefs = Preferences.userRoot().node("/KeyboardMacros");
   }

   public static void exportPreferences() {
      exportPreferencesFunction(FILE_NAME);
   }

   public static boolean exportPreferencesFunction(String var0) {
      Preferences var1 = Preferences.userRoot().node("/KeyboardMacros");
      BufferedOutputStream var2 = null;
      boolean var3 = true;

      try {
         var2 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(var0)));
         var1.exportSubtree(var2);
      } catch (FileNotFoundException var17) {
         var3 = false;
         RRCLogger.log(100, 33, var17, "File Not Found when attempting to export Keyboard Macros from backing store to file: " + var0);
      } catch (IOException var18) {
         var3 = false;
         RRCLogger.log(100, 33, var18, "IO Exception occurred when attempting to export Keyboard Macros from backing store to file: " + var0);
      } catch (BackingStoreException var19) {
         var3 = false;
         RRCLogger.log(100, 33, var19, "Backing Store Exception occurred when attempting to export Keyboard Macros from backing store to file: " + var0);
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var21 = null;
            } catch (IOException var16) {
               var3 = false;
            }
         }
      }

      return var3;
   }

   private static boolean attemptSafeExport(String var0) {
      boolean var1 = false;

      for (short var2 = 0; !var1 && var2 < 2100; var2 += 700) {
         if (var2 > 0) {
            try {
               Thread.sleep(var2);
            } catch (InterruptedException var4) {
            }
         }

         var1 = exportPreferencesFunction(var0);
      }

      return var1;
   }

   public static CommandResult doExport(TreeMap var0, File var1, RaritanPropertyResourceBundle var2) {
      CommandResult var3 = new CommandResult(true, var2.getString("macro.export.success"));
      if (!attemptSafeExport(TEMP_FILE_NAME)) {
         var3.setStatusMessage(var2.getString("macro.export.write.temp.failed"));
         var3.setIsSuccess(false);
         return var3;
      } else {
         String[] var4 = returnNodes();

         for (int var5 = 0; var5 < var4.length; var5++) {
            if (!var0.containsKey(var4[var5])) {
               deleteNode(var4[var5], false);
            }
         }

         if (!attemptSafeExport(var1.getAbsolutePath())) {
            var3.setStatusMessage(var2.getString("macro.export.write.failed"));
            var3.setIsSuccess(false);
         }

         File var8 = new File(TEMP_FILE_NAME);
         if (!importPreferences(var8)) {
            try {
               Thread.sleep(700L);
            } catch (InterruptedException var7) {
            }

            if (!importPreferences(var8)) {
               var3.setStatusMessage((var3.isSuccess() ? "" : var3.getStatusMessage() + "\n\n") + var2.getString("macro.export.reimport.failed"));
            }
         }

         if (var3.isSuccess()) {
            var8.delete();
         }

         return var3;
      }
   }

   public void exportPreferences(String var1) {
      this.exportPreferences(var1, true);
   }

   public void exportPreferences(String var1, boolean var2) {
      Preferences var3 = this.rootPrefs.node(var1);
      var3.put("name", this.macroName);
      var3.putInt("hotKey", this.hotKeyCombination);
      var3.put("macroSequence", this.macroSequence);
      if (var2) {
         BufferedOutputStream var4 = null;

         try {
            var4 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(FILE_NAME)));
            this.rootPrefs.exportSubtree(var4);
         } catch (FileNotFoundException var18) {
            RRCLogger.log(
               100,
               33,
               var18,
               "File Not Found Exception occurred when attempting to export Keyboard Macro '" + var1 + "' from backing store to file: " + FILE_NAME
            );
         } catch (IOException var19) {
            RRCLogger.log(
               100, 33, var19, "IO Exception occurred when attempting to export Keyboard Macro '" + var1 + "' from backing store to file: " + FILE_NAME
            );
         } catch (BackingStoreException var20) {
            RRCLogger.log(
               100,
               33,
               var20,
               "Backing Store Exception occurred when attempting to export Keyboard Macro '" + var1 + "' from backing store to file: " + FILE_NAME
            );
         } finally {
            if (var4 != null) {
               try {
                  var4.close();
                  Object var22 = null;
               } catch (IOException var17) {
               }
            }
         }
      }
   }

   public static void importPreferences() {
      BufferedInputStream var0 = null;

      try {
         var0 = new BufferedInputStream(new FileInputStream(getOrCreateXmlFile(FILE_NAME)));
         importPreferences(var0);
      } catch (FileNotFoundException var10) {
         RRCLogger.log(100, 33, var10, "File Not Found Exception occurred when attempting to import Keyboard Macros from file: " + FILE_NAME);
      } finally {
         if (var0 != null) {
            try {
               var0.close();
               Object var12 = null;
            } catch (IOException var9) {
            }
         }
      }
   }

   public static boolean importPreferences(File var0) {
      boolean var1 = false;

      try {
         var0.createNewFile();
         FileInputStream var2 = new FileInputStream(var0);
         return importPreferences(var2);
      } catch (IOException var3) {
         RRCLogger.log(100, 33, var3, "IO Exception occurred when attempting to import Keyboard Macros from file: " + var0);
         return false;
      }
   }

   public static boolean importPreferences(InputStream var0) {
      try {
         Preferences.importPreferences(var0);
         return true;
      } catch (InvalidPreferencesFormatException var2) {
         RRCLogger.log(100, 33, var2, "Invalid Preferences Format Exception occurred when attempting to import Keyboard Macros from input stream");
         return false;
      } catch (IOException var3) {
         RRCLogger.log(100, 33, var3, "IO Exception occurred when attempting to import Keyboard Macros from input stream");
         return false;
      }
   }

   public void importSinglePreferenceInfo(String var1) {
      Preferences var2 = this.rootPrefs.node(var1);
      this.macroName = var2.get("name", "");
      this.hotKeyCombination = var2.getInt("hotKey", -1);
      this.macroSequence = var2.get("macroSequence", "");
   }

   public void importPreferences(String var1) {
      BufferedInputStream var2 = null;

      try {
         var2 = new BufferedInputStream(new FileInputStream(getOrCreateXmlFile(FILE_NAME)));
         Preferences.importPreferences(var2);
         Preferences var3 = this.rootPrefs.node(var1);
         this.macroName = var3.get("name", "");
         this.hotKeyCombination = var3.getInt("hotKey", -1);
         this.macroSequence = var3.get("macroSequence", "");
      } catch (InvalidPreferencesFormatException var14) {
         RRCLogger.log(
            100, 33, var14, "Invalid Preferences Format Exception occurred when attempting to import Keyboard Macro '" + var1 + "' from file: " + FILE_NAME
         );
      } catch (IOException var15) {
         RRCLogger.log(100, 33, var15, "IOException occurred when attempting to import Keyboard Macro '" + var1 + "' from file: " + FILE_NAME);
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var17 = null;
            } catch (IOException var13) {
            }
         }
      }
   }

   public static void deleteNode(String var0) {
      deleteNode(var0, true);
   }

   public static void deleteNode(String var0, boolean var1) {
      Preferences var2 = Preferences.userRoot().node("/KeyboardMacros");

      try {
         var2.node(var0).removeNode();
         if (var1) {
            exportPreferences();
         }
      } catch (BackingStoreException var4) {
         RRCLogger.log(100, 33, var4, "Backing Store Exception occurred when attempting to delete Keyboard Macros '" + var0);
      }
   }

   public static String[] returnNodes() {
      importPreferences();
      Preferences var0 = Preferences.userRoot().node("/KeyboardMacros");
      String[] var1 = null;

      try {
         var1 = var0.childrenNames();
      } catch (BackingStoreException var3) {
         RRCLogger.log(100, 33, var3, "Backing Store Exception occurred when attempting to get list of Keyboard Macros");
      }

      return var1;
   }

   public static File getOrCreateXmlFile(String var0) {
      File var1 = new File(var0);
      BufferedWriter var2 = null;

      try {
         if (!var1.exists()) {
            var1.createNewFile();
            var2 = new BufferedWriter(new FileWriter(var1));
            var2.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            var2.write("\n\n");
            var2.write("<!DOCTYPE preferences SYSTEM 'http://java.sun.com/dtd/preferences.dtd'>");
            var2.write("\n\n");
            var2.write("<preferences EXTERNAL_XML_VERSION=\"1.0\">");
            var2.write("\n  <root type=\"user\">");
            var2.write("\n    <map />\n    <node name=\"KeyboardMacros\">\n      <map />");
            var2.write("\n    </node>\n  </root>\n</preferences>");
            var2.flush();
         }
      } catch (IOException var12) {
         RRCLogger.log(100, 33, var12, "IO Exception occurred when attempting to check for and create Keyboard Macros file: " + var0);
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var14 = null;
            } catch (IOException var11) {
            }
         }
      }

      return var1;
   }

   public static boolean containsNode(String var0) {
      Preferences var1 = Preferences.userRoot().node("/KeyboardMacros");

      try {
         return var1.nodeExists(var0);
      } catch (BackingStoreException var3) {
         RRCLogger.log(100, 33, var3, "Backing Store Exception occurred when attempting to check for the existence of Keyboard Macro '" + var0 + "'");
         return false;
      }
   }

   public int getHotKeyCombination() {
      return this.hotKeyCombination;
   }

   public String getMacroName() {
      return this.macroName;
   }

   public String getMacroSequence() {
      return this.macroSequence;
   }

   public void setHotKeyCombination(int var1) {
      this.hotKeyCombination = var1;
   }

   public void setMacroName(String var1) {
      this.macroName = var1;
   }

   public void setMacroSequence(String var1) {
      this.macroSequence = var1;
   }

   public static File chooseXmlFile(String var0, int var1, java.awt.Component var2) {
      JFileChooser var3 = new JFileChooser() {
         @Override
         protected JDialog createDialog(java.awt.Component var1) throws HeadlessException {
            JDialog var2x = super.createDialog(var1);
            MPCUtil.jre17WorkaroundInheritAlwaysOnTop(var2x);
            return var2x;
         }
      };
      KeyboardMacrosPreferences.xmlFileFilter var4 = new KeyboardMacrosPreferences().new xmlFileFilter();
      var3.setFileFilter(var4);
      var3.setDialogTitle(var0);
      var3.setMultiSelectionEnabled(false);
      var3.setDialogType(var1);
      var3.setAcceptAllFileFilterUsed(false);
      if (System.getProperty("user.home") != null) {
         var3.setCurrentDirectory(new File(System.getProperty("user.home")));
      }

      int var5 = -1;
      if (var1 == 0) {
         var5 = var3.showOpenDialog(var2);
      } else if (var1 == 1) {
         var5 = var3.showSaveDialog(var2);
      }

      if (var5 == 0) {
         return var3.getSelectedFile().toString().endsWith(".xml") ? var3.getSelectedFile() : new File(var3.getSelectedFile().toString() + ".xml");
      } else {
         return null;
      }
   }

   public static Element getMacrosElement(File var0) {
      Document var1 = null;

      try {
         var1 = DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(var0);
      } catch (SAXException var6) {
         RRCLogger.log(100, 33, var6, "SAX Exception occurred when creating Document to read and find the Keyboard Macros element from file: " + var0);
         return null;
      } catch (IOException var7) {
         RRCLogger.log(100, 33, var7, "IO Exception occurred when creating Document to read and find the Keyboard Macros element from file: " + var0);
         return null;
      } catch (ParserConfigurationException var8) {
         RRCLogger.log(
            100, 33, var8, "Parser Configuration Exception occurred when creating Document to read and find the Keyboard Macros element from file: " + var0
         );
         return null;
      }

      Element var2 = var1.getDocumentElement();
      NodeList var3 = var2.getElementsByTagName("node");
      var2 = null;
      Object var4 = null;

      for (int var5 = 0; var5 < var3.getLength(); var5++) {
         var4 = var3.item(var5);
         if (var4.getNodeType() == 1 && ((Element)var4).getAttribute("name").equals("KeyboardMacros")) {
            var2 = (Element)var4;
         }
      }

      return var2;
   }

   public static TreeMap getValidMacros(NodeList var0) {
      TreeMap var1 = new TreeMap();
      KeyboardMacrosPreferences var2 = null;
      Object var3 = null;
      NodeList var4 = null;

      for (int var5 = 0; var5 < var0.getLength(); var5++) {
         if (var0.item(var5).getNodeType() == 1) {
            var4 = ((Element)var0.item(var5)).getElementsByTagName("entry");
            if (var4.getLength() >= 3) {
               var2 = new KeyboardMacrosPreferences();

               for (int var6 = 0; var6 < var4.getLength(); var6++) {
                  if (var4.item(var6).getNodeType() == 1) {
                     var3 = (Element)var4.item(var6);
                     if (var3.getAttribute("key").equals("name")) {
                        var2.setMacroName(var3.getAttribute("value"));
                     }

                     if (var3.getAttribute("key").equals("hotKey")) {
                        var2.setHotKeyCombination(Integer.parseInt(var3.getAttribute("value")));
                     }

                     if (var3.getAttribute("key").equals("macroSequence")) {
                        var2.setMacroSequence(var3.getAttribute("value"));
                     }
                  }
               }

               if (var2.getMacroName().length() > 0 && var2.getMacroSequence().length() > 0) {
                  var1.put(var2.getMacroName(), var2);
               }
            }
         }
      }

      return var1;
   }

   private class xmlFileFilter extends FileFilter {
      private xmlFileFilter() {
      }

      @Override
      public boolean accept(File var1) {
         return var1.getName().endsWith(".xml") || var1.isDirectory();
      }

      @Override
      public String getDescription() {
         return "XML Files (*.xml)";
      }
   }
}
