package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.smartcard.SmartCardCore;
import com.raritan.smartcard.SmartCardInitException;
import com.raritan.tools.ui.ScreenContext;
import java.awt.event.ActionEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.text.MessageFormat;
import java.util.ArrayList;
import javaclientlib.clientlib.IKvmData;
import javaclientlib.tr.TRLIB_UPDATEINFO;
import javaclientlib.tr.TRRSP_NEW_VIDEO_MODE_DATA;
import javaclientlib.tr.TRSRVR_TARGET_PARAMS;
import javaclientlib.utils.RRCLogger;
import javax.swing.AbstractAction;
import javax.swing.SwingUtilities;
import nn.pp.audiocore.AudioAdapter;
import nn.pp.audiocore.AudioCore;
import nn.pp.audiocore.AudioCoreFactory;
import nn.pp.audiocore.AudioDevice;
import nn.pp.audiocore.AudioEventListener;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.common.audio.AudioBean;
import nn.pp.common.audio.AudioIndexHelper;
import nn.pp.common.smartcard.SmartCardBean;
import nn.pp.common.smartcard.SmartCardIndexHelper;
import nn.pp.core.INotificationEvent;
import nn.pp.core.Platform;
import nn.pp.ext.pref.IApplicationPreferences;
import nn.pp.rccore.IAudioStatusExSupport;
import nn.pp.rccore.IKvmPort;
import nn.pp.rccore.ILicenseSupport;
import nn.pp.vmcore.WorkstationUnlockDetectorFactory;

public class KvmPort extends Port implements IKvmData {
   private KvmStream kvmStream;
   private DeviceView aDeviceView;
   private boolean singleCursorMode;
   private KvmPort.KvmMouse kvmMouse;
   private static final int OVERRIDE_LOCAL_USER = 1;
   private VMConfigInfo vmConfigInfo;
   private volatile VMConfigInfo defaultVMConfigInfo;
   private USBProfilesInfo usbProfilesInfo;
   private SmartCardIndexHelper smartCardIndexHelper = new SmartCardIndexHelper(null);
   private AudioIndexHelper audioIndexHelper = new AudioIndexHelper(null);
   private final KvmPortPermissionHelper portPermissionHelper = new KvmPortPermissionHelper(this);
   private final KvmPort.SmartCardAction smartCardAction = new KvmPort.SmartCardAction();
   private final KvmPort.SelectCardReaderAction selectCardReaderAction = new KvmPort.SelectCardReaderAction();
   private final KvmPort.AudioAction audioAction = new KvmPort.AudioAction();
   private final KvmPort.ConnectAudioAction connectAudioAction = new KvmPort.ConnectAudioAction();
   private final KvmPort.AudioSettingsAction audioSettingsAction = new KvmPort.AudioSettingsAction();
   private volatile boolean rfbSwitchCompleted;
   private final AudioCore audiocore = AudioCoreFactory.loadAudioCore(RRCLogger.getLogger());
   private boolean audioConnected = false;
   private KvmPort.PortAudioAdapter audioAdapter = new KvmPort.PortAudioAdapter();
   private ILicenseSupport license;
   private IAudioStatusExSupport audioEx;

   private boolean isMassStorageConnected(int var1) {
      VMConfigInfo var2 = this.getVmConfigInfo();

      for (VMInterfaceInfo var4 : var2.getListofInterfaces()) {
         if (var4.isInUse()) {
            MassStorageDevice var5 = var4.getMassStorageDevice(var1);
            if (var5 != null && var5.isConnected()) {
               return true;
            }
         }
      }

      return false;
   }

   private boolean isLocalMSConnected() {
      return this.isMassStorageConnected(4);
   }

   private boolean isCdIsoMSConnected() {
      return this.isMassStorageConnected(1);
   }

   private int getMassStorageIndex(int var1) {
      VMConfigInfo var2 = this.getVmConfigInfo();

      for (VMInterfaceInfo var4 : var2.getListofInterfaces()) {
         MassStorageDevice var5 = var4.getMassStorageDevice(var1);
         if (var5 != null) {
            return var4.getInterfaceID();
         }
      }

      return -1;
   }

   private int getLocalMsIndex() {
      return this.getMassStorageIndex(4);
   }

   private int getCdIsoMsIndex() {
      return this.getMassStorageIndex(1);
   }

   private void audioConnectionClosed(Exception var1) {
      if (this.isConnected()) {
         String var2 = var1 != null ? var1.getMessage() : null;
         String var3;
         if (var2 == null) {
            var3 = this.bundle.getString("Audio.audioConnectionClosed");
         } else {
            var3 = MessageFormat.format(this.bundle.getString("Audio.audioConnectionClosedWithReason"), var2);
         }

         RRCLogger.log(150, var3);
         this.getView().getAudioErrorsAndMessagesHandler().errorMessage(this.getView().getShell(), var3, this.getViewName());
         this.connectAudioAction.setConnectionState(false);
      }
   }

   private static VMConfigInfo getDefaultVMConfigInfo() {
      ArrayList var0 = new ArrayList();
      ArrayList var1 = new ArrayList();
      var1.add(new MassStorageDevice(1));
      var0.add(new VMInterfaceInfo(0, var1));
      var1 = new ArrayList();
      var1.add(new MassStorageDevice(4));
      var0.add(new VMInterfaceInfo(1, var1));
      return new VMConfigInfo(var0);
   }

   public KvmPort(ScreenContext var1) {
      super(var1);
      this.singleCursorMode = false;
      this.kvmMouse = new KvmPort.KvmMouse();
      this.smartCardAction.addPropertyChangeListener(new PropertyChangeListener() {
         @Override
         public void propertyChange(PropertyChangeEvent var1) {
            if (var1.getPropertyName().equals("enabled")) {
               KvmPort.this.selectCardReaderAction.setEnabled((Boolean)var1.getNewValue());
               if (KvmPort.this.scrContext != null) {
                  ((RRCScreenContext)KvmPort.this.scrContext).getSmartCardObserver().forceNotifyObservers(null);
               }
            } else if (var1.getPropertyName().equals("ShortDescription")) {
               String var2 = (String)var1.getNewValue();
               if (null == var2) {
                  var2 = KvmPort.this.bundle.getString("SmartCardSelectCardReader.name");
               }

               KvmPort.this.selectCardReaderAction.putValue("ShortDescription", var2);
               if (KvmPort.this.scrContext != null) {
                  ((RRCScreenContext)KvmPort.this.scrContext).getSmartCardObserver().forceNotifyObservers(null);
               }
            }
         }
      });
      this.audioAction.addPropertyChangeListener(new PropertyChangeListener() {
         @Override
         public void propertyChange(PropertyChangeEvent var1) {
            if (var1.getPropertyName().equals("enabled")) {
               KvmPort.this.connectAudioAction.setEnabled((Boolean)var1.getNewValue());
               if (KvmPort.this.scrContext != null) {
                  ((RRCScreenContext)KvmPort.this.scrContext).getAudioObserver().forceNotifyObservers(null);
               }
            } else if (var1.getPropertyName().equals("ShortDescription")) {
               String var2 = (String)var1.getNewValue();
               if (null == var2) {
                  var2 = KvmPort.this.bundle.getString("Audio.connectAudio");
               }

               KvmPort.this.connectAudioAction.putValue("ShortDescription", var2);
               if (KvmPort.this.scrContext != null) {
                  ((RRCScreenContext)KvmPort.this.scrContext).getAudioObserver().forceNotifyObservers(null);
               }
            }
         }
      });
      this.audiocore.addAudioEventListener(this.audioAdapter);
   }

   @Override
   public Stream getStream() {
      return this.kvmStream;
   }

   @Override
   public DeviceView getView() {
      return this.aDeviceView;
   }

   public void setView(DeviceView var1) {
      this.aDeviceView = var1;
      if (this.aDeviceView != null) {
         DevicePreferences var2 = this.device.getDevPrefs();
         if (var2 != null) {
            this.aDeviceView.setUpdateFrequency(200 / (var2.getFramesPerSecond() + 1));
         } else {
            this.aDeviceView.setUpdateFrequency(50L);
         }
      }
   }

   public boolean isStreamConnected() {
      return this.kvmStream != null ? this.kvmStream.isConnected() : false;
   }

   @Override
   public void connect() {
      if (!this.isConnected()) {
         if (this.kvmStream == null) {
            RRCScreenContext var1 = (RRCScreenContext)this.getDevice().getContext();
            IApplicationPreferences var2 = var1.getAppSettings();
            this.kvmStream = new KvmStream(this, var2.getKeyboardType());
            DevicePreferences var3 = this.device.getDevPrefs();
            if (var3 != null) {
               this.kvmStream.setMinFrameUpdateTime(200 / (var3.getFramesPerSecond() + 1));
            }
         }

         String var4 = this.getId();
         Component var5 = this.getParent();
         if (var5 != null && var5 instanceof Paragon) {
            Paragon var6 = (Paragon)var5;
            var4 = var6.getPortal();
         }

         if (this.kvmStream.startVideoStream(var4, this.getTargetDeviceId(), 0)) {
            this.setConnected(true);
            this.setState("CONNECTED");
            this.firePropertyChange("DEVICE_PORT_VIEW_ADD", null, null);
         }
      }
   }

   public void forceConnection() {
      if (this.kvmStream == null) {
         RRCScreenContext var1 = (RRCScreenContext)this.getDevice().getContext();
         IApplicationPreferences var2 = var1.getAppSettings();
         this.kvmStream = new KvmStream(this, var2.getKeyboardType());
         DevicePreferences var3 = this.device.getDevPrefs();
         if (var3 != null) {
            this.kvmStream.setMinFrameUpdateTime(200 / (var3.getFramesPerSecond() + 1));
         }
      }

      String var4 = this.getId();
      Component var5 = this.getParent();
      if (var5 != null && var5 instanceof Paragon) {
         Paragon var6 = (Paragon)var5;
         var4 = var6.getPortal();
      }

      if (this.kvmStream.startVideoStream(var4, this.getTargetDeviceId(), 1)) {
         this.setConnected(true);
         this.setState("CONNECTED");
         this.firePropertyChange("DEVICE_PORT_VIEW_ADD", null, null);
      }
   }

   @Override
   public void disconnect() {
      this.disconnect(true);
   }

   public void disconnect(boolean var1) {
      this.disconnectDevice();
      super.disconnect();
      if (this.isBladePort() && this.getParentBladeChassis() != null) {
         this.getParentBladeChassis().setState("AVAILABLE");
      }

      if (this.aDeviceView != null) {
         this.aDeviceView.removeListeners();
      }

      this.aDeviceView = null;
      this.singleCursorMode = false;
      this.setDeviceView(null);
      this.setVmConfigInfo(null);
      this.defaultVMConfigInfo = null;
      this.setUsbProfilesInfo(null);
      this.rfbSwitchCompleted = false;
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).clearStatusBarLabels();
      this.firePropertyChange("DEVICE_PORT_VIEW_REMOVE", null, null);
      if (var1) {
         if (this.isPrimaryPort()) {
            for (Port var3 : this.getSecondaryPorts()) {
               if (var3 != null && var3 instanceof KvmPort) {
                  ((KvmPort)var3).disconnect(false);
               }
            }
         } else if (this.isSecondaryPort()) {
            Port var4 = this.getPrimaryPort();
            if (var4 != null) {
               var4.disconnect();
            }
         }
      }
   }

   public boolean disconnectDevice() {
      if (!this.isConnected()) {
         return false;
      } else {
         boolean var1 = true;
         this.setConnected(false);
         if (this.aDeviceView != null) {
            var1 = this.aDeviceView.disconnect();
         }

         if (this.kvmStream != null && this.kvmStream.isConnected()) {
            this.kvmStream.stopVideoStream();
         }

         this.kvmStream = null;
         this.setActive(false);
         this.setState("AVAILABLE");
         if (this.equals(((IPReach)this.getBaseDevice()).getActiveKvmPort())) {
            ((IPReach)this.getBaseDevice()).setActiveKvmPort(null);
         }

         if (this.audiocore != null) {
            this.audiocore.disconnect();
         }

         this.audioConnected = false;
         return var1;
      }
   }

   public void setUpKvmMouse(TRSRVR_TARGET_PARAMS var1) {
      this.kvmMouse.setUp(new String(var1.getIConnection()), var1.getICaps(), var1.getISettings());
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            MPCUtil.notifyObservers((RRCScreenContext)KvmPort.this.scrContext, KvmPort.this);
         }
      });
   }

   public KvmPort.KvmMouse getKvmMouse() {
      return this.kvmMouse;
   }

   @Override
   public void notify(final int var1, final int var2) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            if (KvmPort.this.aDeviceView != null) {
               KvmPort.this.aDeviceView.notify(var1, var2);
            }
         }
      });
   }

   @Override
   public void setUpdateFrequency(long var1) {
      if (this.aDeviceView != null) {
         this.aDeviceView.setUpdateFrequency(var1);
      }
   }

   @Override
   public void updateNotify(TRLIB_UPDATEINFO var1) {
      if (this.aDeviceView != null) {
         this.aDeviceView.updateNotify(var1);
      }
   }

   @Override
   public void newVideoModeNotify(final TRRSP_NEW_VIDEO_MODE_DATA var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            if (KvmPort.this.aDeviceView != null) {
               KvmPort.this.aDeviceView.newVideoModeNotify(var1);
            }
         }
      });
   }

   public void toggleSingleMouseCursor() {
      this.singleCursorMode = !this.singleCursorMode;
      if (this.aDeviceView != null) {
         this.doSetMouseMode();
      }
   }

   private void doSetMouseMode() {
      this.aDeviceView.setSingleCursor(this.singleCursorMode);
   }

   public boolean isSingleCursorMode() {
      return this.singleCursorMode;
   }

   public void initSingleCursorMode() {
   }

   public synchronized VMConfigInfo getVmConfigInfo() {
      if (this.vmConfigInfo != null) {
         return this.vmConfigInfo;
      } else if ("VM".equals(this.getPortType())) {
         if (this.defaultVMConfigInfo == null) {
            this.defaultVMConfigInfo = getDefaultVMConfigInfo();
         }

         return this.defaultVMConfigInfo;
      } else {
         return null;
      }
   }

   public synchronized void setVmConfigInfo(VMConfigInfo var1) {
      this.vmConfigInfo = var1;
      if (var1 != null) {
         PropertyChangeListener var2 = new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent var1) {
               if (var1.getPropertyName().equals("connected")) {
                  KvmPort.this.smartCardAction.evaluateEnabled();
                  KvmPort.this.audioAction.evaluateEnabled();
               }
            }
         };

         for (VMInterfaceInfo var5 : var1.getListofInterfaces()) {
            for (MassStorageDevice var8 : var5.getListofMassStorageDev()) {
               var8.addPropertyChangeListener(var2);
            }
         }
      }
   }

   public synchronized USBProfilesInfo getUsbProfilesInfo() {
      return this.usbProfilesInfo;
   }

   public synchronized void setUsbProfilesInfo(USBProfilesInfo var1) {
      this.usbProfilesInfo = var1;
   }

   @Override
   public void setConcurrUsers(int var1) {
      super.setConcurrUsers(var1);
      this.smartCardAction.setUsersCount(var1);
      this.audioAction.setUsersCount(var1);
   }

   public void setLicenseSupport(ILicenseSupport var1) {
      this.license = var1;
   }

   public void setAudioEx(IAudioStatusExSupport var1) {
      this.audioEx = var1;
   }

   public String getTargetSpeakerFormat() {
      if (this.audioEx != null) {
         IAudioStatusExSupport.AudioStatus var1 = this.audioEx.getSpeakerStatus();
         if (var1 != null && var1.isConnected()) {
            return var1.getFormat();
         }
      }

      return null;
   }

   public String getTargetCaptureFormat() {
      if (this.audioEx != null) {
         IAudioStatusExSupport.AudioStatus var1 = this.audioEx.getMicrophoneStatus();
         if (var1 != null && var1.isConnected()) {
            return var1.getFormat();
         }
      }

      return null;
   }

   public void updateLicenses() {
      this.smartCardAction.evaluateEnabled();
      this.audioAction.evaluateEnabled();
   }

   public void setSmartCardIndexHelper(SmartCardIndexHelper var1) {
      this.smartCardIndexHelper = var1;
      this.smartCardAction.setSmartCardAvailable();
   }

   public void setAudioIndexHelper(AudioIndexHelper var1) {
      this.audioIndexHelper = var1;
      this.audioAction.setAudioAvailable();
   }

   public boolean isRfbSwitchCompleted() {
      return this.rfbSwitchCompleted;
   }

   public void setRfbSwitchCompleted(boolean var1) {
      this.rfbSwitchCompleted = var1;
      this.smartCardAction.setSwitchCompleted(var1);
      this.audioAction.setSwitchCompleted(var1);
   }

   public KvmPort.SmartCardAction getSmartCardAction() {
      return this.smartCardAction;
   }

   public KvmPort.AudioAction getAudioAction() {
      return this.audioAction;
   }

   public KvmPort.ConnectAudioAction getConnectAudioAction() {
      return this.connectAudioAction;
   }

   public KvmPort.AudioSettingsAction getAudioSettingsAction() {
      return this.audioSettingsAction;
   }

   public AudioCore getAudioCore() {
      return this.audiocore;
   }

   @Override
   public void setPortType(String var1) {
      super.setPortType(var1);
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            KvmPort.this.smartCardAction.evaluateEnabled();
            KvmPort.this.audioAction.evaluateEnabled();
         }
      });
   }

   public KvmPortPermissionHelper getPortPermissionHelper() {
      return this.portPermissionHelper;
   }

   public KvmPort.SelectCardReaderAction getSelectCardReaderAction() {
      return this.selectCardReaderAction;
   }

   public void reevaluatePermissions() {
      this.audioAction.evaluateEnabled();
      this.smartCardAction.evaluateEnabled();
   }

   abstract class AdditionalVmAction extends AbstractAction {
      protected int usersCount = 1;

      public AdditionalVmAction(String var2) {
         super(var2);
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
      }

      public void setUsersCount(int var1) {
         this.usersCount = var1;
         this.evaluateEnabled();
      }

      public boolean isSwitchCompleted() {
         return KvmPort.this.isRfbSwitchCompleted();
      }

      public void setSwitchCompleted(boolean var1) {
         this.evaluateEnabled();
      }

      public abstract void evaluateEnabled();
   }

   public class AudioAction extends KvmPort.AdditionalVmAction {
      public AudioAction() {
         super(KvmPort.this.bundle.getString("Audio.name"));
         this.setEnabled(false);
      }

      private void setAudioAvailable() {
         this.evaluateEnabled();
      }

      private boolean isBothVMMounted() {
         int var1 = 0;

         for (VMInterfaceInfo var4 : KvmPort.this.vmConfigInfo.getListofInterfaces()) {
            if (var4.isInUse()) {
               var1++;
            }
         }

         if (KvmPort.this.getView().getSmartCardStatusListener().isConnected()) {
            var1++;
         }

         return var1 >= 2;
      }

      @Override
      public void evaluateEnabled() {
         boolean var1 = KvmPort.this.getPortType().equals("VM");
         boolean var2 = KvmPort.this.license == null ? true : KvmPort.this.license.isFeatureLicensed("audio");
         this.setEnabled(
            Platform.isAudioSupported()
               && this.isSwitchCompleted()
               && KvmPort.this.audiocore != null
               && var2
               && AudioDevice.audioDevicesAvailable()
               && var1
               && KvmPort.this.audioIndexHelper.isAudioAvailable()
               && KvmPort.this.portPermissionHelper.getKvmPermission() == IKvmPort.KvmPermission.CONTROL
               && !this.isBothVMMounted()
               && KvmPort.this.isTopLeft()
         );
         if (this.isSwitchCompleted() && !this.isEnabled()) {
            String var3 = "";
            if (!var2) {
               var3 = KvmPort.this.bundle.getString("AudioTooltip.License");
            } else if (!Platform.isAudioSupported()) {
               var3 = KvmPort.this.bundle.getString("AudioTooltip.RequiredOs");
            } else if (!AudioDevice.audioDevicesAvailable()) {
               var3 = KvmPort.this.bundle.getString("AudioTooltip.NoDevices");
            } else if (var1 && KvmPort.this.audioIndexHelper.isAudioAvailable()) {
               if (KvmPort.this.portPermissionHelper.getKvmPermission() != IKvmPort.KvmPermission.CONTROL) {
                  String var6 = MessageFormat.format(KvmPort.this.bundle.getString("AudioTooltip.Denied"), KvmPort.this.getViewName());
                  String var7 = KvmPort.this.bundle.getString("CommonTooltip.ContactSysadmin");
                  var3 = var6 + "\n" + var7;
               } else if (this.isBothVMMounted()) {
                  var3 = KvmPort.this.bundle.getString("AudioTooltip.UsbResources");
               } else if (!KvmPort.this.isTopLeft()) {
                  var3 = KvmPort.this.bundle.getString("AudioTooltip.NotTopLeft");
               }
            } else {
               String var4 = MessageFormat.format(KvmPort.this.bundle.getString("AudioTooltip.NotAVmCim"), KvmPort.this.getViewName());
               String var5 = KvmPort.this.bundle.getString("CommonTooltip.ContactSysadmin");
               var3 = var4 + "\n" + var5;
            }

            RRCLogger.log(300, "AudioMenu is disabled because of - " + var3);
            this.putValue("ShortDescription", "<html>" + var3.replace("\n", "<br>") + "</html>");
         } else {
            this.putValue("ShortDescription", null);
         }
      }
   }

   class AudioSettingsAction extends AbstractAction {
      public AudioSettingsAction() {
         super(KvmPort.this.bundle.getString("Audio.audioSettings"));
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
      }
   }

   public class ConnectAudioAction extends AbstractAction {
      private AudioBean bean;

      public ConnectAudioAction() {
         super(KvmPort.this.bundle.getString("Audio.connectAudio"));
         this.setConnectionState(false);
      }

      public void disconnectAudio() {
         if (KvmPort.this.audiocore != null) {
            KvmPort.this.audiocore.disconnect();
         }

         this.setConnectionState(false);
         KvmPort.this.audiocore.removeNotificationListener(KvmPort.this.audioAdapter);
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
      }

      public AudioBean getAudioBean() {
         RemoteConsoleParameters var1 = KvmPort.this.getView().getRemoteConsoleParameters();
         if (this.bean == null) {
            this.bean = new AudioBean(
               var1.host,
               var1.tcpPort,
               var1.ssl,
               var1.username,
               var1.password,
               var1.rdmSession,
               var1.proxyConnectionIdVM,
               var1.proxyUseSSL,
               var1.ericKey,
               KvmPort.this.getView().getAudioErrorsAndMessagesHandler()
            );
         }

         this.bean.setRfbSessionId(KvmPort.this.getView().getRfbSessionId());
         int var2 = -1;
         int var3 = -1;
         if (KvmPort.this.selectCardReaderAction.smartCardBean != null) {
            var2 = KvmPort.this.selectCardReaderAction.smartCardBean.getMsindex();
         }

         if (KvmPort.this.audioIndexHelper.isAudioAvailable()) {
            var3 = KvmPort.this.audioIndexHelper
               .getAudioIndex(
                  KvmPort.this.isLocalMSConnected(),
                  KvmPort.this.isCdIsoMSConnected(),
                  KvmPort.this.getView().getSmartCardStatusListener().isConnected(),
                  KvmPort.this.getLocalMsIndex(),
                  KvmPort.this.getCdIsoMsIndex(),
                  var2
               );
         }

         this.bean.setMsindex(var3);
         this.bean.setPortId(KvmPort.this.getUniquePortId());
         return this.bean;
      }

      public void setConnectionState(boolean var1) {
         KvmPort.this.audioConnected = var1;
         this.putValue("connected", var1);
         if (KvmPort.this.scrContext != null) {
            ((RRCScreenContext)KvmPort.this.scrContext).getAudioObserver().forceNotifyObservers(null);
         }

         KvmPort.this.smartCardAction.evaluateEnabled();
         if (!var1) {
            this.bean = null;
         }
      }

      public boolean isConnected() {
         return KvmPort.this.audioConnected;
      }
   }

   public class KvmMouse {
      private int mouseAbsolute;
      private int mouseIntelligent;
      private int mouseStandard;
      private int mouseCapability;
      private String mouseConnection = "ps2";
      public static final String ITYPE_MOUSE = "Mouse";
      public static final String ITYPE_KEYBOARD = "Keyboard";
      public static final String ICONNECTION_PS2 = "ps2";
      public static final String ICONNECTION_USB = "usb";
      public static final String ICONNECTION_UNKNOWN = "unknown";
      private static final int MOUSE_CAP_IMPOSSIBLE = 0;
      private static final int MOUSE_CAP_CAN_BE = 1;
      private static final int MOUSE_CAP_IS_RIGHT_NOW = 2;

      public KvmMouse() {
         this.mouseStandard = 2;
         this.mouseIntelligent = 0;
         this.mouseAbsolute = 0;
      }

      private void setUp(String var1, int var2, int var3) {
         if (var1.startsWith("ps2")) {
            this.mouseConnection = "ps2";
         } else if (var1.startsWith("usb")) {
            this.mouseConnection = "usb";
         } else {
            this.mouseConnection = "unknown";
         }

         if ((var2 & 2) != 0) {
            this.mouseAbsolute = 1;
         } else {
            this.mouseAbsolute = 0;
         }

         if ((var2 & 1) == 1) {
            this.mouseIntelligent = 1;
         } else {
            this.mouseIntelligent = 0;
         }

         this.mouseStandard = 1;
         var3 &= var2;
         if ((var3 & 2) != 0) {
            this.mouseAbsolute = 2;
         } else if ((var3 & 1) == 1) {
            this.mouseIntelligent = 2;
         } else {
            this.mouseStandard = 2;
         }
      }

      public boolean enableAbsoluteMouse() {
         return this.mouseAbsolute >= 1;
      }

      public boolean enableIntelligentMouse() {
         return this.mouseIntelligent >= 1;
      }

      public boolean enableStandardMouse() {
         return this.mouseStandard >= 1;
      }

      public boolean isAbsoluteMouse() {
         return this.mouseAbsolute == 2;
      }

      public boolean isStandardMouse() {
         return this.mouseStandard == 2;
      }

      public boolean isIntelligentMouse() {
         return this.mouseIntelligent == 2;
      }
   }

   private class PortAudioAdapter extends AudioAdapter {
      private PortAudioAdapter() {
      }

      @Override
      public void disconnected(Exception var1) {
         KvmPort.this.audioConnectionClosed(var1);
         KvmPort.this.audiocore.removeNotificationListener(this);
      }

      @Override
      public void audioConnected(boolean var1) {
         KvmPort.this.connectAudioAction.setConnectionState(true);
         KvmPort.this.audiocore.addNotificationListener(this);
      }

      @Override
      public void receivedNotification(INotificationEvent var1) {
         KvmPort.this.getView().getAudioErrorsAndMessagesHandler().notificationReceived(KvmPort.this.getView().getShell(), var1, KvmPort.this.getViewName());
      }

      @Override
      public void playbackDeviceStateChanged(AudioEventListener.DeviceState var1) {
         KvmPort.this.getView().setPlaybackState(var1);
      }

      @Override
      public void captureDeviceStateChanged(AudioEventListener.DeviceState var1) {
         KvmPort.this.getView().setCaptureState(var1);
      }
   }

   public class SelectCardReaderAction extends AbstractAction {
      private SmartCardBean smartCardBean;

      public SelectCardReaderAction() {
         super(KvmPort.this.bundle.getString("SmartCardSelectCardReader.name"));
         this.setEnabled(false);
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
      }

      public SmartCardBean getConfiguredSmartCardBean() {
         RemoteConsoleParameters var1 = KvmPort.this.getView().getRemoteConsoleParameters();
         if (this.smartCardBean == null) {
            this.smartCardBean = new SmartCardBean(
               var1.host,
               var1.tcpPort,
               true,
               var1.rdmSession,
               var1.ericKey,
               KvmPort.this.getView().getSmartCardErrorsAndMessagesHandler(),
               WorkstationUnlockDetectorFactory.getWorkstationUnlockDetector()
            );
            DeviceView.SmartCardStatusListeners var2 = KvmPort.this.getView().getSmartCardStatusListener();
            this.smartCardBean.addPropertyChangeListener("CARD_READER_MOUNTED", var2);
            this.smartCardBean.addPropertyChangeListener("DISCONNECTED", var2);
            this.smartCardBean.addPropertyChangeListener("QUIT_NOTIFICATION", var2);
            this.smartCardBean.addPropertyChangeListener("NOTIFICATION_FROM_SERVER", var2);
            this.smartCardBean.addPropertyChangeListener("NO_PROTO_SPPORTED", var2);
            this.smartCardBean.addPropertyChangeListener("CANCEL_ISSUED", var2);
            this.smartCardBean.addPropertyChangeListener("QUIT_ISSUED", var2);
         }

         int var4 = -1;
         int var3 = -1;
         if (KvmPort.this.connectAudioAction.bean != null) {
            var3 = KvmPort.this.connectAudioAction.bean.getMsindex();
         }

         if (KvmPort.this.smartCardIndexHelper.isSmartCardAvailable()) {
            var4 = KvmPort.this.smartCardIndexHelper
               .getSmartCardIndex(
                  KvmPort.this.isLocalMSConnected(),
                  KvmPort.this.isCdIsoMSConnected(),
                  KvmPort.this.audioConnected,
                  KvmPort.this.getLocalMsIndex(),
                  KvmPort.this.getCdIsoMsIndex(),
                  var3
               );
         }

         this.smartCardBean.setMsindex(var4);
         this.smartCardBean.setRfbSessionId(KvmPort.this.getView().getRfbSessionId());
         this.smartCardBean.setTag(KvmPort.this.getViewName());
         return this.smartCardBean;
      }

      public SmartCardBean getSmartCardBean() {
         return this.smartCardBean;
      }

      public void resetSmartCardBean() {
         this.smartCardBean = null;
      }
   }

   public class SmartCardAction extends KvmPort.AdditionalVmAction {
      public SmartCardAction() {
         super(KvmPort.this.bundle.getString("SmartCard.name"));
         this.setEnabled(false);
      }

      public void setSmartCardAvailable() {
         this.evaluateEnabled();
      }

      private boolean isBothVMMounted() {
         int var1 = 0;

         for (VMInterfaceInfo var4 : KvmPort.this.vmConfigInfo.getListofInterfaces()) {
            if (var4.isInUse()) {
               var1++;
            }
         }

         if (KvmPort.this.audioConnected) {
            var1++;
         }

         return var1 >= 2;
      }

      @Override
      public void evaluateEnabled() {
         boolean var1 = KvmPort.this.license == null ? true : KvmPort.this.license.isFeatureLicensed("smartcard");

         assert SwingUtilities.isEventDispatchThread();

         if (this.isSwitchCompleted()) {
            SmartCardCore var2 = ((RRCScreenContext)KvmPort.this.scrContext).getSmartCardCore();
            SmartCardInitException.ExceptionCause var3 = ((RRCScreenContext)KvmPort.this.scrContext).getSmartCardExceptionCause();
            boolean var4 = KvmPort.this.getPortType().equals("VM");
            this.setEnabled(
               this.isSwitchCompleted()
                  && var2 != null
                  && var1
                  && var4
                  && KvmPort.this.smartCardIndexHelper.isSmartCardAvailable()
                  && KvmPort.this.portPermissionHelper.getKvmPermission() == IKvmPort.KvmPermission.CONTROL
                  && this.usersCount == 1
                  && !this.isBothVMMounted()
                  && KvmPort.this.isTopLeft()
            );
            if (this.isSwitchCompleted() && !this.isEnabled()) {
               String var7 = "";
               if (!var1) {
                  var7 = KvmPort.this.bundle.getString("SmartCardTooltip.License");
               } else if (var2 == null) {
                  switch (var3) {
                     case UNSUPPORTED_JRE:
                        var7 = KvmPort.this.bundle.getString("SmartCardTooltip.RequiredJvm");
                        break;
                     case NO_SUPPORTED_SMARTCARD_IMPL:
                        var7 = KvmPort.this.bundle.getString("SmartCardTooltip.RequiredEnvironment");
                        break;
                     case UNSUPPORTED_OS:
                        var7 = KvmPort.this.bundle.getString("SmartCardTooltip.RequiredOs");
                        break;
                     case UNKNOWN_ERROR:
                        var7 = KvmPort.this.bundle.getString("SmartCardTooltip.UnknownError")
                           + "\n"
                           + KvmPort.this.bundle.getString("CommonTooltip.ContactSysadmin");
                  }
               } else if (var4 && KvmPort.this.smartCardIndexHelper.isSmartCardAvailable()) {
                  if (KvmPort.this.portPermissionHelper.getKvmPermission() != IKvmPort.KvmPermission.CONTROL) {
                     String var8 = MessageFormat.format(KvmPort.this.bundle.getString("SmartCardTooltip.Denied"), KvmPort.this.getViewName());
                     String var9 = KvmPort.this.bundle.getString("CommonTooltip.ContactSysadmin");
                     var7 = var8 + "\n" + var9;
                  } else if (this.usersCount != 1) {
                     var7 = MessageFormat.format(KvmPort.this.bundle.getString("SmartCardTooltip.Exclusive"), KvmPort.this.getViewName());
                  } else if (this.isBothVMMounted()) {
                     var7 = KvmPort.this.bundle.getString("SmartCardTooltip.UsbResources");
                  } else if (!KvmPort.this.isTopLeft()) {
                     var7 = KvmPort.this.bundle.getString("SmartCardTooltip.NotTopLeft");
                  }
               } else {
                  String var5 = MessageFormat.format(KvmPort.this.bundle.getString("SmartCardTooltip.NotAVmCim"), KvmPort.this.getViewName());
                  String var6 = KvmPort.this.bundle.getString("CommonTooltip.ContactSysadmin");
                  var7 = var5 + "\n" + var6;
               }

               RRCLogger.log(300, "SmartCardMenu is disabled because of - " + var7);
               this.putValue("ShortDescription", "<html>" + var7.replace("\n", "<br>") + "</html>");
            } else {
               this.putValue("ShortDescription", null);
            }
         }
      }
   }
}
