package com.raritan.rrc.data;

import java.util.Collection;
import java.util.Vector;
import nn.pp.rccore.IKvmPort;

public class KvmPortPermissionHelper {
   private final KvmPort port;
   private KvmPortPermissionHelper.KvmPermission ccPerms;
   private KvmPortPermissionHelper.KvmPermission devicePerms;
   private KvmPortPermissionHelper.VmPermission ccPermsVm;
   private KvmPortPermissionHelper.VmPermission devicePermsVm;

   public KvmPortPermissionHelper(KvmPort var1) {
      this.port = var1;
   }

   public void setKvmPermission(KvmPortPermissionHelper.KvmPermission var1) {
      if (var1.isCCPerms) {
         this.ccPerms = var1;
      } else {
         this.devicePerms = var1;
      }
   }

   public void setVmPermission(KvmPortPermissionHelper.VmPermission var1) {
      if (var1.isCCPerms) {
         this.ccPermsVm = var1;
      } else {
         this.devicePermsVm = var1;
      }
   }

   private IKvmPort.KvmPermission getKvmPermissionInternal() {
      if (this.ccPerms != null) {
         return this.ccPerms.perms;
      } else {
         return this.devicePerms != null ? this.devicePerms.perms : IKvmPort.KvmPermission.DENY;
      }
   }

   public IKvmPort.KvmPermission getKvmPermission() {
      Vector var1 = new Vector();
      var1.add(this.getKvmPermissionInternal());

      for (Port var3 : this.port.getAssociatedPorts()) {
         if (var3.getPortStatus() != 0) {
            var1.add(((KvmPort)var3).getPortPermissionHelper().getKvmPermissionInternal());
         }
      }

      return getMostRestrictiveKvmPermission(var1);
   }

   private IKvmPort.VmPermission getVmPermissionInternal() {
      if (this.ccPermsVm != null) {
         return this.ccPermsVm.perms;
      } else {
         return this.devicePerms != null ? this.devicePermsVm.perms : IKvmPort.VmPermission.DENY;
      }
   }

   public IKvmPort.VmPermission getVmPermission() {
      Vector var1 = new Vector();
      var1.add(this.getVmPermissionInternal());

      for (Port var3 : this.port.getAssociatedPorts()) {
         if (var3.getPortStatus() != 0) {
            var1.add(((KvmPort)var3).getPortPermissionHelper().getVmPermissionInternal());
         }
      }

      return getMostRestrictiveVmPermission(var1);
   }

   public static IKvmPort.KvmPermission getMostRestrictiveKvmPermission(Collection<IKvmPort.KvmPermission> var0) {
      IKvmPort.KvmPermission var1 = IKvmPort.KvmPermission.CONTROL;

      for (IKvmPort.KvmPermission var3 : var0) {
         if (var3 == IKvmPort.KvmPermission.DENY) {
            return IKvmPort.KvmPermission.DENY;
         }

         if (var3 == IKvmPort.KvmPermission.VIEW && var1 == IKvmPort.KvmPermission.CONTROL) {
            var1 = IKvmPort.KvmPermission.VIEW;
         }
      }

      return var1;
   }

   public static IKvmPort.VmPermission getMostRestrictiveVmPermission(Collection<IKvmPort.VmPermission> var0) {
      IKvmPort.VmPermission var1 = IKvmPort.VmPermission.READWRITE;

      for (IKvmPort.VmPermission var3 : var0) {
         if (var3 == IKvmPort.VmPermission.DENY) {
            return IKvmPort.VmPermission.DENY;
         }

         if (var3 == IKvmPort.VmPermission.READONLY && var1 == IKvmPort.VmPermission.READWRITE) {
            var1 = IKvmPort.VmPermission.READONLY;
         }
      }

      return var1;
   }

   public static class KvmPermission {
      private IKvmPort.KvmPermission perms;
      private boolean isCCPerms;

      public KvmPermission(IKvmPort.KvmPermission var1, boolean var2) {
         this.perms = var1;
         this.isCCPerms = var2;
      }
   }

   public static class VmPermission {
      private IKvmPort.VmPermission perms;
      private boolean isCCPerms;

      public VmPermission(IKvmPort.VmPermission var1, boolean var2) {
         this.perms = var1;
         this.isCCPerms = var2;
      }
   }
}
