package com.raritan.rrc.data;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import javax.swing.SwingUtilities;

public class MassStorageDevice {
   public static final String PROPERTY_CONNECTED = "connected";
   private final PropertyChangeSupport propChangeSupport = new PropertyChangeSupport(this);
   private int devType;
   private boolean connected;

   public MassStorageDevice(int var1) {
      this.devType = var1;
   }

   public synchronized boolean isConnected() {
      return this.connected;
   }

   public void setConnected(boolean var1) {
      boolean var2 = this.connected;
      synchronized (this) {
         this.connected = var1;
      }

      this.fireConnected(var2, var1);
   }

   @Override
   public String toString() {
      return "MassStorageDevice : devType : " + this.devType + " Connected : " + this.connected;
   }

   public int getDevType() {
      return this.devType;
   }

   public void addPropertyChangeListener(PropertyChangeListener var1) {
      this.propChangeSupport.addPropertyChangeListener(var1);
   }

   public void removePropertyChangeListener(PropertyChangeListener var1) {
      this.propChangeSupport.removePropertyChangeListener(var1);
   }

   private void fireConnected(final boolean var1, final boolean var2) {
      if (SwingUtilities.isEventDispatchThread()) {
         this.fireConnectedOnEDT(var1, var2);
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               MassStorageDevice.this.fireConnectedOnEDT(var1, var2);
            }
         });
      }
   }

   private void fireConnectedOnEDT(boolean var1, boolean var2) {
      this.propChangeSupport.firePropertyChange("connected", var1, var2);
   }
}
