package com.raritan.rrc.data;

import java.awt.Point;
import java.util.Arrays;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Vector;

public class MultiMonitorPortHandler {
   private List<MultiMonitorPort> ports;
   private LinkedHashMap<String, MultiMonitorPort.PortConfig> allPortConfigs;
   private LinkedHashMap<String, MultiMonitorPort> portsMap;
   private LinkedHashMap<String, MultiMonitorPort> primaryMap;
   private LinkedHashMap<String, MultiMonitorPort> secondaryMap;

   public MultiMonitorPortHandler(List<MultiMonitorPort> var1) {
      this.ports = var1;
      this.allPortConfigs = new LinkedHashMap<>();
      this.portsMap = new LinkedHashMap<>();
      this.primaryMap = new LinkedHashMap<>();
      this.secondaryMap = new LinkedHashMap<>();
      if (var1 != null) {
         for (MultiMonitorPort var3 : var1) {
            for (MultiMonitorPort.PortConfig var5 : var3.getPorts()) {
               if (var5.getMonitorIndex() == 0) {
                  this.primaryMap.put(var5.getPortId(), var3);
               } else {
                  this.secondaryMap.put(var5.getPortId(), var3);
               }

               this.allPortConfigs.put(var5.getPortId(), var5);
               this.portsMap.put(var5.getPortId(), var3);
            }
         }
      }
   }

   public MultiMonitorPortHandler(MultiMonitorPort var1) {
      this(Arrays.asList(var1));
   }

   public MultiMonitorPortHandler() {
      this((List<MultiMonitorPort>)null);
   }

   public boolean isPrimaryPort(String var1) {
      return this.primaryMap.containsKey(var1);
   }

   public boolean isPrimaryPort(Port var1) {
      return this.isPrimaryPort(var1.getTargetDeviceId());
   }

   public boolean isPrimaryOrSinglePort(String var1) {
      return !this.isSecondaryPort(var1);
   }

   public boolean isPrimaryOrSinglePort(Port var1) {
      return this.isPrimaryOrSinglePort(var1.getTargetDeviceId());
   }

   public boolean isSecondaryPort(String var1) {
      return this.secondaryMap.containsKey(var1);
   }

   public boolean isSecondaryPort(Port var1) {
      return this.isSecondaryPort(var1.getTargetDeviceId());
   }

   public Point getLocation(String var1) {
      MultiMonitorPort.PortConfig var2 = this.allPortConfigs.get(var1);
      return var2 == null ? new Point(0, 0) : var2.getMonitorPosition();
   }

   public Point getLocation(Port var1) {
      return this.getLocation(var1.getTargetDeviceId());
   }

   public int getMonitorIndex(String var1) {
      MultiMonitorPort.PortConfig var2 = this.allPortConfigs.get(var1);
      return var2 == null ? -1 : var2.getMonitorIndex();
   }

   public int getMonitorIndex(Port var1) {
      return this.getMonitorIndex(var1.getTargetDeviceId());
   }

   public List<MultiMonitorPort.PortConfig> getSecondaryPorts(String var1) {
      if (!this.primaryMap.containsKey(var1)) {
         return null;
      } else {
         Vector var2 = new Vector();

         for (MultiMonitorPort.PortConfig var4 : this.primaryMap.get(var1).getPorts()) {
            if (!var4.getPortId().equals(var1)) {
               var2.add(var4);
            }
         }

         return var2;
      }
   }

   public List<MultiMonitorPort.PortConfig> getSecondaryPorts(Port var1) {
      return this.getSecondaryPorts(var1.getTargetDeviceId());
   }

   public MultiMonitorPort.PortConfig getPrimaryPort(String var1) {
      if (!this.secondaryMap.containsKey(var1)) {
         return null;
      } else {
         for (MultiMonitorPort.PortConfig var3 : this.secondaryMap.get(var1).getPorts()) {
            if (var3.getMonitorIndex() == 0) {
               return var3;
            }
         }

         return null;
      }
   }

   public MultiMonitorPort.PortConfig getPrimaryPort(Port var1) {
      return this.getPrimaryPort(var1.getTargetDeviceId());
   }
}
