package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.RRCShellInternalFrame;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.ShellInternalFrame;
import java.awt.Point;
import java.util.ArrayList;
import java.util.List;
import java.util.Vector;

public abstract class Port extends Device {
   public static final String KVM_CLASS = "KVM";
   public static final String SERIAL_CLASS = "Serial";
   public static final String OUTLET_CLASS = "Outlet";
   public static final String HTML_CLASS = "HTML";
   public static final String URL_CLASS = "URL";
   public static final String VIRTUAL_CLASS = "Virtual";
   public static final String URL_TYPE = "URL";
   public static final String ADMIN_TYPE = "VT100Admin";
   public static final String POWERPORT_TYPE = "VT100PowerPort";
   public static final String APPLIANCE_OUTLET_TYPE = "Appliance";
   public static final String PARAGONTARGET_OUTLET_TYPE = "ParagonTarget";
   public static final String UMT_PORT_TYPE = "UMT";
   public static final int KVM_ALLOCATION_BYTES = 3145728;
   public static final int ADMIN_ALLOCATION_BYTES = 7340032;
   public static final int POWER_ALLOCATION_BYTES = 1048576;
   private int concurrUsers = 1;
   protected String viewName;
   protected Device device;
   private String portClass;
   private String portType;
   private String targetDeviceId;
   private int targetDeviceIdIntValue;
   private String connectionId;
   private int portIndex;
   private int parentIndex;
   private ArrayList outletIds = new ArrayList();
   private boolean outletPortFlag = false;
   private String statusToolTip = "";
   private String availabilityToolTip = "";
   private boolean viewNameChanged = true;
   private boolean bladePort = false;
   private BladeChassis parentBladeChassis;

   public Port(ScreenContext var1) {
      super(var1);

      try {
         this.jbInit();
      } catch (Exception var3) {
         var3.printStackTrace();
      }
   }

   public Port() {
      this(null);
   }

   public boolean isBladePort() {
      return this.bladePort;
   }

   public void setBladePort(boolean var1) {
      this.bladePort = var1;
   }

   @Override
   public void setConnected(boolean var1) {
      if (this.isBladePort()) {
         this.getParentBladeChassis().setConnected(var1);
      }

      super.setConnected(var1);
   }

   @Override
   public void setId(String var1) {
      String var2 = var1;
      if (!var1.contains("FG")) {
         this.setUniquePortId(var1);
      }

      if (var1 != null && !var1.startsWith("//*[@id=")) {
         var2 = "//*[@id=%s]".replaceFirst("%s", var1);
      }

      super.setId(var2);
   }

   public void addOutletId(String var1) {
      this.outletIds.add(var1);
   }

   public ArrayList getOutletIds() {
      return this.outletIds;
   }

   public void setDeviceClass(String var1) {
      this.portClass = var1;
   }

   @Override
   public String getDeviceClass() {
      return this.portClass;
   }

   public void setPortType(String var1) {
      this.portType = var1;
   }

   public String getPortType() {
      return this.portType;
   }

   public boolean isAdmin() {
      return this.portType != null && this.portType.equalsIgnoreCase("admin");
   }

   public boolean isDiag() {
      return this.portType.equalsIgnoreCase("VT100Admin") && this.portClass.equalsIgnoreCase("Serial");
   }

   public boolean isURL() {
      return this.portType.equalsIgnoreCase("URL") && this.portClass.equalsIgnoreCase("URL");
   }

   public void setTargetDeviceId(String var1) {
      if (StringUtils.notNullOrEmpty(var1)) {
         if (var1.startsWith("//*[@id")) {
            this.targetDeviceId = var1;
         } else {
            try {
               this.targetDeviceIdIntValue = Integer.parseInt(var1);
            } catch (NumberFormatException var3) {
               this.targetDeviceIdIntValue = 0;
            }

            StringBuffer var2 = new StringBuffer("//*[@id=");
            var2.append(this.targetDeviceIdIntValue).append("]");
            this.targetDeviceId = var2.toString();
         }
      }
   }

   public String getStripTargetDeviceId() {
      return this.targetDeviceId.startsWith("//*[@id") ? this.targetDeviceId.substring(8, this.targetDeviceId.length() - 1) : this.targetDeviceId;
   }

   public String getTargetDeviceId() {
      return this.targetDeviceId;
   }

   public int getTargetDeviceIdIntValue() {
      return this.targetDeviceIdIntValue;
   }

   @Override
   public void setPortStatus(int var1, int var2) {
      super.setPortStatus(var1, var2);
   }

   public int getPortStatus() {
      return super.getStatus();
   }

   public void setPortIndex(String var1) {
      int var2 = 0;

      try {
         var2 = Integer.parseInt(var1);
         this.portIndex = var2;
      } catch (NumberFormatException var4) {
         boolean var5 = false;
      }
   }

   @Override
   public String getStatusToolTip() {
      return super.getStatusToolTip();
   }

   @Override
   public String getAvailabilityToolTip() {
      return super.getAvailabilityToolTip();
   }

   public int getSortPos() {
      if (this.portClass.equalsIgnoreCase("HTML")) {
         return 7;
      } else if (this.portType.equalsIgnoreCase("VT100Admin") && this.portClass.equalsIgnoreCase("Serial")) {
         return 8;
      } else if (this.portType.equalsIgnoreCase("URL")) {
         return 9;
      } else if (this.portClass.equals("KVM")) {
         if (this.isConnected()) {
            return 2;
         } else if (super.getStatus() == 0) {
            return 6;
         } else if (super.getStatus() == 1) {
            return 4;
         } else {
            return super.getStatus() == 2 ? 5 : 5;
         }
      } else {
         return 6;
      }
   }

   public boolean isGhost() {
      Device var1 = this.getBaseDevice();
      return this.getGhostMode() == 1 && var1 != null && var1.getGhostMode() == 0;
   }

   public String getDisplayName(int var1) {
      String var2;
      String var3;
      if (this.portIndex >= 0 && !this.isAdmin() && !this.isDiag()) {
         if (this.isBladePort()) {
            int var4 = this.getParentIndex();
            if (this.isURL()) {
               String var5 = "";
               switch (this.portIndex) {
                  case 0:
                     var5 = "A";
                     break;
                  case 1:
                     var5 = "B";
                     break;
                  case 2:
                     var5 = "C";
                     break;
                  case 3:
                     var5 = "D";
                     break;
                  default:
                     var5 = "A";
               }

               var2 = new Integer(var4 + 1).toString() + "-" + var5;
            } else {
               var2 = new Integer(var4 + 1).toString() + "-" + new Integer(this.portIndex + 1).toString();
            }
         } else {
            var2 = new Integer(this.portIndex + 1).toString();
         }

         Device var6 = this.getDevice();
         var3 = ": ";
      } else {
         var2 = "";
         var3 = "";
      }

      String var9 = this.getName();
      String var7;
      if (var9 != null && var9.length() != 0 && !this.isGhost()) {
         var7 = var9;
      } else {
         var7 = "<Unnamed>";
      }

      if (this.isPrimaryPort()) {
         var7 = var7 + " - " + RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale()).getString("DualPortPrimary");
      } else if (this.isSecondaryPort()) {
         var7 = var7 + " - " + RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale()).getString("DualPortSecondary");
      }

      return var1 == 0 ? var2 + var3 + var7 : var7 + var3 + var2;
   }

   public Device getBaseDevice() {
      Object var1 = this;

      while (true) {
         Component var2 = ((Component)var1).getParent();
         if (var2 == null) {
            return var1 instanceof Device ? (Device)var1 : null;
         }

         var1 = var2;
      }
   }

   public int getPortIndex() {
      return this.portIndex;
   }

   public void setDevice(Device var1) {
      this.device = var1;
   }

   public Device getDevice() {
      return this.device;
   }

   @Override
   public synchronized String getViewName() {
      if (StringUtils.nullOrEmpty(this.viewName) || this.viewNameChanged) {
         StringBuffer var1 = new StringBuffer(this.getDevice().getName());
         String var2 = this.getDevice().getDeviceConnector().getInetAddress().getHostAddress();
         if (var2 != null) {
            if (var1.length() == 0) {
               var1.append(var2);
            } else {
               var1.append(" at ").append(var2);
            }
         }

         var1.append(" :: ").append(this.getName());
         var1.insert(0, this.getDevice().getDeviceModel() + " ");
         this.viewName = var1.toString();
         this.viewNameChanged = false;
      }

      return this.viewName;
   }

   @Override
   public void disconnect() {
      ArrayList var1 = null;
      if (this.scrContext != null && ((RRCScreenContext)this.scrContext).getListOfOpenPorts() != null) {
         var1 = ((RRCScreenContext)this.scrContext).getListOfOpenPorts();
      }

      String var2 = this.getId();
      if (var1 != null && var1.size() > 0) {
         if (((IPReach)this.getDevice()).isKvmSwitch()) {
            var2 = this.getTargetDeviceId();
         }

         if (this.getView() != null) {
            ShellInternalFrame var3 = this.getView().getShellInternalFrame();
            if (var3 != null && !var3.isClosed()) {
               ((RRCShellInternalFrame)var3).setFrameActivatedCommand(null);
               ((RRCShellInternalFrame)var3).setFrameClosedCommand(null);
               ((RRCShellInternalFrame)var3).setFrameDeActivatedCommand(null);
               var3.setVisible(false);
               var3.dispose();
            }
         }

         ((RRCScreenContext)this.scrContext).removePortInObservable(this);
      }

      this.arrEvenMsg = null;
      DeviceConnector var5 = this.connector;
      if (var5 != null && var5.isP2scPort()) {
         var5.disConnect();
         this.connector = null;
      }

      System.gc();
   }

   public abstract Stream getStream();

   public abstract DeviceView getView();

   @Override
   public String getConnectionId() {
      return this.connectionId;
   }

   @Override
   public void setConnectionId(String var1) {
      this.connectionId = var1;
   }

   public void setUpdateFrequency(long var1) {
   }

   public boolean isClass(String var1) {
      return this.getDeviceClass().equalsIgnoreCase(var1);
   }

   @Override
   public boolean isType(String var1) {
      return this.getPortType().equalsIgnoreCase(var1);
   }

   @Override
   public String getPortKey() {
      return this.getViewName() + this.getPortIndex();
   }

   private void jbInit() throws Exception {
   }

   public boolean isOutletPort() {
      return this.outletPortFlag;
   }

   public void setOutLetPort(boolean var1) {
      this.outletPortFlag = var1;
   }

   public int getConcurrUsers() {
      return this.concurrUsers;
   }

   public void setConcurrUsers(int var1) {
      this.concurrUsers = var1;
   }

   @Override
   public void setName(String var1) {
      synchronized (this) {
         this.viewNameChanged = true;
         super.setName(var1);
      }

      MPCUtil.notifyOpenPortsObservers((RRCScreenContext)this.scrContext);
   }

   public void setParentIndex(int var1) {
      this.parentIndex = var1;
   }

   public int getParentIndex() {
      return this.parentIndex;
   }

   @Override
   public int getRdmStatAvailable() {
      return super.getRdmStatAvailable();
   }

   public void setParentBladeChassis(BladeChassis var1) {
      this.parentBladeChassis = var1;
   }

   public BladeChassis getParentBladeChassis() {
      return this.parentBladeChassis;
   }

   public boolean isPrimaryPort() {
      return this.getDevice().getMultiMonitorPortHandler().isPrimaryPort(this);
   }

   public boolean isPrimaryOrSinglePort() {
      return this.getDevice().getMultiMonitorPortHandler().isPrimaryOrSinglePort(this);
   }

   public boolean isSecondaryPort() {
      return this.getDevice().getMultiMonitorPortHandler().isSecondaryPort(this);
   }

   public Point getMonitorLocation() {
      return this.getDevice().getMultiMonitorPortHandler().getLocation(this);
   }

   public int getMonitorIndex() {
      return this.getDevice().getMultiMonitorPortHandler().getMonitorIndex(this);
   }

   public boolean isTopLeft() {
      Point var1 = this.getDevice().getMultiMonitorPortHandler().getLocation(this);
      if (var1 != null && (var1.x != 0 || var1.y != 0)) {
         for (Port var3 : this.getAssociatedPorts()) {
            if (var3.getPortStatus() != 0) {
               return false;
            }
         }

         return true;
      } else {
         return true;
      }
   }

   public boolean isMultiMonitorPort() {
      for (Port var2 : this.getAssociatedPorts()) {
         if (var2.getPortStatus() != 0) {
            return true;
         }
      }

      return false;
   }

   public List<MultiMonitorPort.PortConfig> getSecondaryPortConfigs() {
      return this.getDevice().getMultiMonitorPortHandler().getSecondaryPorts(this);
   }

   public List<Port> getSecondaryPorts() {
      Vector var1 = new Vector();
      List var2 = this.getSecondaryPortConfigs();
      if (var2 != null) {
         for (MultiMonitorPort.PortConfig var4 : var2) {
            Port var5 = this.getDevice().getPortByTargetDeviceId(var4.getPortId());
            if (var5 != null) {
               var1.add(var5);
            }
         }
      }

      return var1;
   }

   public MultiMonitorPort.PortConfig getPrimaryPortConfig() {
      return this.getDevice().getMultiMonitorPortHandler().getPrimaryPort(this);
   }

   public Port getPrimaryPort() {
      MultiMonitorPort.PortConfig var1 = this.getPrimaryPortConfig();
      return var1 != null ? this.getDevice().getPortByTargetDeviceId(var1.getPortId()) : null;
   }

   public List<Port> getAssociatedPorts() {
      Vector var1 = new Vector();
      if (this.isPrimaryPort()) {
         return this.getSecondaryPorts();
      } else {
         if (this.isSecondaryPort()) {
            Port var2 = this.getPrimaryPort();
            if (var2 != null) {
               var1.add(var2);

               for (Port var4 : var2.getSecondaryPorts()) {
                  if (var4 != this) {
                     var1.add(var4);
                  }
               }
            }
         }

         return var1;
      }
   }

   @Override
   public String toString() {
      return "Port: id=" + this.getId() + " - portNo=" + this.getPortIndex() + " - targetID=" + this.getTargetDeviceId() + " - name=" + this.getName();
   }
}
