package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.PowerPortView;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommonPopups;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.Timer;

public class PowerPort extends SerialPort {
   private PowerPortView powerPortView;
   private Object powerPortViewSet = new Object();
   private boolean firstResponseReceived = false;
   private Timer connectTimer = null;

   @Override
   public DeviceView getView() {
      return this.powerPortView;
   }

   public void setView(PowerPortView var1) {
      synchronized (this.powerPortViewSet) {
         this.powerPortView = var1;
         this.powerPortViewSet.notify();
      }
   }

   @Override
   public void connect() {
      if (!this.isConnected()) {
         this.firstResponseReceived = false;
         this.connectTimer = new Timer(
            2000,
            new ActionListener() {
               @Override
               public void actionPerformed(ActionEvent var1) {
                  PowerPort.this.connectTimer.stop();
                  if (!PowerPort.this.firstResponseReceived) {
                     RaritanPropertyResourceBundle var2 = RaritanResourceBundle.getResourceBundle(PowerPort.this.scrContext.getLocale());
                     CommonPopups.showInfoDialog(
                        var2.getString("optionpane.error.title"),
                        var2.getString("CouldNotConnectError.message"),
                        PowerPort.this.getView(),
                        PowerPort.this.scrContext
                     );
                  }
               }
            }
         );
         if (this.serialStream == null) {
            this.serialStream = new SerialStream(this);
         }

         try {
            boolean var1 = this.serialStream.connectSerialStream(this.getId(), this.getTargetDeviceId());
            if (var1) {
               byte[] var4 = new byte[]{13, 0};
               this.serialStream.serialOut(1, var4);
               this.connectTimer.start();
               this.setConnected(true);
               this.setState("CONNECTED");
               this.firePropertyChange("DEVICE_PORT_VIEW_ADD", null, null);
            } else {
               ((RRCScreenContext)this.scrContext).removePortInObservable(this);
            }
         } catch (Exception var5) {
         }
      }
   }

   @Override
   public void disconnect() {
      if (this.isConnected()) {
         super.disconnect();
         if (this.powerPortView != null) {
            ((PowerPortView)this.getView()).feedCommandContext(null);
            this.powerPortView.setVisible(false);
            this.powerPortView = null;
         }

         this.firePropertyChange("DEVICE_PORT_VIEW_REMOVE", null, null);
      }
   }

   @Override
   public void serialIn(int var1, byte[] var2) {
      if (!this.firstResponseReceived) {
         this.firstResponseReceived = true;
      }

      synchronized (this.powerPortViewSet) {
         try {
            if (this.powerPortView == null) {
               this.powerPortViewSet.wait(5000L);
            }
         } catch (InterruptedException var6) {
            return;
         }

         if (this.powerPortView != null) {
            this.powerPortView.serialIn(var1, var2);
         }
      }
   }
}
