package com.raritan.rrc.data;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.CancelRFPOperationCommand;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.util.config.ConfigurationManager;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import javaclientlib.clientlib.RFPClient;
import javaclientlib.tr.TRCOMMAND;
import javaclientlib.utils.RRCLogger;

public class RRCRFPClient extends RFPClient {
   private static RRCRFPClient instance;
   private RRCScreenContext scrContext;
   private RaritanPropertyResourceBundle bundle;
   private final String tempCertificateFilename = "cert_temp.rfp";
   private final String tempKeyFilename = "key_temp.rfp";
   private final int bufferSize = 1024;
   private boolean showProgress = false;
   private boolean isKX = false;
   private static Object mutexForInstantiation = new Object();

   private RRCRFPClient() {
      this.bundle = RaritanResourceBundle.getResourceBundle();
   }

   public static RRCRFPClient getInstance() {
      synchronized (mutexForInstantiation) {
         if (instance == null) {
            instance = new RRCRFPClient();
         }
      }

      return instance;
   }

   public void setScreenContext(ScreenContext var1) {
      this.scrContext = (RRCScreenContext)var1;
      ArrayList var2 = (ArrayList)this.scrContext.getSelectedDevicesObservable().getComponent();
      if (var2 != null && var2.size() > 0) {
         Device var3 = (Device)var2.get(0);
         DeviceConnector var4 = var3.getDeviceConnector();

         try {
            this.setTRConnection(var4);
         } catch (Exception var6) {
            RRCLogger.logException(var6);
         }
      }
   }

   public void setShowProgress(boolean var1) {
      this.showProgress = var1;
   }

   @Override
   public boolean TRRSP_RFP_Message_Glue(TRCOMMAND var1, Object var2) {
      return super.TRRSP_RFP_Message_Glue(var1, var2);
   }

   public boolean updateLDAPCertificate(File var1) {
      boolean var2 = false;
      InputStream var3 = null;
      FileOutputStream var4 = null;
      FileInputStream var5 = null;

      try {
         byte[] var6 = new byte[1024];
         var3 = ConfigurationManager.getResourceInputStream(this.scrContext.getClass(), this.scrContext.getApplicationProperty("ldapcert.template.file"));
         var4 = new FileOutputStream("cert_temp.rfp");

         for (int var7 = var3.read(var6); var7 > 0; var7 = var3.read(var6)) {
            var4.write(var6, 0, var7);
         }

         var5 = new FileInputStream(var1);

         for (int var29 = var5.read(var6); var29 > 0; var29 = var5.read(var6)) {
            var4.write(var6, 0, var29);
         }

         var2 = this.send("cert_temp.rfp", 0, false);
      } catch (Exception var24) {
      } finally {
         if (var3 != null) {
            try {
               var3.close();
               Object var26 = null;
            } catch (IOException var23) {
            }
         }

         if (var4 != null) {
            try {
               new File("key_temp.rfp").deleteOnExit();
               var4.close();
               Object var27 = null;
            } catch (IOException var22) {
            }
         }

         if (var5 != null) {
            try {
               var5.close();
               Object var28 = null;
            } catch (IOException var21) {
            }
         }
      }

      return var2;
   }

   public boolean updateLDAPKey(File var1) {
      boolean var2 = false;
      InputStream var3 = null;
      FileOutputStream var4 = null;
      FileInputStream var5 = null;

      try {
         byte[] var6 = new byte[1024];
         var3 = ConfigurationManager.getResourceInputStream(this.scrContext.getClass(), this.scrContext.getApplicationProperty("ldapkey.template.file"));
         var4 = new FileOutputStream("key_temp.rfp");

         for (int var7 = var3.read(var6); var7 > 0; var7 = var3.read(var6)) {
            var4.write(var6, 0, var7);
         }

         var5 = new FileInputStream(var1);

         for (int var29 = var5.read(var6); var29 > 0; var29 = var5.read(var6)) {
            var4.write(var6, 0, var29);
         }

         var2 = this.send("key_temp.rfp", 0, false);
      } catch (Exception var24) {
      } finally {
         if (var3 != null) {
            try {
               var3.close();
               Object var26 = null;
            } catch (IOException var23) {
            }
         }

         if (var4 != null) {
            try {
               new File("key_temp.rfp").deleteOnExit();
               var4.close();
               Object var27 = null;
            } catch (IOException var22) {
            }
         }

         if (var5 != null) {
            try {
               var5.close();
               Object var28 = null;
            } catch (IOException var21) {
            }
         }
      }

      return var2;
   }

   @Override
   public void progress(int var1, int var2) {
      if (this.showProgress && !this.isKX) {
         int var3 = (int)((double)var2 / var1 * 100.0);
         ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setRFPOperationProgress(var3);
         if (var3 == 0) {
            var3 = 1;
         }

         String var4 = var3 - 1 + "% " + this.bundle.getString("rfpclient.progresslabel.text");
         this.scrContext.getLogger().logStatus(var4);
      }
   }

   @Override
   public boolean receive(String var1, String var2, int var3) throws Exception {
      CancelRFPOperationCommand var4 = new CancelRFPOperationCommand(this.scrContext);
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).initRFPProgressComponents(false);
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setCancelRFPOperationCommand(var4);
      boolean var5 = super.receive(var1, var2, var3);
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).hideRFPProgressComponents();
      return var5;
   }

   @Override
   public boolean send(String var1, int var2, boolean var3) throws Exception {
      this.isKX = var3;
      CancelRFPOperationCommand var4 = new CancelRFPOperationCommand(this.scrContext);
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).initRFPProgressComponents(var3);
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setCancelRFPOperationCommand(var4);
      boolean var5 = false;
      var5 = super.send(var1, var2, var3);
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).hideRFPProgressComponents();
      return var5;
   }

   @Override
   public void cancel() {
      super.cancel();
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).hideRFPProgressComponents();
   }

   public String showError(int var1) {
      RRCLogger.log(300, -1, "RFP Error Received: " + var1 + ". Hex Value:0x" + Integer.toHexString(var1));
      String var2 = null;
      switch (var1) {
         case 13:
            var2 = this.bundle.getString("tr.error.file.not.found");
            break;
         case 33562624:
            var2 = this.bundle.getString("unknown.error.client");
            break;
         case 33562625:
         case 33562626:
            var2 = this.bundle.getString("trlib.error.rfp.error.corrupt.file");
            break;
         case 33562627:
         case 33562628:
         case 33562629:
         case 33562630:
            var2 = this.bundle.getString("trlib.error.rfp.failure.occurred");
            break;
         case 33562631:
            var2 = this.bundle.getString("trlib.error.rfp.error.model.mismatch");
            break;
         case 33562632:
            var2 = this.bundle.getString("trlib.error.rfp.error.version.mismatch");
            break;
         case 33562633:
            var2 = this.bundle.getString("trlib.error.rfp.error.timeout");
            break;
         case 33562634:
            var2 = this.bundle.getString("trlib.error.rfp.error.cancel");
            break;
         case 33562635:
            var2 = this.bundle.getString("trlib.error.rfp.error.requset.format");
            break;
         case 33562636:
            var2 = this.bundle.getString("trlib.error.rfp.error.file.not.found");
            break;
         case 33562637:
            var2 = this.bundle.getString("trlib.error.rfp.error.internal");
            break;
         case 33562638:
         case 33562639:
         case 33562640:
         case 33562641:
         case 33562642:
         case 33562643:
         case 33562644:
         case 33562645:
         case 33562646:
         case 33562647:
            var2 = this.bundle.getString("trlib.error.rfp.internal.error");
            break;
         case 33562648:
            var2 = this.bundle.getString("trlib.error.rfp.pack.ack");
            break;
         case 33562650:
            var2 = this.bundle.getString("trlib.error.rfp.file.wrong.model");
            break;
         case 33562651:
            var2 = this.bundle.getString("trlib.error.rfp.file.wrong.type");
            break;
         case 33562652:
         case 33562653:
            var2 = this.bundle.getString("trlib.error.rfp.file.missing.info");
            break;
         case 33562654:
            var2 = this.bundle.getString("trlib.error.rfp.file.not.compatible");
            break;
         case 33562655:
         case 33562656:
         case 33562724:
         case 33562725:
         case 33562726:
         case 33562729:
         case 33562730:
         case 33562731:
         case 33562732:
         case 33562733:
         case 33562734:
         case 33562735:
         case 33562736:
         case 33562737:
         case 33562738:
            var2 = this.bundle.getString("trlib.error.rfp.problem.with.file");
            break;
         case 33562657:
            var2 = this.bundle.getString("trlib.error.rfp.out.of.memory");
            break;
         case 33562727:
         case 33563124:
         case 33563125:
         case 33563126:
         case 33563127:
         case 33563128:
         case 33563129:
            var2 = this.bundle.getString("trlib.error.rfp.restore.failed.problem.with.file");
            break;
         case 33562728:
            var2 = this.bundle.getString("trlib.error.rfp.backup.problem.with.file");
            break;
         case 33563624:
            var2 = this.bundle.getString("trlib.error.rfp.skip.file");
            break;
         case 536870913:
            var2 = this.bundle.getString("trlib.error.not.connected");
            break;
         case 536870914:
            var2 = this.bundle.getString("trlib.error.invalid.parameter");
            break;
         case 536870915:
            var2 = this.bundle.getString("trlib.error.response.too.big");
            break;
         case 536870916:
            var2 = this.bundle.getString("trlib.error.bad.server.response");
            break;
         case 536870917:
            var2 = this.bundle.getString("trlib.error.io.cancel");
            break;
         case 536870918:
            var2 = this.bundle.getString("trlib.error.server.not.found");
            break;
         case 536870919:
            var2 = this.bundle.getString("trlib.error.server.busy");
            break;
         case 536870920:
            var2 = this.bundle.getString("trlib.error.socket");
            break;
         case 536870921:
            var2 = this.bundle.getString("trlib.error.dialup.failed");
            break;
         case 536870922:
            var2 = this.bundle.getString("trlib.error.browser.error");
            break;
         case 536875009:
            var2 = this.bundle.getString("tr.error.invalid.param");
            break;
         case 536875010:
            var2 = this.bundle.getString("tr.error.invalid.command");
            break;
         case 536875011:
            var2 = this.bundle.getString("tr.error.user.already.exists");
            break;
         case 536875012:
            var2 = this.bundle.getString("tr.error.user.not.found");
            break;
         case 536875013:
            var2 = this.bundle.getString("tr.error.permission.denied");
            break;
         case 536875014:
            var2 = this.bundle.getString("tr.error.public.view.denied");
            break;
         case 536875015:
            var2 = this.bundle.getString("tr.error.no.resources");
            break;
         case 536875016:
            var2 = this.bundle.getString("tr.error.internal.error");
            break;
         case 536875017:
            var2 = this.bundle.getString("tr.error.console.busy");
            break;
         case 536875018:
            var2 = this.bundle.getString("tr.error.device.busy");
            break;
         case 536875019:
            var2 = this.bundle.getString("tr.error.server.busy");
            break;
         case 536875021:
            var2 = this.bundle.getString("tr.error.file.not.found");
            break;
         default:
            var2 = this.bundle.getString("unknown.error");
      }

      var2 = "[Error 0x" + Integer.toHexString(var1) + "]: " + var2;
      byte var3 = 50;
      byte var4 = 7;
      int var5 = var2.length();
      if (var5 <= var3 + var4) {
         return var2;
      } else {
         int var6 = 0;
         int var7 = var2.indexOf(32, var3);
         StringBuffer var8 = new StringBuffer(var2.substring(0, var7));

         while (var7 > -1) {
            var6 = var7;
            var7 = var2.indexOf(32, var7 + var3);
            if (var7 + var4 >= var5) {
               var7 = -1;
            }

            var8.append("\n  " + var2.substring(var6, var7 < 0 ? var5 : var7).trim());
         }

         return var8.toString();
      }
   }
}
