package com.raritan.rrc.data;

import com.raritan.rrc.components.serialconsole.Terminal;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.SerialView;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommonPopups;
import javaclientlib.clientlib.ISerialStream;
import javaclientlib.tr.TRSRVR_SERIAL_PARAMS;
import javax.swing.SwingUtilities;

public class SerialPort extends Port implements ISerialStream {
   public Terminal terminal;
   protected SerialStream serialStream;
   private SerialView serialView;

   @Override
   public Stream getStream() {
      return this.serialStream;
   }

   @Override
   public DeviceView getView() {
      return this.serialView;
   }

   public void setView(SerialView var1) {
      this.serialView = var1;
   }

   public void setTerminal(Terminal var1) {
      this.terminal = var1;
   }

   public Terminal getTerminal() {
      return this.terminal;
   }

   @Override
   public void connect() {
      SwingUtilities.invokeLater(new SerialPort.ConnectThread(this));
   }

   @Override
   public void disconnect() {
      if (this.isConnected()) {
         this.disconnectDevice();
         super.disconnect();
         if (this.terminal != null) {
            this.terminal.onFinalize();
         }

         this.serialStream = null;
         this.serialView = null;
         this.terminal = null;
         this.firePropertyChange("DEVICE_PORT_VIEW_REMOVE", null, null);
      }
   }

   public boolean disconnectDevice() {
      try {
         this.serialStream.stopSerialStream();
         this.serialStream = null;
         this.setConnected(false);
         this.setActive(false);
         this.setState("AVAILABLE");
         return true;
      } catch (Exception var2) {
         return false;
      }
   }

   public boolean isAdministrator() {
      DeviceConnector var1 = this.device.getDeviceConnector();
      boolean var2 = (var1.getPermissions() & 2L) != 0L;
      boolean var3 = var1.getServerID().getProtocolVersion() > 11;
      boolean var4 = (var1.getServerID().getSecurityFlags() & 1) != 0;
      return var2 && var3 && var4;
   }

   @Override
   public void serialIn(int var1, byte[] var2) {
      this.serialView.serialIn(var1, var2);
   }

   public boolean setSerialParameters(TRSRVR_SERIAL_PARAMS var1) {
      if (this.isConnected()) {
         try {
            this.serialStream.setSerialStream(var1);
            return true;
         } catch (Exception var3) {
            return false;
         }
      } else {
         return false;
      }
   }

   public String getCodeSet() {
      return this.terminal.getCodeSet();
   }

   public void setCodeSet(String var1) {
      this.terminal.setCodeSet(var1);
      this.terminal.initEmulator();
      this.terminal.saveConfig();
      this.terminal.getVDU().reDraw();
   }

   public int getCursorType() {
      return this.terminal.getCursorType();
   }

   public void setCursorType(int var1) {
      this.terminal.setCursorType(var1);
      this.terminal.getVDU().reDraw();
   }

   public boolean isDiagnosticPort() {
      return "Diagnostic".equals(this.getName());
   }

   @Override
   public boolean serialOut(int var1, byte[] var2) throws Exception {
      return false;
   }

   private class ConnectThread extends Thread {
      private SerialPort serialPort;

      private ConnectThread(SerialPort var2) {
         this.serialPort = var2;
      }

      @Override
      public void run() {
         if (!SerialPort.this.isConnected()) {
            if (SerialPort.this.serialStream == null) {
               SerialPort.this.serialStream = new SerialStream(this.serialPort);
            }

            boolean var1 = SerialPort.this.serialStream.connectSerialStream(this.serialPort.getId(), SerialPort.this.getTargetDeviceId());
            if (var1) {
               SerialPort.this.setConnected(true);
               SerialPort.this.setState("CONNECTED");
               SerialPort.this.firePropertyChange("DEVICE_PORT_VIEW_ADD", null, null);
            } else {
               ((SerialView)SerialPort.this.getView()).getShellInternalFrame().internalFrameClosing(null);
               ((RRCScreenContext)SerialPort.this.scrContext).removePortInObservable(SerialPort.this);
               RaritanPropertyResourceBundle var2 = RaritanResourceBundle.getResourceBundle(SerialPort.this.scrContext.getLocale());
               SerialPort.this.scrContext
                  .getLogger()
                  .logStatus(
                     var2.getString("KVMPort.couldNotConnect.error")
                        + " "
                        + (StringUtils.notNullOrEmpty(this.serialPort.getName()) ? this.serialPort.getName() : var2.getString("DefaultPortString.error"))
                  );
               SerialPort.this.scrContext
                  .getLogger()
                  .logTextInfo(
                     var2.getString("KVMPort.couldNotConnect.error")
                        + " "
                        + (StringUtils.notNullOrEmpty(this.serialPort.getName()) ? this.serialPort.getName() : var2.getString("DefaultPortString.error"))
                  );
               CommonPopups.showCommandResultErrorMessage(
                  var2.getString("KVMPort.couldNotConnect.error")
                     + " "
                     + (StringUtils.notNullOrEmpty(this.serialPort.getName()) ? this.serialPort.getName() : var2.getString("DefaultPortString.error")),
                  null,
                  SerialPort.this.scrContext
               );
            }
         }
      }
   }
}
