package com.raritan.rrc.ui;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.MultiMonitorPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.commands.ShowKVMFromScanCommand;
import com.raritan.rrc.ui.commands.ShowKX2KvmPortCommand;
import com.raritan.rrc.ui.panes.ErrorHandlerImpl;
import com.raritan.rrc.ui.panes.RRCShellInternalFrame;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButtonMenuItem;
import javax.swing.JSeparator;
import javax.swing.SwingWorker;
import javax.swing.event.InternalFrameEvent;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.common.ResourceLoader;
import nn.pp.common.Util;
import nn.pp.common.scan.ScanConnector;
import nn.pp.common.scan.ScanEventListener;
import nn.pp.common.scan.ScanPanelHelper;
import nn.pp.common.scan.TargetState;
import nn.pp.common.scan.VideoSnapshotSelectionListener;
import nn.pp.core.INotificationEvent;
import nn.pp.core.NotificationListener;
import nn.pp.ext.pref.IApplicationPreferences;
import nn.pp.logging.RemoteConsoleLogger;
import nn.pp.rccore.scan.ScanCore;
import nn.pp.rccore.scan.ScanCoreException;
import nn.pp.rccore.scan.ScanCoreFactory;
import nn.pp.rccore.scan.ScanSession;
import nn.pp.rccore.scan.ScanSessionEventsListener;

public class MPCScanFrame extends RRCShellInternalFrame {
   private RaritanPropertyResourceBundle bundle;
   private String NO_VIDEO_FROM_TARGET_SERVER;
   private static TargetState state = TargetState.INACTIVE;
   private static ScanSession scanSession;
   private ScanPanelHelper scph;
   ScanConnector scanConnector;
   private String[] portIds;
   private String[] portNos;
   HashMap<String, String> portTypeMap;
   HashMap<String, String> portPermissionMap;
   private IApplicationPreferences appPrefs;
   private String savedDimension;
   private ArrayList<KvmPort> kvmportList;
   JLabel statusLabel;
   JLabel osdLabel;
   JMenuBar bar;
   JMenu menu;
   JMenu sizeMenu;
   JMenuItem s320_240;
   ButtonGroup bg;
   JMenuItem s160_120;
   JMenuItem pause;
   JMenuItem resume;
   JMenu orientation;
   JMenuItem horizontalSplit;
   JMenuItem verticalSplit;
   ButtonGroup bg1;
   JPanel statusBar;
   JPanel p;
   private RRCScreenContext scrContext;
   private String connectedDeviceId = "";

   public MPCScanFrame(RRCScreenContext var1) {
      this.scrContext = var1;
      this.appPrefs = var1.getAppSettings();
      RaritanDesktopPane var2 = (RaritanDesktopPane)this.scrContext.getPanelMediator().getParent();
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.NO_VIDEO_FROM_TARGET_SERVER = this.bundle.getString("NO.VIDEO");
      this.setTitle(this.bundle.getString("Scan.Title"));
      this.setResizable(this.resizable);
      this.setClosable(true);
      this.pack();
      this.setVisible(false);
      this.setFocusable(true);
      this.setResizable(true);
      this.setSize(var2.getSize());
      this.setMaximizable(true);
      this.setIconifiable(true);
      this.kvmportList = new ArrayList<>();
      this.kvmportList = this.scrContext.getKvmPortsForScan();
      ArrayList var3 = this.getParams();
      final HashMap var4 = new HashMap();
      this.portIds = new String[var3.size()];
      this.portNos = new String[var3.size()];
      int var5 = 0;

      for (RemoteConsoleParameters var7 : var3) {
         var4.put(var7.targetPortId, var7);
         this.portIds[var5] = var7.targetPortId;
         int var8 = -1;

         try {
            if (var7.portIndex.contains(".")) {
               int[] var9 = Util.getPortNumber(var7.portIndex);
               String var10 = Integer.toString(var9[0] + 1);
               String var11 = Integer.toString(var9[1]);
               this.portNos[var5] = var10 + "-" + var11;
            } else {
               var8 = Integer.parseInt(var7.portIndex) + 1;
               this.portNos[var5] = Integer.toString(var8);
            }
         } catch (NumberFormatException var13) {
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Exception Occured:", (Throwable)var13);
         } catch (Exception var14) {
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Exception Occured:", (Throwable)var14);
         }

         var5++;
      }

      this.createLabels();
      this.scanConnector = createScanConnector(var3);
      this.scanConnector.addScanEventListener(new ScanEventListener() {
         @Override
         public void videoComponentAvailable(String var1, JComponent var2x) {
            MPCScanFrame.state = TargetState.INACTIVE;
            MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_white.gif"));
            String var3x = ((RemoteConsoleParameters)var4.get(var1)).portIndex;
            boolean var4x = false;
            int var5x = -1;
            int var6 = -1;
            if (var3x.contains(".")) {
               var4x = true;
               int[] var7 = Util.getPortNumber(var3x);
               var5x = var7[0];
               var6 = var7[1];
            } else {
               var5x = Integer.parseInt(var3x);
            }

            if (var6 != -1) {
               MPCScanFrame.this.statusLabel.setText(var5x + 1 + " - " + var6 + " - " + ((RemoteConsoleParameters)var4.get(var1)).portName);
            } else {
               MPCScanFrame.this.statusLabel.setText(var5x + 1 + " - " + ((RemoteConsoleParameters)var4.get(var1)).portName);
            }
         }

         @Override
         public void scanAbortedOnConnectError() {
            MPCScanFrame.scanSession.close();
         }

         @Override
         public void scanAborted(INotificationEvent var1) {
            MPCScanFrame.scanSession.close();
            System.out.println(var1.isError());
            System.out.println(var1);
         }

         @Override
         public void displayVideoStart(String var1, boolean var2x) {
            if (MPCScanFrame.state == TargetState.INACTIVE) {
               MPCScanFrame.state = TargetState.CONNECTED;
               MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_green.gif"));
            }
         }

         @Override
         public void displayVideoError(String var1, int var2x) {
            MPCScanFrame.state = TargetState.BUSY;
            MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_red.gif"));
            MPCScanFrame.this.osdLabel.setText("");
            MPCScanFrame.this.osdLabel.setToolTipText(null);
         }

         @Override
         public void displayVideoEnd(String var1, Image var2x) {
            MPCScanFrame.state = TargetState.INACTIVE;
            MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_white.gif"));
            MPCScanFrame.this.osdLabel.setToolTipText(null);
         }

         @Override
         public void displayVideoCommunicationError(String var1) {
            MPCScanFrame.state = TargetState.BUSY;
            MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_red.gif"));
            MPCScanFrame.this.osdLabel.setText("");
            MPCScanFrame.this.osdLabel.setToolTipText(null);
         }

         @Override
         public void osdMessageReceived(String var1, String var2x) {
            MPCScanFrame.this.osdLabel.setText(var2x);
            MPCScanFrame.this.osdLabel.setToolTipText(MPCScanFrame.this.osdLabel.getText());
            if (MPCScanFrame.this.NO_VIDEO_FROM_TARGET_SERVER.equals(var2x)) {
               MPCScanFrame.state = TargetState.DOWN;
               MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_yellow.gif"));
            } else {
               MPCScanFrame.state = TargetState.CONNECTED;
               MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_green.gif"));
            }
         }
      });
      this.scanConnector.setScanInterval(this.appPrefs.getScanDisplayInterval() * 1000);
      this.scanConnector.setSwitchInterval(this.appPrefs.getPortScanInterval() * 1000);
      this.savedDimension = this.appPrefs.getScanThumbnailSize();
      String[] var15 = this.savedDimension.split("x");
      new Dimension(160, 120);

      Dimension var16;
      try {
         var16 = new Dimension(Integer.parseInt(var15[0]), Integer.parseInt(var15[1]));
      } catch (NumberFormatException var12) {
         var16 = new Dimension(160, 120);
      }

      String var18 = "vertical";
      var18 = this.appPrefs.getScanOrientation();
      boolean var20 = false;
      if (var18.equalsIgnoreCase("vertical")) {
         var20 = true;
      } else {
         var20 = false;
      }

      this.scph = new ScanPanelHelper(var3, this.scanConnector, var16, var20 ? 0 : 1);
      this.createGUI();
      this.add(this.statusBar, "South");
      this.createScanSession(
         (RemoteConsoleParameters)var3.get(0),
         this.portIds,
         new ScanSessionEventsListener() {
            @Override
            public void disconnected(Exception var1) {
               if (var1 != null) {
                  MPCScanFrame.this.scph.getScanConnector().stop();
                  JOptionPane.showMessageDialog(null, "Error received on Scan session connection");
               }
            }

            @Override
            public void scanSessionCreated(int var1) {
               MPCScanFrame.this.scph.getScanConnector().start(var1);
            }
         },
         new NotificationListener() {
            @Override
            public void receivedNotification(INotificationEvent var1) {
               RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Notification received, aborting scan : " + var1.getErrorCode());
               switch (var1.getErrorCode()) {
                  case -1610612735:
                  case -1610612734:
                  case -1610481662:
                  case -1576927228:
                     MPCScanFrame.this.scph.getScanConnector().stop();
                     ErrorHandlerImpl.getInstance()
                        .handleScanError(var1.getErrorCode(), MPCScanFrame.this.scrContext.getApplication().getContentPane(), MPCScanFrame.this.portNos);
                     break;
                  case -1610481663:
                     if (MPCScanFrame.this.scph != null) {
                        MPCScanFrame.this.scph.getScanConnector().stop();
                     }

                     ErrorHandlerImpl.getInstance()
                        .handleScanError(var1.getErrorCode(), MPCScanFrame.this.scrContext.getApplication().getContentPane(), MPCScanFrame.this.portNos);
               }
            }

            @Override
            public void textNotification(String var1) {
            }
         }
      );
      var2.add(this);
      this.scrContext.setScanFrame(this);
      this.scrContext.setScanFrameOpened(true);
      MPCUtil.notifyObservers(this.scrContext, null);
      this.setVisible(true);
      this.scrContext.focusScanFrame();
   }

   public ScanPanelHelper getScph() {
      return this.scph;
   }

   public void setScph(ScanPanelHelper var1) {
      this.scph = var1;
   }

   public ScanConnector getScanConnector() {
      return this.scanConnector;
   }

   public static ScanSession getScanSession() {
      return scanSession;
   }

   public static void setScanSession(ScanSession var0) {
      scanSession = var0;
   }

   public void setScanConnector(ScanConnector var1) {
      this.scanConnector = var1;
   }

   private void createLabels() {
      this.statusLabel = new MPCScanFrame.MyLabel();
      this.osdLabel = new MPCScanFrame.MyLabel();
   }

   private void createGUI() {
      this.bar = new JMenuBar();
      this.menu = new JMenu(this.bundle.getString("scan.options"));
      this.sizeMenu = new JMenu(this.bundle.getString("thumbnail.size"));
      this.s320_240 = new JRadioButtonMenuItem("320 x 240");
      this.sizeMenu.add(this.s320_240);
      this.bg = new ButtonGroup();
      this.bg.add(this.s320_240);
      this.s160_120 = new JRadioButtonMenuItem("160 x 120");
      this.sizeMenu.add(this.s160_120);
      this.bg.add(this.s160_120);
      ActionListener var1 = new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            String var2 = ((JRadioButtonMenuItem)var1.getSource()).getText();
            if ("320 x 240".equals(var2)) {
               MPCScanFrame.this.scph.setThumbnailSize(new Dimension(320, 240));
            } else if ("160 x 120".equals(var2)) {
               MPCScanFrame.this.scph.setThumbnailSize(new Dimension(160, 120));
            }
         }
      };
      this.s320_240.addActionListener(var1);
      this.s160_120.addActionListener(var1);
      if (this.savedDimension.equals("160x120")) {
         this.s160_120.setSelected(true);
      } else {
         this.s320_240.setSelected(true);
      }

      this.pause = new JMenuItem(this.bundle.getString("Pause.option"));
      ActionListener var2 = new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            MPCScanFrame.state = TargetState.INACTIVE;
            MPCScanFrame.this.statusLabel.setIcon(ResourceLoader.loadImageIcon("Common_led_white.gif"));
            MPCScanFrame.this.osdLabel.setText(MPCScanFrame.this.bundle.getString("paused"));
            MPCScanFrame.this.scanConnector.pause();
         }
      };
      this.pause.addActionListener(var2);
      this.resume = new JMenuItem(this.bundle.getString("resume"));
      ActionListener var3 = new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            MPCScanFrame.this.scanConnector.resume();
         }
      };
      this.resume.addActionListener(var3);
      this.orientation = new JMenu(this.bundle.getString("OptionDialog.SplitOrientation"));
      this.horizontalSplit = new JRadioButtonMenuItem(this.bundle.getString("horizontal"));
      this.verticalSplit = new JRadioButtonMenuItem(this.bundle.getString("vertical"));
      this.bg1 = new ButtonGroup();
      this.bg1.add(this.horizontalSplit);
      this.bg1.add(this.verticalSplit);
      if (this.appPrefs.getScanOrientation().equalsIgnoreCase("vertical")) {
         this.verticalSplit.setSelected(true);
      } else {
         this.horizontalSplit.setSelected(true);
      }

      ActionListener var4 = new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            MPCScanFrame.this.scph.setSplitPaneOrientation(1);
         }
      };
      this.horizontalSplit.addActionListener(var4);
      ActionListener var5 = new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            MPCScanFrame.this.scph.setSplitPaneOrientation(0);
         }
      };
      this.verticalSplit.addActionListener(var5);
      this.orientation.add(this.horizontalSplit);
      this.orientation.add(this.verticalSplit);
      this.menu.add(this.pause);
      this.menu.add(this.resume);
      this.menu.add(new JSeparator());
      this.menu.add((JMenuItem)this.sizeMenu);
      this.menu.add((JMenuItem)this.orientation);
      this.bar.add(this.menu);
      this.scph.addVideoSnapshotSelectionListener(new VideoSnapshotSelectionListener<RemoteConsoleParameters>() {
         public void videoSnapshotSingleClickSelected(RemoteConsoleParameters var1) {
         }

         public void videoSnapshotDoubleClickSelected(RemoteConsoleParameters var1) {
            System.out.println("Double Click Selected.. " + var1.targetPortId);
            MPCScanFrame.this.getScanConnector().pause();
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Pausing Scan before New Connection.");
            int var2x = -1;

            for (int var3x = 0; var3x < MPCScanFrame.this.portIds.length; var3x++) {
               if (MPCScanFrame.this.portIds[var3x].equals(var1.targetPortId)) {
                  var2x = var3x;
               }
            }

            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "User establishing permanent connection to port:" + var1.targetPortId);
            KvmPort var16 = MPCScanFrame.this.kvmportList.get(var2x);
            System.out.println(var16);
            MPCUtil.notifyObservers(MPCScanFrame.this.scrContext, var16);
            ShowKVMFromScanCommand var5x = new ShowKVMFromScanCommand(MPCScanFrame.this.scrContext, var16);
            if (var5x.isExecutable()) {
               CommandResult var6 = var5x.execute();
               if (!var6.isSuccess() && var6.hasErrorDescription()) {
                  MPCScanFrame.this.handleCommandResultErrorDescription(var6);
               } else if (var6.isSuccess()) {
                  MPCScanFrame.this.handleCommandResult(var6);
                  MPCScanFrame.this.scrContext.getPanelMediator().showPanel(var5x.getContext());
                  if (var16.isPrimaryPort()) {
                     ArrayList var7 = (ArrayList)MPCScanFrame.this.scrContext.getSelectedDevicesObservable().getComponent();
                     if (var7 != null && var7.size() > 0) {
                        for (MultiMonitorPort.PortConfig var10 : var16.getSecondaryPortConfigs()) {
                           Map var11 = var16.getDevice().getChildren();
                           if (var11 != null) {
                              for (Object var13 : var11.values()) {
                                 Port var14;
                                 if (var13 instanceof Port && (var14 = (Port)var13).getTargetDeviceId().equals(var10.getPortId())) {
                                    var7.set(0, var14);
                                    ShowKX2KvmPortCommand var15 = new ShowKX2KvmPortCommand(MPCScanFrame.this.scrContext);
                                    var15.setAllowSecondary(true);
                                    if (var15.isExecutable()) {
                                       var15.getContext().setCommandParameter("selectedPortDevice", var16.getDevice());
                                       var6 = var15.execute();
                                       if (!var6.isSuccess() && var6.hasErrorDescription()) {
                                          MPCScanFrame.this.handleCommandResultErrorDescription(var6);
                                       } else if (var6.isSuccess()) {
                                          MPCScanFrame.this.handleCommandResult(var6);
                                          MPCScanFrame.this.scrContext.getPanelMediator().showPanel(var15.getContext());
                                       }
                                    }
                                    break;
                                 }
                              }
                           }
                        }
                     }
                  }
               }
            }
         }
      });
      this.setJMenuBar(this.bar);
      this.add(this.scph.getScanPanel());
      this.statusBar = new JPanel();
      this.statusBar.setLayout(new GridBagLayout());
      GridBagConstraints var6 = new GridBagConstraints();
      this.statusBar.setBorder(BorderFactory.createRaisedBevelBorder());
      this.statusLabel.setBorder(BorderFactory.createLoweredBevelBorder());
      this.osdLabel.setBorder(BorderFactory.createLoweredBevelBorder());
      this.p = new JPanel();
      this.p.setLayout(new GridBagLayout());
      var6.weightx = 0.3;
      var6.weighty = 1.0;
      var6.fill = 1;
      this.p.add(this.statusLabel, var6);
      var6.weightx = 0.7;
      var6.gridx = 1;
      this.p.add(this.osdLabel, var6);
      var6 = new GridBagConstraints();
      var6.weightx = 1.0;
      var6.fill = 1;
      this.statusBar.add(this.p, var6);
   }

   private static ScanConnector createScanConnector(List<RemoteConsoleParameters> var0) {
      ArrayList var1 = new ArrayList();

      for (RemoteConsoleParameters var3 : var0) {
         var1.add(var3.targetPortId);
      }

      return new ScanConnector(var0);
   }

   private void createScanSession(
      final RemoteConsoleParameters var1, final String[] var2, final ScanSessionEventsListener var3, final NotificationListener var4
   ) {
      SwingWorker var5 = new SwingWorker<ScanSession, Void>() {
         protected ScanSession doInBackground() throws Exception {
            ScanCore var1x;
            try {
               var1x = ScanCoreFactory.getDefault();
            } catch (ScanCoreException var6) {
               RemoteConsoleLogger.getInstance().getLogger().log(Level.SEVERE, "Exception on Scan connection", (Throwable)var6);
               throw var6;
            }

            ScanSession var2x;
            if (var1.username != null && var1.password != null) {
               var2x = var1x.createScanSessionWithUsernameAndPassword(var1.getURLCompatibleRemoteHost(), var1.tcpPort, var1.ssl, var1.username, var1.password);
            } else if (var1.ericKey != null) {
               var2x = var1x.createScanSessionWithEricKey(var1.getURLCompatibleRemoteHost(), var1.tcpPort, var1.ssl, var1.ericKey);
            } else {
               if (var1.rdmSession == null) {
                  RemoteConsoleLogger.getInstance().getLogger().log(Level.SEVERE, "Missing authentication parameters");
                  throw new Exception("Missing authentication parameters");
               }

               var2x = var1x.createScanSessionWithRdmSessionID(
                  var1.getURLCompatibleRemoteHost(), var1.tcpPort, var1.ssl, var1.rdmSession, var1.proxyConnectionId, var1.proxyUseSSL
               );
            }

            try {
               var2x.start(var2, var3, var4);
               return var2x;
            } catch (ScanCoreException var4x) {
               RemoteConsoleLogger.getInstance().getLogger().log(Level.SEVERE, "Exception on Scan connection", (Throwable)var4x);
               throw var4x;
            } catch (IOException var5x) {
               RemoteConsoleLogger.getInstance().getLogger().log(Level.SEVERE, "Exception on Scan connection", (Throwable)var5x);
               throw var5x;
            }
         }

         @Override
         protected void done() {
            try {
               try {
                  MPCScanFrame.scanSession = this.get();
               } catch (InterruptedException var6) {
                  Thread.currentThread().interrupt();
                  return;
               } catch (ExecutionException var7) {
                  RemoteConsoleLogger.getInstance().getLogger().log(Level.SEVERE, "Exception on Scan connection", (Throwable)var7);
                  JOptionPane.showMessageDialog(null, "Error connecting to the device.");
                  MPCScanFrame.this.close();
               }
            } finally {
               ;
            }
         }
      };
      var5.execute();
   }

   public void close() {
      try {
         this.scph.getScanConnector().stop();
         if (getScanSession() != null) {
            getScanSession().close();
         }

         this.scrContext.setScanFrame(null);
         this.scrContext.setScanFrameOpened(false);
      } catch (Exception var2) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.SEVERE, "Exception Occured while closing scan frame:", (Throwable)var2);
      }
   }

   @Override
   public void internalFrameClosing(InternalFrameEvent var1) {
      this.close();
      super.internalFrameClosing(var1);
   }

   private static String getPortNumbersAsString(String[] var0) {
      String var1 = "";

      for (int var2 = 0; var2 < var0.length; var2++) {
         var1 = var1 + "," + var0[var2];
      }

      int var3 = var1.length();
      return var1.substring(1, var3 - 1);
   }

   protected void handleCommandResultErrorDescription(CommandResult var1) {
      if (var1 != null) {
         StringBuffer var2 = new StringBuffer("");
         if (var1.getErrorDescription() != null && var1.getErrorDescription().length > 0) {
            for (int var3 = 0; var3 < var1.getErrorDescription().length; var3++) {
               var2.append(var1.getErrorDescription()[var3]);
               var2.append("\n");
            }
         } else if (var1.getStatusMessage() != null) {
            var2.append(var1.getStatusMessage());
         } else {
            var2.append("No command result info.");
         }

         CommonPopups.showCommandResultErrorMessage(var2.toString(), null, this.scrContext);
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   protected void handleCommandResult(CommandResult var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   private ArrayList<RemoteConsoleParameters> getParams() {
      ArrayList var1 = new ArrayList();

      for (int var2 = 0; var2 < this.kvmportList.size(); var2++) {
         RemoteConsoleParameters var3 = new RemoteConsoleParameters();
         KvmPort var4 = this.kvmportList.get(var2);
         if (var4.isBladePort()) {
            var3.portIndex = Integer.toString(var4.getParentIndex()) + "." + Integer.toString(var4.getPortIndex());
         } else {
            var3.portIndex = Integer.toString(var4.getPortIndex());
         }

         var3.targetPortId = var4.getStripTargetDeviceId();
         var3.portName = var4.getName();
         var3.host = com.raritan.tools.util.Util.getURLCompatibleIP(var4.getDevice().getIP());
         var3.tcpPort = var4.getDevice().getHttpsPort();
         var3.rdmSession = "\"" + var4.getDevice().getRdmSessionId() + "\":\"" + var4.getDevice().getRdmSessionKey() + "\"";
         var3.ssl = true;
         var1.add(var3);
         this.setConnectedDeviceId(var4.getDevice().getId());
      }

      return var1;
   }

   public String getConnectedDeviceId() {
      return this.connectedDeviceId;
   }

   public void setConnectedDeviceId(String var1) {
      this.connectedDeviceId = var1;
   }

   public static void main(String[] var0) {
      ArrayList var1 = new ArrayList();
      HashMap var2 = new HashMap();
      HashMap var3 = new HashMap();
      RemoteConsoleParameters var4 = new RemoteConsoleParameters();
      var4.portIndex = "0";
      var4.targetPortId = "P_000d5d0007cb_0";
      var4.portName = "KXG1-LocalPortzzzzzzzzzzzzzzzzzzz";
      var4.username = "admin";
      var4.password = "raritan";
      var4.host = "192.168.52.230";
      var4.tcpPort = 443;
      var4.ssl = true;
      var1.add(var4);
      var2.put("P_000d5d0007cb_0", "VM");
      var3.put("P_000d5d0007cb_0", "CCC");
      RemoteConsoleParameters var5 = new RemoteConsoleParameters();
      var5.portIndex = "1";
      var5.targetPortId = "P_000d5d0007cb_1";
      var5.portName = "Port2";
      var5.username = "admin";
      var5.password = "raritan";
      var5.host = "192.168.52.230";
      var5.tcpPort = 443;
      var5.ssl = true;
      var1.add(var5);
      var2.put("P_000d5d0007cb_1", "VM");
      var3.put("P_000d5d0007cb_1", "CCC");
      RemoteConsoleParameters var6 = new RemoteConsoleParameters();
      var6.portIndex = "2";
      var6.targetPortId = "P_000d5d0007cb_2";
      var6.portName = "Port3";
      var6.username = "admin";
      var6.password = "raritan";
      var6.host = "192.168.52.230";
      var6.tcpPort = 443;
      var6.ssl = true;
      var1.add(var6);
      var2.put("P_000d5d0007cb_2", "VM");
      var3.put("P_000d5d0007cb_2", "CCC");
      RemoteConsoleParameters var7 = new RemoteConsoleParameters();
      var7.portIndex = "3";
      var7.targetPortId = "P_000d5d0007cb_3";
      var7.portName = "Port4";
      var7.username = "admin";
      var7.password = "raritan";
      var7.host = "192.168.52.230";
      var7.tcpPort = 443;
      var7.ssl = true;
      var1.add(var7);
      var2.put("P_000d5d0007cb_3", "VM");
      var3.put("P_000d5d0007cb_3", "CCC");
      RemoteConsoleParameters var8 = new RemoteConsoleParameters();
      var8.portIndex = "23";
      var8.targetPortId = "P_000d5d0007cb_23";
      var8.portName = "CCSG-Local-Port";
      var8.username = "admin";
      var8.password = "raritan";
      var8.host = "192.168.52.230";
      var8.tcpPort = 443;
      var8.ssl = true;
      var1.add(var8);
      var2.put("P_000d5d0007cb_23", "VM");
      var3.put("P_000d5d0007cb_23", "CCC");
      RemoteConsoleParameters var9 = new RemoteConsoleParameters();
      var9.portIndex = "30.0";
      var9.targetPortId = "P_000d5d0007cb_29_0";
      var9.portName = "CCSG-Local-Port";
      var9.username = "admin";
      var9.password = "raritan";
      var9.host = "192.168.52.230";
      var9.tcpPort = 443;
      var9.ssl = true;
      var1.add(var9);
      var2.put("P_000d5d0007cb_29_0", "VM");
      var3.put("P_000d5d0007cb_29_0", "CCC");
      new MPCScanFrame(null);
   }

   private static class MyLabel extends JLabel {
      private MyLabel() {
      }

      @Override
      public Dimension getPreferredSize() {
         return new Dimension(10, super.getPreferredSize().height);
      }

      @Override
      public Dimension getMinimumSize() {
         return this.getPreferredSize();
      }
   }
}
