package com.raritan.rrc.ui;

import java.awt.GraphicsConfiguration;
import java.awt.GraphicsDevice;
import java.awt.GraphicsEnvironment;
import javaclientlib.utils.RRCLogger;

public class MonitorSettingsHandler {
   private static MonitorSettingsHandler instance = null;
   private final RRCScreenContext context;
   private final GraphicsEnvironment ge;
   private GraphicsDevice gd;
   private GraphicsConfiguration gc;

   private MonitorSettingsHandler(RRCScreenContext var1) {
      this.context = var1;
      this.ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
   }

   public static MonitorSettingsHandler getInstance() {
      return instance;
   }

   public static void init(RRCScreenContext var0) {
      synchronized (MonitorSettingsHandler.class) {
         if (instance == null) {
            instance = new MonitorSettingsHandler(var0);
         }
      }

      instance.determineConfiguredGraphicsConfiguration();
   }

   public void determineConfiguredGraphicsConfiguration() {
      String var1 = this.context.getAppSettings().getMonitorSetting();
      int var2 = this.context.getAppSettings().getMonitorCount();
      this.context.setMonitorCountMatch(var2 == this.ge.getScreenDevices().length);
      if (var1 != null && !var1.equals("") && var2 == this.ge.getScreenDevices().length) {
         GraphicsDevice[] var3 = this.ge.getScreenDevices();
         GraphicsDevice var4 = null;

         for (int var5 = 0; var5 < var3.length; var5++) {
            GraphicsDevice var6 = var3[var5];
            if (var1 != null && var6.getIDstring().equals(var1)) {
               var4 = var6;
               break;
            }
         }

         if (var4 != null) {
            this.gc = var4.getDefaultConfiguration();
            this.gd = var4;
            RRCLogger.log(200, 4, "Monitor Setting found. Using Monitor: " + var4.getIDstring());
         } else {
            this.gc = this.ge.getDefaultScreenDevice().getDefaultConfiguration();
            this.gd = this.ge.getDefaultScreenDevice();
            RRCLogger.log(200, 4, "Monitor Setting NOT found. Using default Monitor:: " + this.ge.getDefaultScreenDevice());
         }
      } else {
         this.gc = this.ge.getDefaultScreenDevice().getDefaultConfiguration();
         this.gd = this.ge.getDefaultScreenDevice();
         RRCLogger.log(200, 4, "Monitor Setting NOT found. Using default Monitor:: " + this.ge.getDefaultScreenDevice());
      }
   }

   public void setGraphicsDevice(String var1) {
      GraphicsEnvironment var2 = GraphicsEnvironment.getLocalGraphicsEnvironment();
      GraphicsDevice[] var3 = var2.getScreenDevices();

      for (int var4 = 0; var4 < var3.length; var4++) {
         GraphicsDevice var5 = var3[var4];
         if (var5.getIDstring().equals(var1)) {
            this.gd = var5;
            this.gc = this.gd.getDefaultConfiguration();
            break;
         }
      }
   }

   public int getMonitorCount() {
      return this.ge.getScreenDevices().length;
   }

   public GraphicsDevice getGraphicsDevice() {
      return this.gd;
   }

   public GraphicsConfiguration getGraphicsConfiguration() {
      return this.gc;
   }

   public GraphicsConfiguration getPrimaryGraphicsConfiguration() {
      return this.ge.getDefaultScreenDevice().getDefaultConfiguration();
   }

   public GraphicsConfiguration getSecondaryGraphicsConfiguration(GraphicsDevice var1, int var2) {
      GraphicsDevice[] var3 = this.ge.getScreenDevices();
      int var4 = 0;

      for (int var5 = 0; var5 < var3.length; var5++) {
         if (var3[var5] != var1) {
            if (++var4 == var2) {
               return var3[var5].getDefaultConfiguration();
            }
         }
      }

      return null;
   }

   public GraphicsConfiguration getSecondaryGraphicsConfiguration(int var1) {
      return this.getSecondaryGraphicsConfiguration(this.ge.getDefaultScreenDevice(), var1);
   }
}
