package com.raritan.rrc.ui;

import com.raritan.plaf.RaritanRootPane;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.commands.CloseAppletCommand;
import com.raritan.rrc.ui.components.CommandMenuItemCache;
import com.raritan.rrc.ui.components.FullScreenToolBar;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.ui.panes.mediator.RRCPanelMediator;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.smartcard.SmartCardCoreFactory;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.ui.AbstractUIManager;
import com.raritan.tools.ui.State;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.util.image.DualImageFactory;
import java.awt.Component;
import java.awt.Container;
import java.awt.Cursor;
import java.awt.DefaultKeyboardFocusManager;
import java.awt.Frame;
import java.awt.GraphicsDevice;
import java.awt.Image;
import java.awt.KeyboardFocusManager;
import java.awt.Window;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.Vector;
import java.util.logging.Logger;
import javaclientlib.utils.RRCLogger;
import javax.swing.JApplet;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JOptionPane;
import javax.swing.JRootPane;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;
import javax.swing.event.InternalFrameAdapter;
import javax.swing.event.InternalFrameEvent;
import netscape.javascript.JSObject;
import nn.pp.common.Util;
import nn.pp.core.JVMVersionInfo;
import nn.pp.core.Platform;

public class RRCApplet extends JApplet implements AbstractUIManager {
   private RRCMain main;
   private boolean connected;
   private static final long serialVersionUID = 176995716690523002L;
   private static final int WIDTH = 800;
   private static final int HEIGHT = 600;
   private static final String[] APPLET_PARAMETERS = new String[]{
      "default.locale",
      "application.log.level",
      "application.log.output",
      "application.resource.file",
      "log.panel.history",
      "log.timestamp.format",
      "help.url.root",
      "connection",
      "dialog.panels",
      "dialog.panels_cc"
   };
   private String DocumentBuilderFactory = "javax.xml.parsers.DocumentBuilderFactory";
   private String TransformerFactory = "javax.xml.transform.TransformerFactory";
   private String SAXParserFactory = "javax.xml.parsers.SAXParserFactory";
   private String XSLTCDTMManager = "com.sun.org.apache.xalan.internal.xsltc.dom.XSLTCDTMManager";
   private Component component;
   private RRCScreenContext context;
   private RaritanRootPane customRootPane;
   private static RaritanPropertyResourceBundle bundle = null;
   private List<JDialog> disposedShells = new Vector<>();

   public RRCApplet() {
      this.customRootPane = null;
   }

   @Override
   public void init() {
      Frame var1 = JOptionPane.getFrameForComponent(this);
      boolean var2 = Platform.isLinux() && !"javax.swing.SwingUtilities$SharedOwnerFrame".equals(var1.getClass().getName());
      if (var2) {
         RRCApplet.RaritanKeyboardFocusManager var3 = new RRCApplet.RaritanKeyboardFocusManager();
         KeyboardFocusManager.setCurrentKeyboardFocusManager(var3);
         Frame var4 = JOptionPane.getFrameForComponent(this);
         var4.addWindowListener(RRCPanelMediator.postLinuxWindowAdapter);
      }

      try {
         Logger var10 = Logger.getLogger("java.util.prefs");
         var10.setUseParentHandlers(false);
         System.setProperty(this.DocumentBuilderFactory, "com.sun.org.apache.xerces.internal.jaxp.DocumentBuilderFactoryImpl");
         System.setProperty(this.XSLTCDTMManager, "com.sun.org.apache.xalan.internal.xsltc.dom.XSLTCDTMManager");
         System.setProperty(this.TransformerFactory, "com.sun.org.apache.xalan.internal.xsltc.trax.TransformerFactoryImpl");
         System.setProperty(this.SAXParserFactory, "com.sun.org.apache.xerces.internal.jaxp.SAXParserFactoryImpl");
         UIManager.setLookAndFeel("com.raritan.plaf.RaritanLookAndFeel");
      } catch (ClassNotFoundException var6) {
      } catch (InstantiationException var7) {
      } catch (IllegalAccessException var8) {
      } catch (UnsupportedLookAndFeelException var9) {
      }

      this.setSize(800, 600);
      this.context = (RRCScreenContext)RRCScreenContext.getNewInstance(this.getAppletParameters());
      this.context.setApplication(this);
      this.context.setState(State.INIT);
      this.context.setAppletContext(this.getAppletContext());
      this.context.setAppletCodeBase(this.getCodeBase());
      MonitorSettingsHandler.init(this.context);
      this.main = new RRCMain(this, this.context);
      this.main.loadScreenManager();
      bundle = this.main.getBundle();
      final RRCScreenContext var11 = this.context;

      try {
         SwingUtilities.invokeLater(
            new Runnable() {
               @Override
               public void run() {
                  if (!RRCApplet.this.main.getScreenManager().show()) {
                     CommonPopups.showErrorMessage(
                        RRCApplet.bundle.getString("error.connect.port"),
                        RRCApplet.this.getContentPane(),
                        var11,
                        RRCApplet.bundle.getString("optionpane.error.title")
                     );
                     if (MPCUtil.isCCLaunched(RRCApplet.this.context) && RRCApplet.this.component != null) {
                        ((JFrame)RRCApplet.this.component).dispose();
                     }
                  } else if (RRCApplet.this.context.getSelectView() != null) {
                     RRCApplet.this.context.getSelectView().setViewFocus();
                  }

                  RRCApplet.this.connected = true;
               }
            }
         );
      } catch (Exception var5) {
         RRCLogger.logException(var5);
      }

      if (RRCLogger.logEnabled && this.component != null && this.context != null) {
         CommonPopups.showWarningDialog(bundle.getString("optionpane.warning.tite"), bundle.getString("View.warning.log.on"), this.component, this.context);
      }

      RRCLogger.log(200, 4, JVMVersionInfo.getSystemProperties().toString());
      RRCLogger.log(200, 4, "Multi-platform Client Version: " + bundle.getString("about.label.build"));
      RRCLogger.log(200, 4, "Max memory: " + Runtime.getRuntime().maxMemory());
      RRCLogger.log(200, 4, "Disable Direct Draw: " + System.getProperty("sun.java2d.noddraw"));
      if (this.getParameter("connection") != null) {
         this.getFrameComponent();
      }
   }

   @Override
   public Component getOptionComponent() {
      return this;
   }

   @Override
   public URL getIconBase() {
      return this.main.getIconBase();
   }

   @Override
   protected JRootPane createRootPane() {
      try {
         this.customRootPane = new RaritanRootPane(this);
      } catch (Exception var2) {
      }

      return this.customRootPane;
   }

   @Override
   public void destroy() {
      if (MPCUtil.isCCLaunched(this.context)) {
         ArrayList var5 = this.context.getListOfOpenPorts();
         int var4 = var5.size();

         for (int var3 = 0; var3 < var4; var3++) {
            String var2;
            if (var5.get(var3) != null) {
               var2 = var5.get(var3).toString();
            } else {
               var2 = null;
            }

            if (var2 != null && this.context != null) {
               Port var1 = (Port)this.context.getPortByKeyObservable(var2);
               if (var1.isConnected()) {
                  var1.disconnect();
               }
            }
         }
      } else {
         DeviceTreeController.getInstance().stop();
      }

      SmartCardCoreFactory.reset();
      if (this.customRootPane != null) {
         this.customRootPane.destroy();
         this.customRootPane = null;
      }

      if (this.context != null) {
         this.context.destroy();
         this.context = null;
      }

      if (this.main != null) {
         this.main.dispose();
         this.main = null;
      }

      if (this.customRootPane != null) {
         this.customRootPane.destroy();
         this.customRootPane = null;
      }

      DeviceTreeController.clearInstance();
      DualImageFactory.clearCachedImages();
      CommandMenuItemCache.destroy();
      super.destroy();
   }

   private Map getAppletParameters() {
      HashMap var1 = new HashMap();
      Object var2 = null;

      for (int var3 = 0; var3 < APPLET_PARAMETERS.length; var3++) {
         var2 = this.getParameter(APPLET_PARAMETERS[var3]);
         if (var2 != null) {
            var1.put(APPLET_PARAMETERS[var3], var2);
         }
      }

      return var1;
   }

   @Override
   public boolean isStandalone() {
      return false;
   }

   @Override
   public Container getContentPane() {
      Container var1 = this.main.getActiveContentPane();
      return var1 != null ? var1 : super.getContentPane();
   }

   @Override
   public Container getContentPaneForPort(Port var1) {
      Container var2 = this.main.getContentPaneForPort(var1);
      return var2 != null ? var2 : this.getContentPane();
   }

   public JComponent getUIComponent() {
      return this.getRootPane();
   }

   public Component getFrameComponent() {
      if (this.component == null) {
         String var1 = this.getParameter("title");
         String var2 = this.getParameter("InternalFrame");
         if (var2 != null && var2.equals("true")) {
            RRCApplet.InnerFrameAdapter var4 = new RRCApplet.InnerFrameAdapter();
            var4.setConfirmation(true);
            this.component = new JInternalFrame(bundle.getString("main.screen.title"));
            ((JInternalFrame)this.component).setContentPane(this.getContentPane());
            ((JInternalFrame)this.component).setDefaultCloseOperation(0);
            ((JInternalFrame)this.component).addInternalFrameListener(var4);
         } else {
            RRCMain.InnerWindowAdapter var3 = this.main.getInnerWindowAdapter();
            var3.setConfirmation(true);
            var3.setCommand(new CloseAppletCommand(this.context));
            this.component = new JFrame(var1, this.main.getGraphicsConfig());
            ((JFrame)this.component).setContentPane(this.getContentPane());
            ((JFrame)this.component).setDefaultCloseOperation(0);
            ((JFrame)this.component).addWindowListener(var3);
         }

         this.component.setVisible(true);
         this.component.setSize(this.getWidth(), this.getHeight());
         Properties var5 = this.context.getApplicationProperties();
         var5.put("embeddedInFrame", "true");
         this.context.setApplicationProperties(var5);
      }

      return this.component;
   }

   public boolean connect() {
      return this.main.getScreenManager() != null
         && this.main.getScreenManager().getScreenContext() != null
         && this.main.getScreenManager().getScreenContext().getSelectedDevicesObservable() != null;
   }

   private void appletClosed() {
      this.firePropertyChange("connection", "opened", "closed");
   }

   @Override
   public void disconnect() {
      ArrayList var1 = (ArrayList)this.main.getScreenManager().getScreenContext().getSelectedDevicesObservable().getComponent();
      if (var1 != null) {
         Device var2 = (Device)var1.get(0);
         if (var2 != null && var2.isConnected()) {
            var2.disconnect();
         }

         if (this.component != null) {
            if (this.component instanceof JInternalFrame) {
               ((JInternalFrame)this.component).dispose();
            } else {
               ((JFrame)this.component).dispose();
            }
         }
      }

      this.appletClosed();
   }

   @Override
   public void stop() {
      try {
         RRCLogger.closeFileHandler();
         if (MPCUtil.isCCLaunched(this.context)) {
            JSObject var1 = JSObject.getWindow(this);
            JSObject var2 = (JSObject)var1.getMember("parent");
         } else {
            String var6 = this.getCodeBase().getHost();
            String var7 = "";
            int var3;
            if ((var3 = this.getCodeBase().getPort()) != -1) {
               var7 = ":" + var3;
            }

            URL var4 = new URL("https://" + var6 + var7 + "/exit.html");
            this.getAppletContext().showDocument(var4);
         }
      } catch (Exception var5) {
      }

      this.appletClosed();
   }

   @Override
   public synchronized void changeScreen(boolean var1, JInternalFrame var2, Port var3, AbstractUIManager.FullScreenTarget var4) {
      if (var1) {
         this.main.enterFullScreen(var2, var3, var4);
      } else {
         this.main.returnFromFullScreen();
      }
   }

   @Override
   public Cursor getBlankCursor() {
      return this.main.getBlankCursor();
   }

   @Override
   public Cursor getDefaultCursor() {
      return this.main.getDefaultCursor();
   }

   @Override
   public GraphicsDevice getGraphicsDevice() {
      return this.main.getGraphicsDevice();
   }

   @Override
   public void setGraphicsDevice(String var1) {
      this.main.setGraphicsDevice(var1);
   }

   @Override
   public FullScreenToolBar getFSToolBar(JInternalFrame var1) {
      return this.main.getFSToolBar(var1);
   }

   public void closeAllWindows() {
      this.context.getPanelMediator().hideAll();
   }

   @Override
   public void setFrameVisible(boolean var1) {
      Runnable var2 = new Runnable() {
         @Override
         public void run() {
            for (JDialog var2x : RRCApplet.this.disposedShells) {
               var2x.dispose();
            }

            RRCApplet.this.disposedShells.clear();
         }
      };
      if (var1) {
         SwingUtilities.invokeLater(var2);
      } else {
         var2.run();
      }

      if (this.component == null) {
         super.getContentPane().getComponent(0).setVisible(var1);
         this.invalidate();
         this.validate();
      } else if (Util.isJavaWithFocusProblem()) {
         Frame var3 = JOptionPane.getFrameForComponent(this);
         var3.setVisible(var1);
         if (var1) {
            var3.setFocusableWindowState(true);
            var3.invalidate();
            var3.validate();
            var3.requestFocus();
         }
      } else {
         super.setVisible(var1);
         if (var1) {
            this.getContentPane().invalidate();
            this.getContentPane().validate();
         }
      }
   }

   @Override
   public void setIconImage(Image var1) {
   }

   @Override
   public String getAppId() {
      return this.main.getAppId();
   }

   @Override
   public void addDisposedShell(JDialog var1) {
      if (!this.disposedShells.contains(var1)) {
         this.disposedShells.add(var1);
      }
   }

   private class InnerFrameAdapter extends InternalFrameAdapter implements ConfirmableCommandInterface {
      private boolean confirmation = false;

      private InnerFrameAdapter() {
      }

      @Override
      public void internalFrameClosing(InternalFrameEvent var1) {
         boolean var2 = false;
         if (this.getConfirmation()) {
            var2 = CommonPopups.showExitConfirmationDialog(RRCApplet.this.getContentPane(), RRCApplet.this.context) != 2;
         }

         if (!var2) {
            RRCApplet.this.disconnect();
         }
      }

      @Override
      public void setConfirmation(boolean var1) {
         this.confirmation = var1;
      }

      @Override
      public boolean getConfirmation() {
         return this.confirmation;
      }
   }

   public static class LinuxWindowDeactivatedHandler extends WindowAdapter {
      @Override
      public void windowDeactivated(WindowEvent var1) {
         RRCApplet.RaritanKeyboardFocusManager var2 = (RRCApplet.RaritanKeyboardFocusManager)KeyboardFocusManager.getCurrentKeyboardFocusManager();
         Window var3 = var1.getWindow();
         if (var1.getOppositeWindow() == null) {
            var2.setGlobalActiveWindow(var3);
            var2.setGlobalFocusedWindow(var3);
         }
      }
   }

   public static class RaritanKeyboardFocusManager extends DefaultKeyboardFocusManager {
      @Override
      public void setGlobalActiveWindow(Window var1) {
         super.setGlobalActiveWindow(var1);
      }

      @Override
      public void setGlobalFocusedWindow(Window var1) {
         super.setGlobalFocusedWindow(var1);
      }
   }
}
