package com.raritan.rrc.ui;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.commands.ExitSystemCommand;
import com.raritan.rrc.ui.commands.ShowTargetScreenResolutionCommand;
import com.raritan.rrc.ui.components.FullScreenToolBar;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.ui.AbstractUIManager;
import com.raritan.tools.ui.State;
import com.raritan.tools.ui.components.CommonPopups;
import java.awt.Component;
import java.awt.Container;
import java.awt.Cursor;
import java.awt.GraphicsConfiguration;
import java.awt.GraphicsDevice;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Vector;
import java.util.logging.Logger;
import javaclientlib.utils.RRCLogger;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import nn.pp.core.JVMVersionInfo;

public class RRCApplication extends JFrame implements AbstractUIManager {
   private static final long serialVersionUID = 6415390041361678243L;
   private static RRCMain.InnerWindowAdapter listenerAdapter;
   private static final int WIDTH = 800;
   private static final int HEIGHT = 600;
   private RRCMain main;
   private RRCScreenContext context;
   private static RaritanPropertyResourceBundle bundle = null;
   private List<JDialog> disposedShells = new Vector<>();

   public RRCApplication(String var1, final RRCScreenContext var2, GraphicsConfiguration var3) {
      super(var1, var3);
      this.setDefaultCloseOperation(0);
      this.context = var2;
      this.context.setApplication(this);
      this.context.setState(State.INIT);
      this.main = new RRCMain(this, this.context);
      this.main.loadScreenManager();
      bundle = this.main.getBundle();
      this.setTitle(var1);
      if (System.getProperty("java.version").compareTo("1.6.0") < 0) {
         JOptionPane var4 = new JOptionPane(
            bundle.getString("Application.error.notSupported.java"), 0, -1, null, new Object[]{bundle.getString("basescreen.command.ok.text")}
         );
         JDialog var5 = var4.createDialog(null, bundle.getString("optionpane.error.title"));
         var5.setModal(true);
         var5.setVisible(true);
         System.exit(0);
      }

      listenerAdapter = this.main.getInnerWindowAdapter();
      listenerAdapter.setCommand(new ExitSystemCommand(this.context));
      listenerAdapter.setConfirmation(true);
      this.addWindowListener(listenerAdapter);
      this.pack();
      this.setSize(800, 600);
      SwingUtilities.invokeLater(
         new Runnable() {
            @Override
            public void run() {
               RRCApplication.this.setVisible(true);
               if (!RRCApplication.this.main.getScreenManager().show()) {
                  CommonPopups.showErrorMessage(
                     RRCApplication.bundle.getString("error.connect.port"),
                     RRCApplication.this.getContentPane(),
                     var2,
                     RRCApplication.bundle.getString("optionpane.error.title")
                  );
                  RRCApplication.this.disconnect();
               }

               if (RRCLogger.logEnabled) {
                  CommonPopups.showWarningDialog(
                     RRCApplication.bundle.getString("optionpane.warning.tite"),
                     RRCApplication.bundle.getString("View.warning.log.on"),
                     RRCApplication.this,
                     RRCApplication.this.context
                  );
               }
            }
         }
      );
      RRCLogger.log(200, 4, JVMVersionInfo.getSystemProperties().toString());
      RRCLogger.log(200, 4, "Multi-platform Client Version: " + bundle.getString("about.label.build"));
      RRCLogger.log(200, 4, "Max memory: " + Runtime.getRuntime().maxMemory());
      RRCLogger.log(200, 4, "Disable Direct Draw: " + System.getProperty("sun.java2d.noddraw"));
   }

   @Override
   public Component getOptionComponent() {
      return this;
   }

   @Override
   public URL getIconBase() {
      return this.main.getIconBase();
   }

   @Override
   public Container getContentPane() {
      Container var1 = this.main.getActiveContentPane();
      return var1 != null ? var1 : super.getContentPane();
   }

   @Override
   public Container getContentPaneForPort(Port var1) {
      Container var2 = this.main.getContentPaneForPort(var1);
      return var2 != null ? var2 : this.getContentPane();
   }

   @Override
   public boolean isStandalone() {
      return true;
   }

   @Override
   public synchronized void changeScreen(boolean var1, JInternalFrame var2, Port var3, AbstractUIManager.FullScreenTarget var4) {
      try {
         if (var1) {
            this.main.enterFullScreen(var2, var3, var4);
         } else {
            this.main.returnFromFullScreen();
         }
      } catch (InternalError var8) {
         try {
            this.context.getPanelMediator().showStatusPanel(true);
         } catch (Exception var7) {
         }

         ShowTargetScreenResolutionCommand var6 = new ShowTargetScreenResolutionCommand(this.context);
         if (var6.isExecutable()) {
            var6.execute();
         }
      }
   }

   public static void main(String[] var0) {
      try {
         UIManager.setLookAndFeel("com.raritan.plaf.RaritanLookAndFeel");
      } catch (Exception var6) {
      }

      Logger var1 = Logger.getLogger("java.util.prefs");
      var1.setUseParentHandlers(false);
      HashMap var2 = new HashMap();

      for (int var3 = 0; var3 < var0.length; var3++) {
         int var4 = var0[var3].indexOf("=");
         var2.put(var0[var3].substring(0, var4), var0[var3].substring(var4 + 1, var0[var3].length()));
      }

      Object var7 = null;
      if (var2.containsKey("title")) {
         var7 = (String)var2.get("title");
      } else {
         var7 = "Raritan Multi-Platform Client";
      }

      RRCScreenContext var9 = (RRCScreenContext)RRCScreenContext.getNewInstance(var2);
      MonitorSettingsHandler.init(var9);
      new RRCApplication((String)var7, var9, MonitorSettingsHandler.getInstance().getGraphicsConfiguration());
   }

   @Override
   public Cursor getBlankCursor() {
      return this.main.getBlankCursor();
   }

   @Override
   public Cursor getDefaultCursor() {
      return this.main.getDefaultCursor();
   }

   @Override
   public GraphicsDevice getGraphicsDevice() {
      return this.main.getGraphicsDevice();
   }

   @Override
   public void setGraphicsDevice(String var1) {
      this.main.setGraphicsDevice(var1);
   }

   @Override
   public void disconnect() {
      ArrayList var1 = (ArrayList)this.main.getScreenManager().getScreenContext().getSelectedDevicesObservable().getComponent();
      if (var1 != null) {
         Device var2 = (Device)var1.get(0);
         if (var2 != null && var2.isConnected()) {
            var2.disconnect();
         }
      }

      System.exit(0);
   }

   @Override
   public FullScreenToolBar getFSToolBar(JInternalFrame var1) {
      return this.main.getFSToolBar(var1);
   }

   @Override
   public void setFrameVisible(boolean var1) {
      Runnable var2 = new Runnable() {
         @Override
         public void run() {
            for (JDialog var2x : RRCApplication.this.disposedShells) {
               var2x.dispose();
            }

            RRCApplication.this.disposedShells.clear();
         }
      };
      if (var1) {
         SwingUtilities.invokeLater(var2);
      } else {
         var2.run();
      }

      super.setVisible(var1);
      if (var1) {
         this.getContentPane().invalidate();
         this.getContentPane().validate();
      }
   }

   @Override
   public String getAppId() {
      return this.main.getAppId();
   }

   @Override
   public void addDisposedShell(JDialog var1) {
      if (!this.disposedShells.contains(var1)) {
         this.disposedShells.add(var1);
      }
   }
}
