package com.raritan.rrc.ui;

import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.components.CommandMenuItemCache;
import com.raritan.rrc.ui.components.FullScreenFrame;
import com.raritan.rrc.ui.components.FullScreenToolBar;
import com.raritan.rrc.ui.screens.RRCScreenManager;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.AbstractUIManager;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.ShellInternalFrame;
import com.raritan.tools.util.ImageHolder;
import java.awt.Container;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.GraphicsConfiguration;
import java.awt.GraphicsDevice;
import java.awt.HeadlessException;
import java.awt.Image;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.image.MemoryImageSource;
import java.beans.PropertyVetoException;
import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Date;
import java.util.HashMap;
import java.util.Locale;
import java.util.Random;
import java.util.Map.Entry;
import javaclientlib.utils.RRCLogger;
import javax.swing.JComponent;
import javax.swing.JInternalFrame;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.border.Border;
import nn.pp.core.Platform;

public class RRCMain {
   private RRCScreenContext context;
   private static final filterPrintStream fps = new filterPrintStream();
   private AbstractUIManager ui;
   private RaritanPropertyResourceBundle bundle;
   MonitorSettingsHandler mh;
   private RRCScreenManager screenManager;
   private RRCMain.InnerWindowAdapter listenerAdapter = new RRCMain.InnerWindowAdapter();
   private GraphicsDevice gd;
   private GraphicsConfiguration graphicsConfig;
   private boolean dontShowMainFrame = false;
   private Cursor defaultCursor;
   private Cursor blankCursor;
   private String appId = null;
   private HashMap<JInternalFrame, FullScreenFrame> fullScreenFrames = new HashMap<>();

   public RRCMain(AbstractUIManager var1, RRCScreenContext var2) {
      this.ui = var1;
      this.context = var2;
      String var3 = var2.getApplicationProperty("application.resource.file");
      var2.setLocale(var1.getLocale());
      if (var1.getLocale() != Locale.US && var1.getLocale() != Locale.UK) {
         var3 = var3 + "_" + var2.getLocale().toString() + ".properties";
         System.out.println(var3);
         URL var4 = this.getClass().getResource(var3);
         System.out.println("Checking for existence of:" + var4);
         if (var4 == null) {
            System.out.println("Properties File Doesn't Exist, defaulting to English");
            RRCLogger.log(200, 4, "Resource File for Locale " + var1.getLocale() + " doesn't exist defaulting to English");
            var3 = var2.getApplicationProperty("application.resource.file") + "_" + Locale.US.getLanguage() + ".properties";
         }
      } else {
         var3 = var2.getApplicationProperty("application.resource.file") + "_" + Locale.US.getLanguage() + ".properties";
      }

      RaritanResourceBundle.initResourceBundle(var3, this.getClass(), var2.getLocale());
      this.bundle = RaritanResourceBundle.getResourceBundle(var2.getLocale());
      this.initFileChooserLabels();
      commonInits.initializePseudoConstants(this.bundle, fps, var2);
      commonInits.initializeCommonItems(var2);
      this.mh = MonitorSettingsHandler.getInstance();
      this.mh.determineConfiguredGraphicsConfiguration();
      this.gd = this.mh.getGraphicsDevice();
      this.graphicsConfig = this.mh.getGraphicsConfiguration();
      String var8 = this.bundle.getString("help.window.title");
      ImageHolder var5 = new ImageHolder(var2);
      Image var6 = var5.getImage(this.bundle.getString("raritan.icon"));
      var1.setIconImage(var6);
      if (var1.getLocale() != Locale.US
         && var1.getLocale() != Locale.TRADITIONAL_CHINESE
         && var1.getLocale() != Locale.SIMPLIFIED_CHINESE
         && var1.getLocale() != Locale.JAPAN) {
         var2.setHelpManager(RRCScreenContext.createHelpManager(var8, var6, Locale.US));
      } else {
         var2.setHelpManager(RRCScreenContext.createHelpManager(var8, var6, var2.getLocale()));
      }
   }

   public void loadScreenManager() {
      this.screenManager = RRCScreenManager.getNewInstance(this.context);
      this.context.addObserver(this.screenManager);
      this.screenManager.setApplication(this.ui);
      this.screenManager.setFullScreenStrategy();
      CommandMenuItemCache.init();
   }

   public void dispose() {
      if (this.screenManager != null) {
         this.screenManager.destroy();
         this.screenManager = null;
      }
   }

   public RaritanPropertyResourceBundle getBundle() {
      return this.bundle;
   }

   public GraphicsDevice getGraphicsDevice() {
      return this.gd;
   }

   public void setGraphicsDevice(String var1) {
      this.mh.setGraphicsDevice(var1);
      this.gd = this.mh.getGraphicsDevice();
      this.graphicsConfig = this.mh.getGraphicsConfiguration();
   }

   public GraphicsConfiguration getGraphicsConfig() {
      return this.graphicsConfig;
   }

   public RRCMain.InnerWindowAdapter getInnerWindowAdapter() {
      return this.listenerAdapter;
   }

   public RRCScreenManager getScreenManager() {
      return this.screenManager;
   }

   public synchronized void enterFullScreen(JInternalFrame var1, Port var2, AbstractUIManager.FullScreenTarget var3) {
      this.context.getPanelMediator().showStatusPanel(false);
      MonitorSettingsHandler var4 = MonitorSettingsHandler.getInstance();
      GraphicsConfiguration var5 = this.graphicsConfig;
      if (var3 == AbstractUIManager.FullScreenTarget.SECONDARY) {
         if ((var5 = var4.getSecondaryGraphicsConfiguration(1)) == null) {
            return;
         }
      } else if (var3 == AbstractUIManager.FullScreenTarget.PRIMARY) {
         if (var4.getMonitorCount() == 1) {
            var3 = AbstractUIManager.FullScreenTarget.SINGLE;
         } else {
            var5 = var4.getPrimaryGraphicsConfiguration();
         }
      }

      this.listenerAdapter.setConfirmation(false);
      FullScreenFrame var6 = new FullScreenFrame(this.context, this, this.screenManager, this.bundle, var5, var1, var2, var3);
      this.fullScreenFrames.put(var1, var6);
      if (!this.dontShowMainFrame) {
         this.ui.setFrameVisible(false);
      }

      var6.setVisible(true);
      this.context.getMenuBar().setMenuItemTargetScreenResolution(true);
      this.context.getMenuBar().enableMenusInFullScreenMode(false);
      this.context.getMainScreenMediator().enableWindowMenu(false);
   }

   public synchronized void returnFromFullScreen() {
      if (this.fullScreenFrames.size() != 0) {
         this.context.getPanelMediator().showStatusPanel(true);
         this.addMenuBar();
         this.listenerAdapter.setConfirmation(true);

         for (FullScreenFrame var2 : this.fullScreenFrames.values()) {
            var2.setVisible(false);
            var2.dispose();
         }

         this.fullScreenFrames.clear();
         if (!this.dontShowMainFrame) {
            this.ui.setFrameVisible(true);
         }

         System.runFinalization();
         System.gc();
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               RRCMain.this.context.resetDefaultFocus();
            }
         });
         this.context.getMenuBar().setMenuItemTargetScreenResolution(false);
         this.context.getMenuBar().enableMenusInFullScreenMode(true);
         this.context.getMainScreenMediator().enableWindowMenu(true);
      }
   }

   public synchronized void returnOnDisconnect() {
      this.listenerAdapter.setConfirmation(true);
      if (this.screenManager.getFullScreenStrategy() == 0) {
         this.gd.setFullScreenWindow(null);
      }

      this.context.getMenuBar().setMenuItemTargetScreenResolution(false);
      this.context.getMenuBar().enableMenusInFullScreenMode(true);
      this.context.getMainScreenMediator().enableWindowMenu(true);

      for (FullScreenFrame var2 : this.fullScreenFrames.values()) {
         var2.dispose();
      }

      this.fullScreenFrames.clear();
      if (!this.dontShowMainFrame) {
         this.ui.setFrameVisible(true);
      }

      this.context.getMainScreenMediator().selectStatusBarView(this.context.getMainScreenMediator().getCheckStatusBarMenuItems().get(0).isSelected());
      System.runFinalization();
      System.gc();
   }

   public synchronized void returnOnSecondaryDisconnect(JInternalFrame var1) {
      FullScreenFrame var2 = this.fullScreenFrames.remove(var1);
      if (var2 != null) {
         var2.dispose();
      }
   }

   public synchronized void updateInternalFrameReference(
      GraphicsDevice var1, Port var2, Port var3, JInternalFrame var4, JInternalFrame var5, Border var6, JComponent var7, Dimension var8, Rectangle var9
   ) {
      HashMap var10 = new HashMap();
      if (var2 != null) {
         for (Port var12 : var2.getSecondaryPorts()) {
            for (Entry var14 : this.fullScreenFrames.entrySet()) {
               if (((FullScreenFrame)var14.getValue()).getPort() == var12) {
                  var10.put(((FullScreenFrame)var14.getValue()).getGraphicsConfiguration(), var14.getKey());
                  break;
               }
            }
         }
      }

      for (Port var20 : var3.getSecondaryPorts()) {
         GraphicsConfiguration var22 = this.mh.getSecondaryGraphicsConfiguration(var1, var20.getMonitorIndex());
         if (var22 != null) {
            JInternalFrame var24 = (JInternalFrame)var10.remove(var22);
            if (var24 != null) {
               FullScreenFrame var15 = this.fullScreenFrames.get(var24);
               if (var15 != null) {
                  var15.switchToPortView(var15.getPort(), var20);
                  continue;
               }
            }

            ShellInternalFrame var25 = var20.getView().getShellInternalFrame();
            FullScreenFrame var16 = new FullScreenFrame(
               this.context, this, this.screenManager, this.bundle, var22, var25, var20, AbstractUIManager.FullScreenTarget.SECONDARY
            );
            this.fullScreenFrames.put(var25, var16);
            var20.getView().setFullScreenMode(true);
            var16.setVisible(true);
         }
      }

      for (JInternalFrame var21 : var10.values()) {
         FullScreenFrame var23 = this.fullScreenFrames.remove(var21);
         if (var23 != null) {
            var23.setVisible(false);
            var23.getPort().getView().setFullScreenMode(false);
            var23.dispose();
         }
      }

      FullScreenFrame var19 = this.fullScreenFrames.remove(var4);
      if (var19 != null) {
         var19.updateInternalFrameReference(var2, var3, var5, var6, var7, var8, var9);
      }

      this.fullScreenFrames.put(var5, var19);
   }

   public boolean fullScreenRequiresNewFrame(Port var1, JInternalFrame var2) {
      if (Platform.isLinux()) {
         return true;
      } else {
         FullScreenFrame var3 = this.fullScreenFrames.get(var2);
         GraphicsConfiguration var4 = this.mh.getGraphicsConfiguration();
         if (var1.isPrimaryPort()) {
            var4 = this.mh.getPrimaryGraphicsConfiguration();
         }

         return var3 != null && var3.getGraphicsConfiguration() != var4;
      }
   }

   public void recreateFullScreen(final Port var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            synchronized (RRCMain.this) {
               RRCMain.this.dontShowMainFrame = true;
               RRCMain.this.returnFromFullScreen();

               try {
                  var1.getView().getShellInternalFrame().setSelected(true);
               } catch (PropertyVetoException var4) {
               }

               var1.getView().setTargetScreenResolution(true);
               RRCMain.this.dontShowMainFrame = false;
            }
         }
      });
   }

   public Cursor getBlankCursor() {
      if (this.blankCursor == null) {
         int[] var1 = new int[256];
         Image var2 = Toolkit.getDefaultToolkit().createImage(new MemoryImageSource(16, 16, var1, 0, 16));

         try {
            this.blankCursor = Toolkit.getDefaultToolkit().createCustomCursor(var2, new Point(0, 0), "invisiblecursor");
         } catch (HeadlessException var4) {
         } catch (IndexOutOfBoundsException var5) {
         }
      }

      return this.blankCursor;
   }

   public Cursor getDefaultCursor() {
      if (this.defaultCursor == null) {
         this.defaultCursor = new Cursor(0);
      }

      return this.defaultCursor;
   }

   public URL getIconBase() {
      try {
         File var1 = new File("nn/pp/common/icons/");
         return !var1.exists() ? this.getClass().getClassLoader().getResource("nn/pp/common/icons/") : var1.toURL();
      } catch (MalformedURLException var2) {
         return null;
      }
   }

   public Container getActiveContentPane() {
      return FullScreenFrame.getActiveContentPane();
   }

   public Container getContentPaneForPort(Port var1) {
      return FullScreenFrame.getContentPaneForPort(var1);
   }

   public FullScreenToolBar getFSToolBar(JInternalFrame var1) {
      FullScreenFrame var2 = this.fullScreenFrames.get(var1);
      return var2 != null ? var2.getFSToolBar() : null;
   }

   public void addMenuBar() {
      this.screenManager.getMainScreen().addMenuBar();
   }

   public synchronized String getAppId() {
      if (this.appId == null) {
         this.appId = new Date().getTime() + "_" + new Random().nextInt();
      }

      return this.appId;
   }

   private void initFileChooserLabels() {
      UIManager.put("FileChooser.acceptAllFileFilterText", this.bundle.getString("FileChooser.acceptAllFileFilterText"));
      UIManager.put("FileChooser.cancelButtonText", this.bundle.getString("FileChooser.cancelButtonText"));
      UIManager.put("FileChooser.cancelButtonToolTipText", this.bundle.getString("FileChooser.cancelButtonToolTipText"));
      UIManager.put("FileChooser.detailsViewButtonAccessibleName", this.bundle.getString("FileChooser.detailsViewButtonAccessibleName"));
      UIManager.put("FileChooser.detailsViewButtonToolTipText", this.bundle.getString("FileChooser.detailsViewButtonToolTipText"));
      UIManager.put("FileChooser.directoryDescriptionText", this.bundle.getString("FileChooser.directoryDescriptionText"));
      UIManager.put("FileChooser.directoryOpenButtonText", this.bundle.getString("FileChooser.directoryOpenButtonText"));
      UIManager.put("FileChooser.directoryOpenButtonToolTipText", this.bundle.getString("FileChooser.directoryOpenButtonToolTipText"));
      UIManager.put("FileChooser.fileDescriptionText", this.bundle.getString("FileChooser.fileDescriptionText"));
      UIManager.put("FileChooser.fileAttrHeaderText", this.bundle.getString("FileChooser.fileAttrHeaderText"));
      UIManager.put("FileChooser.fileDateHeaderText", this.bundle.getString("FileChooser.fileDateHeaderText"));
      UIManager.put("FileChooser.fileNameHeaderText", this.bundle.getString("FileChooser.fileNameHeaderText"));
      UIManager.put("FileChooser.fileNameLabelText", this.bundle.getString("FileChooser.fileNameLabelText"));
      UIManager.put("FileChooser.fileSizeHeaderText", this.bundle.getString("FileChooser.fileSizeHeaderText"));
      UIManager.put("FileChooser.filesOfTypeLabelText", this.bundle.getString("FileChooser.filesOfTypeLabelText"));
      UIManager.put("FileChooser.fileTypeHeaderText", this.bundle.getString("FileChooser.fileTypeHeaderText"));
      UIManager.put("FileChooser.helpButtonText", this.bundle.getString("FileChooser.helpButtonText"));
      UIManager.put("FileChooser.helpButtonToolTipText", this.bundle.getString("FileChooser.helpButtonToolTipText"));
      UIManager.put("FileChooser.homeFolderAccessibleName", this.bundle.getString("FileChooser.homeFolderAccessibleName"));
      UIManager.put("FileChooser.homeFolderToolTipText", this.bundle.getString("FileChooser.homeFolderToolTipText"));
      UIManager.put("FileChooser.listViewButtonAccessibleName", this.bundle.getString("FileChooser.listViewButtonAccessibleName"));
      UIManager.put("FileChooser.listViewButtonToolTipText", this.bundle.getString("FileChooser.listViewButtonToolTipText"));
      UIManager.put("FileChooser.lookInLabelText", this.bundle.getString("FileChooser.lookInLabelText"));
      UIManager.put("FileChooser.newFolderAccessibleName", this.bundle.getString("FileChooser.newFolderAccessibleName"));
      UIManager.put("FileChooser.newFolderErrorSeparator", this.bundle.getString("FileChooser.newFolderErrorSeparator"));
      UIManager.put("FileChooser.newFolderErrorText", this.bundle.getString("FileChooser.newFolderErrorText"));
      UIManager.put("FileChooser.newFolderToolTipText", this.bundle.getString("FileChooser.newFolderToolTipText"));
      UIManager.put("FileChooser.openButtonText", this.bundle.getString("FileChooser.openButtonText"));
      UIManager.put("FileChooser.openButtonToolTipText", this.bundle.getString("FileChooser.openButtonToolTipText"));
      UIManager.put("FileChooser.openDialogTitleText", this.bundle.getString("FileChooser.openDialogTitleText"));
      UIManager.put("FileChooser.saveButtonText", this.bundle.getString("FileChooser.saveButtonText"));
      UIManager.put("FileChooser.saveButtonToolTipText", this.bundle.getString("FileChooser.saveButtonToolTipText"));
      UIManager.put("FileChooser.saveDialogTitleText", this.bundle.getString("FileChooser.saveDialogTitleText"));
      UIManager.put("FileChooser.saveInLabelText", this.bundle.getString("FileChooser.saveInLabelText"));
      UIManager.put("FileChooser.updateButtonText", this.bundle.getString("FileChooser.updateButtonText"));
      UIManager.put("FileChooser.updateButtonToolTipText", this.bundle.getString("FileChooser.updateButtonToolTipText"));
      UIManager.put("FileChooser.upFolderAccessibleName", this.bundle.getString("FileChooser.upFolderAccessibleName"));
      UIManager.put("FileChooser.upFolderToolTipText", this.bundle.getString("FileChooser.upFolderToolTipText"));
   }

   public class InnerWindowAdapter extends WindowAdapter implements CommandHolder, ConfirmableCommandInterface {
      private boolean confirmation = false;
      private Command command;

      @Override
      public void windowClosing(WindowEvent var1) {
         boolean var2 = false;
         Command var3 = this.getCommand();

         try {
            if (this.getConfirmation()) {
               var2 = CommonPopups.showExitConfirmationDialog(RRCMain.this.ui.getContentPane(), RRCMain.this.context) != 2;
            }
         } finally {
            if (!var2) {
               if (var3 != null) {
                  var3.execute();
               } else {
                  RRCMain.this.context.getLogger().logTextError(" (This Item has NO command attached!) ");
               }
            }
         }
      }

      @Override
      public void setConfirmation(boolean var1) {
         this.confirmation = var1;
      }

      @Override
      public boolean getConfirmation() {
         return this.confirmation;
      }

      @Override
      public Command getCommand() {
         return this.command;
      }

      @Override
      public void setCommand(Command var1) {
         this.command = var1;
      }
   }
}
