package com.raritan.rrc.ui;

import com.raritan.protocol.browser.DeviceNameAddressProvider;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.VirtualMediaBean;
import com.raritan.rrc.data.VirtualMediaLocalBean;
import com.raritan.rrc.ui.commands.DoRunKeyboardMacroCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaImagePanelCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaLocalPanelCommand;
import com.raritan.rrc.ui.components.RRCMenuBar;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.KvmMenuPopupKey;
import com.raritan.rrc.ui.panes.RRCShellInternalFrame;
import com.raritan.rrc.ui.panes.mediator.MainScreenMediator;
import com.raritan.smartcard.SmartCardCore;
import com.raritan.smartcard.SmartCardCoreFactory;
import com.raritan.smartcard.SmartCardInitException;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.State;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandMenuItem;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.util.ObservableContainer;
import com.raritan.tools.util.config.ConfigurableException;
import com.raritan.tools.util.config.ConfigurationManager;
import com.util.kbd.KeyboardUtil;
import java.awt.Component;
import java.awt.Image;
import java.beans.PropertyVetoException;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Observable;
import java.util.Properties;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;
import javax.swing.JInternalFrame;
import nn.pp.common.help.HelpManager;
import nn.pp.core.Platform;
import nn.pp.ext.pref.ApplicationPreferences;
import nn.pp.ext.pref.IApplicationPreferences;
import nn.pp.logging.RemoteConsoleLogger;

public class RRCScreenContext extends ScreenContext {
   private static final String INITIAL_PROPERTIES_FILE = "JavaRRC.properties";
   private MainScreenMediator mainScreenMediator;
   private IApplicationPreferences appSettings;
   private RRCMenuBar menubar;
   private ObservableContainer selectedDevices = new ObservableContainer("Selected Devices");
   private ObservableContainer openPorts = new ObservableContainer("Open Ports");
   private ObservableContainer scanFrameObserver = new ObservableContainer("ScanFrameObserver");
   private final ObservableContainer smartCardObserver = new ObservableContainer("SmartCardObserver");
   private final ObservableContainer audioObserver = new ObservableContainer("AudioObserver");
   private HashMap arrOpenPorts = new HashMap();
   private ArrayList listOpenPorts = new ArrayList();
   private ArrayList arrScanFrame = new ArrayList();
   private final HashMap userInfoMap = new HashMap();
   private static String kvmPopupKey;
   private int popupKeycode;
   private HelpManager helpManager;
   private DeviceNameAddressProvider devNameAddrProvider;
   private final SmartCardCore smartCardCore;
   private final SmartCardInitException.ExceptionCause smartCardExceptionCause;
   private MPCScanFrame scanFrame = null;
   public static final int PROFILE_BY_NAME = 0;
   public static final int PROFILE_BY_IP = 1;
   public static final int PROFILE_BY_DNS = 2;
   public static final int PROFILE_BY_SCAN = 3;
   public static final int DEVICEVIEW_BY_NAME = 0;
   public static final int DEVICEVIEW_BY_IP = 1;
   public static final int DEVICEVIEW_BY_DNS = 2;
   public static final int DEVICEVIEW_BY_SCAN = 3;
   private int viewBy = 0;
   private boolean monitorCountMatch = false;
   private boolean scanFrameOpened = false;
   private ArrayList<KvmPort> kvmPortsForScan;

   private RRCScreenContext(State var1) {
      super(var1);
      this.appSettings = new ApplicationPreferences();
      this.appSettings.importPreferences();
      RRCLogger.setLog(RemoteConsoleLogger.getInstance().getLogger().getLevel(), -1, this.appSettings.isEnableLogging());
      SmartCardCore var2 = null;
      SmartCardInitException.ExceptionCause var3 = null;

      try {
         var2 = SmartCardCoreFactory.getDefault();
      } catch (SmartCardInitException var5) {
         RRCLogger.log(300, "Exception occured on smart card initialization ", var5);
         var3 = var5.getExceptionCause();
      }

      this.smartCardCore = var2;
      this.smartCardExceptionCause = var3;
   }

   public static ScreenContext getNewInstance(Map var0) {
      RRCScreenContext var1 = new RRCScreenContext(State.LOGGEDOUT);

      try {
         Properties var2 = ConfigurationManager.loadConfiguration(RRCScreenContext.class, "JavaRRC.properties");
         if (var0 != null && var0.size() > 0) {
            mergeProperties(var2, var0);
         }

         var1.setApplicationProperties(var2);
      } catch (ConfigurableException var3) {
      }

      return var1;
   }

   public synchronized void setMainScreenMediator(MainScreenMediator var1) {
      this.mainScreenMediator = var1;
   }

   public MainScreenMediator getMainScreenMediator() {
      return this.mainScreenMediator;
   }

   public ObservableContainer getSelectedDevicesObservable() {
      return this.selectedDevices;
   }

   public ObservableContainer getOpenPortsObservable() {
      return this.openPorts;
   }

   public Object getPortByKeyObservable(Port var1) {
      String var2 = this.createPortKey(var1);
      return this.arrOpenPorts.get(var2);
   }

   public Object getPortByKeyObservable(String var1) {
      return this.arrOpenPorts.get(var1);
   }

   public void addPortInObservable(Port var1) {
      String var2 = this.createPortKey(var1);
      this.arrOpenPorts.put(var2, var1);
      this.listOpenPorts.add(var2);
      this.getOpenPortsObservable().setComponent(this.arrOpenPorts);
   }

   private String createPortKey(Port var1) {
      Device var2 = var1.getDevice();
      DeviceConnector var3 = var2.getDeviceConnector();
      InetAddress var4 = var3.getInetAddress();
      String var5 = var1.getId();
      if (((IPReach)var1.getDevice()).isKvmSwitch()) {
         var5 = var1.getTargetDeviceId();
      }

      return var4.getHostAddress() + " " + var5;
   }

   public void removePortInObservable(Port var1) {
      String var2 = this.createPortKey(var1);
      this.arrOpenPorts.remove(var2);
      this.listOpenPorts.remove(var2);
      this.getOpenPortsObservable().setComponent(this.arrOpenPorts);
   }

   public void sendOpenPortNotification() {
      this.getOpenPortsObservable().setComponent(this.arrOpenPorts);
   }

   public HashMap getOpenPortsObservableByDeviceIP(long var1) {
      HashMap var3 = new HashMap();
      Iterator var4 = this.arrOpenPorts.keySet().iterator();
      Object var5 = null;

      while (var4.hasNext()) {
         var5 = (String)var4.next();
         if (var5.indexOf(String.valueOf(var1)) == 0) {
            var3.put(var5, this.arrOpenPorts.get(var5));
         }
      }

      return var3;
   }

   @Override
   public void destroy() {
      this.selectedDevices.deleteObservers();
      this.openPorts.deleteObservers();
      this.selectedDevices = null;
      this.openPorts = null;
      this.mainScreenMediator = null;
      super.destroy();
   }

   private static void mergeProperties(Properties var0, Map var1) {
      Object var2 = null;
      Object var3 = null;

      for (String var5 : var1.keySet()) {
         var3 = (String)var1.get(var5);
         var0.put(var5, var3);
      }
   }

   @Override
   public void createNotificationHandlers() {
   }

   @Override
   public void destroyNotificationHandlers() {
   }

   public IApplicationPreferences getAppSettings() {
      return this.appSettings;
   }

   public HashMap getUserInfoMap() {
      return this.userInfoMap;
   }

   public ArrayList getListOfOpenPorts() {
      return this.listOpenPorts;
   }

   public void setSelectedPort(Port var1) {
      this.getSelectedDevicesObservable().setComponent(var1);
   }

   public Port getSelectedPort() {
      ObservableContainer var1 = this.getSelectedDevicesObservable();
      if (var1 != null) {
         ArrayList var2 = (ArrayList)var1.getComponent();
         if (var2 != null && var2.get(0) != null) {
            Device var3 = (Device)var2.get(0);
            if (var3 instanceof Port) {
               return (Port)var3;
            }
         }
      }

      return null;
   }

   @Override
   public void resetDefaultFocus() {
      DeviceView var1 = null;
      Port var2 = this.getSelectedPort();
      if (var2 != null) {
         String var3 = "";
         var3 = var2.getViewName() + var2.getPortIndex();
         this.toggleMenuBar(var3);
      }

      if (var2 != null && var2.getView() != null) {
         var1 = var2.getView();
      }

      if (var1 != null && var1.getShellInternalFrame() != null && var1.getShellInternalFrame().isSelected()) {
         var1.setViewFocus();
      }
   }

   public void resetDesktopFocus() {
      DeviceView var1 = null;
      RaritanDesktopPane var2 = (RaritanDesktopPane)this.getPanelMediator().getParent();
      JInternalFrame[] var3 = var2.getAllFrames();
      if (var3 != null && var3.length > 0) {
         RRCShellInternalFrame var4 = (RRCShellInternalFrame)var3[var3.length - 1];
         var1 = var4.getDeviceView();
         if (var1 == null) {
            return;
         }

         try {
            var4.setSelected(true);
            var1.setViewFocus();
         } catch (PropertyVetoException var6) {
         }
      }
   }

   public void focusScanFrame() {
      RaritanDesktopPane var1 = (RaritanDesktopPane)this.getPanelMediator().getParent();
      JInternalFrame[] var2 = var1.getAllFrames();
      System.out.println("No. Of frames:" + var2.length);
      if (var2 != null && var2.length > 0) {
         for (int var3 = 0; var3 < var2.length; var3++) {
            try {
               RRCShellInternalFrame var4 = (RRCShellInternalFrame)var2[var3];
               if (!(var4 instanceof MPCScanFrame)) {
                  var4.toBack();
                  var4.setFocusable(false);
                  var4.setSelected(false);
                  var4.setIcon(true);
               } else {
                  ((MPCScanFrame)var4).setSelected(true);
                  ((MPCScanFrame)var4).requestFocus();
                  ((MPCScanFrame)var4).requestFocusInWindow();
               }
            } catch (Exception var5) {
               var5.printStackTrace();
            }
         }
      }
   }

   public static void setKvmPopupKey(String var0) {
      kvmPopupKey = var0;
   }

   public static String getKvmPopupKey() {
      return kvmPopupKey;
   }

   public void setPopupKeycode(int var1) {
      this.popupKeycode = var1;
   }

   public int getPopupKeyCode() {
      if (this.popupKeycode <= 0 && kvmPopupKey != null && !"".equals(kvmPopupKey.trim())) {
         new KvmMenuPopupKey(this);
      }

      return this.popupKeycode;
   }

   public void setMonitorCountMatch(boolean var1) {
      this.monitorCountMatch = var1;
   }

   public boolean isMonitorCountMatch() {
      return this.monitorCountMatch;
   }

   public void setScanFrameOpened(boolean var1) {
      this.scanFrameOpened = var1;
   }

   public boolean isScanFrameOpened() {
      return this.scanFrameOpened;
   }

   public MPCScanFrame getScanFrame() {
      return this.scanFrame;
   }

   public void setScanFrame(MPCScanFrame var1) {
      if (var1 != null) {
         this.arrScanFrame.add(var1);
      } else {
         this.arrScanFrame.remove(0);
      }

      this.getScanFrameObserver().setComponent(this.arrScanFrame);
      this.scanFrame = var1;
   }

   public DeviceView getSelectView() {
      Port var1 = this.getSelectedPort();
      return var1 != null ? var1.getView() : null;
   }

   public void toggleMenuBar(String var1) {
      for (CommandMenu var3 : this.getMainScreenMediator().getVirtualMediaMenus()) {
         this.toggleMenuBar(var1, var3);
      }
   }

   private void toggleMenuBar(String var1, CommandMenu var2) {
      if (!var2.isPopupMenuVisible()) {
         RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(this.getLocale());
         String var4 = "";
         String var5 = "";
         Map var6 = this.getVirtualMediaLocalMap();
         if (var6 != null) {
            VirtualMediaLocalBean var7 = (VirtualMediaLocalBean)var6.get(var1);
            if (var7 != null && var7.isDriveConnected()) {
               var4 = var3.getString("VirtualMediaDisconnect") + " " + var7.getConnectedDrive();
            } else {
               var4 = var3.getString("VirtualMediaLocalConnect.name");
            }
         } else {
            var4 = var3.getString("VirtualMediaLocalConnect.name");
         }

         Map var14 = this.getVirtualMediaImageMap();
         if (var14 != null) {
            VirtualMediaBean var8 = (VirtualMediaBean)var14.get(var1);
            if (var8 != null && var8.isDriveConnected()) {
               var5 = var3.getString("VirtualMediaDisconnect") + " " + var8.getConnectedDrive();
            } else {
               var5 = var3.getString("VirtualMediaImageConnect.name");
            }
         } else {
            var5 = var3.getString("VirtualMediaImageConnect.name");
         }

         CommandMenuItem var9 = null;
         Component[] var10 = var2.getMenuComponents();

         for (int var11 = 0; var11 < var10.length; var11++) {
            var9 = (CommandMenuItem)var10[var11];
            var9.removeObservable(this.getSelectedDevicesObservable());
            var9.removeActionListener((RRCMenuBar)this.getMainScreenMediator().getKeyboardMenus().get(0).getParent());
         }

         var2.removeAll();
         var9 = new CommandMenuItem(var4, this) {
            @Override
            public void update(Observable var1, Object var2x) {
               super.update(var1, var2x);
               this.setToolTipText(((ShowVirtualMediaLocalPanelCommand)this.getCommand()).getToolTip());
            }
         };
         var9.setCommand(new ShowVirtualMediaLocalPanelCommand(this));
         var9.addActionListener((RRCMenuBar)this.getMainScreenMediator().getKeyboardMenus().get(0).getParent());
         var9.addObservable(this.getSelectedDevicesObservable());
         if (this.getLocale() == Locale.US || this.getLocale() == Locale.UK) {
            var9.setDisplayedMnemonicIndex(Integer.parseInt(var3.getString("MnemonicKey.VirtualMediaLocalConnectIndex")));
         }

         var9.setMnemonic(KeyboardUtil.getKeyCode(new Character(var3.getString("MnemonicKey.VirtualMediaLocalConnect").toCharArray()[0])));
         var9.setToolTipText(((ShowVirtualMediaLocalPanelCommand)var9.getCommand()).getToolTip());
         var2.add(var9);
         if (!Platform.isVirtualMediaSupported()) {
            var9.setEnabled(false);
         }

         var9 = new CommandMenuItem(var5, this) {
            @Override
            public void update(Observable var1, Object var2x) {
               super.update(var1, var2x);
               this.setToolTipText(((ShowVirtualMediaImagePanelCommand)this.getCommand()).getToolTip());
            }
         };
         var9.setCommand(new ShowVirtualMediaImagePanelCommand(this));
         var9.addActionListener((RRCMenuBar)this.getMainScreenMediator().getKeyboardMenus().get(0).getParent());
         var9.addObservable(this.getSelectedDevicesObservable());
         if (this.getLocale() == Locale.US || this.getLocale() == Locale.UK) {
            var9.setDisplayedMnemonicIndex(Integer.parseInt(var3.getString("MnemonicKey.VirtualMediaImageConnectIndex")));
         }

         var9.setMnemonic(KeyboardUtil.getKeyCode(new Character(var3.getString("MnemonicKey.VirtualMediaImageConnect").toCharArray()[0])));
         var9.setToolTipText(((ShowVirtualMediaImagePanelCommand)var9.getCommand()).getToolTip());
         var2.add(var9);
         var2.repaint();
      }
   }

   public String getParamValue(Map var1, String var2, boolean var3) throws RRCGeneralException {
      String var4 = "";
      if (var1.get(var2) == null && var3) {
         throw new RRCGeneralException(var2 + " is missing");
      } else {
         return (String)var1.get(var2);
      }
   }

   public void addPredefinedMacro(String var1, int var2, String var3) {
      try {
         if (!KeyboardMacrosPreferences.containsNode(var1)) {
            KeyboardMacrosPreferences var4 = new KeyboardMacrosPreferences();
            var4.setMacroName(var1);
            var4.setHotKeyCombination(var2);
            var4.setMacroSequence(var3);
            var4.exportPreferences(var1);

            for (CommandMenu var6 : this.getMainScreenMediator().getKeyboardMenus()) {
               CommandMenuItem var7 = new CommandMenuItem(var1, this);
               var7.setCommand(new DoRunKeyboardMacroCommand(this));
               var7.addActionListener((RRCMenuBar)var6.getParent());
               var6.add(var7);
            }
         }
      } catch (Exception var8) {
         RRCLogger.logException(var8);
      }
   }

   public synchronized HelpManager getHelpManager() {
      return this.helpManager;
   }

   public synchronized void setHelpManager(HelpManager var1) {
      this.helpManager = var1;
   }

   public static HelpManager createHelpManager(String var0, Image var1, Locale var2) {
      ResourceBundle var3 = PropertyResourceBundle.getBundle("com.raritan.rrc.resources.help.HelpMap", var2);

      assert var3 != null : "HelpMap file missing";

      return new HelpManager(var3, RRCApplication.class.getClassLoader(), "nn/pp/common/help/", var0, var1);
   }

   @Override
   public synchronized DeviceNameAddressProvider getDeviceNameAddressProvider() {
      return this.devNameAddrProvider;
   }

   public synchronized void setDeviceNameAddressProvider(DeviceNameAddressProvider var1) {
      this.devNameAddrProvider = var1;
   }

   public synchronized void setDeviceViewBy(int var1) {
      this.viewBy = var1;
   }

   public synchronized int getCreateProfileBy() {
      return this.viewBy;
   }

   public SmartCardCore getSmartCardCore() {
      return this.smartCardCore;
   }

   public SmartCardInitException.ExceptionCause getSmartCardExceptionCause() {
      return this.smartCardExceptionCause;
   }

   public ObservableContainer getSmartCardObserver() {
      return this.smartCardObserver;
   }

   public ObservableContainer getAudioObserver() {
      return this.audioObserver;
   }

   public ObservableContainer getScanFrameObserver() {
      return this.scanFrameObserver;
   }

   public void setMenuBar(RRCMenuBar var1) {
      this.menubar = var1;
   }

   public RRCMenuBar getMenuBar() {
      return this.menubar;
   }

   public void setKvmPortsForScan(ArrayList<KvmPort> var1) {
      this.kvmPortsForScan = new ArrayList<>();
      this.kvmPortsForScan = var1;
   }

   public ArrayList<KvmPort> getKvmPortsForScan() {
      return this.kvmPortsForScan;
   }

   public void setSelectedKvmPort(KvmPort var1) {
   }
}
