package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.Toolkit;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import javaclientlib.utils.RRCLogger;
import javax.imageio.ImageIO;
import javax.swing.JFileChooser;
import nn.pp.common.FileNameExtensionFilter;
import nn.pp.rccore.RCCore;

public class DoCaptureTargetScreenshotCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doCaptureTargetScreenshotCommand";

   public DoCaptureTargetScreenshotCommand(RRCScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doCaptureTargetScreenshotCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      Port var1 = ((RRCScreenContext)this.scrContext).getSelectedPort();
      if (var1 != null && var1.isConnected() && var1.getDeviceClass().equals("KVM") && var1.isConnected()) {
         RFBView var2 = var1.getView() instanceof RFBView ? (RFBView)var1.getView() : null;
         if (var2 != null) {
            DoCaptureTargetScreenshotCommand.ScreenshotHandler var3 = new DoCaptureTargetScreenshotCommand.ScreenshotHandler(var2, var2.getRCCore());
            var3.screenshotToFile();
         } else {
            RRCLogger.log(100, 1, "View is null in DoCalibrateColorCommand");
         }
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      return new CommandResult();
   }

   @Override
   public boolean isExecutable() {
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (var1 != null && var1.size() != 0) {
         Device var2 = (Device)var1.get(0);
         if (var2 instanceof Port && var2.isConnected()) {
            Port var3 = (Port)var2;
            if (var3.getDeviceClass().equalsIgnoreCase("KVM") && var3.getDevice().getHandler().canDoTargetScreenCapture()) {
               return true;
            }
         }

         return false;
      } else {
         return false;
      }
   }

   class ScreenshotHandler {
      private AbstractDisplay parent;
      private RCCore rcCore;

      public ScreenshotHandler(AbstractDisplay var2, RCCore var3) {
         this.parent = var2;
         this.rcCore = var3;
      }

      private File adjustFile(JFileChooser var1) {
         FileNameExtensionFilter var2 = (FileNameExtensionFilter)var1.getFileFilter();
         File var3 = var1.getSelectedFile();
         String var4 = var2.getExtensions()[0];
         String var5 = var3.getName();
         if (!var5.toLowerCase().endsWith(var4)) {
            var5 = var5 + "." + var4;
            var3 = new File(var3.getParent(), var5);
         }

         return var3;
      }

      private int showSaveDisplayQuestion(File var1, JFileChooser var2) {
         return CommonPopups.showFileOverwriteConfirmationDialog(this.parent, DoCaptureTargetScreenshotCommand.this.scrContext);
      }

      public void screenshotToFile() {
         JFileChooser var1 = new JFileChooser(System.getProperty("user.home")) {
            @Override
            public void approveSelection() {
               File var1x = ScreenshotHandler.this.adjustFile(this);
               if (var1x != null && var1x.exists()) {
                  int var2 = ScreenshotHandler.this.showSaveDisplayQuestion(var1x, this);
                  if (var2 == 1) {
                     return;
                  }
               }

               super.approveSelection();
            }
         };
         var1.setFileSelectionMode(0);
         var1.setMultiSelectionEnabled(false);
         var1.setAcceptAllFileFilterUsed(false);
         var1.addChoosableFileFilter(new FileNameExtensionFilter("PNG image files", "png"));
         var1.addChoosableFileFilter(new FileNameExtensionFilter("BMP image files", "bmp"));
         var1.addChoosableFileFilter(new FileNameExtensionFilter("JPEG image files", "jpg"));
         int var2 = var1.showSaveDialog(this.parent);
         if (var2 == 0) {
            FileNameExtensionFilter var3 = (FileNameExtensionFilter)var1.getFileFilter();
            String var4 = var3.getExtensions()[0];
            File var5 = this.adjustFile(var1);
            BufferedImage var6 = this.rcCore.getSnapshot();
            if (var6 == null) {
               this.error(DoCaptureTargetScreenshotCommand.this.getBundle().getString("CaptureScreenshot.cannotGetImage"));
               return;
            }

            try {
               if (!ImageIO.write(var6, var4, var5)) {
                  throw new Exception();
               }
            } catch (Exception var8) {
               this.error(DoCaptureTargetScreenshotCommand.this.getBundle().getString("CaptureScreenshot.cannotWriteImage"));
               return;
            }
         }
      }

      public void screenshotToClipboard() {
         final BufferedImage var1 = this.rcCore.getSnapshot();
         if (var1 == null) {
            this.error(DoCaptureTargetScreenshotCommand.this.getBundle().getString("CaptureScreenshot.cannotGetImage"));
         } else {
            Toolkit.getDefaultToolkit().getSystemClipboard().setContents(new Transferable() {
               @Override
               public DataFlavor[] getTransferDataFlavors() {
                  return new DataFlavor[]{DataFlavor.imageFlavor};
               }

               @Override
               public boolean isDataFlavorSupported(DataFlavor var1x) {
                  return DataFlavor.imageFlavor.equals(var1x);
               }

               @Override
               public Object getTransferData(DataFlavor var1x) throws UnsupportedFlavorException, IOException {
                  if (!DataFlavor.imageFlavor.equals(var1x)) {
                     throw new UnsupportedFlavorException(var1x);
                  } else {
                     return var1;
                  }
               }
            }, null);
         }
      }

      private void error(String var1) {
         CommonPopups.showCommandResultErrorMessage(var1, this.parent, DoCaptureTargetScreenshotCommand.this.scrContext);
      }
   }
}
