package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.ProductCodes;
import com.raritan.rrc.ui.RRCApplet;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.util.ModemOSSupport;
import com.raritan.rrc.util.TaskCompletionNotifier;
import com.raritan.rrc.util.modem.DialStatusListener;
import com.raritan.rrc.util.modem.ModemConnector;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.MissingResourceException;
import javaclientlib.utils.RRCLogger;
import javax.swing.SwingUtilities;
import netscape.javascript.JSObject;

public class DoDialCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "DoDialCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   private Device device;

   public DoDialCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "DoDialCommand";
   }

   @Override
   public void doExecute(CommandResult var1) {
      ArrayList var2 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (var2 != null && var2.size() > 0) {
         this.device = (Device)var2.get(0);
         String var3 = new String(((IPReach)this.device).getConnectionInfo().getUserInfo().getName());
         String var4 = new String(((IPReach)this.device).getConnectionInfo().getUserInfo().getPassword());
         DevicePreferences var5 = this.device.getDevPrefs();
         if (var3 == null || var3.trim().equals("")) {
            var1.setStatusMessage("[" + var5.getPhone() + "]: " + this.bundle.getString("Device.emptyUsername"));
            var1.setIsSuccess(false);
            return;
         }

         ModemConnector var6 = var5.getModemConnector();
         if (var6 != null) {
            CommonPopups.showInfoDialog(this.bundle.getString("dial.confirm.title"), this.bundle.getString("dial.confirm.text"), null, this.scrContext);
            var1.setIsSuccess(false);
            return;
         }

         JSObject var7 = null;
         if (this.scrContext.getApplication() instanceof RRCApplet) {
            var7 = JSObject.getWindow((RRCApplet)this.scrContext.getApplication());
         }

         var6 = ModemConnector.getConnector(var7, this.scrContext.getLocale());
         var5.setModemConnector(var6);
         String var32 = var5.getPhone();
         String var8 = var5.getModem();
         this.scrContext.getLogger().logStatus(this.bundle.getString("dial.start.msg") + var32);
         ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel(this.bundle.getString("dial.start.msg") + var32);
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("dial.start.msg") + var32);
         this.device.setCancelLogin(false);
         final TaskCompletionNotifier var9 = new TaskCompletionNotifier(this);

         try {
            label292: {
               DialStatusListener var10 = new DialStatusListener() {
                  @Override
                  public void dialingStatus(final String var1) {
                     SwingUtilities.invokeLater(new Runnable() {
                        @Override
                        public void run() {
                           DoDialCommand.this.scrContext.getLogger().logStatus(var1);
                           DoDialCommand.this.scrContext.getLogger().logTextInfo(var1);
                           ShowDialbackMessageCommand var1x = new ShowDialbackMessageCommand(DoDialCommand.this.scrContext);
                           CommandContext var2x = var1x.getContext();
                           var2x.setCommandParameter("dialbackMessagePanel.message", var1);
                           var2x.setCommandParameter("devices", DoDialCommand.this.device);
                           var2x.setCommandParameter("taskCompletionNotifier", var9);
                           var1x.execute();
                        }
                     });
                  }
               };
               var6.addDialStatusListener(var10);
               long var11 = -1L;

               try {
                  if (!ProductCodes.getInstance().isKSXG2(var5.getProductType())
                     && !ProductCodes.getInstance().isKX101G2(var5.getProductType())
                     && !ProductCodes.getInstance().isKXG2(var5.getProductType())
                     && !ProductCodes.getInstance().isDominionLX(var5.getProductType())) {
                     var11 = var6.rasConnect(var32, var8);
                  } else {
                     var11 = var6.rasConnectWithIdentity(var32, var8, var3, var4);
                  }
               } catch (Exception var26) {
                  var1.setIsSuccess(false);
                  RRCLogger.log(300, 4, var26, "Exception on modem connect");
                  var5.setModemConnector(null);
                  var6.rasHangUp();
                  var6 = null;
                  return;
               } finally {
                  if (var6 != null) {
                     var6.removeDialStatusListener(var10);
                  }
               }

               if (var11 == 0L) {
                  String var34 = this.bundle.getString("dial.connected.msg") + " " + var32;
                  var1.setIsSuccess(true);
                  var1.setStatusMessage(var34);
                  RRCLogger.log(300, 4, "Modem connection sucessfull.");
                  this.device.setIPPort(var5.getPort());
                  InetAddress var35 = null;

                  try {
                     var35 = InetAddress.getByName(var6.rasGetServerIP());
                  } catch (UnknownHostException var25) {
                     assert false : "rasGetServerIP returned a value other than IP address";

                     var25.printStackTrace();
                  }

                  this.device.setAddressList(Arrays.asList(var35));
                  this.device.setState("DEVICE_DISCONNECTED");
                  this.device.firePropertyChange("DEVICE_DISCONNECTED", null, null);
                  RRCLogger.log(300, 4, "Attempting DoLoginCommand after modem connection");
                  DoLoginCommand var14 = new DoLoginCommand(this.scrContext);
                  var14.getContext().setCommandParameter("devices", this.device);
                  CommandResult var15 = var14.execute();
                  var1.setIsSuccess(var15.isSuccess());
                  var1.setStatusMessage(var15.getStatusMessage());
                  if (var15.isSuccess()) {
                     RRCLogger.log(300, 4, "Sucess on DoLoginCommand after modem connection");
                     break label292;
                  }

                  RRCLogger.log(300, 4, "Failure on DoLoginCommand after modem connection. Message : " + var15.getStatusMessage());
                  var5.setModemConnector(null);
                  var6.rasHangUp();
                  var6 = null;
                  return;
               }

               if (!this.device.isCancelLogin()) {
                  String var13 = this.bundle.getString("dial.error.general") + " " + var11 + ": " + this.getMessageForCode(var11);
                  RRCLogger.log(300, 4, "modem connection failed. Message : " + var13);
                  var1.setIsSuccess(false);
                  var1.setStatusMessage(var13);
                  var5.setModemConnector(null);
                  var6.rasHangUp();
                  var6 = null;
                  return;
               }

               RRCLogger.log(300, 4, "Modem connection Cancelled.");
               var1.setIsSuccess(true);
               return;
            }
         } finally {
            var9.fireTaskCompleted();
         }
      }

      var1.setIsSuccess(true);
   }

   @Override
   public boolean isExecutable() {
      if (!ModemOSSupport.isOSSupported()) {
         return false;
      } else {
         ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
         if (var1 != null && var1.size() > 0) {
            Device var2 = (Device)var1.get(0);
            DevicePreferences var3 = var2.getDevPrefs();
            if (var3 != null && var3.getModemConnector() != null) {
               return false;
            }
         }

         return true;
      }
   }

   @Override
   protected boolean executeWithBlocking() {
      return false;
   }

   private String translateRasErrorCode(long var1) {
      if (var1 >= 600L && var1 <= 745L) {
         return "dial.error.msg." + var1;
      } else {
         return var1 == 752L ? "dial.error.msg.752" : "dial.error.msg.default";
      }
   }

   private String getMessageForCode(long var1) {
      try {
         return this.bundle.getString("dial.error.msg." + var1);
      } catch (MissingResourceException var4) {
         return this.bundle.getString("dial.error.msg.default");
      }
   }
}
