package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.RRCRFPClient;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.panes.RPSelectionDialog;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import javaclientlib.clientlib.RFPClient;
import javaclientlib.clientlib.TRConnection;
import javaclientlib.tr.RFP;
import javaclientlib.tr.RFP_FILE;
import javaclientlib.utils.RRCLogger;
import javax.swing.JOptionPane;

public class DoLoadConfigurationCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doLoadDeviceConfigurationCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   private File file;

   public DoLoadConfigurationCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doLoadDeviceConfigurationCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      this.file = (File)this.getContext().getCommandParameter("selectedFile");
      RRCRFPClient var2 = RRCRFPClient.getInstance();
      var2.setScreenContext(this.scrContext);
      new DoLoadConfigurationCommand.DoLoadDeviceConfigThread().start();
      var1.setIsSuccess(true);
      var1.setStatusMessage("");
      this.scrContext.getLogger().logTextDebug(" Finished ");
      return var1;
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private boolean isValidDeviceConfigFile(File var1) throws IOException {
      RFPClient var2 = new RFPClient();
      RFP var3 = var2.getInfo(var1.getPath());
      if (var3 == null) {
         return false;
      } else {
         boolean var4 = false;
         RFP_FILE var5 = null;

         for (int var6 = 0; var6 < var3.getFileCount(); var6++) {
            var5 = var3.getRfpFile(var6);
            if (var5.getMetaFileName() != 0) {
               String var7 = new String(var5.getFileName());
               if (var7.equals("DeviceConfigFile")) {
                  var4 = true;
               } else if (var7.equals("MP432PortConfigFile")) {
                  var4 = true;
               } else if (var7.equals("UserConfigFile")) {
                  var4 = true;
               } else if (var7.equals("All")) {
                  var4 = true;
               }
            }
         }

         return var4;
      }
   }

   private class DoLoadDeviceConfigThread extends Thread {
      protected DoLoadDeviceConfigThread() {
         super("DoLoadDeviceConfigThread");
      }

      @Override
      public void run() {
         ArrayList var1 = (ArrayList)((RRCScreenContext)DoLoadConfigurationCommand.this.scrContext).getSelectedDevicesObservable().getComponent();
         Device var2 = (Device)var1.get(0);
         RRCRFPClient var3 = RRCRFPClient.getInstance();
         var3.setScreenContext(DoLoadConfigurationCommand.this.scrContext);

         try {
            if (DoLoadConfigurationCommand.this.isValidDeviceConfigFile(DoLoadConfigurationCommand.this.file)) {
               DoLoadConfigurationCommand.this.scrContext.getLogger().logStatus(DoLoadConfigurationCommand.this.bundle.getString("info.do.loaddeviceconfig"));
               var3.createRFPConnection();
               RFP var4 = var3.getInfo(DoLoadConfigurationCommand.this.file.getPath());
               if (var4 != null && var4.getAllRPIDs().length > 0) {
                  RPSelectionDialog var5 = new RPSelectionDialog(
                     DoLoadConfigurationCommand.this.scrContext.getApplication().getContentPane(), var4.getAllRPIDs(), DoLoadConfigurationCommand.this.bundle
                  );
                  if (!var5.hasValidPackages()) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 65, "File " + DoLoadConfigurationCommand.this.file.getName() + " has no valid RP tags.");
                     }

                     JOptionPane.showMessageDialog(null, DoLoadConfigurationCommand.this.bundle.getString("rpid.package.error.NoValidRPTags"));
                     var3.closeRFPConnection();
                     return;
                  }

                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 64, "Restoring new configuration file with packages.");
                  }

                  String[] var6 = var5.selectRPDialog();
                  if (var6 == null) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 64, "Restoration of file packages cancelled by user.");
                     }

                     var3.closeRFPConnection();
                     return;
                  }

                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(400, 64, "Package codes selected: ");
                  }

                  StringBuffer var7 = new StringBuffer("<" + DoLoadConfigurationCommand.this.bundle.getString("rpid.package.RFPMessageTag") + ">");

                  for (int var8 = 0; var8 < var6.length; var8++) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 64, var6[var8]);
                     }

                     var7.append("<RP rpid=\"" + var6[var8] + "\"></RP>");
                  }

                  var7.append("</" + DoLoadConfigurationCommand.this.bundle.getString("rpid.package.RFPMessageTag") + ">");
                  if (!var3.sendRFPMessagePackage(var7.toString())) {
                     int var9 = TRConnection.getLastError();
                     String var16;
                     if (var9 == -1) {
                        if (RRCLogger.logEnabled) {
                           RRCLogger.log(300, 64, "RFP Message could not be sent (-1 returnedfrom sendRFPMessagePackage)");
                        }

                        var16 = DoLoadConfigurationCommand.this.bundle.getString("rpid.package.error.CannotSendRFPMessage");
                     } else {
                        if (RRCLogger.logEnabled) {
                           RRCLogger.log(300, 64, "Error # " + var9 + ": " + var3.showError(TRConnection.getLastError()));
                        }

                        var16 = var3.showError(TRConnection.getLastError());
                     }

                     var3.closeRFPConnection();
                     JOptionPane.showMessageDialog(null, var16);
                     return;
                  }
               }

               var3.setShowProgress(true);
               boolean var11 = var3.send(DoLoadConfigurationCommand.this.file.getPath(), 0, false);
               var3.setShowProgress(false);
               if (!var11 || !var2.isConnected()) {
                  String var14 = var3.showError(TRConnection.getLastError());
                  CommonPopups.showCommandResultErrorMessage(var14, null, DoLoadConfigurationCommand.this.scrContext);
                  CommonPopups.showInfoDialog(
                     "", DoLoadConfigurationCommand.this.bundle.getString("notRestoredSuccessfully.error"), null, DoLoadConfigurationCommand.this.scrContext
                  );
                  DoLoadConfigurationCommand.this.scrContext
                     .getLogger()
                     .logStatus(DoLoadConfigurationCommand.this.bundle.getString("notRestoredSuccessfully.error"));
               } else if (var3.getNeedAutoReboot()) {
                  CommonPopups.showInfoDialog(
                     DoLoadConfigurationCommand.this.bundle.getString("confirmation.dialog.do.restartdevice.title"),
                     DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig.kx2"),
                     null,
                     DoLoadConfigurationCommand.this.scrContext
                  );
                  var2.disconnect();
                  DoLoadConfigurationCommand.this.scrContext
                     .getLogger()
                     .logStatus(DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig.kx2"));
                  ((RRCStatusBar)DoLoadConfigurationCommand.this.scrContext.getPanelMediator().getStatusPanel())
                     .setTextLabel(DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig.kx2"));
               } else {
                  int var12 = CommonPopups.showConfirmationDialog(
                     DoLoadConfigurationCommand.this.bundle.getString("confirmation.dialog.do.restartdevice.title"),
                     DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig.confirmation"),
                     null,
                     DoLoadConfigurationCommand.this.scrContext
                  );
                  if (var12 == 2) {
                     var12 = CommonPopups.showConfirmationDialog(
                        DoLoadConfigurationCommand.this.bundle.getString("confirmation.dialog.do.restartdevice.title"),
                        DoLoadConfigurationCommand.this.bundle.getString("confirmation.dialog.do.restartdevice.text"),
                        null,
                        DoLoadConfigurationCommand.this.scrContext
                     );
                     if (var12 == 2) {
                        DoRestartDeviceCommand var15 = new DoRestartDeviceCommand(DoLoadConfigurationCommand.this.scrContext);
                        var15.getContext().setCommandParameter("devices", var2);
                        var15.execute();
                     }

                     CommonPopups.showInfoDialog(
                        "", DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig"), null, DoLoadConfigurationCommand.this.scrContext
                     );
                     DoLoadConfigurationCommand.this.scrContext
                        .getLogger()
                        .logStatus(DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig"));
                     ((RRCStatusBar)DoLoadConfigurationCommand.this.scrContext.getPanelMediator().getStatusPanel())
                        .setTextLabel(DoLoadConfigurationCommand.this.bundle.getString("success.do.loaddeviceconfig"));
                  }
               }
            } else {
               CommonPopups.showCommandResultErrorMessage(
                  DoLoadConfigurationCommand.this.bundle.getString("invalidRFPFileMessage.error"), null, DoLoadConfigurationCommand.this.scrContext
               );
               CommonPopups.showInfoDialog(
                  "", DoLoadConfigurationCommand.this.bundle.getString("notRestoredSuccessfully.error"), null, DoLoadConfigurationCommand.this.scrContext
               );
               DoLoadConfigurationCommand.this.scrContext
                  .getLogger()
                  .logStatus(DoLoadConfigurationCommand.this.bundle.getString("notRestoredSuccessfully.error"));
            }
         } catch (Exception var10) {
            var10.printStackTrace();
            var3.closeRFPConnection();
            DoLoadConfigurationCommand.this.scrContext.getLogger().logTextDebug(" " + var10.getMessage());
            DoLoadConfigurationCommand.this.scrContext
               .getLogger()
               .logStatus(DoLoadConfigurationCommand.this.bundle.getString("error.ioexception.loaddeviceconfig") + var10.getMessage());
         }

         var3.closeRFPConnection();
      }
   }
}
