package com.raritan.rrc.ui.commands;

import com.raritan.protocol.browser.TooManyDevicesException;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.DeviceUnavailableException;
import com.raritan.rrc.data.FindByBasedAddressSelector;
import com.raritan.rrc.data.G1DeviceHandlerImpl;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KX101G1DeviceHandlerImpl;
import com.raritan.rrc.data.KX101G2DeviceHandlerImpl;
import com.raritan.rrc.data.KX2DeviceHandlerImpl;
import com.raritan.rrc.data.NoSuitableAddress;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.text.MessageFormat;
import java.util.ArrayList;
import javaclientlib.tr.TRLIB_COMM;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.utils.RRCLogger;

public class DoLoginCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doLoginCommand";
   private RaritanPropertyResourceBundle bundle;
   DeviceConnector connector = null;

   public DoLoginCommand(ScreenContext var1) {
      super(var1);
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public String getKey() {
      return "doLoginCommand";
   }

   @Override
   protected void doExecute(CommandResult var1) {
      if (this.connector != null && !this.connector.isGDMode()) {
         this.connector = null;
      }

      IPReach var2 = (IPReach)this.cmdContext.getCommandParameter("devices");
      if (var2 != null) {
         String var3 = new String(var2.getConnectionInfo().getUserInfo().getName());
         String var4 = new String(var2.getConnectionInfo().getUserInfo().getPassword());
         boolean var5 = false;
         TRLIB_USERINFO var6 = new TRLIB_USERINFO();

         try {
            if (var3 == null || var3.trim().equals("")) {
               var1.setStatusMessage("[" + this.getNameIP(var2) + "]: " + this.bundle.getString("Device.emptyUsername"));
               var1.setIsSuccess(false);
               return;
            }

            var6.setName(var3.getBytes());
            var6.setPassword(var4.getBytes());
            TRLIB_COMM var7 = new TRLIB_COMM();
            var7.setConnType(2);
            var7.setServerName(var2.getName().getBytes());
            var7.setDnsName(var2.getName().getBytes());
            if (var2.isProfiled()) {
               var7.setIpPort(var2.getDevPrefs().getPort());
               if (var2.getDevPrefs().getKey() != null) {
                  var7.setPrivateKey(var2.getDevPrefs().getKey().getBytes());
               }
            } else {
               var7.setIpPort((int)var2.getIPPort());
            }

            var7.setFindBy(0);
            FindByBasedAddressSelector var8 = null;

            try {
               var8 = new FindByBasedAddressSelector(
                  var2, ((RRCScreenContext)this.scrContext).getAppSettings().isIPv6NetworkingEnabled(), this.scrContext.getDeviceNameAddressProvider()
               );
            } catch (UnknownHostException var17) {
               this.scrContext.getLogger().logTextInfo("[" + this.getNameDNS(var2) + "]: " + this.bundle.getString("error.unknownHostname"));
               var1.setStatusMessage("[" + this.getNameDNS(var2) + "]: " + this.bundle.getString("error.unknownHostname"));
               var1.setIsSuccess(false);
               return;
            } catch (DeviceUnavailableException var18) {
               String var26 = this.bundle.getString("error.devicenotfound");
               var26 = MessageFormat.format(var26, var18.getDeviceName());
               this.scrContext.getLogger().logTextInfo(var26);
               var1.setStatusMessage(var26);
               var1.setIsSuccess(false);
               return;
            } catch (TooManyDevicesException var19) {
               String var10 = this.bundle.getString("TOOMANY_DEVICES_WITH_NAME");
               var10 = MessageFormat.format(var10, var19.getIdentifier());
               this.scrContext.getLogger().logTextInfo(var10);
               var1.setStatusMessage(var10);
               var1.setIsSuccess(false);
               return;
            }

            InetAddress var9 = null;
            ArrayList var28 = new ArrayList();
            boolean var11 = false;

            while (var8.hasMoreAddress()) {
               try {
                  var9 = var8.getNextAddress();
                  String var12 = this.bundle.getString("status.attemptingconnect");
                  var12 = MessageFormat.format(var12, var9.getHostAddress());
                  this.scrContext.getLogger().logTextInfo(var12);
               } catch (NoSuitableAddress var16) {
                  this.scrContext.getLogger().logTextInfo("[" + this.getNameIP(var2) + "]: " + this.bundle.getString("error.ipv6networkingnotavailable"));
                  var1.setStatusMessage("[" + this.getNameIP(var2) + "]: " + this.bundle.getString("error.ipv6networkingnotavailable"));
                  var1.setIsSuccess(false);
                  return;
               }

               var7.setInetAddress(var9);
               if (this.connector == null) {
                  this.connector = new DeviceConnector(var2, var6);
               }

               var2.setArrEvenMsg(null);
               var2.addPropertyChangeListener(DeviceTreeController.getInstance((RRCScreenContext)this.scrContext));
               var2.setCancelLogin(false);
               var2.setDeviceConnector(this.connector);
               var5 = this.connector.connect(var7, var6, null, null);
               if (!var5) {
                  if (this.connector != null) {
                     this.connector.disConnect();
                     this.connector = null;
                  }

                  var1.setIsSuccess(true);
                  return;
               }

               while (!this.connector.getAuthenticated() && !this.connector.getAuthFailed() && !var2.isCancelLogin() && !this.connector.isNoResponseFromIP()) {
                  Thread.sleep(200L);
               }

               if (this.connector.getAuthenticated() || this.connector.getAuthFailed() || var2.isCancelLogin()) {
                  var11 = true;
                  break;
               }

               var28.add(var9);
               String var13 = this.bundle.getString("Device.message1050");
               var13 = MessageFormat.format(var13, var9.getHostAddress());
               this.scrContext.getLogger().logTextInfo(var13);
            }

            if (!var11) {
               String var32 = this.bundle.getString("Device.message1050");
               var32 = MessageFormat.format(var32, ((InetAddress)var28.get(0)).getHostAddress());
               var1.setStatusMessage(var32);
               var1.setIsSuccess(false);
               return;
            }

            if (this.connector.isKX2Device() && !this.connector.isKX101G2Device()) {
               var2.setHandler(new KX2DeviceHandlerImpl(var2));
            } else if (this.connector.isKX2Device() && this.connector.isKX101G2Device()) {
               var2.setHandler(new KX101G2DeviceHandlerImpl(var2));
            } else if (this.connector.isKX101G1Device()) {
               var2.setHandler(new KX101G1DeviceHandlerImpl(var2));
            } else {
               var2.setHandler(new G1DeviceHandlerImpl(var2));
            }

            if (var2.isCancelLogin()) {
               RRCLogger.log(300, 4, "Login Cancelled.");
               if (this.connector != null) {
                  this.connector.disConnect();
                  this.connector = null;
               }

               var1.setIsSuccess(true);
               return;
            }

            if (this.connector.getAuthFailed() || !this.connector.isConnected()) {
               RRCLogger.log(300, 4, "Login Failed");
               String var31 = "";

               for (int var36 = 0; var36 < var2.getArrEvenMsg().size(); var36++) {
                  int var14 = (Integer)var2.getArrEvenMsg().get(var36);
                  if (var14 == 1040
                     || var14 == 1008
                     || var14 == 1041
                     || var14 == 1042
                     || var14 == 1043
                     || var14 == 1044
                     || var14 == 1045
                     || var14 == 1046
                     || var14 == 1047
                     || var14 == 1048
                     || var14 == 1049
                     || var14 == 1051
                     || var14 == 1052
                     || var14 == 1053) {
                     var1.setStatusMessage(
                        "["
                           + this.getNameIP(var2, var9)
                           + "]: "
                           + this.bundle.getMessage("Device.message" + var2.getArrEvenMsg().get(var36), (Integer)var2.getArrEvenMsg().get(var36))
                     );
                     if (var14 == 1053) {
                        String var15 = this.bundle.getString("Device.message1053");
                        CommonPopups.showCommandResultErrorMessage(
                           "[" + var2.getName() + " " + var2.getIP() + "]: " + var15, null, (RRCScreenContext)this.scrContext
                        );
                        var1.setIsSuccess(true);
                     } else {
                        var1.setIsSuccess(false);
                     }

                     return;
                  }

                  if (var36 != var2.getArrEvenMsg().size() - 1) {
                     this.scrContext
                        .getLogger()
                        .logTextInfo(
                           "["
                              + this.getNameIP(var2, var9)
                              + "]: "
                              + this.bundle.getMessage("Device.message" + var2.getArrEvenMsg().get(var36), (Integer)var2.getArrEvenMsg().get(var36))
                        );
                  } else {
                     var31 = this.bundle.getMessage("Device.message" + var2.getArrEvenMsg().get(var36), (Integer)var2.getArrEvenMsg().get(var36));
                  }

                  if ((Integer)var2.getArrEvenMsg().get(var36) == 1026) {
                     var1.setIsSuccess(false);
                     return;
                  }
               }

               var1.setStatusMessage("[" + this.getNameIP(var2, var9) + "]: " + var31);
               var1.setIsSuccess(false);
               return;
            }

            if (var2.isConnected()) {
               RRCLogger.log(300, 4, "Login to Device Successful.");
               String var30 = "";

               for (int var35 = 0; var35 < var2.getArrEvenMsg().size(); var35++) {
                  if ((Integer)var2.getArrEvenMsg().get(var35) != 1026) {
                     this.scrContext
                        .getLogger()
                        .logTextInfo(
                           "["
                              + this.getNameIP(var2, var9)
                              + "]: "
                              + this.bundle.getMessage("Device.message" + var2.getArrEvenMsg().get(var35), (Integer)var2.getArrEvenMsg().get(var35))
                        );
                  }

                  if (var35 == var2.getArrEvenMsg().size() - 1) {
                     var30 = this.bundle.getMessage("Device.message" + var2.getArrEvenMsg().get(var35), (Integer)var2.getArrEvenMsg().get(var35));
                  }
               }

               ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel("[" + this.getNameIP(var2, var9) + "]: " + var30);
               var2.setRdmSessionId(this.connector.getRdmSessionID());
               var2.setRdmSessionKey(this.connector.getRdmSessionKey());
               if (this.connector != null && this.connector.isGDMode()) {
                  var2.getHandler().doPostLogin(true);
               } else {
                  var2.getHandler().doPostLogin(MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext));
               }

               var2.getHandler().showRSA(MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext));
               if (var2.isRSAEnabled() && !var2.isRSAAccepted()) {
                  var1.setIsSuccess(false);
                  if (this.connector != null) {
                     this.connector.disConnect();
                     this.connector = null;
                  }

                  return;
               }

               var2.setState("CONNECTED");
               var1.setIsSuccess(true);
               var6.setName(var3.getBytes());
               ((RRCScreenContext)this.scrContext).getUserInfoMap().put(var9.getHostAddress(), var6);
               var2.updateDevice();
               MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, var2);
            }
         } catch (Exception var20) {
            RRCLogger.logException(var20);
            if (this.connector != null) {
               this.connector.disConnect();
               this.connector = null;
            }

            var1.setIsSuccess(false);
            return;
         }

         if (var2.isProfiled()) {
            DevicePreferences var22 = var2.getDevPrefs();
            var22.setUserName(var3);
            var22.setPassword(var4);
            String var24 = null;
            if (var2.isProfiled()) {
               var24 = var22.getNodeName();
            }

            if (var24 != null) {
               var22.exportPreferences(var24);
            }
         }

         var1.setIsSuccess(true);
      }
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   public String getNameDNS(Device var1) {
      String var2 = var1.getDnsName();
      if (var1.isProfiled()) {
         DevicePreferences var3 = var1.getDevPrefs();
         if (var3.getConnectionType() == 2 && var3.getFindBy() == 2) {
            var2 = var3.getDnsName();
         }
      }

      return this.getNameIP(var1, var2);
   }

   private String getNameIP(Device var1, InetAddress var2) {
      return this.getNameIP(var1, var2.getHostAddress());
   }

   private String getNameIP(Device var1, String var2) {
      String var3 = var1.getName();
      if (var3 == null || "".equals(var3)) {
         var3 = this.bundle.getString("error.unknown");
      }

      return var3 + " " + var2;
   }

   private String getNameIP(Device var1) {
      return Device.getNameIP(var1, this.bundle.getString("error.unknown"));
   }
}
