package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCMenuBar;
import com.raritan.rrc.ui.panes.KeyboardMacroPanel;
import com.raritan.rrc.ui.panes.mediator.RRCPanelMediator;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandMenuItem;
import com.util.kbd.KeyboardKey;
import java.util.ArrayList;
import java.util.Iterator;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;
import nn.pp.common.ApplicationContext;

public class DoModifyKeyboardMacroCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doModifyKeyboardMacroCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());

   public DoModifyKeyboardMacroCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doModifyKeyboardMacroCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      String var2 = (String)this.cmdContext.getCommandParameter("keyboardMacroName");
      String var3 = (String)this.cmdContext.getCommandParameter("oldMacroName");
      Integer var4 = (Integer)this.cmdContext.getCommandParameter("keyboardMacroHotKey");
      ArrayList var5 = (ArrayList)this.cmdContext.getCommandParameter("macroSequence");
      if (StringUtils.nullOrEmpty(var2)) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("missingMacroName.error"));
         var1.setStatusMessage(this.bundle.getString("missingMacroName.error"));
         var1.setIsSuccess(false);
         return var1;
      } else if (var5.size() == 0) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("emptyMacroSequence.error"));
         var1.setStatusMessage(this.bundle.getString("emptyMacroSequence.error"));
         var1.setIsSuccess(false);
         return var1;
      } else if (this.checkForUnreleasedKeys(var5)) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("unreleasedMacroSequenceKeys.error"));
         var1.setStatusMessage(this.bundle.getString("unreleasedMacroSequenceKeys.error"));
         var1.setIsSuccess(false);
         return var1;
      } else {
         if (!var2.equals(var3)) {
            if (KeyboardMacrosPreferences.containsNode(var2)) {
               this.scrContext.getLogger().logTextInfo(this.bundle.getString("duplicatedMacroName.error"));
               var1.setStatusMessage(this.bundle.getString("duplicatedMacroName.error"));
               var1.setIsSuccess(false);
               return var1;
            }

            KeyboardMacrosPreferences.deleteNode(var3);
            KeyboardMacroPanel var6 = ((RRCPanelMediator)this.scrContext.getPanelMediator()).getMainKeyboardMacroPanel();
            var6.removeMacroFromList(var3);
            var6.addMacroToList(var2);
         }

         PopulateKeyboardMenuCommand.removeMacro(var3);
         KeyboardMacrosPreferences var18 = new KeyboardMacrosPreferences();
         var18.setMacroName(var2);
         var18.setHotKeyCombination(var4);
         StringBuffer var7 = new StringBuffer();

         for (KeyboardKey var9 : var5) {
            String var10 = var9.toString();
            if (var10.startsWith(this.bundle.getString("press.text"))) {
               var7.append("p ");
            } else if (var10.startsWith(this.bundle.getString("release.text"))) {
               var7.append("r ");
            } else {
               var7.append("s ");
            }

            var7.append(var9.getIndex());
            var7.append("&&");
         }

         var7.delete(var7.length() - 2, var7.length());
         var18.setMacroSequence(var7.toString());
         var18.exportPreferences(var2);

         for (CommandMenu var11 : ((RRCScreenContext)this.scrContext).getMainScreenMediator().getKeyboardMenus()) {
            Object var12 = null;

            for (int var13 = 0; var13 < var11.getMenuComponentCount(); var13++) {
               if (var11.getMenuComponent(var13) instanceof CommandMenuItem) {
                  var12 = (CommandMenuItem)var11.getMenuComponent(var13);
                  if (((CommandMenuItem)var12).getCommand() instanceof DoRunKeyboardMacroCommand) {
                     var11.remove((JMenuItem)var12);
                     var13--;
                  }
               }
            }

            String[] var22 = KeyboardMacrosPreferences.returnNodes();
            CommandMenuItem var14 = null;
            Object var15 = null;
            int var16 = 0;

            for (int var17 = 0; var17 < var22.length; var17++) {
               var14 = new CommandMenuItem(var22[var17], this.scrContext);
               new KeyboardMacrosPreferences();
               var18.importPreferences(var22[var17]);
               var16 = var18.getHotKeyCombination();
               if (var16 > -1) {
                  var14.setAccelerator(KeyStroke.getKeyStroke(var16 + 48, 10));
               }

               var14.setCommand(new DoRunKeyboardMacroCommand(this.scrContext));
               var14.addActionListener((RRCMenuBar)var11.getParent());
               var11.add(var14);
            }
         }

         PopulateKeyboardMenuCommand.addMacro(var18);
         ApplicationContext.getInstance().setAttribute("HOTKEYMAP", null);
         this.scrContext.getLogger().logTextDebug(" Finished ");
         return var1;
      }
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private boolean checkForUnreleasedKeys(ArrayList var1) {
      Iterator var2 = var1.iterator();

      while (var2.hasNext()) {
         boolean var3 = true;
         KeyboardKey var4 = (KeyboardKey)var2.next();
         String var5 = var4.toString();
         if (var5.startsWith(this.bundle.getString("press.text"))) {
            String var6 = var5.replaceFirst(this.bundle.getString("press.text"), this.bundle.getString("release.text"));
            Object var7 = null;

            for (int var8 = 0; var8 < var1.size(); var8++) {
               var7 = (KeyboardKey)var1.get(var8);
               if (((KeyboardKey)var7).toString().equals(var6)) {
                  var3 = false;
                  break;
               }
            }

            if (var3) {
               return true;
            }
         }
      }

      return false;
   }
}
