package com.raritan.rrc.ui.commands;

import com.raritan.protocol.browser.TooManyDevicesException;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.util.Util;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.StringTokenizer;
import javaclientlib.utils.RRCLogger;

public class DoModifyProfileCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doModifyProfileCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());

   public DoModifyProfileCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doModifyProfileCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      IPReach var2 = (IPReach)this.cmdContext.getCommandParameter("devices");
      DevicePreferences var3 = (DevicePreferences)this.cmdContext.getCommandParameter("connectionInfo");
      String var4 = this.calculateExportKey(var2);
      if ("".equals(var4)) {
         RRCLogger.log(-1, 300, "Node name is null in Preferences");
         var1.setIsSuccess(false);
         return var1;
      } else {
         String var5 = var3.getIp();
         DeviceTreeController var6 = DeviceTreeController.getInstance((RRCScreenContext)this.scrContext);
         if (StringUtils.nullOrEmpty(var3.getDescription())) {
            var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.descriptionEmptyErrorMsg"));
            var1.setIsSuccess(false);
            return var1;
         } else if (var3.getPort() >= 0 && var3.getPort() <= 65535) {
            InetAddress var7 = null;
            if (var3.getConnectionType() == 2) {
               if (var3.getFindBy() == 0) {
                  if (!Util.isValidIPAddress(var3.getIp())) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.ipInvalidErrorMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }

                  String var8 = var3.getIp();

                  try {
                     var7 = InetAddress.getByName(var8);
                  } catch (UnknownHostException var16) {
                  }

                  if (var7.isAnyLocalAddress()) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.ipInvalidErrorMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }

                  if (Util.isValidIPV4Address(var8)) {
                     var8 = this.processIp(var8);
                  }

                  var3.setIp(var8);
                  var5 = var8;
               } else if (var3.getFindBy() == 1) {
                  if (StringUtils.nullOrEmpty(var3.getName())) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameEmptyErrorMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }

                  if (var3.getName().length() > 80) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameTooLongMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }

                  var5 = var3.getName();
               } else if (var3.getFindBy() == 2) {
                  if (StringUtils.nullOrEmpty(var3.getDnsName())) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.dnsNameEmptyErrorMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }

                  if (var3.getDnsName().length() > 80) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameTooLongMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }

                  var5 = var3.getDnsName();
               }
            } else if (var3.getConnectionType() == 1) {
               if (StringUtils.nullOrEmpty(var3.getPhone())) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.phoneEmptyErrorMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               OS var17 = OS.getCurrent();
               if ((var17 == OS.LINUX || var17 == OS.SOLARIS || var17 == OS.MAC) && StringUtils.nullOrEmpty(var3.getModem())) {
                  var1.setStatusMessage("No modem entered.");
                  var1.setIsSuccess(false);
                  return var1;
               }

               var5 = var3.getPhone();
            }

            String var18 = var3.getKey();
            String var9 = var3.getConfirmKey();
            if (var18 != null && var9 != null && !var18.equals(var9)) {
               var1.setStatusMessage(this.bundle.getString("ConnectionProfile.keyMisMatchError"));
               var1.setIsSuccess(false);
               return var1;
            } else {
               if (!var3.getDescription().equalsIgnoreCase(var2.getDevPrefs().getDescription())) {
                  String[] var10 = DevicePreferences.returnNodes();
                  DevicePreferences var11 = null;
                  String var12 = null;

                  for (int var13 = 0; var13 < var10.length; var13++) {
                     var11 = new DevicePreferences();
                     var11.importPreferences(var10[var13]);
                     if (var11.getDescription().equalsIgnoreCase(var3.getDescription())) {
                        var12 = var11.getDescription();
                        break;
                     }
                  }

                  if (StringUtils.notNullOrEmpty(var12)) {
                     var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.descriptionExistsErrorMsg"));
                     var1.setIsSuccess(false);
                     return var1;
                  }
               }

               IPReach var19 = new IPReach();
               var19.setDevPrefs(var3);
               var19.setDescription(var3.getDescription());
               var19.setState("UNAVAILABLE");
               DevicePreferences var21 = var2.getDevPrefs();
               switch (var3.getConnectionType()) {
                  case 1:
                     if ((var21.getConnectionType() != 1 || !var21.getPhone().equals(var3.getPhone())) && var6.isProfileByPhoneExists(var3.getPhone())) {
                        var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.phoneNumberExistsErrorMsg"));
                        var1.setIsSuccess(false);
                        return var1;
                     } else {
                        var6.removeDevice(var2);
                        DevicePreferences.deleteNode(var4);
                        var3.exportPreferences(var5);
                        var6.createPhoneProfiledEntry(var3.getPhone(), var19);
                        var1.setIsSuccess(true);
                        this.scrContext.getLogger().logTextDebug(" Finished ");
                        return var1;
                     }
                  case 2:
                     switch (var3.getFindBy()) {
                        case 0:
                           if ((var21.getConnectionType() != 2 || var21.getFindBy() != 0 || !var21.getInetAddess().equals(var3.getInetAddess()))
                              && var6.isProfileByIPExists(var7)) {
                              var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.ipAddrExistsErrorMsg"));
                              var1.setIsSuccess(false);
                              return var1;
                           }

                           var6.removeDevice(var2);
                           DevicePreferences.deleteNode(var4);
                           var3.exportPreferences(var5);
                           var6.createIPProfiledEntry(var7, var3.getPort(), var19);
                           var1.setIsSuccess(true);
                           this.scrContext.getLogger().logTextDebug(" Finished ");
                           return var1;
                        case 1:
                           if ((var21.getConnectionType() != 2 || var21.getFindBy() != 1 || !var21.getName().equalsIgnoreCase(var3.getName()))
                              && var6.isProfileByNameExists(var3.getName())) {
                              var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameExistsErrorMsg"));
                              var1.setIsSuccess(false);
                              return var1;
                           }

                           var6.removeDevice(var2);
                           DevicePreferences.deleteNode(var4);
                           var3.exportPreferences(var5);

                           try {
                              var6.createNameProfiledEntry(var3.getName(), var19, true);
                           } catch (TooManyDevicesException var15) {
                           }

                           var1.setIsSuccess(true);
                           this.scrContext.getLogger().logTextDebug(" Finished ");
                           return var1;
                        case 2:
                           if ((var21.getConnectionType() != 2 || var21.getFindBy() != 2 || !var21.getDnsName().equalsIgnoreCase(var3.getDnsName()))
                              && var6.isProfileByDNSExists(var3.getDnsName())) {
                              var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.dnsExistsErrorMsg"));
                              var1.setIsSuccess(false);
                              return var1;
                           }

                           var6.removeDevice(var2);
                           DevicePreferences.deleteNode(var4);
                           var3.exportPreferences(var5);

                           try {
                              var6.createDNSProfiledEntry(var3.getDnsName(), var3.getPort(), var19, true);
                           } catch (TooManyDevicesException var14) {
                           }

                           var1.setIsSuccess(true);
                           this.scrContext.getLogger().logTextDebug(" Finished ");
                           return var1;
                     }
                  default:
                     var1.setIsSuccess(true);
                     this.scrContext.getLogger().logTextDebug(" Finished ");
                     return var1;
               }
            }
         } else {
            var1.setStatusMessage(this.bundle.getString("Error.InvalidPort") + '\uffff');
            var1.setIsSuccess(false);
            return var1;
         }
      }
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private String calculateExportKey(IPReach var1) {
      String var2 = var1.getDevPrefs().getIp();
      if (var1.getDevPrefs().getConnectionType() == 2) {
         if (var1.getDevPrefs().getFindBy() == 1) {
            var2 = var1.getDevPrefs().getName();
         } else if (var1.getDevPrefs().getFindBy() == 2) {
            var2 = var1.getDevPrefs().getDnsName();
         }
      } else {
         var2 = var1.getDevPrefs().getPhone();
      }

      return var2;
   }

   private String processIp(String var1) {
      Object var2 = null;
      StringTokenizer var3 = new StringTokenizer(var1, ".");
      StringBuffer var4 = new StringBuffer();

      while (var3.hasMoreTokens()) {
         var2 = var3.nextToken();
         int var5 = 0;
         if (var2 != null) {
            var5 = Integer.parseInt((String)var2);
            var4.append(String.valueOf(var5));
            var4.append(".");
         }
      }

      return var4.deleteCharAt(var4.length() - 1).toString();
   }
}
