package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCMenuBar;
import com.raritan.rrc.ui.panes.KeyboardMacroPanel;
import com.raritan.rrc.ui.panes.mediator.RRCPanelMediator;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandMenuItem;
import com.util.kbd.KeyboardKey;
import java.util.ArrayList;
import java.util.Iterator;
import javax.swing.KeyStroke;
import nn.pp.common.ApplicationContext;

public class DoNewKeyboardMacroCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doNewKeyboardMacroCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());

   public DoNewKeyboardMacroCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doNewKeyboardMacroCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      String var2 = (String)this.cmdContext.getCommandParameter("keyboardMacroName");
      Integer var3 = (Integer)this.cmdContext.getCommandParameter("keyboardMacroHotKey");
      ArrayList var4 = (ArrayList)this.cmdContext.getCommandParameter("macroSequence");
      if (StringUtils.nullOrEmpty(var2)) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("missingMacroName.error"));
         var1.setStatusMessage(this.bundle.getString("missingMacroName.error"));
         var1.setIsSuccess(false);
         return var1;
      } else if (var4.size() == 0) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("emptyMacroSequence.error"));
         var1.setStatusMessage(this.bundle.getString("emptyMacroSequence.error"));
         var1.setIsSuccess(false);
         return var1;
      } else if (this.checkForUnreleasedKeys(var4)) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("unreleasedMacroSequenceKeys.error"));
         var1.setStatusMessage(this.bundle.getString("unreleasedMacroSequenceKeys.error"));
         var1.setIsSuccess(false);
         return var1;
      } else if (KeyboardMacrosPreferences.containsNode(var2)) {
         this.scrContext.getLogger().logTextInfo(this.bundle.getString("duplicatedMacroName.error"));
         var1.setStatusMessage(this.bundle.getString("duplicatedMacroName.error"));
         var1.setIsSuccess(false);
         return var1;
      } else {
         KeyboardMacrosPreferences var5 = new KeyboardMacrosPreferences();
         var5.setMacroName(var2);
         var5.setHotKeyCombination(var3);
         StringBuffer var6 = new StringBuffer();

         for (KeyboardKey var8 : var4) {
            String var9 = var8.toString();
            if (var9.startsWith(this.bundle.getString("press.text"))) {
               var6.append("p ");
            } else if (var9.startsWith(this.bundle.getString("release.text"))) {
               var6.append("r ");
            } else {
               var6.append("s ");
            }

            var6.append(var8.getIndex());
            var6.append("&&");
         }

         var6.delete(var6.length() - 2, var6.length());
         var5.setMacroSequence(var6.toString());
         var5.exportPreferences(var2);
         KeyboardMacroPanel var14 = ((RRCPanelMediator)this.scrContext.getPanelMediator()).getMainKeyboardMacroPanel();
         var14.addMacroToList(var2);

         for (CommandMenu var11 : ((RRCScreenContext)this.scrContext).getMainScreenMediator().getKeyboardMenus()) {
            CommandMenuItem var12 = new CommandMenuItem(var2, this.scrContext);
            int var13 = var5.getHotKeyCombination();
            if (var13 > -1) {
               var12.setAccelerator(KeyStroke.getKeyStroke(var13 + 48, 10));
               PopulateKeyboardMenuCommand.addMacro(var5);
            }

            var12.setCommand(new DoRunKeyboardMacroCommand(this.scrContext));
            var12.addActionListener((RRCMenuBar)var11.getParent());
            var11.add(var12);
         }

         ApplicationContext.getInstance().setAttribute("HOTKEYMAP", null);
         this.scrContext.getLogger().logTextDebug(" Finished ");
         return var1;
      }
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private boolean checkForUnreleasedKeys(ArrayList var1) {
      Iterator var2 = var1.iterator();

      while (var2.hasNext()) {
         boolean var3 = true;
         KeyboardKey var4 = (KeyboardKey)var2.next();
         String var5 = var4.toString();
         if (var5.startsWith(this.bundle.getString("press.text"))) {
            String var6 = var5.replaceFirst(this.bundle.getString("press.text"), this.bundle.getString("release.text"));
            Object var7 = null;

            for (int var8 = 0; var8 < var1.size(); var8++) {
               var7 = (KeyboardKey)var1.get(var8);
               if (((KeyboardKey)var7).toString().equals(var6)) {
                  var3 = false;
                  break;
               }
            }

            if (var3) {
               return true;
            }
         }
      }

      return false;
   }
}
