package com.raritan.rrc.ui.commands;

import com.raritan.protocol.browser.TooManyDevicesException;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.util.Util;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;
import javaclientlib.tr.TRLIB_USERINFO;

public class DoNewProfileCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doNewProfileCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());

   public DoNewProfileCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doNewProfileCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      DevicePreferences var2 = (DevicePreferences)this.cmdContext.getCommandParameter("connectionInfo");
      IPReach var3 = null;
      IPReach var4 = (IPReach)this.cmdContext.getCommandParameter("devices");
      DeviceTreeController var5 = DeviceTreeController.getInstance((RRCScreenContext)this.scrContext);
      String var6 = var2.getIp();
      if (StringUtils.nullOrEmpty(var2.getDescription())) {
         var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.descriptionEmptyErrorMsg"));
         var1.setIsSuccess(false);
         return var1;
      } else if (var2.getPort() >= 0 && var2.getPort() <= 65535) {
         String var7 = var2.getIp();
         InetAddress var8 = null;
         if (var2.getConnectionType() == 2) {
            if (var2.getFindBy() == 0) {
               if (!Util.isValidIPAddress(var7)) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.ipInvalidErrorMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               try {
                  var8 = InetAddress.getByName(var7);
               } catch (UnknownHostException var18) {
               }

               if (var8.isAnyLocalAddress()) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.ipInvalidErrorMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               if (Util.isValidIPV4Address(var7)) {
                  var7 = this.processIp(var7);
               }

               var2.setIp(var7);
               var6 = var7;
            } else if (var2.getFindBy() == 1) {
               if (StringUtils.nullOrEmpty(var2.getName())) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameEmptyErrorMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               if (var2.getName().length() > 80) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameTooLongMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               var6 = var2.getName();
            } else if (var2.getFindBy() == 2) {
               if (StringUtils.nullOrEmpty(var2.getDnsName())) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.dnsNameEmptyErrorMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               if (var2.getDnsName().length() > 80) {
                  var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameTooLongMsg"));
                  var1.setIsSuccess(false);
                  return var1;
               }

               var6 = var2.getDnsName();
            }
         } else if (var2.getConnectionType() == 1) {
            if (StringUtils.nullOrEmpty(var2.getPhone())) {
               var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.phoneEmptyErrorMsg"));
               var1.setIsSuccess(false);
               return var1;
            }

            var6 = var2.getPhone();
            OS var9 = OS.getCurrent();
            if ((var9 == OS.LINUX || var9 == OS.SOLARIS || var9 == OS.MAC) && StringUtils.nullOrEmpty(var2.getModem())) {
               var1.setStatusMessage("No modem entered.");
               var1.setIsSuccess(false);
               return var1;
            }
         }

         String var23 = var2.getKey();
         String var10 = var2.getConfirmKey();
         if (var23 != null && var10 != null && !var23.equals(var10)) {
            var1.setStatusMessage(this.bundle.getString("ConnectionProfile.keyMisMatchError"));
            var1.setIsSuccess(false);
            return var1;
         } else {
            String[] var11 = DevicePreferences.returnNodes();
            DevicePreferences var12 = null;
            String var13 = null;

            for (int var14 = 0; var14 < var11.length; var14++) {
               var12 = new DevicePreferences();
               var12.importPreferences(var11[var14]);
               if (var12.getDescription().equalsIgnoreCase(var2.getDescription())) {
                  var13 = var12.getDescription();
               }
            }

            if (StringUtils.notNullOrEmpty(var13)) {
               var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.descriptionExistsErrorMsg"));
               var1.setIsSuccess(false);
               return var1;
            } else {
               switch (var2.getConnectionType()) {
                  case 1:
                     if (var5.isProfileByPhoneExists(var2.getPhone())) {
                        var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.phoneNumberExistsErrorMsg"));
                        var1.setIsSuccess(false);
                        return var1;
                     }

                     var3 = new IPReach();
                     var3.setDevPrefs(var2);
                     var3.setDescription(var2.getDescription());
                     var2.exportPreferences(var2.getPhone());
                     var5.createPhoneProfiledEntry(var2.getPhone(), var3);
                     var1.setIsSuccess(true);
                     this.scrContext.getLogger().logTextDebug(" Finished ");
                     return var1;
                  case 2:
                     switch (var2.getFindBy()) {
                        case 0:
                           if (var5.isProfileByIPExists(var8)) {
                              var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.ipAddrExistsErrorMsg"));
                              var1.setIsSuccess(false);
                              return var1;
                           }

                           var3 = new IPReach();
                           var3.setDevPrefs(var2);
                           var3.setDescription(var2.getDescription());
                           var3.setState("UNAVAILABLE");
                           var5.createIPProfiledEntry(var8, var2.getPort(), var3);
                           if (var4 != null) {
                              this.removeOldProfiles(var4);
                              this.updateUserNameAndPassword(var4, var2);
                           }

                           var2.exportPreferences(var6);
                           var1.setIsSuccess(true);
                           this.scrContext.getLogger().logTextDebug(" Finished ");
                           return var1;
                        case 1:
                           if (var5.isProfileByNameExists(var2.getName())) {
                              var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.nameExistsErrorMsg"));
                              var1.setIsSuccess(false);
                              return var1;
                           } else {
                              var3 = new IPReach();
                              var3.setDevPrefs(var2);
                              var3.setDescription(var2.getDescription());
                              var3.setState("UNAVAILABLE");

                              try {
                                 var5.createNameProfiledEntry(var2.getName(), var3, false);
                              } catch (TooManyDevicesException var17) {
                                 String var26 = this.bundle.getString("TOOMANY_DEVICES_WITH_NAME");
                                 var26 = MessageFormat.format(var26, var2.getName());
                                 var1.setStatusMessage(var26);
                                 var1.setIsSuccess(false);
                                 return var1;
                              }

                              if (var4 != null) {
                                 this.removeOldProfiles(var4);
                                 this.updateUserNameAndPassword(var4, var2);
                              }

                              var2.exportPreferences(var6);
                              var1.setIsSuccess(true);
                              this.scrContext.getLogger().logTextDebug(" Finished ");
                              return var1;
                           }
                        case 2:
                           if (var5.isProfileByDNSExists(var2.getDnsName())) {
                              var1.setStatusMessage(this.bundle.getString("AddConnectionDialog.dnsExistsErrorMsg"));
                              var1.setIsSuccess(false);
                              return var1;
                           } else {
                              var3 = new IPReach();
                              var3.setDevPrefs(var2);
                              var3.setDescription(var2.getDescription());
                              var3.setState("UNAVAILABLE");

                              try {
                                 var5.createDNSProfiledEntry(var2.getDnsName(), var2.getPort(), var3, false);
                              } catch (TooManyDevicesException var16) {
                                 String var15 = this.bundle.getString("TOOMANY_DEVICES_WITH_DNS");
                                 var15 = MessageFormat.format(var15, var2.getDnsName());
                                 var1.setStatusMessage(var15);
                                 var1.setIsSuccess(false);
                                 return var1;
                              }

                              if (var4 != null) {
                                 this.removeOldProfiles(var4);
                                 this.updateUserNameAndPassword(var4, var2);
                              }

                              var2.exportPreferences(var6);
                              var1.setIsSuccess(true);
                              this.scrContext.getLogger().logTextDebug(" Finished ");
                              return var1;
                           }
                     }
                  default:
                     var1.setIsSuccess(true);
                     this.scrContext.getLogger().logTextDebug(" Finished ");
                     return var1;
               }
            }
         }
      } else {
         var1.setStatusMessage(this.bundle.getString("Error.InvalidPort") + '\uffff');
         var1.setIsSuccess(false);
         return var1;
      }
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private String processIp(String var1) {
      Object var2 = null;
      StringTokenizer var3 = new StringTokenizer(var1, ".");
      StringBuffer var4 = new StringBuffer();

      while (var3.hasMoreTokens()) {
         var2 = var3.nextToken();
         int var5 = 0;
         if (var2 != null) {
            var5 = Integer.parseInt((String)var2);
            var4.append(String.valueOf(var5));
            var4.append(".");
         }
      }

      return var4.deleteCharAt(var4.length() - 1).toString();
   }

   private String calculateExportKey(IPReach var1) {
      String var2 = var1.getDevPrefs().getIp();
      if (var1.getDevPrefs().getConnectionType() == 2) {
         if (var1.getDevPrefs().getFindBy() == 1) {
            var2 = var1.getDevPrefs().getName();
         } else if (var1.getDevPrefs().getFindBy() == 2) {
            var2 = var1.getDevPrefs().getDnsName();
         }
      } else {
         var2 = var1.getDevPrefs().getPhone();
      }

      return var2;
   }

   private void updateUserNameAndPassword(Device var1, DevicePreferences var2) {
      List var3 = var1.getAddressList();
      Iterator var4 = var3.iterator();
      if (var4.hasNext()) {
         String var5 = ((InetAddress)var4.next()).getHostAddress();
         TRLIB_USERINFO var6 = (TRLIB_USERINFO)((RRCScreenContext)this.scrContext).getUserInfoMap().get(var5);
         if (var6 != null) {
            String var7 = StringUtils.trim(new String(var6.getName()));
            String var8 = StringUtils.trim(new String(var6.getPassword()));
            if (StringUtils.notNullOrEmpty(var7)) {
               var2.setUserName(var7);
            }

            if (StringUtils.notNullOrEmpty(var8)) {
               var2.setPassword(var8);
            }
         }
      }
   }

   private void removeOldProfiles(Device var1) {
      List var2 = var1.getAddressList();
      Iterator var3 = var2.iterator();

      while (var3.hasNext()) {
         String var4 = ((InetAddress)var3.next()).getHostAddress();
         DevicePreferences.deleteNode(var4);
      }
   }
}
