package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.ScreenContext;
import java.text.MessageFormat;
import java.util.ArrayList;
import javaclientlib.utils.RRCLogger;
import javaclientlib.utils.XMLParser;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class DoPowerOnCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doPowerOnCommand";

   public DoPowerOnCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doPowerOnCommand";
   }

   @Override
   public void doExecute(CommandResult var1) {
      this.scrContext.getLogger().logTextDebug(" Started ");
      ArrayList var2 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (!var2.isEmpty()) {
         Port var3 = (Port)var2.get(0);
         String var4 = var3.getDeviceConnector().databaseRequest("<Power><On>" + var3.getStripTargetDeviceId() + "</On></Power>", 60000);
         boolean var5 = false;
         if (var4 != null) {
            Document var6 = null;

            try {
               var6 = XMLParser.getXMLDocument(var4);
            } catch (SAXException var13) {
               RRCLogger.log(300, 1, var13, "Invalid xml response " + var4);
               this.setFailureResult(var1, var3.getName());
               return;
            }

            if (var6 != null) {
               NodeList var7 = var6.getElementsByTagName("Error");
               if (var7.getLength() == 0) {
                  return;
               }

               if (var7.getLength() == 1) {
                  Node var8 = var7.item(0);
                  String var9 = var8.getTextContent();

                  try {
                     int var10 = Integer.parseInt(var9.trim());
                     if (var10 < 0) {
                        var1.setIsSuccess(false);
                        String var11 = this.getBundle().getString("POWER_OPERATION_ON_ERR");
                        var11 = MessageFormat.format(var11, var3.getName());
                        var11 = "[" + var10 + "]: " + var11;
                        var1.setStatusMessage(var11);
                        var1.setErrorDescription(new Object[]{var11});
                        RRCLogger.log(300, 1, "PowerOn operation failed. Error code : " + var10);
                        return;
                     }
                  } catch (NumberFormatException var12) {
                     RRCLogger.log(300, 1, "incorrect response from server " + var4);
                     var5 = true;
                  }
               } else {
                  RRCLogger.log(300, 1, "incorrect response from server " + var4);
                  var5 = true;
               }
            } else {
               var5 = true;
               RRCLogger.log(300, 1, "Parser config error");
            }
         } else {
            RRCLogger.log(300, 1, "Null response from server");
            var5 = true;
         }

         if (var5) {
            this.setFailureResult(var1, var3.getName());
         }
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
   }

   private void setFailureResult(CommandResult var1, String var2) {
      var1.setIsSuccess(false);
      String var3 = this.getBundle().getString("POWER_OPERATION_ON_ERR");
      var3 = MessageFormat.format(var3, var2);
      var1.setStatusMessage(var3);
      var1.setErrorDescription(new Object[]{var3});
   }

   @Override
   public boolean isExecutable() {
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (var1 != null && var1.size() > 0) {
         Device var2 = (Device)var1.get(0);
         if (var2 != null
            && var2 instanceof Port
            && (var2.getDeviceClass().equals("KVM") || var2.getDeviceClass().equals("Serial"))
            && ((Port)var2).isOutletPort()
            && !((Port)var2).isSecondaryPort()) {
            if (var2.getDeviceConnector().usePowerControlFromCC) {
               return var2.getDeviceConnector().getCCPowerControlPermission();
            }

            return true;
         }
      }

      return false;
   }
}
