package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.RRCRFPClient;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.io.File;
import java.util.ArrayList;
import javaclientlib.clientlib.TRConnection;

public class DoSaveActivityLogCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "saveActivityLogCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   private File file;

   public DoSaveActivityLogCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "saveActivityLogCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      var1.setIsSuccess(true);

      try {
         this.file = (File)this.getContext().getCommandParameter("selectedFile");
         if (this.file == null) {
            var1.setIsSuccess(false);
            var1.setStatusMessage(this.bundle.getString("filebrowser.save.cannotopen"));
            return var1;
         }

         new DoSaveActivityLogCommand.DoSaveActivityLogThread().start();
         var1.setIsSuccess(true);
      } catch (Exception var3) {
         var1.setIsSuccess(false);
         var1.setStatusMessage(this.bundle.getString("error.ioexception.saveactivitylog") + " " + var3.getMessage());
         this.scrContext.getLogger().logTextDebug(var3.getMessage());
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      return var1;
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private class DoSaveActivityLogThread extends Thread {
      protected DoSaveActivityLogThread() {
         super("DoSaveActivityLogThread");
      }

      @Override
      public void run() {
         ArrayList var1 = (ArrayList)((RRCScreenContext)DoSaveActivityLogCommand.this.scrContext).getSelectedDevicesObservable().getComponent();
         Device var2 = (Device)var1.get(0);
         RRCRFPClient var3 = RRCRFPClient.getInstance();
         var3.setScreenContext(DoSaveActivityLogCommand.this.scrContext);
         var3.setShowProgress(false);

         try {
            boolean var4 = var3.receive("LogExportFile", DoSaveActivityLogCommand.this.file.getPath(), 0);
            if (!var4) {
               CommonPopups.showInfoDialog(
                  DoSaveActivityLogCommand.this.bundle.getString("confirmation.dialog.do.saveactivitylog.title"),
                  var3.showError(TRConnection.getLastError()),
                  null,
                  DoSaveActivityLogCommand.this.scrContext
               );
               DoSaveActivityLogCommand.this.scrContext.getLogger().logStatus(DoSaveActivityLogCommand.this.bundle.getString("error.do.saveactivitylog"));
               DoSaveActivityLogCommand.this.scrContext
                  .getLogger()
                  .logTextInfo("[" + var2.getNameIP() + "]: " + DoSaveActivityLogCommand.this.bundle.getString("error.do.saveactivitylog"));
               return;
            }

            DoSaveActivityLogCommand.this.scrContext.getLogger().logStatus(DoSaveActivityLogCommand.this.bundle.getString("success.do.saveactivitylog"));
            DoSaveActivityLogCommand.this.scrContext
               .getLogger()
               .logTextInfo("[" + var2.getNameIP() + "]: " + DoSaveActivityLogCommand.this.bundle.getString("success.do.saveactivitylog"));
            CommonPopups.showInfoDialog(
               DoSaveActivityLogCommand.this.bundle.getString("confirmation.dialog.do.saveactivitylog.title"),
               DoSaveActivityLogCommand.this.bundle.getString("success.do.saveactivitylog"),
               null,
               DoSaveActivityLogCommand.this.scrContext
            );
         } catch (Exception var5) {
            DoSaveActivityLogCommand.this.scrContext.getLogger().logTextDebug(" " + var5.getMessage());
            DoSaveActivityLogCommand.this.scrContext
               .getLogger()
               .logStatus(DoSaveActivityLogCommand.this.bundle.getString("error.ioexception.saveactivitylog") + var5.getMessage());
         }
      }
   }
}
