package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.ContextPopupMenu;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.KvmMenuPopupKey;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.ui.screens.RRCScreenManager;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.util.kbd.KeyHIDValue;
import java.util.HashMap;
import java.util.Map.Entry;
import javaclientlib.utils.RRCLogger;
import nn.pp.common.ApplicationContext;
import nn.pp.ext.pref.ApplicationPreferencesVO;
import nn.pp.logging.RemoteConsoleLogger;

public class DoSaveOptionsCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "doSaveOptionsCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());

   public DoSaveOptionsCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "doSaveOptionsCommand";
   }

   @Override
   public CommandResult execute() {
      CommandResult var1 = null;

      try {
         this.scrContext.getLogger().logTextDebug(" Started ");
         var1 = new CommandResult();
         Boolean var2 = (Boolean)this.cmdContext.getCommandParameter("showScrollBorders");
         Boolean var3 = (Boolean)this.cmdContext.getCommandParameter("autoSyncMouse");
         Boolean var4 = (Boolean)this.cmdContext.getCommandParameter("showSingleCursorModeInstructions");
         Boolean var5 = (Boolean)this.cmdContext.getCommandParameter("autoColorCal");
         Boolean var6 = (Boolean)this.cmdContext.getCommandParameter("enableLaunchInFullScreenMode");
         Integer var7 = (Integer)this.cmdContext.getCommandParameter("osuiHotKey");
         Integer var8 = (Integer)this.cmdContext.getCommandParameter("keyboardType");
         Boolean var9 = (Boolean)this.cmdContext.getCommandParameter("keyboardTypeChanged");
         String var10 = (String)this.cmdContext.getCommandParameter("broadcastPort");
         String var11 = (String)this.cmdContext.getCommandParameter("defaultHttpsPort");
         String var12 = (String)this.cmdContext.getCommandParameter("KeyboardShortcutMenuHotKey");
         Boolean var13 = (Boolean)this.cmdContext.getCommandParameter("enableLogging");
         Boolean var14 = (Boolean)this.cmdContext.getCommandParameter("IPv6NetworkingEnabled");
         String var15 = (String)this.cmdContext.getCommandParameter("monitorSetting");
         Integer var16 = -1;
         if (this.cmdContext.getCommandParameter("monitorCount") != null) {
            var16 = (Integer)this.cmdContext.getCommandParameter("monitorCount");
         }

         Boolean var17 = (Boolean)this.cmdContext.getCommandParameter("enableSingleMouse");
         Boolean var18 = (Boolean)this.cmdContext.getCommandParameter("enableScaling");
         Boolean var19 = (Boolean)this.cmdContext.getCommandParameter("pinMenu");
         String var20 = (String)this.cmdContext.getCommandParameter("scanDisplayInterval");
         String var21 = (String)this.cmdContext.getCommandParameter("scanDiaplyIntervalPort");
         String var22 = (String)this.cmdContext.getCommandParameter("thumbnailSize");
         String var23 = (String)this.cmdContext.getCommandParameter("splitOrientation");
         boolean var24 = ((RRCScreenContext)this.scrContext).getAppSettings().isIPv6NetworkingEnabled();
         if (StringUtils.notNullOrEmpty(var10)) {
            int var25 = 0;
            int var26 = 0;

            try {
               var25 = new Integer(var10);
               var26 = new Integer(var11);
            } catch (NumberFormatException var37) {
               var1.setStatusMessage(this.bundle.getString("Error.InvalidPort") + '\uffff');
               var1.setIsSuccess(false);
               return var1;
            }

            int var27 = ((RRCScreenContext)this.scrContext).getAppSettings().getBroadcastPort();
            if (!this.validatePort(var25)) {
               var1.setStatusMessage(this.bundle.getString("Error.InvalidPort") + '\uffff');
               var1.setIsSuccess(false);
               return var1;
            }

            if (!this.validatePort(var26)) {
               var1.setStatusMessage(this.bundle.getString("Error.InvalidPort") + '\uffff');
               var1.setIsSuccess(false);
               return var1;
            }

            int var28 = 10;
            int var29 = 10;

            try {
               var28 = new Integer(var20);
               var29 = new Integer(var21);
            } catch (NumberFormatException var36) {
               var1.setStatusMessage(this.bundle.getString("Scan.Invalid.Interval"));
               var1.setIsSuccess(false);
               return var1;
            }

            if (!this.validateScanInterval(var28)) {
               var1.setStatusMessage(this.bundle.getString("Scan.Invalid.Interval"));
               var1.setIsSuccess(false);
               return var1;
            }

            if (!this.validateScanInterval(var29)) {
               var1.setStatusMessage(this.bundle.getString("Scan.Invalid.Interval"));
               var1.setIsSuccess(false);
               return var1;
            }

            if (var8 != null) {
               HashMap var30 = (HashMap)((RRCScreenContext)this.scrContext).getOpenPortsObservable().getComponent();
               if (var30 != null && var30.size() > 0) {
                  for (Object var32 : var30.entrySet()) {
                     Entry var33 = (Entry)var32;
                     if (var33.getValue() instanceof KvmPort) {
                        KvmPort var34 = (KvmPort)var33.getValue();
                        if (var34 != null && var34.getView() != null && var34.getView() instanceof RFBView) {
                           RRCLogger.log(300, -1, "Changing keyboard type to " + var8 + " of port " + var34.getPortIndex());
                           RFBView var35 = (RFBView)var34.getView();
                           var35.keyboardTypeChanged(var8);
                        }
                     }
                  }
               }
            }

            if (var2 != null && var3 != null && var4 != null && var7 != null && var8 != null && var13 != null) {
               ApplicationPreferencesVO var43 = new ApplicationPreferencesVO(
                  var2, var3, var4, var7, var8, var25, var26, var5, var12, var13, var14, var6, var15, var16, var17, var18, var19, var28, var29, var22, var23
               );
               ((RRCScreenContext)this.scrContext).getAppSettings().setAllData(var43);
               RRCLogger.enableLogging(var13);
               RemoteConsoleLogger.getInstance().enableLogging(var13);
               DeviceView var46 = null;
               Port var48 = ((RRCScreenContext)this.scrContext).getSelectedPort();
               if (var48 != null) {
                  var46 = var48.getView();
                  var48.getDevice().getHandler().updateHotkeys();
               }

               if (var46 != null) {
                  ContextPopupMenu var49 = var46.getContextPopupMenu();
                  if (var49 != null) {
                     var49.setKVMPopupMenuLabel("Send " + var12);
                  }
               }

               ApplicationContext.getInstance().setAttribute("SCROLLBORDERS", var2);
               new KvmMenuPopupKey((RRCScreenContext)this.scrContext);
               if (var9) {
                  KeyHIDValue.setHIDMap(var8);
                  if (var46 != null) {
                     var46.keyboardTypeChanged(var8);
                  }

                  RRCScreenManager.addLanguageSpecificMacros(var8, (RRCScreenContext)this.scrContext);
               }
            }

            if (var25 != var27 || var24 != var14) {
               DoRefreshNavigatorCommand var44 = new DoRefreshNavigatorCommand(this.scrContext);
               if (var44.isExecutable()) {
                  CommandResult var47 = var44.execute();
               }
            }

            String var45 = ((RRCScreenContext)this.scrContext).getAppSettings().getMonitorSetting();
            if (var45 != null && !var45.equals("")) {
               this.scrContext.getApplication().setGraphicsDevice(var45);
            }
         }

         this.scrContext.getLogger().logTextDebug(" Finished ");
      } catch (Exception var38) {
         var38.printStackTrace();
      }

      return var1;
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private boolean validateScanInterval(int var1) {
      return var1 >= 10 && var1 <= 255;
   }

   private boolean validatePort(int var1) {
      return var1 >= 0 && var1 <= 65535;
   }
}
