package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.RRCRFPClient;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.io.File;
import java.util.ArrayList;
import javaclientlib.clientlib.TRConnection;
import javaclientlib.utils.RRCLogger;

public class DoSaveTotalConfigurationCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "saveTotalConfigurationCommand";
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   private File file;

   public DoSaveTotalConfigurationCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "saveTotalConfigurationCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();

      try {
         this.file = (File)this.getContext().getCommandParameter("selectedFile");
         if (this.file != null) {
            new DoSaveTotalConfigurationCommand.DoSaveTotalConfigThread().start();
         }

         var1.setIsSuccess(true);
      } catch (Exception var3) {
         var1.setIsSuccess(false);
         var1.setStatusMessage(this.bundle.getString("error.do.saveTotalconfig") + " " + var3.getMessage());
         this.scrContext.getLogger().logTextDebug(var3.getMessage());
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      return var1;
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private class DoSaveTotalConfigThread extends Thread {
      protected DoSaveTotalConfigThread() {
         super("DoSaveTotalConfigThread");
      }

      @Override
      public void run() {
         ArrayList var1 = (ArrayList)((RRCScreenContext)DoSaveTotalConfigurationCommand.this.scrContext).getSelectedDevicesObservable().getComponent();
         Device var2 = (Device)var1.get(0);
         DoSaveTotalConfigurationCommand.this.scrContext
            .getLogger()
            .logStatus(DoSaveTotalConfigurationCommand.this.bundle.getString("info.do.savetotalconfig"));
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 65, "Requesting configuration file for Backup All command");
         }

         RRCRFPClient var3 = RRCRFPClient.getInstance();
         var3.setScreenContext(DoSaveTotalConfigurationCommand.this.scrContext);
         var3.setShowProgress(true);

         try {
            var3.createRFPConnection();
            boolean var4 = var3.receive("All", DoSaveTotalConfigurationCommand.this.file.getPath(), 0);
            if (var4) {
               DoSaveTotalConfigurationCommand.this.scrContext
                  .getLogger()
                  .logStatus(DoSaveTotalConfigurationCommand.this.bundle.getString("success.do.savetotalconfig"));
               DoSaveTotalConfigurationCommand.this.scrContext
                  .getLogger()
                  .logTextInfo("[" + var2.getNameIP() + "]: " + DoSaveTotalConfigurationCommand.this.bundle.getString("success.do.savetotalconfig"));
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(200, 65, DoSaveTotalConfigurationCommand.this.bundle.getString("success.do.savetotalconfig"));
                  RRCLogger.log(200, 65, "    [" + var2.getNameIP() + "]");
               }

               CommonPopups.showInfoDialog(
                  DoSaveTotalConfigurationCommand.this.bundle.getString("confirmation.dialog.do.savetotalconfig.title"),
                  DoSaveTotalConfigurationCommand.this.bundle.getString("success.do.savetotalconfig"),
                  null,
                  DoSaveTotalConfigurationCommand.this.scrContext
               );
               return;
            }

            var3.closeRFPConnection();
            CommonPopups.showInfoDialog(
               DoSaveTotalConfigurationCommand.this.bundle.getString("confirmation.dialog.do.savetotalconfig.title"),
               var3.showError(TRConnection.getLastError()),
               null,
               DoSaveTotalConfigurationCommand.this.scrContext
            );
            DoSaveTotalConfigurationCommand.this.scrContext
               .getLogger()
               .logStatus(DoSaveTotalConfigurationCommand.this.bundle.getString("error.do.savetotalconfig"));
            DoSaveTotalConfigurationCommand.this.scrContext
               .getLogger()
               .logTextInfo("[" + var2.getNameIP() + "]: " + DoSaveTotalConfigurationCommand.this.bundle.getString("error.do.savetotalconfig"));
            if (RRCLogger.logEnabled) {
               RRCLogger.log(200, 65, DoSaveTotalConfigurationCommand.this.bundle.getString("error.do.savetotalconfig"));
               RRCLogger.log(200, 65, "    [" + var2.getNameIP() + "]");
            }
         } catch (Exception var8) {
            DoSaveTotalConfigurationCommand.this.scrContext.getLogger().logTextDebug(" " + var8.getMessage());
            DoSaveTotalConfigurationCommand.this.scrContext
               .getLogger()
               .logStatus(DoSaveTotalConfigurationCommand.this.bundle.getString("error.ioexception.savetotalconfig") + var8.getMessage());
            if (RRCLogger.logEnabled) {
               RRCLogger.log(200, 65, DoSaveTotalConfigurationCommand.this.bundle.getString("error.ioexception.savetotalconfig"));
            }

            return;
         } finally {
            var3.closeRFPConnection();
         }
      }
   }
}
