package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.RRCMenuBar;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandMenuItem;
import java.util.ArrayList;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;

public class PopulateKeyboardMenuCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "populateKeyboardMenuCommand";
   private static KeyboardMacrosPreferences[] keyboardMacroPrefs = new KeyboardMacrosPreferences[10];
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   private JMenu sunMacrosMenu;

   public PopulateKeyboardMenuCommand(ScreenContext var1) {
      super(var1);

      for (int var2 = 0; var2 < keyboardMacroPrefs.length; var2++) {
         keyboardMacroPrefs[var2] = null;
      }

      String[] var6 = KeyboardMacrosPreferences.returnNodes();
      KeyboardMacrosPreferences var3 = null;
      int var4 = 0;

      for (int var5 = 0; var5 < var6.length; var5++) {
         var3 = new KeyboardMacrosPreferences();
         var3.importPreferences(var6[var5]);
         var4 = var3.getHotKeyCombination();
         if (var4 > -1) {
            keyboardMacroPrefs[var4] = var3;
         }
      }
   }

   public static KeyboardMacrosPreferences getMacro(int var0) {
      return var0 >= 0 && var0 < keyboardMacroPrefs.length ? keyboardMacroPrefs[var0] : null;
   }

   public static void addMacro(KeyboardMacrosPreferences var0) {
      int var1 = var0.getHotKeyCombination();
      if (var1 >= 0 && var1 <= 9) {
         keyboardMacroPrefs[var1] = var0;
      }
   }

   public static void removeMacro(String var0) {
      for (int var1 = 0; var1 < keyboardMacroPrefs.length; var1++) {
         if (keyboardMacroPrefs[var1] != null && keyboardMacroPrefs[var1].getMacroName().equals(var0)) {
            keyboardMacroPrefs[var1] = null;
            return;
         }
      }
   }

   @Override
   public String getKey() {
      return "populateKeyboardMenuCommand";
   }

   @Override
   public CommandResult execute() {
      for (int var1 = 0; var1 < keyboardMacroPrefs.length; var1++) {
         keyboardMacroPrefs[var1] = null;
      }

      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var13 = new CommandResult();
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      DeviceView var3 = var2.getSelectView();

      for (CommandMenu var6 : var2.getMainScreenMediator().getKeyboardMenus()) {
         Object var7 = null;

         for (int var8 = 0; var8 < var6.getMenuComponentCount(); var8++) {
            if (var6.getMenuComponent(var8) instanceof CommandMenuItem) {
               var7 = (CommandMenuItem)var6.getMenuComponent(var8);
               if (((CommandMenuItem)var7).getCommand() instanceof DoRunKeyboardMacroCommand) {
                  var6.remove((JMenuItem)var7);
                  var8--;
               }
            }
         }

         if (var3.isSunTarget()) {
            if (this.sunMacrosMenu == null) {
               RRCMenuBar var15 = (RRCMenuBar)var6.getParent();
               this.sunMacrosMenu = var15.getSunMacroJMenu(var3, this.scrContext);
            }

            if (!var6.isMenuComponent(this.sunMacrosMenu)) {
               var6.add(this.sunMacrosMenu);
               var6.addSeparator();
            }
         } else if (this.sunMacrosMenu != null && var6.isMenuComponent(this.sunMacrosMenu)) {
            var6.remove(this.sunMacrosMenu);
            var6.remove(var6.getItemCount() - 1);
         }

         String[] var16 = KeyboardMacrosPreferences.returnNodes();
         CommandMenuItem var9 = null;
         KeyboardMacrosPreferences var10 = null;
         int var11 = 0;

         for (int var12 = 0; var12 < var16.length; var12++) {
            var9 = new CommandMenuItem(var16[var12], this.scrContext);
            var10 = new KeyboardMacrosPreferences();
            var10.importPreferences(var16[var12]);
            var11 = var10.getHotKeyCombination();
            if (var11 > -1) {
               var9.setAccelerator(KeyStroke.getKeyStroke(var11 + 48, 10));
               keyboardMacroPrefs[var11] = var10;
            }

            var9.setCommand(new DoRunKeyboardMacroCommand(this.scrContext));
            var9.addActionListener((RRCMenuBar)((RRCScreenContext)this.scrContext).getMainScreenMediator().getKeyboardMenus().get(0).getParent());
            var6.add(var9);
         }

         var6.repaint();
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      return var13;
   }

   @Override
   public boolean isExecutable() {
      Object var1 = null;
      if (this.scrContext != null
         && ((RRCScreenContext)this.scrContext).getSelectedDevicesObservable() != null
         && ((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent() != null) {
         ArrayList var2 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
         if (var2.get(0) != null) {
            var1 = (Device)var2.get(0);
            if (var1 instanceof Port && ((Device)var1).isConnected()) {
               Port var3 = (Port)var1;
               if (var3.getDeviceClass().equalsIgnoreCase("KVM")) {
                  return true;
               }
            }
         }
      }

      return false;
   }
}
