package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceFactory;
import com.raritan.rrc.data.Paragon;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.io.IOException;
import java.util.ArrayList;
import javax.swing.SwingUtilities;
import javax.xml.parsers.ParserConfigurationException;
import org.xml.sax.SAXException;

public class PopulateParagonPortsCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "populateParagonPortsCommand";
   private RaritanPropertyResourceBundle bundle;
   private Paragon device = null;

   public PopulateParagonPortsCommand(ScreenContext var1) {
      super(var1);
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public String getKey() {
      return "populateParagonPortsCommand";
   }

   @Override
   public CommandResult execute() {
      CommandResult var1 = new CommandResult();
      this.device = (Paragon)((ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent()).get(0);
      this.device.setContext(this.scrContext);
      DeviceFactory var2 = DeviceFactory.getInstance();

      try {
         var2.updateDevice(this.device, this.device.getDocument(), this.scrContext, false);
         this.device.connect();
         DeviceTreeController.getInstance((RRCScreenContext)this.scrContext).populateParagonPorts(this.device);
         if (this.device.hasChildren()) {
            this.device.firePropertyChange("DEVICE_PORTS_ADD", null, null);
         }
      } catch (ParserConfigurationException var4) {
         this.processXMLError();
      } catch (SAXException var5) {
         this.processXMLError();
      } catch (IOException var6) {
         this.processXMLError();
      }

      return var1;
   }

   private void processXMLError() {
      if (this.scrContext != null && this.bundle != null && this.device != null) {
         SwingUtilities.invokeLater(
            new Runnable() {
               @Override
               public void run() {
                  RaritanPropertyResourceBundle var1 = RaritanResourceBundle.getResourceBundle(PopulateParagonPortsCommand.this.scrContext.getLocale());
                  if (var1 != null) {
                     CommonPopups.showCommandResultErrorMessage(
                        "[" + PopulateParagonPortsCommand.this.device.getNameIP() + "]: " + var1.getString("corruptXmlError.message"),
                        null,
                        PopulateParagonPortsCommand.this.scrContext
                     );
                  }
               }
            }
         );
      }
   }

   @Override
   public boolean isExecutable() {
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (var1 != null && var1.size() > 0) {
         Device var2 = (Device)var1.get(0);
         if (var2 instanceof Paragon) {
            return !var2.isConnected();
         }
      }

      return false;
   }
}
