package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import java.io.File;
import java.io.IOException;
import java.util.SortedMap;
import java.util.TreeMap;
import javaclientlib.utils.RRCLogger;
import javax.swing.JOptionPane;
import nn.pp.ext.macro.IMacro;
import nn.pp.ext.macro.MacroFactory;
import org.xml.sax.SAXException;

public class ShowImportMacrosCommand extends AbstractCommand {
   private static RaritanPropertyResourceBundle bundle;
   public static final String COMMAND_KEY = "showImportMacrosCommand";

   public ShowImportMacrosCommand(ScreenContext var1) {
      super(var1);
      bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public String getKey() {
      return "showImportMacrosCommand";
   }

   @Override
   public boolean isExecutable() {
      return true;
   }

   private TreeMap getMacrosFromFile(StringBuffer var1) {
      this.scrContext.getLogger().logTextDebug(" Started ");
      SortedMap var2 = null;
      File var3 = KeyboardMacrosPreferences.chooseXmlFile(
         bundle.getString("macro.import.file.dialog.title"), 0, JOptionPane.getFrameForComponent(this.scrContext.getApplication().getContentPane())
      );
      if (var3 == null) {
         var1.append(bundle.getString("macro.import.file.selection.cancelled"));
         return null;
      } else {
         if (!var3.exists()) {
            var1.append(bundle.getString("macro.import.file.selection.not.exist") + ": " + var3.toString());
         } else if (!var3.canRead()) {
            var1.append(bundle.getString("macro.import.file.selection.unreadable") + ": " + var3.toString());
         }

         if (var1.length() < 1) {
            try {
               var2 = MacroFactory.getInstance().getMacroParser().getValidMacros(var3);
            } catch (IOException var9) {
               RRCLogger.log(300, 1, var9, "Exception on parsing KeyboardMacroFile : " + var3);
               var1.append(bundle.getString("macro.import.file.selection.invalid"));
            } catch (SAXException var10) {
               RRCLogger.log(300, 1, var10, "Exception on parsing KeyboardMacroFile : " + var3);
               var1.append(bundle.getString("macro.import.file.selection.invalid"));
            }
         }

         TreeMap var4 = null;
         if (var2 != null) {
            var4 = new TreeMap(var2);

            for (String var6 : var2.keySet()) {
               KeyboardMacrosPreferences var7 = new KeyboardMacrosPreferences();
               IMacro var8 = (IMacro)var2.get(var6);
               var7.setMacroName(var6);
               var7.setHotKeyCombination(var8.getHotKey());
               var7.setMacroSequence(var8.getSequence());
               var4.put(var6, var7);
            }

            this.getContext().setCommandParameter("importExportSelectedMacros", var4);
         } else {
            var4 = new TreeMap();
         }

         return var4;
      }
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult(true, "");
      StringBuffer var2 = new StringBuffer();
      TreeMap var3 = this.getMacrosFromFile(var2);
      if (var2.length() > 0) {
         var1.setIsSuccess(false);
         if (var3 != null) {
            var1.setStatusMessage(var2.toString());
         }
      } else if (var3.size() < 1) {
         var1.setIsSuccess(false);
         var1.setStatusMessage(bundle.getString("macro.import.none.in.file"));
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      return var1;
   }
}
