package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import javaclientlib.utils.RRCLogger;

public class ShowKVMFromScanCommand extends ConnectionCommand {
   public static final String COMMAND_KEY = "showKVMFromScanCommand";
   private RaritanPropertyResourceBundle bundle;
   private KvmPort kvmPort;
   private RRCScreenContext ctx;

   public ShowKVMFromScanCommand(ScreenContext var1, KvmPort var2) {
      super(var1);
      this.ctx = (RRCScreenContext)var1;
      this.kvmPort = var2;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public String getKey() {
      return "showKVMFromScanCommand";
   }

   @Override
   public CommandResult execute() {
      RRCLogger.log(300, 1, "execute Started");
      CommandResult var1 = new CommandResult(true, "");
      long var2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory() + Runtime.getRuntime().freeMemory();
      RRCLogger.log(300, 5, "Free memory " + var2);
      if (3145728L >= var2) {
         System.runFinalization();
         System.gc();
         var2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory() + Runtime.getRuntime().freeMemory();
         RRCLogger.log(300, 5, "Free memory after GC " + var2);
         if (3145728L >= var2) {
            var1.setStatusMessage(this.bundle.getString("outOfMemory.error"));
            var1.setIsSuccess(false);
            return var1;
         }
      }

      if (this.kvmPort.getPortStatus() == 0) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 5, "Port unavailable " + this.kvmPort.getId());
         }

         var1.setIsSuccess(false);
         var1.setStatusMessage(
            "["
               + this.kvmPort.getDevice().getNameIP()
               + "]: "
               + this.bundle.getString("KVMPort.couldNotConnect.error")
               + " "
               + (StringUtils.notNullOrEmpty(this.kvmPort.getName()) ? this.kvmPort.getName() : this.bundle.getString("DefaultPortString.error"))
         );
         return var1;
      } else {
         this.getContext().setCommandParameter("ports", this.kvmPort);
         RRCLogger.log(300, 1, "execute Finished");
         return var1;
      }
   }

   @Override
   public boolean isExecutable() {
      try {
         if (this.kvmPort != null
            && this.kvmPort instanceof Port
            && this.kvmPort.getDeviceClass().equals("KVM")
            && !this.kvmPort.isConnected()
            && this.kvmPort.getPortStatus() != 0
            && this.kvmPort.getRdmStatAvailable() != 4) {
            System.out.println("Returning True.....");
            return true;
         }
      } catch (Exception var2) {
         var2.printStackTrace();
      }

      System.out.println("Returning False.....");
      return false;
   }
}
