package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.MPCScanFrame;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import java.util.ArrayList;
import javaclientlib.utils.RRCLogger;

public class ShowKX2KvmPortCommand extends ConnectionCommand {
   public static final String COMMAND_KEY = "showKX2KvmPortCommand";
   private RaritanPropertyResourceBundle bundle;
   private RRCScreenContext scrContext;
   private boolean allowSecondary;

   public ShowKX2KvmPortCommand(ScreenContext var1) {
      super(var1);
      this.scrContext = (RRCScreenContext)var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public String getKey() {
      return "showKX2KvmPortCommand";
   }

   public void setAllowSecondary(boolean var1) {
      this.allowSecondary = var1;
   }

   @Override
   public CommandResult execute() {
      RRCLogger.log(300, 1, "execute Started");
      CommandResult var1 = new CommandResult(true, "");
      long var2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory() + Runtime.getRuntime().freeMemory();
      RRCLogger.log(300, 5, "Free memory " + var2);
      if (3145728L >= var2) {
         System.runFinalization();
         System.gc();
         var2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory() + Runtime.getRuntime().freeMemory();
         RRCLogger.log(300, 5, "Free memory after GC " + var2);
         if (3145728L >= var2) {
            var1.setStatusMessage(this.bundle.getString("outOfMemory.error"));
            var1.setIsSuccess(false);
            return var1;
         }
      }

      KvmPort var4 = (KvmPort)((ArrayList)this.scrContext.getSelectedDevicesObservable().getComponent()).get(0);
      if (var4.getPortStatus() == 0) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 5, "Port unavailable " + var4.getId());
         }

         var1.setIsSuccess(false);
         var1.setStatusMessage(
            "["
               + var4.getDevice().getNameIP()
               + "]: "
               + this.bundle.getString("KVMPort.couldNotConnect.error")
               + " "
               + (StringUtils.notNullOrEmpty(var4.getName()) ? var4.getName() : this.bundle.getString("DefaultPortString.error"))
         );
         return var1;
      } else if (var4.isPrimaryPort() && var4.getSecondaryPortConfigs().size() == 0 && !MPCUtil.isCCLaunched(this.scrContext)) {
         var1.setIsSuccess(false);
         var1.setStatusMessage("[" + var4.getDevice().getNameIP() + "]: " + this.bundle.getString("KVMPort.secondaryNotAvailable.error"));
         return var1;
      } else {
         this.getContext().setCommandParameter("ports", var4);
         if (var4.getDevice().isScanSupported() && this.scrContext.getScanFrame() != null) {
            MPCScanFrame var5 = this.scrContext.getScanFrame();
            String var6 = var4.getDevice().getId();
            if (this.scrContext.isScanFrameOpened() && var5.getConnectedDeviceId().equals(var6)) {
               var5.getScanConnector().pause();
            }
         }

         RRCLogger.log(300, 1, "execute Finished");
         return var1;
      }
   }

   @Override
   public boolean isExecutable() {
      ArrayList var1 = (ArrayList)this.scrContext.getSelectedDevicesObservable().getComponent();

      try {
         if (var1 != null && var1.size() > 0) {
            Port var2 = (Port)var1.get(0);
            if (var2 != null
               && var2 instanceof Port
               && var2.getDeviceClass().equals("KVM")
               && !var2.isConnected()
               && var2.getPortStatus() != 0
               && var2.getRdmStatAvailable() != 4
               && (this.allowSecondary || !var2.isSecondaryPort())
               && (this.scrContext.getOpenPortsObservable().getComponent() == null || this.scrContext.getPortByKeyObservable(var2) == null)) {
               return true;
            }
         }
      } catch (ClassCastException var3) {
      }

      return false;
   }
}
