package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.util.ArrayList;
import javaclientlib.clientlib.TRConnection;
import javaclientlib.utils.RRCLogger;

public class ShowKvmPortCommand extends ConnectionCommand {
   public static final String COMMAND_KEY = "showKvmPortCommand";
   private static final int errCodeMask = 4095;
   private RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());

   public ShowKvmPortCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "showKvmPortCommand";
   }

   @Override
   public CommandResult execute() {
      CommandResult var1 = new CommandResult();
      if (this.setBusy(true)) {
         var1.setIsSuccess(false);
         var1.setStatusMessage(this.bundle.getString("TR_ERROR." + Integer.toString(11)));
         return var1;
      } else {
         long var2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory() + Runtime.getRuntime().freeMemory();
         if (3145728L >= var2) {
            System.runFinalization();
            System.gc();
            var2 = Runtime.getRuntime().maxMemory() - Runtime.getRuntime().totalMemory() + Runtime.getRuntime().freeMemory();
            if (3145728L >= var2) {
               var1.setStatusMessage(this.bundle.getString("outOfMemory.error"));
               var1.setIsSuccess(false);
               return var1;
            }
         }

         KvmPort var4 = (KvmPort)((ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent()).get(0);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(
               300, 5, "ShowKvmPort " + var4.toString() + ", port " + var4.getId() + ", connected " + var4.isConnected() + ", type " + var4.getPortType()
            );
         }

         if (var4.getPortStatus() == 0) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 5, "Port unavailable " + var4.getId());
            }

            var1.setIsSuccess(false);
            var1.setStatusMessage(
               "["
                  + var4.getDevice().getNameIP()
                  + "]: "
                  + this.bundle.getString("KVMPort.couldNotConnect.error")
                  + " "
                  + (StringUtils.notNullOrEmpty(var4.getName()) ? var4.getName() : this.bundle.getString("DefaultPortString.error"))
            );
            return var1;
         } else {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 5, "ShowKvmPortCommand connecting, already connected ?" + var4.isConnected());
            }

            var4.connect();
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 5, "ShowKvmPortCommand connect now connected ?" + var4.isConnected() + ", err=" + TRConnection.getLastError());
            }

            this.setBusy(false);
            if (!var4.isConnected()) {
               boolean var5 = false;
               int var6 = TRConnection.getLastError();
               int var7 = var6 & -4096;
               var6 &= 4095;
               if (var6 == 12) {
                  if (var7 == 0) {
                     var7 = 536875008;
                  }

                  var1.setIsSuccess(false);
                  String var8 = null;
                  byte var9 = 0;
                  if (var7 == 536875008) {
                     var8 = "TR_ERROR.";
                     var9 = 24;
                  }

                  RaritanPropertyResourceBundle var10 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
                  String var11 = var8 + Integer.toString(var6);
                  var5 = CommonPopups.showConfirmationDialog(var10.getString(var11 + ".title"), var10.getString(var11 + ".text"), null, this.scrContext) == 2;
                  if (!var5) {
                     return var1;
                  }

                  var4.forceConnection();
                  this.setBusy(false);
               }
            }

            if (!var4.isConnected()) {
               this.getTRSRVR_ErrorResult(var1, var4);
            } else {
               MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, var4);
               var1.setIsSuccess(true);
               this.getContext().setCommandParameter("ports", var4);
            }

            return var1;
         }
      }
   }

   @Override
   public boolean isExecutable() {
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();

      try {
         if (var1 != null && var1.size() > 0) {
            Port var2 = (Port)var1.get(0);
            if (var2 instanceof Port
               && var2.getDeviceClass().equals("KVM")
               && !var2.isConnected()
               && var2.getPortStatus() != 0
               && !var2.isSecondaryPort()
               && (
                  ((RRCScreenContext)this.scrContext).getOpenPortsObservable().getComponent() == null
                     || ((RRCScreenContext)this.scrContext).getPortByKeyObservable(var2) == null
               )) {
               return true;
            }
         }
      } catch (ClassCastException var3) {
      }

      return false;
   }
}
