package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCApplet;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import java.awt.KeyboardFocusManager;
import java.awt.Window;
import java.util.ArrayList;
import javax.swing.SwingUtilities;

public class ShowTargetScreenResolutionCommand extends AbstractCommand {
   String POPUP_FULLSCREEN_WARNING1_TEXT = "PopupFullScreenWarning1.text";
   String POPUP_FULLSCREEN_WARNING2_TEXT = "PopupFullScreenWarning2.text";
   String POPUP_FULLSCREEN_WARNING_TITLE = "PopupFullScreenWarning.title";
   public static final String COMMAND_KEY = "showTargetScreenResolutionCommand";

   public ShowTargetScreenResolutionCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "showTargetScreenResolutionCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      CommandResult var1 = new CommandResult();
      Port var2 = ((RRCScreenContext)this.scrContext).getSelectedPort();
      if (var2 instanceof KvmPort) {
         KvmPort var3 = (KvmPort)var2;
         DeviceView var4 = var3.getView();
         if (var4 != null && var3.isConnected()) {
            if (!var4.isTargetScreenResolution()) {
               RaritanPropertyResourceBundle var5 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
               if (CommonPopups.showConfirmationDialog(
                     var5.getString(this.POPUP_FULLSCREEN_WARNING_TITLE),
                     var5.getString(this.POPUP_FULLSCREEN_WARNING1_TEXT)
                        + RRCScreenContext.getKvmPopupKey()
                        + var5.getString(this.POPUP_FULLSCREEN_WARNING2_TEXT),
                     var4,
                     this.scrContext,
                     new String[]{"basescreen.command.ok.text", "basescreen.command.cancel.text"}
                  )
                  == 2) {
                  var4.toggleTargetScreenResolution();
               } else {
                  ((RRCScreenContext)this.scrContext).getMainScreenMediator().getToolBarFullScreenButton().setSelected(false);
                  ((RRCScreenContext)this.scrContext).getMenuBar().setMenuItemTargetScreenResolution(false);
                  this.scrContext.resetDefaultFocus();
               }
            } else {
               boolean var10 = KeyboardFocusManager.getCurrentKeyboardFocusManager() instanceof RRCApplet.RaritanKeyboardFocusManager;
               final Window var6 = null;
               final RRCApplet.LinuxWindowDeactivatedHandler var7 = null;
               if (var10) {
                  var6 = SwingUtilities.getWindowAncestor(((RRCScreenContext)this.scrContext).getApplication().getContentPane());
                  var7 = new RRCApplet.LinuxWindowDeactivatedHandler();
                  var6.addWindowListener(var7);
               }

               ((RRCScreenContext)this.scrContext).getMainScreenMediator().getToolBarFullScreenButton().setSelected(false);
               var4.toggleTargetScreenResolution();
               if (var10) {
                  SwingUtilities.invokeLater(new Runnable() {
                     @Override
                     public void run() {
                        var6.removeWindowListener(var7);
                     }
                  });
               }
            }
         }
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      return var1;
   }

   @Override
   public boolean isExecutable() {
      Object var1 = null;
      if (this.scrContext != null
         && ((RRCScreenContext)this.scrContext).getSelectedDevicesObservable() != null
         && ((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent() != null) {
         ArrayList var2 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
         if (var2.get(0) != null) {
            var1 = (Device)var2.get(0);
            if (var1 instanceof KvmPort && ((Device)var1).isConnected() && ((Device)var1).getDeviceConnector() != null) {
               return true;
            }
         }
      }

      return false;
   }
}
