package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.MassStorageDevice;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.VMConfigInfo;
import com.raritan.rrc.data.VMInterfaceInfo;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.ScreenContext;
import java.text.MessageFormat;
import java.util.ArrayList;
import nn.pp.rccore.IKvmPort;

public class ShowVirtualMediaImagePanelCommand extends AbstractCommand {
   public static final String COMMAND_KEY = "showVirtualMediaPanelCommand";
   private String tooltip = null;

   public ShowVirtualMediaImagePanelCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public String getKey() {
      return "showVirtualMediaPanelCommand";
   }

   @Override
   public CommandResult execute() {
      this.scrContext.getLogger().logTextDebug(" Started ");
      Port var1 = ((RRCScreenContext)this.scrContext).getSelectedPort();
      DeviceView var2 = var1.getView();
      if (var2 != null) {
         var2.getCommandHandler().handleCommand(this, this.scrContext);
      }

      this.setCommandParameters(this.getVMInterfaceInfo());
      this.scrContext.getLogger().logTextDebug(" Finished ");
      return new CommandResult(true, "");
   }

   @Override
   public boolean isExecutable() {
      this.tooltip = null;
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (var1 != null && var1.size() != 0 && var1.get(0) instanceof Port) {
         Port var2 = (Port)var1.get(0);
         if (var2 instanceof KvmPort && var2.isConnected()) {
            if (!var2.getPortType().equals("VM")) {
               String var8 = "<html>" + this.getBundle().getString("vm.tooltip.notavmcim").replaceAll("\n", "<br>") + "</html>";
               this.tooltip = MessageFormat.format(var8, var2.getName());
               return false;
            } else {
               KvmPort var3 = (KvmPort)var2;
               VMConfigInfo var4 = var3.getVmConfigInfo();
               if (var3.getPortPermissionHelper().getVmPermission() == IKvmPort.VmPermission.DENY) {
                  String var9 = "<html>" + this.getBundle().getString("vm.tooltip.denied").replaceAll("\n", "<br>") + "</html>";
                  this.tooltip = MessageFormat.format(var9, var3.getName());
                  return false;
               } else {
                  if (var4 != null && var4.isCimActive()) {
                     VMInterfaceInfo var5 = var4.getVMInterface(1);
                     if (var5 != null) {
                        if (var5.isMultiLUN() && var5.isInUse() && var2.isTopLeft()) {
                           MassStorageDevice var6 = var5.getMassStorageDevice(1);
                           boolean var7 = var6.isConnected();
                           if (!var7) {
                              this.tooltip = "<html>" + this.getBundle().getString("vm.tooltip.noresources").replaceAll("\n", "<br>") + "</html>";
                           }

                           return var7;
                        }

                        if (!var2.isTopLeft()) {
                           this.tooltip = "<html>" + this.getBundle().getString("vm.tooltip.nottopleft").replaceAll("\n", "<br>") + "</html>";
                           return false;
                        }

                        return true;
                     }
                  }

                  return false;
               }
            }
         } else {
            return false;
         }
      } else {
         return false;
      }
   }

   private void setCommandParameters(VMInterfaceInfo var1) {
      this.getContext().setCommandParameter("VM_vminterfaceinfo", var1);
   }

   private VMInterfaceInfo getVMInterfaceInfo() {
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      KvmPort var2 = (KvmPort)var1.get(0);
      VMConfigInfo var3 = var2.getVmConfigInfo();

      assert var3 != null;

      VMInterfaceInfo var4 = var3.getVMInterface(1);

      assert var4 != null;

      return var4;
   }

   public String getToolTip() {
      return this.tooltip;
   }
}
