package com.raritan.rrc.ui.commands;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.VMConfigInfo;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.ScreenContext;
import java.text.MessageFormat;
import java.util.ArrayList;
import javaclientlib.utils.RRCLogger;
import nn.pp.rccore.IKvmPort;

public class VirtualMediaMenuCommand extends KVMPortDummyCommand {
   public static final String COMMAND_KEY = "virtualMediaMenuCommand";
   private String tooltip = null;

   public VirtualMediaMenuCommand(ScreenContext var1) {
      super(var1);
   }

   @Override
   public CommandResult execute() {
      CommandResult var1 = new CommandResult();
      this.scrContext.getLogger().logTextDebug(" Started ");
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      DeviceView var3 = var2.getSelectView();
      if (var3 != null) {
         var3.getCommandHandler().handleCommand(this, this.scrContext);
      } else {
         RRCLogger.log(100, 1, "View is null in MouseMenuCommand");
      }

      this.scrContext.getLogger().logTextDebug(" Finished ");
      var1.setIsSuccess(true);
      return var1;
   }

   @Override
   public boolean isExecutable() {
      this.tooltip = null;
      if (!super.isExecutable()) {
         return false;
      } else {
         ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
         if (var1 != null && var1.size() != 0 && var1.get(0) instanceof Port) {
            Port var2 = (Port)var1.get(0);
            if (!(var2 instanceof KvmPort)) {
               return false;
            } else if (!var2.getPortType().equals("VM") && var2.isConnected()) {
               String var6 = "<html>" + this.getBundle().getString("vm.tooltip.notavmcim").replaceAll("\n", "<br>") + "</html>";
               this.tooltip = MessageFormat.format(var6, var2.getName());
               return false;
            } else if (var2.getPortType().equals("VM") && var2.isConnected()) {
               KvmPort var3 = (KvmPort)var2;
               VMConfigInfo var4 = var3.getVmConfigInfo();
               if (var3.getPortPermissionHelper().getVmPermission() == IKvmPort.VmPermission.DENY) {
                  String var5 = "<html>" + this.getBundle().getString("vm.tooltip.denied").replaceAll("\n", "<br>") + "</html>";
                  this.tooltip = MessageFormat.format(var5, var3.getName());
                  return false;
               } else {
                  assert var4 != null;

                  if (var4.isCimActive() && var4.getListofInterfaces().size() <= 0) {
                     this.tooltip = "<html>" + this.getBundle().getString("vm.tooltip.noresources").replaceAll("\n", "<br>") + "</html>";
                     return false;
                  } else if (!var2.isTopLeft()) {
                     this.tooltip = "<html>" + this.getBundle().getString("vm.tooltip.nottopleft").replaceAll("\n", "<br>") + "</html>";
                     return false;
                  } else {
                     return var4.isCimActive() && var4.getListofInterfaces().size() > 0;
                  }
               }
            } else {
               return false;
            }
         } else {
            return false;
         }
      }
   }

   public String getToolTip() {
      return this.tooltip;
   }
}
