package com.raritan.rrc.ui.components;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.ConnectAudioCommand;
import com.raritan.rrc.ui.commands.DoDeleteProfileCommand;
import com.raritan.rrc.ui.commands.DoDisconnectCommand;
import com.raritan.rrc.ui.commands.DoPowerCycleCommand;
import com.raritan.rrc.ui.commands.DoPowerOffCommand;
import com.raritan.rrc.ui.commands.DoPowerOnCommand;
import com.raritan.rrc.ui.commands.DoRestartDeviceCommand;
import com.raritan.rrc.ui.commands.DoSwitchCommand;
import com.raritan.rrc.ui.commands.ShowAddProfileCommand;
import com.raritan.rrc.ui.commands.ShowLoadConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowModifyProfileCommand;
import com.raritan.rrc.ui.commands.ShowSaveActivityLogCommand;
import com.raritan.rrc.ui.commands.ShowSaveDeviceConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowSaveDiagnosticLogCommand;
import com.raritan.rrc.ui.commands.ShowSaveTotalConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowSaveUserConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowSerialParametersCommand;
import com.raritan.rrc.ui.commands.ShowUpdateDeviceCommand;
import com.raritan.rrc.ui.commands.ShowUpdateLDAPCertificateCommand;
import com.raritan.rrc.ui.commands.ShowUpdateLDAPKeyCommand;
import com.raritan.rrc.ui.commands.ShowUserPasswordCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaImagePanelCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaLocalPanelCommand;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandMenuItem;
import com.util.kbd.KeyboardUtil;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Locale;
import java.util.Observable;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu.Separator;

public class CommandMenuItemCache {
   private static CommandMenuItemCache cache;
   private static Collection menuItems = null;
   public static String connectLocalVirtualMedia = "VirtualMediaLocalConnect.name";
   public static String disconnectLocalVirtualMedia = "VirtualMediaDisconnect";
   CommandMenuItem virtualMediaLocalMenu;
   CommandMenuItem virtualMediaImageMenu;
   CommandMenuItem connectAudioMenuItem;
   private static Collection allMenuItems = null;

   private CommandMenuItemCache() {
   }

   private void init(ScreenContext var1, ActionListener var2) {
      final RaritanPropertyResourceBundle var4 = RaritanResourceBundle.getResourceBundle(var1.getLocale());
      CommandMenuItem var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SWITCH_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new DoSwitchCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SWITCH_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SWITCH_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.DISCONNECT_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new DoDisconnectCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.DISCONNECT_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.DISCONNECT_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.ADD_PROFILE_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowAddProfileCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.ADD_PROFILE_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.ADD_PROFILE_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.MODIFY_PROFILE_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowModifyProfileCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.MODIFY_PROFILE_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.MODIFY_PROFILE_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.DELETE_PROFILE_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setConfirmation(true);
      var3.setCommand(new DoDeleteProfileCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.DELETE_PROFILE_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.DELETE_PROFILE_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SERIAL_PARAMETERS_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowSerialParametersCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SERIAL_PARAMETERS_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SERIAL_PARAMETERS_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.RESTART_DEVICE_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new DoRestartDeviceCommand(var1));
      var3.setConfirmation(true);
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.RESTART_DEVICE_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.RESTART_DEVICE_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SAVE_USER_CONFIGURATION_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowSaveUserConfigurationCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SAVE_ACTIVITY_LOG_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SAVE_USER_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SAVE_DEVICE_CONFIGURATION_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowSaveDeviceConfigurationCommand((RRCScreenContext)var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SAVE_DEVICE_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SAVE_DEVICE_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SAVE_TOTAL_CONFIGURATION_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowSaveTotalConfigurationCommand((RRCScreenContext)var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SAVE_TOTAL_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SAVE_TOTAL_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.RESTORE_DEVICE_CONFIGURATION_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowLoadConfigurationCommand((RRCScreenContext)var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.RESTORE_DEVICE_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.RESTORE_DEVICE_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SAVE_ACTIVITY_LOG_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowSaveActivityLogCommand((RRCScreenContext)var1));
      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SAVE_ACTIVITY_LOG_ACTION_MNEMONIC).toCharArray()[0]));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SAVE_ACTIVITY_LOG_ACTION_MNEMONIC_INDEX)));
      }

      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.SAVE_DIAGNOSTIC_LOG_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowSaveDiagnosticLogCommand((RRCScreenContext)var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.SAVE_DIAGNOSTIC_LOG_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.SAVE_DIAGNOSTIC_LOG_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      JMenu var5 = new JMenu(var4.getString(MenuItemResourceBundleConstants.UPDATE_ACTION_NAME));
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.CHANGE_PASSWORD_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowUserPasswordCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.CHANGE_PASSWORD_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.CHANGE_PASSWORD_ACTION_MNEMONIC).toCharArray()[0]));
      var5.add((JMenuItem)var3);
      allMenuItems.add(var3);
      var5.addSeparator();
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.UPDATE_DEVICE_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowUpdateDeviceCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.UPDATE_DEVICE_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.UPDATE_DEVICE_ACTION_MNEMONIC).toCharArray()[0]));
      var5.add((JMenuItem)var3);
      allMenuItems.add(var3);
      JMenu var6 = new JMenu(var4.getString(MenuItemResourceBundleConstants.UPDATE_LDAP_ACTION_NAME));
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.UPDATE_LDAP_CERTIFICATE_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowUpdateLDAPCertificateCommand(var1));
      var6.add((JMenuItem)var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.UPDATE_LDAP_KEY_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new ShowUpdateLDAPKeyCommand(var1));
      var6.add((JMenuItem)var3);
      allMenuItems.add(var3);
      var5.add((JMenuItem)var6);
      menuItems.add(var5);
      menuItems.add(new Separator());
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.POWER_ON_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new DoPowerOnCommand(var1));
      var3.setConfirmation(true);
      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.POWER_ON_ACTION_MNEMONIC).toCharArray()[0]));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.POWER_ON_ACTION_MNEMONIC_INDEX)));
      }

      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.POWER_OFF_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new DoPowerOffCommand(var1));
      var3.setConfirmation(true);
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.POWER_OFF_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.POWER_OFF_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      var3 = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.CYCLE_POWER_ACTION_NAME), var1);
      var3.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      var3.addActionListener(var2);
      var3.setCommand(new DoPowerCycleCommand(var1));
      var3.setConfirmation(true);
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         var3.setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.CYCLE_POWER_ACTION_MNEMONIC_INDEX)));
      }

      var3.setMnemonic(new Character(var4.getString(MenuItemResourceBundleConstants.CYCLE_POWER_ACTION_MNEMONIC).toCharArray()[0]));
      menuItems.add(var3);
      allMenuItems.add(var3);
      menuItems.add(new Separator());
      this.virtualMediaLocalMenu = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.VIRTUAL_MEDIA_CONNECT_ACTION_NAME), var1) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((ShowVirtualMediaLocalPanelCommand)this.getCommand()).getToolTip());
         }
      };
      this.virtualMediaLocalMenu.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      this.virtualMediaLocalMenu.addActionListener(var2);
      this.virtualMediaLocalMenu.setCommand(new ShowVirtualMediaLocalPanelCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         this.virtualMediaLocalMenu
            .setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.VIRTUAL_MEDIA_ACTION_MNEMONIC_INDEX)));
      }

      this.virtualMediaLocalMenu
         .setMnemonic(KeyboardUtil.getKeyCode(new Character(var4.getString(MenuItemResourceBundleConstants.VIRTUAL_MEDIA_ACTION_MNEMONIC).toCharArray()[0])));
      menuItems.add(this.virtualMediaLocalMenu);
      allMenuItems.add(this.virtualMediaLocalMenu);
      this.virtualMediaImageMenu = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.VIRTUAL_MEDIA_IMAGE_CONNECT_ACTION_NAME), var1) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((ShowVirtualMediaImagePanelCommand)this.getCommand()).getToolTip());
         }
      };
      this.virtualMediaImageMenu.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      this.virtualMediaImageMenu.addActionListener(var2);
      this.virtualMediaImageMenu.setCommand(new ShowVirtualMediaImagePanelCommand(var1));
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         this.virtualMediaImageMenu
            .setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.VIRTUAL_MEDIA_IMAGE_ACTION_MNEMONIC_INDEX)));
      }

      this.virtualMediaImageMenu
         .setMnemonic(
            KeyboardUtil.getKeyCode(new Character(var4.getString(MenuItemResourceBundleConstants.VIRTUAL_MEDIA_IMAGE_ACTION_MNEMONIC).toCharArray()[0]))
         );
      menuItems.add(this.virtualMediaImageMenu);
      allMenuItems.add(this.virtualMediaImageMenu);
      menuItems.add(new Separator());
      this.connectAudioMenuItem = new CommandMenuItem(var4.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT), var1) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((ConnectAudioCommand)this.getCommand()).getToolTip());
            this.setText(
               ((ConnectAudioCommand)this.getCommand()).isConnected()
                  ? var4.getString(MenuItemResourceBundleConstants.AUDIO_DISCONNECT)
                  : var4.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT)
            );
         }
      };
      this.connectAudioMenuItem.addActionListener(var2);
      this.connectAudioMenuItem.setCommand(new ConnectAudioCommand(var1));
      this.connectAudioMenuItem.addObservable(((RRCScreenContext)var1).getSelectedDevicesObservable());
      this.connectAudioMenuItem.addObservable(((RRCScreenContext)var1).getOpenPortsObservable());
      this.connectAudioMenuItem.addObservable(((RRCScreenContext)var1).getAudioObserver());
      if (var1.getLocale() == Locale.US || var1.getLocale() == Locale.UK) {
         this.connectAudioMenuItem
            .setDisplayedMnemonicIndex(Integer.parseInt(var4.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT_AUDIO_MNEMONIC_INDEX)));
      }

      this.connectAudioMenuItem
         .setMnemonic(KeyboardUtil.getKeyCode(new Character(var4.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT_AUDIO_MNEMONIC).toCharArray()[0])));
      menuItems.add(this.connectAudioMenuItem);
      allMenuItems.add(this.connectAudioMenuItem);
   }

   public static synchronized CommandMenuItemCache getInstance(ScreenContext var0, ActionListener var1) {
      if (cache == null) {
         if (var0 == null) {
            throw new NullPointerException("scrContext is null");
         }

         if (var1 == null) {
            throw new NullPointerException("aListener is null");
         }

         cache = new CommandMenuItemCache();
         cache.init(var0, var1);
      }

      return cache;
   }

   public static void init() {
      menuItems = new ArrayList(26);
      allMenuItems = new ArrayList(21);
   }

   public static void destroy() {
      cache = null;
      menuItems = null;
      allMenuItems = null;
   }

   public static CommandMenuItemCache getInstance() {
      return cache;
   }

   public Collection getCommandMenuItems() {
      return Collections.unmodifiableCollection(menuItems);
   }

   public Collection getAllCommandMenuItems() {
      return Collections.unmodifiableCollection(allMenuItems);
   }

   public CommandMenuItem getVirtualMediaImageMenu() {
      return this.virtualMediaImageMenu;
   }

   public CommandMenuItem getVirtualMediaLocalMenu() {
      return this.virtualMediaLocalMenu;
   }
}
