package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.ShowSingleCursorInstructionCommand;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.MultyObserverComponentInterface;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JToggleButton;

public class CommandToggleButton extends JToggleButton implements CommandHolder, ConfirmableCommandInterface, MultyObserverComponentInterface {
   protected ScreenContext scrContext;
   private static final long serialVersionUID = -6418447216864629068L;
   private Command command;
   private boolean confirmation = false;
   private HashMap observables = new HashMap();

   public CommandToggleButton(ScreenContext var1) {
      this.scrContext = var1;
      this.init();
      this.observables = new HashMap();
   }

   public CommandToggleButton(Icon var1, ScreenContext var2) {
      super(var1);
      this.scrContext = var2;
      this.init();
   }

   public CommandToggleButton(String var1, ScreenContext var2) {
      super(var1);
      this.scrContext = var2;
      this.init();
   }

   public CommandToggleButton(Action var1, ScreenContext var2) {
      super(var1);
      this.scrContext = var2;
      this.init();
   }

   public CommandToggleButton(String var1, Icon var2, ScreenContext var3) {
      super(var1, var2);
      this.scrContext = var3;
      this.init();
   }

   protected void init() {
      this.command = new DummyCommand(this.scrContext);
      this.setEnabled(this.command.isExecutable());
      CommandToggleButton.EnterKeyListener var1 = new CommandToggleButton.EnterKeyListener();
      this.addKeyListener(var1);
   }

   @Override
   public void setCommand(Command var1) {
      this.command = var1;
      this.setEnabled(this.command != null ? this.command.isExecutable() : false);
   }

   @Override
   public Command getCommand() {
      return this.command;
   }

   @Override
   public boolean getConfirmation() {
      return this.confirmation;
   }

   @Override
   public void setConfirmation(boolean var1) {
      this.confirmation = var1;
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void update(Observable var1, Object var2) {
      this.setSelected(false);
      if (this.getCommand() != null) {
         if (this.getCommand() instanceof ShowSingleCursorInstructionCommand) {
            ArrayList var3 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
            if (var3 != null && var3.size() > 0) {
               Object var4 = var3.get(0);
               if (var4 != null && var4 instanceof Port && ((Port)var4).isConnected() && ((Port)var4).getDeviceClass().equals("KVM")) {
                  boolean var5 = ((KvmPort)var4).isSingleCursorMode();
                  this.setSelected(var5);
               }
            }
         }

         this.setEnabled(this.getCommand().isExecutable());
      } else {
         this.setEnabled(false);
      }
   }

   public class EnterKeyListener extends KeyAdapter {
      @Override
      public void keyPressed(KeyEvent var1) {
         if (var1.getKeyCode() == 10) {
            CommandToggleButton.this.doClick();
         }
      }
   }
}
