package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.G2SerialPort;
import com.raritan.rrc.data.HtmlPort;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.SerialPort;
import com.raritan.rrc.ui.MPCScanFrame;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.MultyObserverComponentInterface;
import com.raritan.tools.ui.panes.displays.ShellInternalFrame;
import com.raritan.tools.util.ObservableContainer;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;
import javax.swing.border.BevelBorder;
import nn.pp.common.ResourceLoader;

public class ConnectedServersToolBar extends JToolBar implements MultyObserverComponentInterface {
   private final HashMap observables = new HashMap();
   private RRCScreenContext scrContext;
   private ButtonGroup bGroup;
   private HashMap buttonMappings;
   private Port selectedButton;
   JToggleButton scanButton;

   public ConnectedServersToolBar(RRCScreenContext var1) {
      this.scrContext = var1;
      this.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.addObservable(this.scrContext.getOpenPortsObservable());
      this.addObservable(this.scrContext.getScanFrameObserver());
      this.setRollover(true);
      this.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1), BorderFactory.createRaisedBevelBorder()));
      this.bGroup = new ButtonGroup();
      this.buttonMappings = new HashMap();
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public synchronized void update(Observable var1, Object var2) {
      if ("Open Ports".equals(((ObservableContainer)var1).getContainerName())) {
         if (var2 != null) {
            HashMap var3 = (HashMap)var2;
            if (!this.buttonMappings.keySet().containsAll(var3.values())) {
               for (final Port var5 : var3.values()) {
                  if (!this.buttonMappings.containsKey(var5)) {
                     final JToggleButton var6 = new JToggleButton(var5.getName());
                     var6.addActionListener(
                        new ActionListener() {
                           @Override
                           public void actionPerformed(ActionEvent var1) {
                              if (var5.equals(ConnectedServersToolBar.this.selectedButton)) {
                                 ConnectedServersToolBar.this.clearSelection();
                                 ConnectedServersToolBar.this.selectButtonFrame(var5, false);
                              } else {
                                 if (ConnectedServersToolBar.this.selectedButton != null
                                    && ConnectedServersToolBar.this.selectedButton.getView() != null
                                    && ConnectedServersToolBar.this.selectedButton.getView().getShellInternalFrame() != null) {
                                    try {
                                       ConnectedServersToolBar.this.selectedButton.getView().getShellInternalFrame().setSelected(false);
                                    } catch (PropertyVetoException var3x) {
                                       var3x.printStackTrace();
                                    }
                                 }

                                 ConnectedServersToolBar.this.selectedButton = var5;
                                 ConnectedServersToolBar.this.selectButtonFrame(var5, var6.isSelected());
                                 var5.getView().setViewFocus();
                              }
                           }
                        }
                     );
                     var6.setToolTipText(var5.getViewName());
                     var6.setBorder(new BevelBorder(0));
                     var6.setBorderPainted(true);
                     var6.setPreferredSize(new Dimension(50, 20));
                     if (var5 instanceof KvmPort) {
                        var6.setIcon(
                           ResourceLoader.loadImageIcon(RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale()).getString("KvmPortActive.image"))
                        );
                     } else if (var5 instanceof HtmlPort) {
                        var6.setIcon(
                           ResourceLoader.loadImageIcon(RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale()).getString("HtmlPortActive.image"))
                        );
                     } else if (var5 instanceof SerialPort || var5 instanceof G2SerialPort) {
                        var6.setIcon(
                           ResourceLoader.loadImageIcon(
                              RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale()).getString("SerialPortActive.image")
                           )
                        );
                     }

                     this.buttonMappings.put(var5, var6);
                     this.bGroup.add(var6);
                     var6.setSelected(true);
                     this.selectedButton = var5;
                     this.add(var6);
                     this.revalidate();
                     this.repaint();
                     break;
                  }
               }
            } else if (!var3.values().containsAll(this.buttonMappings.keySet())) {
               for (Port var15 : this.buttonMappings.keySet()) {
                  if (!var3.containsValue(var15)) {
                     JToggleButton var18 = (JToggleButton)this.buttonMappings.remove(var15);
                     this.bGroup.remove(var18);
                     this.remove(var18);
                     this.revalidate();
                     this.repaint();
                     var18 = null;
                     break;
                  }
               }
            } else if (this.buttonMappings.keySet().containsAll(var3.values()) && var3.values().containsAll(this.buttonMappings.keySet())) {
               for (Port var16 : var3.values()) {
                  if (this.buttonMappings.containsKey(var16)) {
                     JToggleButton var20 = (JToggleButton)this.buttonMappings.get(var16);
                     if (!var20.getText().equals(var16.getName())) {
                        var20.setText(var16.getName());
                        String var7 = var16.getViewName();
                        var20.setToolTipText(var7);
                        if (var16.getView() != null && var16.getView().getShellInternalFrame() != null) {
                           var16.getView().getShellInternalFrame().setTitle(var7);
                        }
                     }
                  }
               }
            }
         }
      } else if ("Selected Devices".equals(((ObservableContainer)var1).getContainerName())) {
         Object var9 = null;
         if (var2 == null) {
            return;
         }

         ArrayList var14 = (ArrayList)var2;
         if (var14.get(0) != null) {
            var9 = (Device)var14.get(0);
            if (var9 instanceof Port) {
               Port var17 = (Port)var9;
               if (var17.isConnected()) {
                  if (var17.getView() != null && var17.getView().getShellInternalFrame() != null) {
                     JToggleButton var21 = (JToggleButton)this.buttonMappings.get(var17);
                     if (var21 != null) {
                        var21.setSelected(true);
                        this.selectedButton = var17;
                     }
                  } else {
                     this.clearSelection();
                  }
               } else {
                  this.clearSelection();
               }
            } else {
               this.clearSelection();
            }
         }
      } else if ("ScanFrameObserver".equals(((ObservableContainer)var1).getContainerName())) {
         try {
            ArrayList var11 = (ArrayList)var2;
            if (var11.size() == 1) {
               this.scanButton = new JToggleButton("Scan Window");
               this.scanButton.addActionListener(new ActionListener() {
                  @Override
                  public void actionPerformed(ActionEvent var1) {
                     ConnectedServersToolBar.this.selectScanFrame(ConnectedServersToolBar.this.scanButton.isSelected());
                     ConnectedServersToolBar.this.scrContext.focusScanFrame();
                  }
               });
               this.scanButton.setToolTipText("Scan Window");
               this.scanButton.setBorder(new BevelBorder(0));
               this.scanButton.setBorderPainted(true);
               this.scanButton.setPreferredSize(new Dimension(50, 20));
               this.scanButton
                  .setIcon(ResourceLoader.loadImageIcon(RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale()).getString("KvmPortActive.image")));
               this.bGroup.add(this.scanButton);
               this.scanButton.setSelected(true);
               this.add(this.scanButton);
            } else {
               System.out.println("Scan Frame CLOSED....");
               this.bGroup.remove(this.scanButton);
               this.remove(this.scanButton);
               this.scanButton = null;
            }

            this.revalidate();
            this.repaint();
         } catch (Exception var8) {
            var8.printStackTrace();
         }
      }
   }

   public void clearSelection() {
      this.selectedButton = null;
      this.bGroup.setSelected(new JButton("dummy").getModel(), true);
   }

   public void selectScanFrame(boolean var1) {
      try {
         MPCScanFrame var2 = this.scrContext.getScanFrame();
         if (var2 != null) {
            if (var1) {
               if (var2.isIcon()) {
                  var2.setIcon(false);
               }

               var2.setSelected(!var1);
            } else {
               var2.setIcon(!var1);
            }
         }
      } catch (PropertyVetoException var3) {
         RRCLogger.logException(var3);
      } catch (Exception var4) {
         RRCLogger.logException(var4);
      }
   }

   public void selectButtonFrame(Port var1, boolean var2) {
      try {
         ShellInternalFrame var3 = var1.getView().getShellInternalFrame();
         if (var2) {
            if (var3.isIcon()) {
               var3.setIcon(false);
            }

            var3.setSelected(var2);
         } else if (this.scrContext.isScanFrameOpened()) {
            var3.setIcon(false);
         } else {
            var3.setIcon(!var2);
         }
      } catch (PropertyVetoException var4) {
         RRCLogger.logException(var4);
      }
   }
}
