package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCApplet;
import com.raritan.rrc.ui.RRCMain;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.screens.RRCScreenManager;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.ui.AbstractUIManager;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.util.ImageHolder;
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.GraphicsConfiguration;
import java.awt.Insets;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import java.util.List;
import java.util.Timer;
import java.util.TimerTask;
import java.util.Vector;
import javaclientlib.utils.RRCLogger;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JPanel;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.plaf.basic.BasicInternalFrameUI;

public class FullScreenFrame extends JFrame {
   private final RRCScreenContext ctx;
   private final RRCMain rrcMain;
   private final RRCScreenManager screenManager;
   private final RaritanPropertyResourceBundle bundle;
   private final GraphicsConfiguration gc;
   private JInternalFrame viewFrame;
   private Port port;
   private AbstractUIManager.FullScreenTarget target;
   private JComponent northPane;
   private Dimension northPaneSize;
   private Rectangle viewFrameBounds;
   private Border jifBorder;
   private FullScreenToolBar bar;
   private boolean disposed = false;
   private static FullScreenFrame activeFrame = null;
   private static List<FullScreenFrame> allFrames = new Vector<>();
   private static boolean ignore = false;
   private WindowAdapter selectionWindowAdapter = new WindowAdapter() {
      @Override
      public void windowActivated(WindowEvent var1) {
         FullScreenFrame.this.activateView();
      }
   };
   private MouseAdapter selectionMouseAdapter = new MouseAdapter() {
      @Override
      public void mouseEntered(MouseEvent var1) {
         if (FullScreenFrame.activeFrame != FullScreenFrame.this) {
            FullScreenFrame.this.activateView();
         }
      }

      @Override
      public void mouseMoved(MouseEvent var1) {
         if (FullScreenFrame.activeFrame != FullScreenFrame.this) {
            FullScreenFrame.this.activateView();
         }
      }
   };

   public FullScreenFrame(
      RRCScreenContext var1,
      RRCMain var2,
      RRCScreenManager var3,
      RaritanPropertyResourceBundle var4,
      GraphicsConfiguration var5,
      JInternalFrame var6,
      Port var7,
      AbstractUIManager.FullScreenTarget var8
   ) {
      super(var5);
      this.ctx = var1;
      this.rrcMain = var2;
      this.screenManager = var3;
      this.bundle = var4;
      this.gc = var5;
      this.viewFrame = var6;
      this.port = var7;
      this.target = var8;
      allFrames.add(this);
      ImageHolder var9 = new ImageHolder(var1);
      this.setTitle(var4.getString("main.screen.title"));
      this.setIconImage(var9.getImage(var4.getString("raritan.icon")));
      this.setUndecorated(true);
      this.northPane = ((BasicInternalFrameUI)var6.getUI()).getNorthPane();
      this.northPaneSize = this.northPane.getSize();
      this.jifBorder = var6.getBorder();
      this.viewFrameBounds = var6.getBounds();
      JPanel var10 = new JPanel(new BorderLayout());
      var10.add(var6, "Center");
      boolean var11 = false;
      if (var1 != null) {
         var11 = var1.getAppSettings().isPinMenu();
      }

      this.bar = new FullScreenToolBar(
         var1,
         var4,
         var10,
         var2,
         var6,
         this.jifBorder,
         this.northPane,
         this.northPaneSize,
         this.viewFrameBounds,
         var11,
         var5,
         var7,
         this.selectionMouseAdapter,
         var8 != AbstractUIManager.FullScreenTarget.SECONDARY,
         var8 == AbstractUIManager.FullScreenTarget.SECONDARY
      );
      this.getContentPane().add(this.bar, "North");
      this.bar.setVisible(true);
      this.getContentPane().add(var10, "Center");
   }

   @Override
   public void setVisible(boolean var1) {
      if (this.disposed) {
         super.setVisible(var1);
      } else {
         if (var1) {
            activeFrame = this;
            this.northPane.setVisible(false);
            this.viewFrame.setBorder(new EmptyBorder(0, 0, 0, 0));
            Dimension var2 = this.gc.getBounds().getSize();
            this.northPane.setPreferredSize(new Dimension(0, 0));
            if (this.ctx.getApplication() instanceof RRCApplet) {
               this.setAlwaysOnTop(true);
            }

            switch (this.screenManager.getFullScreenStrategy()) {
               case 1:
                  this.setSize(var2.width, var2.height);
                  break;
               case 2:
                  Insets var3 = Toolkit.getDefaultToolkit().getScreenInsets(this.gc);
                  this.setSize(var2.width - var3.left - var3.right, var2.height - var3.top - var3.bottom);
                  break;
               case 3:
                  this.setExtendedState(6);
                  break;
               default:
                  this.rrcMain.getGraphicsDevice().setFullScreenWindow(this);
            }

            this.addWindowListener(this.selectionWindowAdapter);
            if (this.ctx.getSelectedDevicesObservable() != null && this.ctx.getSelectedDevicesObservable().getComponent() != null) {
               Device var7 = (Device)((ArrayList)this.ctx.getSelectedDevicesObservable().getComponent()).get(0);
               this.bar.enableMenuBar(var7);
            }
         } else {
            this.removeWindowListener(this.selectionWindowAdapter);
            if (this.screenManager.getFullScreenStrategy() == 0) {
               this.rrcMain.getGraphicsDevice().setFullScreenWindow(null);
            }

            RaritanDesktopPane var6 = (RaritanDesktopPane)this.ctx.getPanelMediator().getParent();
            this.viewFrame.setSize(var6.getSize());
            var6.add(this.viewFrame);

            try {
               if (this.viewFrame.isIcon()) {
                  this.viewFrame.setIcon(false);
               }
            } catch (PropertyVetoException var5) {
               RRCLogger.logException(var5);
            }

            try {
               if (this == activeFrame) {
                  if (!this.viewFrame.isSelected()) {
                     this.viewFrame.setSelected(true);
                  } else {
                     this.viewFrame.toFront();
                  }
               } else {
                  this.viewFrame.setSelected(false);
               }
            } catch (PropertyVetoException var4) {
               var4.printStackTrace();
               RRCLogger.logException(var4);
            }

            this.northPane.setPreferredSize(this.northPaneSize);
            this.northPane.setVisible(true);
            this.viewFrame.setBorder(this.jifBorder);
            this.viewFrame.setBounds(this.viewFrameBounds);
         }

         super.setVisible(var1);
      }
   }

   @Override
   public void dispose() {
      this.removeWindowListener(this.selectionWindowAdapter);
      this.bar.dispose();
      allFrames.remove(this);
      if (activeFrame == this || allFrames.isEmpty()) {
         activeFrame = null;
      }

      this.disposed = true;
      super.dispose();
   }

   public Port getPort() {
      return this.port;
   }

   public FullScreenToolBar getFSToolBar() {
      return this.bar;
   }

   public void updateInternalFrameReference(Port var1, Port var2, JInternalFrame var3, Border var4, JComponent var5, Dimension var6, Rectangle var7) {
      this.port = var2;
      this.viewFrame = var3;
      this.jifBorder = var4;
      this.northPane = var5;
      this.northPaneSize = var6;
      this.viewFrameBounds = var7;
   }

   public void switchToPortView(Port var1, Port var2) {
      this.bar.switchToPortView(var1, var2, true);
   }

   public JInternalFrame getViewFrame() {
      return this.bar.getViewFrame();
   }

   public static Container getActiveContentPane() {
      return activeFrame != null ? activeFrame.getContentPane() : null;
   }

   public static Container getContentPaneForPort(Port var0) {
      for (FullScreenFrame var2 : allFrames) {
         if (var2.getPort() == var0) {
            return var2;
         }
      }

      return null;
   }

   private void activateView() {
      if (!ignore && !this.disposed) {
         ignore = true;

         for (FullScreenFrame var2 : allFrames) {
            try {
               var2.viewFrame.setSelected(var2 == this);
            } catch (Exception var4) {
            }
         }

         activeFrame = this;
         new Timer().schedule(new TimerTask() {
            @Override
            public void run() {
               synchronized (this) {
                  FullScreenFrame.ignore = false;
                  MPCUtil.notifyObservers(FullScreenFrame.this.ctx, FullScreenFrame.this.port);
               }
            }
         }, 10L);
      }
   }
}
