package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.MonitorSettingsHandler;
import com.raritan.rrc.ui.RRCMain;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoDisconnectCommand;
import com.raritan.rrc.ui.commands.ShowTargetScreenResolutionCommand;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.MultyObserverComponentInterface;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.util.ObservableContainer;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GraphicsConfiguration;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Observable;
import java.util.Timer;
import java.util.TimerTask;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JInternalFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;
import javax.swing.SwingUtilities;
import javax.swing.border.BevelBorder;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.plaf.basic.BasicInternalFrameUI;

public class FullScreenToolBar extends JToolBar implements MultyObserverComponentInterface {
   private static final long serialVersionUID = 8859595065369693406L;
   private ButtonGroup bGroup;
   private Port selectedButton;
   private RRCScreenContext context;
   private RaritanPropertyResourceBundle bundle = null;
   private FullScreenToolBar.FullScreenMouseHandler mmh;
   private MouseAdapter smh;
   private RRCMain rrcMain;
   private JInternalFrame newframe;
   private JComponent northPane = null;
   private Dimension northPaneSize = null;
   private Rectangle viewFrameBounds = null;
   private Border jifBorder = null;
   private JPanel pane = null;
   private JPanel portPanel;
   private JPanel widgetPanel;
   private HashMap buttonMappings;
   private HashMap observables = new HashMap();
   private boolean hasExtraPortsOpen = false;
   private RRCMenuBar menubar;
   private RRCMenuBar disabledMenubar;
   private boolean createNewMenuBar;
   private JPanel menubarContainer;
   private JPanel disabledMenubarContainer;
   JPanel p;
   JScrollPane scrollPane;
   JLabel txtLabel;
   String hotKey;
   private boolean pinState = false;
   private boolean showFlag = false;
   private GraphicsConfiguration graphicsConfig;
   private boolean useTargetButtons = false;
   private boolean disposed = false;
   private ImageIcon pinIcon;
   private ImageIcon unpinIcon;
   private JToggleButton pinButton;

   public FullScreenToolBar(
      RRCScreenContext var1,
      RaritanPropertyResourceBundle var2,
      JPanel var3,
      RRCMain var4,
      JInternalFrame var5,
      Border var6,
      JComponent var7,
      Dimension var8,
      Rectangle var9,
      boolean var10,
      GraphicsConfiguration var11,
      Port var12,
      MouseAdapter var13,
      boolean var14,
      boolean var15
   ) {
      this.context = var1;
      this.bundle = var2;
      this.rrcMain = var4;
      this.newframe = var5;
      this.pane = var3;
      this.jifBorder = var6;
      this.northPane = var7;
      this.northPaneSize = var8;
      this.viewFrameBounds = var9;
      this.pinState = var10;
      this.graphicsConfig = var11;
      this.useTargetButtons = var14;
      this.pinIcon = var1.getImageIcon("Common_pin.gif");
      this.unpinIcon = var1.getImageIcon("Common_unpin.gif");
      this.mmh = new FullScreenToolBar.FullScreenMouseHandler();
      this.smh = var13;
      this.selectedButton = var12 != null ? var12 : var1.getSelectedPort();
      this.createNewMenuBar = var15;
      if (var15) {
         RRCMenuBar var16 = new RRCMenuBar(var1, false);
         var16.setMenuItemTargetScreenResolution(true);
         var16.enableMenusInFullScreenMode(false);
         var16.getWindowMenu().setEnabled(false);
         this.menubar = var16;
      } else {
         this.menubar = var1.getMenuBar();
      }

      this.setRollover(true);
      this.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1), BorderFactory.createRaisedBevelBorder()));
      this.bGroup = new ButtonGroup();
      this.buttonMappings = new HashMap();
      this.addObservable(this.context.getSelectedDevicesObservable());
      this.addObservable(this.context.getOpenPortsObservable());
      this.setLayout(new BorderLayout());
      this.createPortPanel();
      this.selectedButton.getView().addCustomMouseListener(this.smh);
      this.selectedButton.getView().addCustomMouseMotionListener(this.smh);
   }

   private void createPortPanel() {
      this.hotKey = this.context.getAppSettings().getkeyboardMenuHotkey();
      this.hotKey = this.hotKey.replace("Alt", "LeftAlt");
      this.portPanel = new JPanel(new FlowLayout(2));
      this.scrollPane = new JScrollPane();
      Dimension var1 = this.graphicsConfig.getBounds().getSize();
      this.scrollPane.setPreferredSize(new Dimension(var1.width, 50));
      JPanel var2 = new JPanel();
      var2.add(this.createOptionButton());
      var2.add(this.portPanel);
      this.scrollPane.getViewport().add(var2);
      this.scrollPane.getViewport().validate();
      this.scrollPane.setHorizontalScrollBarPolicy(30);
      this.scrollPane.setVerticalScrollBarPolicy(21);
      JScrollBar var3 = this.scrollPane.getHorizontalScrollBar();
      var3.setPreferredSize(new Dimension(5, 10));
      this.add(this.scrollPane, "West");
      this.createPortButtons();
      this.createWidgetsPanel();
      this.portPanel.add(this.widgetPanel);
      this.setLabelText();
   }

   private void createWidgetsPanel() {
      this.widgetPanel = new JPanel(new FlowLayout(2));
      CommandButton var1 = new CommandButton(this.bundle.getString("FullScreenToolbar.returnToNormalButton.label"), this.context);
      var1.setToolTipText(this.bundle.getString("FullScreenToolbar.returnToNormalButton.tooltip"));
      var1.setBorder(new BevelBorder(0));
      var1.setBorderPainted(true);
      var1.setPreferredSize(new Dimension(20, 20));
      final ShowTargetScreenResolutionCommand var2 = new ShowTargetScreenResolutionCommand(this.context);
      var1.setCommand(var2);
      var1.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            SwingUtilities.invokeLater(new Runnable() {
               @Override
               public void run() {
                  var2.execute();
                  FullScreenToolBar.this.context.resetDefaultFocus();
               }
            });
         }
      });
      this.widgetPanel.add(var1);
      CommandButton var3 = new CommandButton(this.bundle.getString("FullScreenToolbar.crossButton.label"), this.context);
      var3.setToolTipText(this.bundle.getString("FullScreenToolbar.crossButton.tooltip"));
      var3.setBorder(new BevelBorder(0));
      var3.setBorderPainted(true);
      var3.setPreferredSize(new Dimension(20, 20));
      final DoDisconnectCommand var4 = new DoDisconnectCommand(this.context);
      var3.setCommand(var4);
      var3.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            var4.getContext().setCommandParameter("selectedPortDevice", FullScreenToolBar.this.selectedButton);
            SwingUtilities.invokeLater(new Runnable() {
               @Override
               public void run() {
                  var4.execute();
                  if (FullScreenToolBar.this.selectedButton != null) {
                     MPCUtil.notifyObservers(FullScreenToolBar.this.context, FullScreenToolBar.this.selectedButton);

                     for (CommandMenu var2x : FullScreenToolBar.this.context.getMainScreenMediator().getWindowMenus()) {
                        var2x.setEnabled(false);
                     }
                  }
               }
            });
         }
      });
      this.widgetPanel.add(var3);
   }

   private JPanel createOptionButton() {
      this.p = new JPanel();
      JPanel var1 = new JPanel(new BorderLayout());
      var1.setAlignmentX(0.0F);
      var1.setAlignmentY(0.0F);
      if (this.selectedButton.isMultiMonitorPort()) {
         this.menubarContainer = new JPanel(new BorderLayout());
         this.menubarContainer.setAlignmentX(0.0F);
         this.menubarContainer.setAlignmentY(0.0F);
         this.menubarContainer.add(this.menubar, "Center");
         this.disabledMenubarContainer = new JPanel(new BorderLayout());
         this.disabledMenubarContainer.setAlignmentX(0.0F);
         this.disabledMenubarContainer.setAlignmentY(0.0F);
         this.disabledMenubarContainer.add(this.disabledMenubar = new RRCMenuBar(this.context, true), "Center");
         var1.add(this.menubarContainer, "North");
         var1.add(this.disabledMenubarContainer, "South");
         this.disabledMenubarContainer.setVisible(false);
      } else {
         var1.add(this.menubar, "North");
      }

      JPanel var2 = new JPanel();
      var2.setLayout(new FlowLayout());
      this.pinButton = new JToggleButton(this.pinState ? this.pinIcon : this.unpinIcon);
      this.pinButton.setPreferredSize(new Dimension(this.pinIcon.getIconWidth(), this.pinIcon.getIconHeight()));
      this.pinButton.setOpaque(false);
      this.pinButton.addItemListener(new ItemListener() {
         @Override
         public void itemStateChanged(ItemEvent var1) {
            FullScreenToolBar.this.pinState = !FullScreenToolBar.this.pinState;
            if (FullScreenToolBar.this.pinState) {
               FullScreenToolBar.this.setVisible(true);
               if (FullScreenToolBar.this.mmh.getPort() != null) {
                  FullScreenToolBar.this.mmh.getPort().getView().removeCustomMouseMotionListener(FullScreenToolBar.this.mmh);
                  FullScreenToolBar.this.mmh.getPort().getView().removeCustomMouseListener(FullScreenToolBar.this.mmh);
               }
            } else {
               FullScreenToolBar.this.setVisible(false);
               if (FullScreenToolBar.this.context != null && FullScreenToolBar.this.context.getSelectView() != null) {
                  FullScreenToolBar.this.context.getSelectView().setContextMenuKVMVisible(false);
               }

               if (FullScreenToolBar.this.mmh.getPort() != null) {
                  System.out.println("Adding pin listener");
                  FullScreenToolBar.this.mmh.getPort().getView().addCustomMouseMotionListener(FullScreenToolBar.this.mmh);
                  FullScreenToolBar.this.mmh.getPort().getView().addCustomMouseListener(FullScreenToolBar.this.mmh);
               }

               FullScreenToolBar.this.pane.validate();
            }

            FullScreenToolBar.this.togglePinState();
            FullScreenToolBar.this.focusVideo();
         }
      });
      JLabel var3 = new JLabel(this.context.getImageIcon("Common_Raritan_Title.gif"));
      this.txtLabel = new JLabel();
      var2.add(this.txtLabel);
      var2.add(this.pinButton);
      var2.add(var3);
      this.p.add(var2);
      this.p.add(var1);
      return this.p;
   }

   private void togglePinState() {
      this.pinButton.setIcon(this.pinState ? this.pinIcon : this.unpinIcon);
   }

   private void focusVideo() {
      this.selectedButton.getView().setViewFocus();
   }

   public void removeMenuBar() {
      this.remove(this.p);
   }

   public void createPortButtons() {
      ArrayList var1 = this.context.getListOfOpenPorts();

      for (int var2 = 0; var2 < var1.size(); var2++) {
         String var3 = (String)var1.get(var2);
         if (var3 != null) {
            final Port var4 = (Port)this.context.getPortByKeyObservable(var3);
            if (var4 instanceof KvmPort) {
               if (this.useTargetButtons && (var4.isPrimaryOrSinglePort() || MonitorSettingsHandler.getInstance().getMonitorCount() == 1)) {
                  final JToggleButton var5 = new JToggleButton(var4.getName());
                  this.buttonMappings.put(var4, var5);
                  var5.addActionListener(new ActionListener() {
                     @Override
                     public void actionPerformed(ActionEvent var1) {
                        if (!var4.equals(FullScreenToolBar.this.selectedButton)) {
                           Port var2x = FullScreenToolBar.this.selectedButton;
                           FullScreenToolBar.this.selectedButton = var4;
                           if (var5.isSelected()) {
                              FullScreenToolBar.this.selectButtonFrame(var2x, var4, true);
                           }
                        }

                        var4.getView().setViewFocus();
                     }
                  });
                  var5.setToolTipText(var4.getViewName());
                  var5.setBorder(new BevelBorder(0));
                  var5.setBorderPainted(true);
                  var5.setPreferredSize(new Dimension(50, 20));
                  var5.setIcon(this.context.getImageIcon(RaritanResourceBundle.getResourceBundle(this.context.getLocale()).getString("KvmPortActive.image")));
                  this.bGroup.add(var5);
                  if (var4.equals(this.selectedButton)) {
                     var5.setSelected(true);
                     this.mmh.setPort(var4);
                  } else {
                     try {
                        var4.getView().getShellInternalFrame().setSelected(false);
                     } catch (PropertyVetoException var8) {
                        var8.printStackTrace();
                     }
                  }

                  this.portPanel.add(var5);
               } else {
                  this.mmh.setPort(this.selectedButton);
                  this.buttonMappings.put(var4, null);
               }
            } else {
               try {
                  var4.getView().getShellInternalFrame().setSelected(false);
                  this.hasExtraPortsOpen = true;
               } catch (PropertyVetoException var7) {
                  var7.printStackTrace();
               }
            }
         }
      }
   }

   public void switchToPortView(Port var1, Port var2, boolean var3) {
      try {
         if (var3) {
            this.pane.removeAll();
            this.mmh.removePort();
            RaritanDesktopPane var4 = (RaritanDesktopPane)this.context.getPanelMediator().getParent();
            this.newframe.setSize(var4.getSize());
            this.northPane.setPreferredSize(this.northPaneSize);
            this.northPane.setVisible(true);
            this.newframe.setBorder(this.jifBorder);
            this.newframe.setBounds(this.viewFrameBounds);
            var4.add(this.newframe);
            this.newframe.setSelected(false);
            if (var1 != null && var1.getView() != null) {
               var1.getView().setFullScreenMode(false);
               var1.getView().removeCustomMouseListener(this.smh);
               var1.getView().removeCustomMouseMotionListener(this.smh);
            }
         }

         var2.getView().setFullScreenMode(true);
         var2.getView().addCustomMouseListener(this.smh);
         var2.getView().addCustomMouseMotionListener(this.smh);
         this.mmh.setPort(var2);
         JInternalFrame var6 = this.newframe;
         this.newframe = var2.getView().getShellInternalFrame();
         if (this.newframe.isIcon()) {
            this.newframe.setIcon(false);
         }

         this.northPane = ((BasicInternalFrameUI)this.newframe.getUI()).getNorthPane();
         this.northPane.setVisible(false);
         this.northPaneSize = this.northPane.getSize();
         this.viewFrameBounds = this.newframe.getBounds();
         this.jifBorder = this.newframe.getBorder();
         this.newframe.setBorder(new EmptyBorder(0, 0, 0, 0));
         this.northPane.setPreferredSize(new Dimension(0, 0));
         this.pane.add(this.newframe, "Center");
         this.pane.validate();
         this.newframe.setSelected(true);
         this.rrcMain
            .updateInternalFrameReference(
               this.getGraphicsConfiguration().getDevice(),
               var1,
               var2,
               var6,
               this.newframe,
               this.jifBorder,
               this.northPane,
               this.northPaneSize,
               this.viewFrameBounds
            );
      } catch (PropertyVetoException var5) {
         RRCLogger.logException(var5);
      }
   }

   private void selectButtonFrame(Port var1, Port var2, boolean var3) {
      if (this.useTargetButtons) {
         if (this.rrcMain.fullScreenRequiresNewFrame(var2, this.newframe)) {
            this.rrcMain.recreateFullScreen(var2);
         } else {
            this.switchToPortView(var1, var2, var3);
         }
      }
   }

   public void dispose() {
      this.disposed = true;
      this.removeObservable(this.context.getOpenPortsObservable());
      this.observables = null;
      this.buttonMappings = null;
      this.portPanel.removeAll();
      this.widgetPanel.removeAll();
      this.mmh.removePort();
      if (this.selectedButton != null && this.selectedButton.getView() != null) {
         this.selectedButton.getView().removeCustomMouseListener(this.smh);
         this.selectedButton.getView().removeCustomMouseMotionListener(this.smh);
      }

      this.portPanel = null;
      this.widgetPanel = null;
      this.mmh = null;
      if (this.createNewMenuBar && this.menubar != null) {
         this.menubar.dispose();
      }

      this.menubar = null;
      if (this.disabledMenubar != null) {
         this.disabledMenubar.dispose();
      }

      this.disabledMenubar = null;
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public synchronized void update(Observable var1, Object var2) {
      if (!this.disposed) {
         if ("Open Ports".equals(((ObservableContainer)var1).getContainerName())) {
            if (var2 != null) {
               HashMap var3 = (HashMap)var2;
               if (this.buttonMappings.keySet().containsAll(var3.values()) || this.hasExtraPortsOpen) {
                  if (!var3.values().containsAll(this.buttonMappings.keySet())) {
                     for (Port var5 : this.buttonMappings.keySet()) {
                        if (!var3.containsValue(var5)) {
                           JToggleButton var6 = (JToggleButton)this.buttonMappings.remove(var5);
                           if (var6 != null) {
                              this.bGroup.remove(var6);
                              this.portPanel.remove(var6);
                           }

                           this.portPanel.revalidate();
                           this.portPanel.repaint();
                           this.scrollPane.revalidate();
                           this.scrollPane.repaint();
                           var6 = null;
                           if (!this.useTargetButtons && var5 == this.selectedButton) {
                              this.clearSelection();
                              this.rrcMain.returnOnSecondaryDisconnect(this.newframe);
                           } else if (this.buttonMappings.size() <= 0) {
                              this.clearSelection();
                              this.rrcMain.returnOnDisconnect();
                              this.rrcMain.addMenuBar();
                           } else if (this.selectedButton != null && this.selectedButton.equals(var5)) {
                              Port var7 = this.selectedButton;
                              this.mmh.removePort();

                              for (Iterator var8 = this.buttonMappings.keySet().iterator(); var8.hasNext(); this.selectedButton = null) {
                                 this.selectedButton = (Port)var8.next();
                                 JToggleButton var9 = (JToggleButton)this.buttonMappings.get(this.selectedButton);
                                 if (var9 != null) {
                                    var9.setSelected(true);
                                    break;
                                 }
                              }

                              if (this.selectedButton != null) {
                                 this.selectButtonFrame(var7, this.selectedButton, false);

                                 for (CommandMenu var10 : this.context.getMainScreenMediator().getWindowMenus()) {
                                    var10.setEnabled(false);
                                 }
                              } else {
                                 this.clearSelection();
                                 this.rrcMain.returnOnDisconnect();
                                 this.rrcMain.addMenuBar();
                              }
                           }
                           break;
                        }
                     }
                  } else if (var3.values().containsAll(this.buttonMappings.keySet())) {
                     for (Port var12 : var3.values()) {
                        if (this.buttonMappings.containsKey(var12)) {
                           JToggleButton var14 = (JToggleButton)this.buttonMappings.get(var12);
                           if (var14 != null && !var14.getText().equals(var12.getName())) {
                              var14.setText(var12.getName());
                              var14.setToolTipText(var12.getViewName());
                           }
                        }
                     }
                  }
               }
            }
         } else if ("Selected Devices".equals(((ObservableContainer)var1).getContainerName()) && ((ArrayList)var2).get(0) != null) {
            this.enableMenuBar((Device)((ArrayList)var2).get(0));
         }
      }
   }

   public void clearSelection() {
      this.selectedButton = null;
      this.bGroup.setSelected(new JButton("dummy").getModel(), true);
   }

   public void setLabelText() {
      if (this.context.getSelectView().isSingleCursor()) {
         this.txtLabel.setText(this.hotKey + ", " + this.bundle.getString("FullScreen.exitSMM"));
      } else {
         this.txtLabel.setText("");
      }

      this.validate();
   }

   public void setToolBarVisible(boolean var1) {
      try {
         Timer var2 = new Timer(true);
         var2.schedule(new FullScreenToolBar.ShowMessage(), 0L, 5000L);
      } catch (Exception var3) {
         RRCLogger.logException(var3);
      }
   }

   public JInternalFrame getViewFrame() {
      return this.newframe;
   }

   public void enableMenuBar(Device var1) {
      if (this.menubarContainer != null && this.disabledMenubarContainer != null && var1 != null && var1 instanceof Port) {
         this.menubarContainer.setVisible(var1 == this.selectedButton);
         this.disabledMenubarContainer.setVisible(var1 != this.selectedButton);
      }
   }

   class FullScreenMouseHandler extends MouseAdapter {
      private Port port;

      public void setPort(Port var1) {
         this.port = var1;
         if (!FullScreenToolBar.this.pinState) {
            var1.getView().addCustomMouseListener(this);
            var1.getView().addCustomMouseMotionListener(this);
         }
      }

      public Port getPort() {
         return this.port;
      }

      public void removePort() {
         if (this.port != null && this.port.getView() != null) {
            this.port.getView().removeCustomMouseListener(this);
            this.port.getView().removeCustomMouseMotionListener(this);
         }
      }

      public void removeBar(MouseEvent var1) {
         FullScreenToolBar.this.setVisible(false);
         if (FullScreenToolBar.this.context != null && FullScreenToolBar.this.context.getSelectView() != null) {
            FullScreenToolBar.this.context.getSelectView().setContextMenuKVMVisible(false);
         }

         FullScreenToolBar.this.pane.validate();
      }

      public void addBar(MouseEvent var1) {
         FullScreenToolBar.this.setVisible(true);
      }

      @Override
      public void mouseMoved(MouseEvent var1) {
         if (var1.getY() <= 20 || var1.getY() < 0 || FullScreenToolBar.this.showFlag) {
            this.addBar(var1);
         } else if (FullScreenToolBar.this.isVisible()) {
            this.removeBar(var1);
         }

         FullScreenToolBar.this.setLabelText();
      }

      @Override
      public void mouseExited(MouseEvent var1) {
         this.addBar(var1);
         FullScreenToolBar.this.setLabelText();
      }
   }

   class ShowMessage extends TimerTask {
      int num = 1;

      public ShowMessage() {
      }

      @Override
      public void run() {
         if (this.num > 0) {
            FullScreenToolBar.this.showFlag = true;
            if (!FullScreenToolBar.this.isVisible()) {
               FullScreenToolBar.this.setFocusable(true);
               FullScreenToolBar.this.setVisible(true);
            }

            this.num--;
         } else {
            FullScreenToolBar.this.showFlag = false;
            this.cancel();
         }
      }
   }
}
