package com.raritan.rrc.ui.components;

public class IntegerValidator implements FieldValidator {
   public static final int NEVER = 0;
   public static final int OPTIONAL = 1;
   public static final int ALWAYS = 2;
   private int minimum;
   private int maximum;
   private int rangeCheckDigits;
   private int signRequired;
   private String message;

   public IntegerValidator() {
      this(Integer.MIN_VALUE, Integer.MAX_VALUE, 0);
   }

   public IntegerValidator(int var1, int var2, String var3) {
      this(var1, var2, 0);
      this.message = var3;
   }

   public IntegerValidator(int var1, int var2) {
      this(var1, var2, 0);
      int var3 = Integer.toString(Math.abs(var1)).length();
      int var4 = Integer.toString(Math.abs(var2)).length();
      this.startRangeCheckAt(Math.min(var3, var4));
   }

   public IntegerValidator(int var1, int var2, int var3) {
      this.minimum = var1;
      this.maximum = var2;
      this.startRangeCheckAt(var3);
   }

   @Override
   public boolean isValid(String var1) {
      byte var2 = 1;
      boolean var3 = false;
      char var4 = var1.charAt(0);
      if (var4 == '+' || var4 == '-') {
         var3 = true;
         var1 = var1.substring(1);
         if (var4 == '-') {
            var2 = -1;
         }
      }

      if (this.signRequired == 0 && var3) {
         return false;
      } else if (this.signRequired == 2 && !var3) {
         return false;
      } else if (var1.length() == 0) {
         return true;
      } else {
         int var5;
         try {
            var5 = Integer.parseInt(var1) * var2;
         } catch (Exception var7) {
            return false;
         }

         return var1.length() < this.rangeCheckDigits ? true : var5 >= this.minimum && var5 <= this.maximum;
      }
   }

   @Override
   public String getMessage() {
      return this.message;
   }

   public void startRangeCheckAt(int var1) {
      this.rangeCheckDigits = var1;
   }

   public void setSignRequired(int var1) {
      this.signRequired = var1;
   }
}
