package com.raritan.rrc.ui.components;

import java.awt.Color;
import java.awt.Component;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.List;
import javax.swing.DefaultListModel;
import javax.swing.JCheckBox;
import javax.swing.JList;
import javax.swing.ListCellRenderer;
import javax.swing.UIDefaults;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;

public class JCheckBoxList extends JList {
   static Color listForeground;
   static Color listBackground;
   static Color listSelectionForeground;
   static Color listSelectionBackground;
   private JCheckBox[] listCheckBoxes;

   public JCheckBoxList() {
      new JCheckBoxList(new String[0]);
   }

   public JCheckBoxList(String[] var1) {
      this.listCheckBoxes = new JCheckBox[var1.length];
      this.setListData(var1);

      for (int var2 = 0; var2 < var1.length; var2++) {
         this.listCheckBoxes[var2] = new JCheckBox(var1[var2]);
      }

      this.finishConstruction();
   }

   public JCheckBoxList(JCheckBox[] var1) {
      DefaultListModel var2 = new DefaultListModel();
      this.listCheckBoxes = var1;

      for (int var3 = 0; var3 < var1.length; var3++) {
         var2.addElement(var1[var3].getText());
      }

      this.finishConstruction();
      this.setModel(var2);
   }

   private void finishConstruction() {
      this.addMouseListener(new JCheckBoxList.ListMouseListener());
      this.addKeyListener(new JCheckBoxList.ListKeyListener());
      this.setCellRenderer(new JCheckBoxList.CheckBoxRenderer());
   }

   public int getSelectedCheckBoxCount() {
      int var1 = 0;

      for (int var2 = 0; var2 < this.listCheckBoxes.length; var2++) {
         if (this.listCheckBoxes[var2].isSelected()) {
            var1++;
         }
      }

      return var1;
   }

   public List getSelectedLabels() {
      ArrayList var1 = new ArrayList();

      for (int var2 = 0; var2 < this.listCheckBoxes.length; var2++) {
         if (this.listCheckBoxes[var2].isSelected()) {
            var1.add(this.listCheckBoxes[var2].getText());
         }
      }

      return var1;
   }

   public void selectAllCheckBoxes(boolean var1) {
      for (int var2 = 0; var2 < this.listCheckBoxes.length; var2++) {
         this.listCheckBoxes[var2].setSelected(var1);
      }

      this.repaint();
   }

   static {
      UIDefaults var0 = UIManager.getLookAndFeel().getDefaults();
      listForeground = var0.getColor("List.foreground");
      listBackground = var0.getColor("List.background");
      listSelectionForeground = var0.getColor("List.selectionForeground");
      listSelectionBackground = var0.getColor("List.selectionBackground");
   }

   class CheckBoxRenderer implements ListCellRenderer {
      protected Border noFocusBorder = new EmptyBorder(1, 1, 1, 1);

      @Override
      public Component getListCellRendererComponent(JList var1, Object var2, int var3, boolean var4, boolean var5) {
         JCheckBox var6 = JCheckBoxList.this.listCheckBoxes[var3];
         var6.setBackground(var4 ? var1.getSelectionBackground() : var1.getBackground());
         var6.setForeground(var4 ? var1.getSelectionForeground() : var1.getForeground());
         var6.setEnabled(var1.isEnabled());
         var6.setFont(var1.getFont());
         var6.setFocusPainted(false);
         var6.setBorderPainted(true);
         var6.setBorder(var4 ? UIManager.getBorder("List.focusCellHighlightBorder") : this.noFocusBorder);
         return var6;
      }
   }

   class ListKeyListener extends KeyAdapter {
      @Override
      public void keyPressed(KeyEvent var1) {
         if (var1.getKeyCode() == 32 && var1.getID() == 401 && JCheckBoxList.this.getSelectedIndex() >= 0) {
            JCheckBox var2 = JCheckBoxList.this.listCheckBoxes[JCheckBoxList.this.getSelectedIndex()];
            var2.setSelected(!var2.isSelected());
            JCheckBoxList.this.repaint();
         }
      }
   }

   class ListMouseListener extends MouseAdapter {
      @Override
      public void mousePressed(MouseEvent var1) {
         int var2 = JCheckBoxList.this.locationToIndex(var1.getPoint());
         if (var2 >= 0 && var2 < JCheckBoxList.this.getModel().getSize()) {
            JCheckBox var3 = JCheckBoxList.this.listCheckBoxes[var2];
            var3.setSelected(!var3.isSelected());
            JCheckBoxList.this.repaint();
         }
      }
   }
}
