package com.raritan.rrc.ui.components;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Toolkit;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import javax.swing.FocusManager;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.PlainDocument;

public class MaskTextField extends JTextField implements DocumentListener, FocusListener, KeyListener {
   private TextGroup parent;
   private String mask;
   private Color maskColor = TextGroup.DEFAULT_MASK_COLOR;
   private boolean displayPartialMask = true;
   private boolean isFocusTraversable = true;
   private FieldValidator validator;
   private StringBuffer textBuffer = new StringBuffer();

   public MaskTextField(int var1, String var2) {
      super(var1);
      this.setMask(var2);
      if (var2.trim().length() == 0) {
         this.setMask(null);
      }

      this.getDocument().addDocumentListener(this);
      this.addFocusListener(this);
      this.addKeyListener(this);
   }

   public void setParent(TextGroup var1) {
      this.parent = var1;
   }

   public void setMask(String var1) {
      this.mask = var1;
   }

   public String getMask() {
      return this.mask;
   }

   public void setMaskColor(Color var1) {
      this.maskColor = var1;
   }

   public Color getMaskColor() {
      return this.parent != null ? this.parent.getMaskColor() : this.maskColor;
   }

   public void setDisplayPartialMask(boolean var1) {
      this.displayPartialMask = var1;
   }

   public boolean isDisplayPartialMask() {
      return this.parent != null ? this.parent.isDisplayPartialMask() : this.displayPartialMask;
   }

   public void setValidator(FieldValidator var1) {
      this.validator = var1;
   }

   @Override
   public boolean isFocusTraversable() {
      return this.isFocusTraversable;
   }

   public void setFocusTraversable(boolean var1) {
      this.isFocusTraversable = var1;
   }

   @Override
   public void paintComponent(Graphics var1) {
      super.paintComponent(var1);
      if (this.mask != null) {
         int var2 = this.getDocument().getLength();
         if (this.isDisplayPartialMask() && var2 < this.mask.length()) {
            var1.setColor(this.getMaskColor());
            FontMetrics var7 = this.getFontMetrics(this.getFont());
            int var8 = this.getInsets().top + var7.getAscent();
            int var9 = this.getInsets().left + var7.stringWidth(this.getText());
            var1.drawString(this.mask.substring(var2), var9, var8);
         } else if (!this.isDisplayPartialMask() && var2 == 0) {
            Dimension var3 = this.getSize();
            var1.setColor(this.getMaskColor());
            FontMetrics var4 = this.getFontMetrics(this.getFont());
            int var5 = this.getInsets().top + var4.getAscent();
            int var6 = this.getInsets().left + (var3.width - var4.stringWidth(this.mask)) / 2;
            var1.drawString(this.mask, var6, var5);
         }
      }
   }

   @Override
   protected Document createDefaultModel() {
      return new MaskTextField.SizeDocument(this.getColumns());
   }

   @Override
   public void insertUpdate(DocumentEvent var1) {
      Document var2 = var1.getDocument();
      if (var2.getLength() == this.getColumns()) {
         Container var3 = this.getParent();
         if (var3 instanceof TextGroup) {
            ((TextGroup)var3).tab(this, 1);
         } else {
            FocusManager.getCurrentManager().focusNextComponent(this);
         }
      }
   }

   @Override
   public void removeUpdate(DocumentEvent var1) {
   }

   @Override
   public void changedUpdate(DocumentEvent var1) {
   }

   @Override
   public void focusGained(FocusEvent var1) {
      JTextField var2 = (JTextField)var1.getSource();
      var2.selectAll();
      var2.setToolTipText(null);
   }

   @Override
   public void focusLost(FocusEvent var1) {
   }

   @Override
   public void keyTyped(KeyEvent var1) {
      if (!this.isAlwaysValid(var1)) {
         if (this.validator != null) {
            this.setToolTipText(null);
            String var2 = this.getPossibleText(var1);
            if (!this.validator.isValid(var2)) {
               this.setToolTipText(this.validator.getMessage());
               Component var3 = (Component)var1.getSource();
               var3.dispatchEvent(new KeyEvent(var3, 401, 0L, 2, 112));
               var1.consume();
            }
         }
      }
   }

   @Override
   public void keyPressed(KeyEvent var1) {
   }

   @Override
   public void keyReleased(KeyEvent var1) {
   }

   protected boolean isAlwaysValid(KeyEvent var1) {
      boolean var2 = false;
      switch (var1.getKeyCode()) {
         case 8:
         case 9:
         case 27:
            var2 = true;
         default:
            return var2;
      }
   }

   private String getPossibleText(KeyEvent var1) {
      JTextField var2 = (JTextField)var1.getSource();
      this.textBuffer.setLength(0);
      this.textBuffer.append(var2.getText());
      int var3 = var2.getSelectionStart();
      int var4 = var2.getSelectionEnd();
      this.textBuffer.delete(var3, var4);
      this.textBuffer.insert(var3, var1.getKeyChar());
      return this.textBuffer.toString();
   }

   class SizeDocument extends PlainDocument {
      private int maximumFieldLength = 0;

      public SizeDocument(int var2) {
         this.maximumFieldLength = var2;
      }

      @Override
      public void insertString(int var1, String var2, AttributeSet var3) throws BadLocationException {
         if (var2 != null) {
            if (this.getLength() + var2.length() > this.maximumFieldLength) {
               Toolkit.getDefaultToolkit().beep();
            } else {
               super.insertString(var1, var2, var3);
            }
         }
      }
   }
}
