package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.BladeChassis;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.URLPort;
import com.raritan.rrc.data.VirtualBladeChassis;
import com.raritan.rrc.ui.models.DeviceDisplayLabelExtractor;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.util.image.DualImageFactory;
import java.awt.Component;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeCellRenderer;
import nn.pp.common.ResourceLoader;

public class NavigatorRenderer extends DefaultTreeCellRenderer {
   public static final String PROFILED_STATE = "PROFILED";
   public static final String NO_PROFILE_STATE = "NOT_PROFILED";
   public static final String MODEM_PROFILE_STATE = "MODEM_PROFILED";
   protected static final String DEVICE_CONNECTED_STATE = "CONNECTED";
   protected static final String DEVICE_UNAVAILABLE_STATE = "UNAVAILABLE";
   protected static final String DEVICE_DISCONNECTED_STATE = "AVAILABLE";
   public static final int UNAVAILABLE = 0;
   public static final int AVAILABLE = 1;
   public static final int BUSY = 2;
   private static final long serialVersionUID = -3067401733113474686L;
   protected ScreenContext scrContext;
   private String rootLabelString;
   private JLabel rootLabel = null;
   private String rootIcon;
   private String deviceConnected;
   private String deviceDisonnected;
   private String deviceUnavailable;
   private String profiledDevice;
   private String modemProfiledDevice;
   private String notProfiledDevice;
   private String virtualMedia;
   private String serialPort;
   private String serialPortActive;
   private String paragonDevice;
   private String paragonDeviceActive;
   private String kvmPort;
   private String portUnavalable;
   private String portOccupied;
   private String kvmPortActive;
   private String htmlPort;
   private boolean flag;
   private String htmlPortActive;
   private DeviceDisplayLabelExtractor labelExtractor = null;

   public NavigatorRenderer(ScreenContext var1, boolean var2) {
      this.scrContext = var1;
      this.flag = var2;
      RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.rootLabelString = var3.getString("NavigatorRoot.name");
      this.rootIcon = var3.getString("NavigatorRoot.image");
      this.deviceConnected = var3.getString("DeviceConnected.image");
      this.deviceDisonnected = var3.getString("DeviceDisconnected.image");
      this.deviceUnavailable = var3.getString("DeviceUnavailable.image");
      this.profiledDevice = var3.getString("NewProfileAction.image");
      this.modemProfiledDevice = var3.getString("modemProfiled.image");
      this.notProfiledDevice = var3.getString("notProfiledDevice.image");
      this.virtualMedia = var3.getString("virtualMedia.image");
      this.serialPort = var3.getString("SerialPort.image");
      this.serialPortActive = var3.getString("SerialPortActive.image");
      this.kvmPort = var3.getString("KvmPort.image");
      this.portUnavalable = var3.getString("PortUnavalable.image");
      this.portOccupied = var3.getString("PortOccupied.image");
      this.kvmPortActive = var3.getString("KvmPortActive.image");
      this.htmlPort = var3.getString("HtmlPort.image");
      this.htmlPortActive = var3.getString("HtmlPortActive.image");
      this.paragonDevice = var3.getString("Paragon.image");
      this.paragonDeviceActive = var3.getString("ParagonActive.image");
      this.rootLabel = new JLabel(this.rootLabelString, this.scrContext.getImageIcon(this.rootIcon), 0);
   }

   public ImageIcon getIcon(String var1, String var2, int var3, boolean var4, boolean var5) {
      if (var1.equals("Paragon")) {
         return var2.equals("CONNECTED") ? ResourceLoader.loadImageIcon(this.paragonDeviceActive) : ResourceLoader.loadImageIcon(this.paragonDevice);
      } else if (var1.equals("BladeChassis")) {
         if (var2.equals("CONNECTED")) {
            return ResourceLoader.loadImageIcon(this.kvmPortActive);
         } else if (var3 == 0) {
            return ResourceLoader.loadImageIcon(this.portUnavalable);
         } else {
            return var3 == 2 ? ResourceLoader.loadImageIcon(this.portOccupied) : ResourceLoader.loadImageIcon(this.kvmPort);
         }
      } else if (var1.equals("Serial")) {
         return var2.equals("CONNECTED") ? ResourceLoader.loadImageIcon(this.serialPortActive) : ResourceLoader.loadImageIcon(this.serialPort);
      } else if (var1.equals("KVM")) {
         if (var2.equals("CONNECTED")) {
            return ResourceLoader.loadImageIcon(this.kvmPortActive);
         } else if (var3 == 0) {
            return ResourceLoader.loadImageIcon(this.portUnavalable);
         } else {
            return var3 == 2 ? ResourceLoader.loadImageIcon(this.portOccupied) : ResourceLoader.loadImageIcon(this.kvmPort);
         }
      } else if (var1.equals("HTML")) {
         return var4 ? ResourceLoader.loadImageIcon(this.htmlPortActive) : ResourceLoader.loadImageIcon(this.htmlPort);
      } else if (var1.equals("URL") || var1.equals("VirtualBladeChassis")) {
         return null;
      } else if (var4) {
         return ResourceLoader.loadImageIcon(this.deviceConnected);
      } else {
         return var2.equals("UNAVAILABLE") ? ResourceLoader.loadImageIcon(this.deviceUnavailable) : ResourceLoader.loadImageIcon(this.deviceDisonnected);
      }
   }

   public ImageIcon getConnectionIcon(boolean var1, boolean var2, String var3) {
      if (var3.equals("BladeChassis") || var3.equals("VirtualBladeChassis")) {
         return null;
      } else if (var2) {
         return ResourceLoader.loadImageIcon(this.modemProfiledDevice);
      } else {
         return var1 ? ResourceLoader.loadImageIcon(this.profiledDevice) : ResourceLoader.loadImageIcon(this.notProfiledDevice);
      }
   }

   @Override
   public Component getTreeCellRendererComponent(JTree var1, Object var2, boolean var3, boolean var4, boolean var5, int var6, boolean var7) {
      Object var8 = null;
      if (var2 != null && var2 instanceof DefaultMutableTreeNode) {
         if (((DefaultMutableTreeNode)var2).isRoot()) {
            return this.rootLabel;
         }

         this.setToolTipText("");
         var8 = (Device)((DefaultMutableTreeNode)var2).getUserObject();
         if (var8 instanceof Port) {
            Port var9 = (Port)var8;
            String var10 = var9.getDisplayName(((Device)var8).getSortType());
            if (var3) {
               if (var9.isConnected() && var9.hasFocus()) {
                  this.setFont(this.getFont().deriveFont(1));
               } else {
                  this.setFont(this.getFont().deriveFont(0));
               }
            } else {
               this.setFont(this.getFont().deriveFont(0));
            }

            super.getTreeCellRendererComponent(var1, var10, var3, var4, var5, var6, var7);
            String var11 = "<html><font>";
            String var12 = "<b>Port Name: </b>" + var10;
            String var13 = "";
            String var14 = "<br><b>Status: </b>" + var9.getStatusToolTip();
            String var15 = "<br><b>Availability: </b>" + var9.getAvailabilityToolTip();
            if (((Port)var8).getPortType().equals("VM")) {
               var13 = var13 + "<br><b>Type: </b>Virtual Media";
            }

            this.setIcon(
               this.getIcon(((Port)var8).getDeviceClass(), ((Device)var8).getState(), var9.getPortStatus(), ((Port)var8).isConnected(), ((Port)var8).isActive())
            );
            if (var9 instanceof URLPort) {
               String var16 = "" + ((URLPort)var9).getLink();
               var11 = var11 + "<b> Name: </b>" + var10 + "<br><b> URL: " + var16 + "</b>";
            } else {
               var11 = var11 + var12 + var13 + var14 + var15;
            }

            this.setToolTipText(var11);
         } else {
            String var18 = "";
            if (var8 instanceof IPReach) {
               var18 = this.labelExtractor.getDisplayLabel((Device)var8);
               this.setToolTipText(this.labelExtractor.getToolTip((Device)var8));
            } else if (var8 instanceof VirtualBladeChassis) {
               VirtualBladeChassis var19 = (VirtualBladeChassis)var8;
               var18 = var19.getDisplayName(((Device)var8).getSortType());
               this.setToolTipText(null);
            } else if (var8 instanceof BladeChassis) {
               BladeChassis var20 = (BladeChassis)var8;
               var18 = var20.getDisplayName(((Device)var8).getSortType());
               String var22 = "<html><font>";
               var22 = var22 + "<b>Blade Chassis Name: </b>" + var18;
               var22 = var22 + "<br><b>Status: </b>" + var20.getStatusToolTip();
               var22 = var22 + "<br><b>Availability: </b>" + var20.getAvailabilityToolTip();
               this.setToolTipText(var22);
            }

            super.getTreeCellRendererComponent(var1, var18.trim(), var3, var4, var5, var6, var7);
            this.setFont(this.getFont().deriveFont(0));
            this.setIcon(
               DualImageFactory.getDualImageIcon(
                  this.getConnectionIcon(((Device)var8).isProfiled(), ((Device)var8).isModemProfiled(), ((Device)var8).getDeviceType()),
                  this.getIcon(
                     ((Device)var8).getDeviceType(),
                     ((Device)var8).getState(),
                     ((Device)var8).getStatus(),
                     ((Device)var8).isConnected(),
                     ((Device)var8).isActive()
                  )
               )
            );
         }
      }

      return this;
   }

   public boolean isFlag() {
      return this.flag;
   }

   public void setFlag(boolean var1) {
      this.flag = var1;
   }

   public void setDeviceDisplayLabelExtractor(DeviceDisplayLabelExtractor var1) {
      this.labelExtractor = var1;
   }
}
