package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.USBProfile;
import com.raritan.rrc.data.USBProfilesInfo;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.AudioMenuCommand;
import com.raritan.rrc.ui.commands.AudioSettingsCommand;
import com.raritan.rrc.ui.commands.CascadeWindowsCommand;
import com.raritan.rrc.ui.commands.CloseAppletCommand;
import com.raritan.rrc.ui.commands.ConnectAudioCommand;
import com.raritan.rrc.ui.commands.DoAbsoluteMouseCommand;
import com.raritan.rrc.ui.commands.DoAutoSenseCommand;
import com.raritan.rrc.ui.commands.DoCalibrateColorCommand;
import com.raritan.rrc.ui.commands.DoCaptureTargetScreenshotCommand;
import com.raritan.rrc.ui.commands.DoChangeActiveUSBProfileCommand;
import com.raritan.rrc.ui.commands.DoCopyCommand;
import com.raritan.rrc.ui.commands.DoEnterOnscreenMenuCommand;
import com.raritan.rrc.ui.commands.DoExitOnscreenMenuCommand;
import com.raritan.rrc.ui.commands.DoIntelligentMouseCommand;
import com.raritan.rrc.ui.commands.DoPasteCommand;
import com.raritan.rrc.ui.commands.DoPowerCycleCommand;
import com.raritan.rrc.ui.commands.DoPowerOffCommand;
import com.raritan.rrc.ui.commands.DoPowerOnCommand;
import com.raritan.rrc.ui.commands.DoRefreshScreenCommand;
import com.raritan.rrc.ui.commands.DoRestartDeviceCommand;
import com.raritan.rrc.ui.commands.DoRunKeyboardMacroCommand;
import com.raritan.rrc.ui.commands.DoSelectAllTextCommand;
import com.raritan.rrc.ui.commands.DoSendAltTabCommand;
import com.raritan.rrc.ui.commands.DoSendCtrlAltDelCommand;
import com.raritan.rrc.ui.commands.DoSendCtrlNumlockCommand;
import com.raritan.rrc.ui.commands.DoSendFixedMacroCommand;
import com.raritan.rrc.ui.commands.DoSortByChannelCommand;
import com.raritan.rrc.ui.commands.DoSortByChannelNameCommand;
import com.raritan.rrc.ui.commands.DoSortByChannelStatusCommand;
import com.raritan.rrc.ui.commands.DoStandardMouseCommand;
import com.raritan.rrc.ui.commands.DoStopLoggingCommand;
import com.raritan.rrc.ui.commands.DoSynchronizeMouseCommand;
import com.raritan.rrc.ui.commands.ExitSystemCommand;
import com.raritan.rrc.ui.commands.HelpDisplayCommand;
import com.raritan.rrc.ui.commands.KVMPortDummyCommand;
import com.raritan.rrc.ui.commands.MouseMenuCommand;
import com.raritan.rrc.ui.commands.PopulateKeyboardMenuCommand;
import com.raritan.rrc.ui.commands.PopulateWindowMenuCommand;
import com.raritan.rrc.ui.commands.SelectCardReaderCommand;
import com.raritan.rrc.ui.commands.SerialPortDummyCommand;
import com.raritan.rrc.ui.commands.ShowAboutCommand;
import com.raritan.rrc.ui.commands.ShowAllDevicesCommand;
import com.raritan.rrc.ui.commands.ShowCSToolbarCommand;
import com.raritan.rrc.ui.commands.ShowConnectionInfoCommand;
import com.raritan.rrc.ui.commands.ShowExportMacrosCommand;
import com.raritan.rrc.ui.commands.ShowHistoryCommand;
import com.raritan.rrc.ui.commands.ShowImportMacrosCommand;
import com.raritan.rrc.ui.commands.ShowKeyboardMacrosCommand;
import com.raritan.rrc.ui.commands.ShowLoadConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowMessageCommand;
import com.raritan.rrc.ui.commands.ShowNavigatorCommand;
import com.raritan.rrc.ui.commands.ShowNewProfileCommand;
import com.raritan.rrc.ui.commands.ShowOptionsCommand;
import com.raritan.rrc.ui.commands.ShowPropertiesCommand;
import com.raritan.rrc.ui.commands.ShowSaveActivityLogCommand;
import com.raritan.rrc.ui.commands.ShowSaveDeviceConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowSaveDiagnosticLogCommand;
import com.raritan.rrc.ui.commands.ShowSaveTotalConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowSaveUserConfigurationCommand;
import com.raritan.rrc.ui.commands.ShowSendTextToTargetCommand;
import com.raritan.rrc.ui.commands.ShowSerialSettingsCommand;
import com.raritan.rrc.ui.commands.ShowSingleCursorInstructionCommand;
import com.raritan.rrc.ui.commands.ShowStartLoggingCommand;
import com.raritan.rrc.ui.commands.ShowStatusBarCommand;
import com.raritan.rrc.ui.commands.ShowTargetScreenResolutionCommand;
import com.raritan.rrc.ui.commands.ShowToolbarCommand;
import com.raritan.rrc.ui.commands.ShowToolsCommand;
import com.raritan.rrc.ui.commands.ShowUpdateDeviceCommand;
import com.raritan.rrc.ui.commands.ShowUpdateLDAPCertificateCommand;
import com.raritan.rrc.ui.commands.ShowUpdateLDAPKeyCommand;
import com.raritan.rrc.ui.commands.ShowUserPasswordCommand;
import com.raritan.rrc.ui.commands.ShowVideoScaleCommand;
import com.raritan.rrc.ui.commands.ShowVideoSettingsCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaImagePanelCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaLocalPanelCommand;
import com.raritan.rrc.ui.commands.ShowWithoutGroupsCommand;
import com.raritan.rrc.ui.commands.ShowWithoutTargetsCommand;
import com.raritan.rrc.ui.commands.SmartCardMenuCommand;
import com.raritan.rrc.ui.commands.TileWindowsCommand;
import com.raritan.rrc.ui.commands.USBProfileCommand;
import com.raritan.rrc.ui.commands.VirtualMediaMenuCommand;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandCheckMenuItem;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandMenuItem;
import com.raritan.tools.ui.components.CommandRadioMenuItem;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.util.CommandUtil;
import com.util.kbd.KeyboardUtil;
import java.awt.Component;
import java.awt.DefaultKeyboardFocusManager;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Observable;
import javax.swing.ButtonGroup;
import javax.swing.JApplet;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;
import javax.swing.event.MenuEvent;
import javax.swing.event.MenuListener;
import javax.swing.event.PopupMenuEvent;
import javax.swing.event.PopupMenuListener;
import nn.pp.core.Platform;
import nn.pp.ext.pref.IApplicationPreferences;

public class RRCMenuBar extends JMenuBar implements ActionListener, MenuListener {
   String CONNECTION_MENU_NAME = "ConnectionMenu.name";
   String NEW_PROFILE_ACTION_NAME = "NewProfileAction.name";
   String NEW_PROFILE_ACTION_MNEMONIC_INDEX = "MnemonicKey.NewProfileIndex";
   String NEW_PROFILE_ACTION_MNEMONIC = "MnemonicKey.NewProfile";
   String PROPERTIES_ACTION_NAME = "PropertiesAction.name";
   String PROPERTIES_ACTION_MNEMONIC_INDEX = "MnemonicKey.PropertiesIndex";
   String PROPERTIES_ACTION_MNEMONIC = "MnemonicKey.Properties";
   String CONNECTION_INFO_ACTION_NAME = "ConnectionInfoAction.name";
   String CONNECTION_INFO_ACTION_MNEMONIC_INDEX = "MnemonicKey.ConnectionInfoIndex";
   String CONNECTION_INFO_ACTION_MNEMONIC = "MnemonicKey.ConnectionInfo";
   String EXIT_ACTION_NAME = "ExitAction.name";
   String EXIT_ACTION_MNEMONIC_INDEX = "MnemonicKey.ExitIndex";
   String EXIT_ACTION_MNEMONIC = "MnemonicKey.Exit";
   String SERIAL_MENU_NAME = "SerialMenu.name";
   String SETTINGS_ACTION_NAME = "SettingsAction.name";
   String SETTINGS_ACTION_MNEMONIC_INDEX = "MnemonicKey.SettingsIndex";
   String SETTINGS_ACTION_MNEMONIC = "MnemonicKey.Settings";
   String HISTORY_ACTION_NAME = "HistoryAction.name";
   String HISTORY_ACTION_MNEMONIC = "MnemonicKey.History";
   String HISTORY_ACTION_MNEMONIC_INDEX = "MnemonicKey.HistoryIndex";
   String COPY_ACTION_NAME = "CopyAction.name";
   String COPY_ACTION_MNEMONIC = "MnemonicKey.Copy";
   String COPY_ACTION_MNEMONIC_INDEX = "MnemonicKey.CopyIndex";
   String PASTE_ACTION_NAME = "PasteAction.name";
   String PASTE_ACTION_MNEMONIC = "MnemonicKey.Paste";
   String PASTE_ACTION_MNEMONIC_INDEX = "MnemonicKey.PasteIndex";
   String SELECT_ALL_TEXT_ACTION_NAME = "SelectAllTextAction.name";
   String SELECT_ALL_TEXT_ACTION_MNEMONIC = "MnemonicKey.SelectAllText";
   String SELECT_ALL_TEXT_ACTION_MNEMONIC_INDEX = "MnemonicKey.SelectAllTextIndex";
   String START_LOGGING_ACTION_NAME = "StartLoggingAction.name";
   String START_LOGGING_ACTION_MNEMONIC = "MnemonicKey.Start";
   String START_LOGGING_ACTION_MNEMONIC_INDEX = "MnemonicKey.StartIndex";
   String STOP_LOGGING_ACTION_NAME = "StopLoggingAction.name";
   String STOP_LOGGING_ACTION_MNEMONIC = "MnemonicKey.Stop";
   String STOP_LOGGING_ACTION_MNEMONIC_INDEX = "MnemonicKey.StopIndex";
   String KEYBOARD_MENU_NAME = "KeyboardMenu.name";
   String SEND_CTRL_ALT_DELETE_ACTION_NAME = "SendCtrlAltDeleteAction.name";
   String SEND_CTRL_ALT_DELETE_ACTION_MNEMONIC = "MnemonicKey.KeyBoardCAD";
   String SEND_CTRL_ALT_DELETE_ACTION_MNEMONIC_INDEX = "MnemonicKey.KeyBoardCADIndex";
   String SEND_ALT_TAB_ACTION_NAME = "SendAltTabKvmMenu.name";
   String SEND_ALT_TAB_ACTION_MNEMONIC = "MnemonicKey.KeyBoardAltTab";
   String SEND_ALT_TAB_ACTION_MNEMONIC_INDEX = "MnemonicKey.KeyBoardAltTabIndex";
   String SEND_CTRL_NUMLOCK_ACTION_NAME = "SendCtrlNumlockAction.name";
   String SEND_CTRL_NUMLOCK_ACTION_MNEMONIC = "MnemonicKey.KeyBoardCtrlNumlock";
   String SEND_CTRL_NUMLOCK_ACTION_MNENONIC_INDEX = "MnemonicKey.KeyBoardCtrlNumlockIndex";
   String SEND_KVM_POPUP_KEY_ACTION_NAME = "SendKVMPopupKeyAction.name";
   String SEND_KVM_POPUP_KEY_MNEMONIC = "MnemonicKey.KeyBoardCAM";
   String SEND_KVM_POPUP_KEY_MNEMONIC_INDEX = "MnemonicKey.KeyBoardCAMIndex";
   String PRINT_SCREEN_MNEMONIC = "MnemonicKey.PrintScreen";
   String PRINT_SCREEN_MNEMONIC_INDEX = "MnemonicKey.PrintScreenIndex";
   String ENTER_ONSCREEN_MENU_ACTION_NAME = "EnterOnScreenMenuAction.name";
   String ENTER_ONSCREEN_MENU_ACTION_MNEMONIC = "MnemonicKey.Enter";
   String ENTER_ONSCREEN_MENU_ACTION_MNEMONIC_INDEX = "MnemonicKey.EnterIndex";
   String EXIT_ONSCREEN_MENU_ACTION_NAME = "ExitOnScreenMenuAction.name";
   String EXIT_ONSCREEN_MENU_ACTION_MNEMONIC = "MnemonicKey.ExitOnScreen";
   String EXIT_ONSCREEN_MENU_ACTION_MNEMONIC_INDEX = "MnemonicKey.ExitOnScreenIndex";
   String SEND_TEXT_TO_TARGET_ACTION_NAME = "SendTextToTargetAction.name";
   String SEND_TEXT_TO_TARGET_ACTION_MNEMONIC = "MnemonicKey.SendTextToTarget";
   String SEND_TEXT_TO_TARGET_ACTION_MNEMONIC_INDEX = "MnemonicKey.SendTextToTargetIndex";
   String KEYBOARD_MACROS_ACTION_NAME = "KeyboardMacrosAction.name";
   String KEYBOARD_MACROS_ACTION_MNEMONIC = "MnemonicKey.KeyBoardMacros";
   String KEYBOARD_MACROS_ACTION_MNEMONIC_INDEX = "MnemonicKey.KeyBoardMacrosIndex";
   String EXPORT_KEYBOARD_MACROS_ACTION_NAME = "ExportMacros.name";
   String EXPORT_KEYBOARD_MACROS_ACTION_MNEMONIC = "MnemonicKey.ExportMacros";
   String EXPORT_KEYBOARD_MACROS_ACTION_MNEMONIC_INDEX = "MnemonicKey.ExportMacrosIndex";
   String IMPORT_KEYBOARD_MACROS_ACTION_NAME = "ImportMacros.name";
   String IMPORT_KEYBOARD_MACROS_ACTION_MNEMONIC = "MnemonicKey.ImportMacros";
   String IMPORT_KEYBOARD_MACROS_ACTION_MNEMONIC_INDEX = "MnemonicKey.ImportMacrosIndex";
   String VIDEO_MENU_NAME = "VideoMenu.name";
   String REFRESH_SCREEN_ACTION_NAME = "RefreshScreenAction.name";
   String REFRESH_SCREEN_ACTION_MNEMONIC_INDEX = "MnemonicKey.RefreshScreenIndex";
   String REFRESH_SCREEN_ACTION_MNEMONIC = "MnemonicKey.RefreshScreen";
   String AUTO_SENSE_ACTION_NAME = "AutoSenseAction.name";
   String AUTO_SENSE_ACTION_MNEMONIC_INDEX = "MnemonicKey.AutoSenseIndex";
   String AUTO_SENSE_ACTION_MNEMONIC = "MnemonicKey.AutoSense";
   String CALIBRATE_COLOR_ACTION_NAME = "CalibrateColorAction.name";
   String CALIBRATE_COLOR_ACTION_MNEMONIC_INDEX = "MnemonicKey.CalibrateIndex";
   String CALIBRATE_COLOR_ACTION_MNEMONIC = "MnemonicKey.Calibrate";
   String VIDEO_SETTINGS_ACTION_NAME = "VideoSettingsAction.name";
   String VIDEO_SETTINGS_ACTION_MNEMONIC_INDEX = "MnemonicKey.VideoSettingsIndex";
   String VIDEO_SETTINGS_ACTION_MNEMONIC = "MnemonicKey.VideoSettings";
   String SCREENSHOT_ACTION_NAME = "CaptureScreenshot.name";
   String SCREENSHOT_ACTION_MNEMONIC_INDEX = "MnemonicKey.CaptureScreenshotIndex";
   String SCREENSHOT_ACTION_MNEMONIC = "MnemonicKey.CaptureScreenshot";
   String SCALE_VIDEO_ACTION_NAME = "ScaleVideoAction.name";
   String MOUSE_MENU_NAME = "MouseMenu.name";
   String SYNCHRONIZE_MOUSE_ACTION_NAME = "SynchronizeMouseAction.name";
   String SYNCHRONIZE_MOUSE_ACTION_MNEMONIC_INDEX = "MnemonicKey.SynchronizeMouseIndex";
   String SYNCHRONIZE_MOUSE_ACTION_MNEMONIC = "MnemonicKey.SynchronizeMouse";
   String SINGLE_MOUSE_CURSOR_ACTION_NAME = "SingleMouseCursorAction.name";
   String SINGLE_MOUSE_CURSOR_ACTION_MNEMONIC_INDEX = "MnemonicKey.SingleMouseModeIndex";
   String SINGLE_MOUSE_CURSOR_ACTION_MNEMONIC = "MnemonicKey.SingleMouseMode";
   String ABSOLUTE_MOUSE_ACTION_NAME = "AbsoluteMouseAction.name";
   String INTELLIGENT_MOUSE_ACTION_NAME = "IntelligentMouseAction.name";
   String STANDARD_MOUSE_ACTION_NAME = "StandardMouseAction.name";
   String TOOLS_MENU_NAME = "ToolsMenu.name";
   String OPTIONS_ACTION_NAME = "OptionsAction.name";
   String OPTIONS_ACTION_MNEMONIC_INDEX = "MnemonicKey.OptionIndex";
   String OPTIONS_ACTION_MNEMONIC = "MnemonicKey.Option";
   String VM_ACTION_NAME = "VirtualMedia.name";
   String VM_CONNECT_LOCAL_NAME = "VirtualMediaLocalConnect.name";
   String VM_CONNECT_IMAGE_NAME = "VirtualMediaImageConnect.name";
   String VIRTUAL_MEDIA_IMAGE_ACTION_MNEMONIC_INDEX = "MnemonicKey.VirtualMediaImageConnectIndex";
   String VIRTUAL_MEDIA_IMAGE_ACTION_MNEMONIC = "MnemonicKey.VirtualMediaImageConnect";
   String VIRTUAL_MEDIA_LOCAL_ACTION_MNEMONIC_INDEX = "MnemonicKey.VirtualMediaLocalConnectIndex";
   String VIRTUAL_MEDIA_LOCAL_ACTION_MNEMONIC = "MnemonicKey.VirtualMediaLocalConnect";
   String SMARTCARD_ACTION_NAME = "SmartCard.name";
   String SMARTCARD_SELECT_CARDREADER_NAME = "SmartCardSelectCardReader.name";
   String SMARTCARD_SELECT_CARDREADER_MNEMONIC = "MnemonicKey.SmartCardSelectCardReader";
   String SMARTCARD_SELECT_CARDREADER_MNEMONIC_INDEX = "MnemonicKey.SmartCardSelectCardReaderIndex";
   String SHORTCUT_KEYS_NAME = "ShortcutKeys.name";
   String RESTART_DEVICE_ACTION_NAME = "RestartDeviceAction.name";
   String RESTART_DEVICE_ACTION_MNEMONIC_INDEX = "MnemonicKey.RestartIndex";
   String RESTART_DEVICE_ACTION_MNEMONIC = "MnemonicKey.Restart";
   String SAVE_USER_CONFIGURATION_ACTION_NAME = "SaveUserConfigurationAction.name";
   String SAVE_USER_CONFIGURATION_ACTION_MNEMONIC_INDEX = "MnemonicKey.SaveUserConfigIndex";
   String SAVE_USER_CONFIGURATION_ACTION_MNEMONIC = "MnemonicKey.SaveUserConfig";
   String SAVE_DEVICE_CONFIGURATION_ACTION_NAME = "SaveDeviceConfigurationAction.name";
   String SAVE_DEVICE_CONFIGURATION_ACTION_MNEMONIC_INDEX = "MnemonicKey.SaveDevConfigIndex";
   String SAVE_DEVICE_CONFIGURATION_ACTION_MNEMONIC = "MnemonicKey.SaveDevConfig";
   String SAVE_TOTAL_CONFIGURATION_ACTION_NAME = "SaveTotalConfigurationAction.name";
   String SAVE_TOTAL_CONFIGURATION_ACTION_MNEMONIC_INDEX = "MnemonicKey.SaveTotalConfigIndex";
   String SAVE_TOTAL_CONFIGURATION_ACTION_MNEMONIC = "MnemonicKey.SaveTotalConfig";
   String RESTORE_DEVICE_CONFIGURATION_ACTION_NAME = "RestoreDeviceConfigurationAction.name";
   String RESTORE_DEVICE_CONFIGURATION_ACTION_MNEMONIC_INDEX = "MnemonicKey.RestoreIndex";
   String RESTORE_DEVICE_CONFIGURATION_ACTION_MNEMONIC = "MnemonicKey.Restore";
   String SAVE_ACTIVITY_LOG_ACTION_NAME = "SaveActivityLogAction.name";
   String SAVE_ACTIVITY_LOG_ACTION_MNEMONIC_INDEX = "MnemonicKey.SaveActivityLogIndex";
   String SAVE_ACTIVITY_LOG_ACTION_MNEMONIC = "MnemonicKey.SaveActivityLog";
   String SAVE_DIAGNOSTIC_LOG_ACTION_NAME = "SaveDiagnosticLogAction.name";
   String SAVE_DIAGNOSTIC_LOG_ACTION_MNEMONIC_INDEX = "MnemonicKey.SaveDiagnosticLogIndex";
   String SAVE_DIAGNOSTIC_LOG_ACTION_MNEMONIC = "MnemonicKey.SaveDiagnosticLog";
   String UPDATE_ACTION_NAME = "UpdateAction.name";
   String CHANGE_PASSWORD_ACTION_NAME = "ChangePassword.name";
   String CHANGE_PASSWORD_ACTION_MNEMONIC_INDEX = "MnemonicKey.UserPasswordIndex";
   String CHANGE_PASSWORD_ACTION_MNEMONIC = "MnemonicKey.UserPassword";
   String UPDATE_DEVICE_ACTION_NAME = "UpdateDeviceAction.name";
   String UPDATE_DEVICE_ACTION_MNEMONIC_INDEX = "MnemonicKey.UpdateDeviceIndex";
   String UPDATE_DEVICE_ACTION_MNEMONIC = "MnemonicKey.UpdateDevice";
   String UPDATE_LDAP_ACTION_NAME = "UpdateLdapAction.name";
   String UPDATE_LDAP_CERTIFICATE_ACTION_NAME = "UpdateLdapCertificateAction.name";
   String UPDATE_LDAP_KEY_ACTION_NAME = "UpdateLdapKeyAction.name";
   String POWER_ON_ACTION_NAME = "PowerOnAction.name";
   String POWER_ON_ACTION_MNEMONIC = "MnemonicKey.PowerOn";
   String POWER_ON_ACTION_MNEMONIC_INDEX = "MnemonicKey.PowerOnIndex";
   String POWER_OFF_ACTION_NAME = "PowerOffAction.name";
   String POWER_OFF_ACTION_MNEMONIC_INDEX = "MnemonicKey.PowerOffIndex";
   String POWER_OFF_ACTION_MNEMONIC = "MnemonicKey.PowerOff";
   String CYCLE_POWER_ACTION_NAME = "CyclePowerAction.name";
   String CYCLE_POWER_ACTION_MNEMONIC_INDEX = "MnemonicKey.CycleIndex";
   String CYCLE_POWER_ACTION_MNEMONIC = "MnemonicKey.Cycle";
   String VIEW_MENU_NAME = "ViewMenu.name";
   String TOOLBAR_ACTION_NAME = "ToolbarAction.name";
   String TOOLBAR_ACTION_MNEMONIC_INDEX = "MnemonicKey.ToolbarIndex";
   String TOOLBAR_ACTION_MNEMONIC = "MnemonicKey.Toolbar";
   String CS_TOOLBAR_ACTION_NAME = "ConnectedServerToolbarAction.name";
   String CS_TOOLBAR_ACTION_MNEMONIC_INDEX = "MnemonicKey.CSToolbarIndex";
   String CS_TOOLBAR_ACTION_MNEMONIC = "MnemonicKey.CSToolbar";
   String STATUSBAR_ACTION_NAME = "StatusbarAction.name";
   String STATUSBAR_ACTION_MNEMONIC_INDEX = "MnemonicKey.StatusbarIndex";
   String STATUSBAR_ACTION_MNEMONIC = "MnemonicKey.Statusbar";
   String NAVIGATOR_ACTION_NAME = "NavigatorAction.name";
   String NAVIGATOR_ACTION_MNEMONIC_INDEX = "MnemonicKey.NavigatorIndex";
   String NAVIGATOR_ACTION_MNEMONIC = "MnemonicKey.Navigator";
   String MESSAGE_ACTION_NAME = "MessageAction.name";
   String MESSAGE_ACTION_MNEMONIC_INDEX = "MnemonicKey.MessageIndex";
   String MESSAGE_ACTION_MNEMONIC = "MnemonicKey.Message";
   String ALL_DEVICES_ACTION_NAME = "AllDevicesAction.name";
   String ALL_DEVICES_ACTION_MNEMONIC_INDEX = "MnemonicKey.AllDeviceIndex";
   String ALL_DEVICES_ACTION_MNEMONIC = "MnemonicKey.AllDevice";
   String FULL_SCREEN_ACTION_NAME = "FullScreenAction.name";
   String TARGET_SCREEN_RESOLUTION_ACTION_NAME = "TargetScreenResolutionAction.name";
   String TARGET_SCREEN_RESOLUTION_ACTION_MNEMONIC_INDEX = "MnemonicKey.TargetFullScreenIndex";
   String TARGET_SCREEN_RESOLUTION_ACTION_MNEMONIC = "MnemonicKey.TargetFullScreen";
   String SHOW_ACTION_NAME = "ShowAction.name";
   String SHOW_ALL_ACTION_NAME = "ShowAllAction.name";
   String SHOW_ALL_ACTION_MNEMONIC_INDEX = "MnemonicKey.ShowALLIndex";
   String SHOW_ALL_ACTION_MNEMONIC = "MnemonicKey.ShowAll";
   String SHOW_WITHOUT_TARGETS_ACTION_NAME = "ShowWithoutTargetsAction.name";
   String SHOW_WITHOUT_TARGETS_ACTION_MNEMONIC_INDEX = "MnemonicKey.ShowWithoutTargetsIndex";
   String SHOW_WITHOUT_TARGETS_ACTION_MNEMONIC = "MnemonicKey.ShowWithoutTargets";
   String SHOW_GROUPS_ACTION_NAME = "ShowGroupsAction.name";
   String SHOW_POWERSTRIPS_ACTION_NAME = "ShowPowerstripsAction.name";
   String SHOW_POWERSTRIPS_ACTION_MNEMONIC_INDEX = "MnemonicKey.ShowPowerstripsIndex";
   String SHOW_POWERSTRIPS_ACTION_MNEMONIC = "MnemonicKey.ShowPowerstrips";
   String SHOW_TOOLS_ACTION_NAME = "ShowToolsAction.name";
   String SORT_ACTION_NAME = "SortAction.name";
   String SORT_BY_CHANNEL_NUMBER_ACTION_NAME = "SortByChannelNumberAction.name";
   String SORT_BY_CHANNEL_NAME_ACTION_NAME = "SortByChannelNameAction.name";
   String SORT_BY_CHANNEL_STATUS_ACTION_NAME = "SortByChannelStatusAction.name";
   String WINDOW_MENU_NAME = "WindowMenu.name";
   String CASCADE_ACTION_NAME = "CascadeAction.name";
   String CASCADE_ACTION_MNEMONIC_INDEX = "MnemonicKey.CascadeIndex";
   String CASCADE_ACTION_MNEMONIC = "MnemonicKey.Cascade";
   String TILE_ACTION_NAME = "TileAction.name";
   String TILE_ACTION_MNEMONIC_INDEX = "MnemonicKey.TileIndex";
   String TILE_ACTION_MNEMONIC = "MnemonicKey.Tile";
   String HELP_MENU_NAME = "HelpMenu.name";
   String ABOUT_ACTION_NAME = "AboutAction.name";
   String ABOUT_ACTION_MNEMONIC_INDEX = "MnemonicKey.AboutIndex";
   String ABOUT_ACTION_MNEMONIC = "MnemonicKey.About";
   String USBPROFILE_ACTION_NAME = "USBProfile.name";
   String USBPROFILE_OTHERPROFILES_NAME = "USBOtherProfile.name";
   String USBPROFILE_HELP_NAME = "USBProfileHelp.name";
   private static final long serialVersionUID = 7955263841109965203L;
   protected RRCScreenContext scrContext;
   protected RaritanPropertyResourceBundle bundle;
   private CommandMenu menu;
   private CommandMenu submenu;
   private CommandMenu submenu2;
   private CommandMenuItem menuItem;
   private CommandMenu windowMenu;
   private CommandMenuItem exitMenu;
   private CommandMenu virtualMediaMenu;
   private CommandMenuItem virtualMediaLocalMenuItem;
   private CommandMenuItem virtualMediaImageMenuItem;
   private CommandMenu audioMenu;
   private CommandMenuItem connectAudioMenuItem;
   private CommandMenuItem audioSettingsItem;
   private CommandMenu keyboardMenu;
   private CommandMenu smartCardMenu;
   private CommandMenuItem selectCardReaderMenuItem;
   private CommandCheckMenuItem menuItemTargetScreenResolution;
   private CommandMenuItem menuItemSingleMouseMode;
   private CommandRadioMenuItem radioMenuItemAbsoluteMouse;
   private CommandRadioMenuItem radioMenuItemIntelligentMouse;
   private CommandRadioMenuItem radioMenuItemStandardMouse;
   private CommandCheckMenuItem checkMenuItemToolbar;
   private CommandCheckMenuItem checkMenuItemCSToolbar;
   private CommandCheckMenuItem checkMenuItemStatusBar;
   private CommandCheckMenuItem checkMenuItemNavigator;
   private CommandCheckMenuItem checkMenuItemMessage;
   private CommandCheckMenuItem checkMenuItemScaleVideo;
   private CommandCheckMenuItem checkShowAllMenuItem;
   private CommandCheckMenuItem checkMenuItemShowWithoutTargets;
   private CommandCheckMenuItem checkMenuItemGroups;
   private CommandCheckMenuItem checkMenuItemShowPowerstrips;
   private CommandCheckMenuItem checkMenuItemShowTools;
   private CommandCheckMenuItem checkMenuItemSortByChannelNumber;
   private CommandCheckMenuItem checkMenuItemSortByChannelName;
   private CommandCheckMenuItem checkMenuItemSortByChannelStatus;
   private ButtonGroup sortButtonGroup;
   private ButtonGroup mouseButtonGroup;
   private CommandMenuItem menuItemUSBProfileHelp;
   private Component focusComponent = null;

   public RRCMenuBar(RRCScreenContext var1, boolean var2) {
      this.scrContext = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      JPopupMenu.setDefaultLightWeightPopupEnabled(true);
      this.menu = new CommandMenu(this.bundle.getString(this.CONNECTION_MENU_NAME), this.scrContext);
      this.menu.setOpaque(false);
      this.add(this.menu);
      if (var2) {
         this.menu.setEnabled(false);
      }

      this.menuItem = new CommandMenuItem(this.bundle.getString(this.NEW_PROFILE_ACTION_NAME), this.scrContext);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.NEW_PROFILE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.NEW_PROFILE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowNewProfileCommand(this.scrContext));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.PROPERTIES_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new ShowPropertiesCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.PROPERTIES_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.PROPERTIES_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.CONNECTION_INFO_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new ShowConnectionInfoCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.CONNECTION_INFO_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.CONNECTION_INFO_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.exitMenu = new CommandMenuItem(this.bundle.getString(this.EXIT_ACTION_NAME), this.scrContext);
      this.exitMenu.addActionListener(this);
      if (this.scrContext.getApplication() instanceof JApplet) {
         this.exitMenu.setCommand(new CloseAppletCommand(this.scrContext));
      } else {
         this.exitMenu.setCommand(new ExitSystemCommand(this.scrContext));
      }

      this.exitMenu.setConfirmation(true);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.exitMenu.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.EXIT_ACTION_MNEMONIC_INDEX)));
      }

      this.exitMenu.setMnemonic(new Character(this.bundle.getString(this.EXIT_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.exitMenu);
      this.menu = new CommandMenu(this.bundle.getString(this.USBPROFILE_ACTION_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      } else {
         this.menu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.menu.addObservable(this.scrContext.getOpenPortsObservable());
         this.menu.setCommand(new USBProfileCommand(this.scrContext));
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.menuItemUSBProfileHelp = new CommandMenuItem(this.bundle.getString(this.USBPROFILE_HELP_NAME), this.scrContext);
      this.menuItemUSBProfileHelp.setCommand(new HelpDisplayCommand(this.scrContext));
      this.menuItemUSBProfileHelp.addActionListener(this);
      JPopupMenu var3 = this.menu.getPopupMenu();
      final CommandMenu var4 = this.menu;
      final JMenu var5 = new JMenu(this.bundle.getString(this.USBPROFILE_OTHERPROFILES_NAME));
      var3.addPopupMenuListener(new PopupMenuListener() {
         @Override
         public void popupMenuCanceled(PopupMenuEvent var1) {
         }

         @Override
         public void popupMenuWillBecomeInvisible(PopupMenuEvent var1) {
         }

         @Override
         public void popupMenuWillBecomeVisible(PopupMenuEvent var1) {
            var4.removeAll();
            var5.removeAll();
            ArrayList var2x = (ArrayList)RRCMenuBar.this.scrContext.getSelectedDevicesObservable().getComponent();

            assert var2x != null;

            assert var2x.size() > 0;

            assert var2x.get(0) instanceof KvmPort;

            KvmPort var3x = (KvmPort)var2x.get(0);
            USBProfilesInfo var4x = var3x.getUsbProfilesInfo();

            assert var4x != null;

            List var5x = var4x.getUSBProfiles();
            DoChangeActiveUSBProfileCommand var6 = new DoChangeActiveUSBProfileCommand(RRCMenuBar.this.scrContext);
            USBProfile var7 = var4x.getActiveUSBProfile();

            assert var7 != null;

            for (USBProfile var9 : var5x) {
               CommandRadioMenuItem var10 = new CommandRadioMenuItem(var9.getProfileName(), RRCMenuBar.this.scrContext);
               var10.setCommand(var6);
               var10.putClientProperty("SelectedUSBProfile", var9);
               var10.setActionCommand("SelectedUSBProfile");
               var10.addActionListener(RRCMenuBar.this);
               if (var7.equals(var9)) {
                  var10.setSelected(true);
                  var4.add(var10, 0);
               } else if (var9.isProbable()) {
                  var4.add(var10);
               } else {
                  var5.add((JMenuItem)var10);
               }
            }

            var4.add(var5);
            var5.setEnabled(var5.getMenuComponentCount() > 0);
            var4.addSeparator();
            var4.add(RRCMenuBar.this.menuItemUSBProfileHelp);
         }
      });
      this.menu = new CommandMenu(this.bundle.getString(this.SERIAL_MENU_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      } else {
         this.menu.addActionListener(this);
         this.menu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.menu.addObservable(this.scrContext.getOpenPortsObservable());
         this.menu.setCommand(new SerialPortDummyCommand(this.scrContext));
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SETTINGS_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowSerialSettingsCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SETTINGS_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SETTINGS_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.HISTORY_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowHistoryCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.HISTORY_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.HISTORY_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.COPY_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoCopyCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.COPY_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.COPY_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.PASTE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoPasteCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.PASTE_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.PASTE_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SELECT_ALL_TEXT_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoSelectAllTextCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SELECT_ALL_TEXT_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SELECT_ALL_TEXT_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.START_LOGGING_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowStartLoggingCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.START_LOGGING_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.START_LOGGING_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.STOP_LOGGING_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoStopLoggingCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.STOP_LOGGING_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.STOP_LOGGING_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menu = new CommandMenu(this.bundle.getString(this.KEYBOARD_MENU_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      } else {
         this.menu.addActionListener(this);
         this.menu.addMenuListener(this);
         this.menu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.menu.addObservable(this.scrContext.getOpenPortsObservable());
         this.menu.setCommand(new PopulateKeyboardMenuCommand(this.scrContext));
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SEND_CTRL_ALT_DELETE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoSendCtrlAltDelCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SEND_CTRL_ALT_DELETE_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SEND_CTRL_ALT_DELETE_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SEND_ALT_TAB_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoSendAltTabCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SEND_ALT_TAB_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SEND_ALT_TAB_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SEND_CTRL_NUMLOCK_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoSendCtrlNumlockCommand(this.scrContext));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SEND_CTRL_NUMLOCK_ACTION_MNEMONIC).toCharArray()[0]));
      this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SEND_CTRL_NUMLOCK_ACTION_MNENONIC_INDEX)));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.ENTER_ONSCREEN_MENU_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoEnterOnscreenMenuCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.ENTER_ONSCREEN_MENU_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.ENTER_ONSCREEN_MENU_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.EXIT_ONSCREEN_MENU_ACTION_NAME), this.scrContext);
      this.menuItem.setAccelerator(KeyStroke.getKeyStroke(27, 0));
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoExitOnscreenMenuCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.EXIT_ONSCREEN_MENU_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.EXIT_ONSCREEN_MENU_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SEND_TEXT_TO_TARGET_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowSendTextToTargetCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SEND_TEXT_TO_TARGET_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SEND_TEXT_TO_TARGET_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.EXPORT_KEYBOARD_MACROS_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowExportMacrosCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.EXPORT_KEYBOARD_MACROS_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.EXPORT_KEYBOARD_MACROS_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.IMPORT_KEYBOARD_MACROS_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowImportMacrosCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.IMPORT_KEYBOARD_MACROS_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.IMPORT_KEYBOARD_MACROS_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.KEYBOARD_MACROS_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new ShowKeyboardMacrosCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.KEYBOARD_MACROS_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.KEYBOARD_MACROS_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      String[] var6 = KeyboardMacrosPreferences.returnNodes();
      this.menuItem = null;
      KeyboardMacrosPreferences var7 = null;
      int var8 = 0;

      for (int var9 = 0; var9 < var6.length; var9++) {
         this.menuItem = new CommandMenuItem(var6[var9], this.scrContext);
         var7 = new KeyboardMacrosPreferences();
         var7.importPreferences(var6[var9]);
         var8 = var7.getHotKeyCombination();
         if (var8 > -1) {
            this.menuItem.setAccelerator(KeyStroke.getKeyStroke(var8 + 48, 10));
         }

         this.menuItem.setCommand(new DoRunKeyboardMacroCommand(this.scrContext));
         this.menuItem.addActionListener(this);
         this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.menu.add(this.menuItem);
      }

      this.keyboardMenu = this.menu;
      this.scrContext.getMainScreenMediator().addKeyboardMenu(this.keyboardMenu);
      this.menu = new CommandMenu(this.bundle.getString(this.VIDEO_MENU_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      } else {
         this.menu.addActionListener(this);
         this.menu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.menu.addObservable(this.scrContext.getOpenPortsObservable());
         this.menu.setCommand(new KVMPortDummyCommand(this.scrContext));
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.REFRESH_SCREEN_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoRefreshScreenCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.REFRESH_SCREEN_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.REFRESH_SCREEN_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.AUTO_SENSE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoAutoSenseCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.AUTO_SENSE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.AUTO_SENSE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.CALIBRATE_COLOR_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoCalibrateColorCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.CALIBRATE_COLOR_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.CALIBRATE_COLOR_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.VIDEO_SETTINGS_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new ShowVideoSettingsCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.VIDEO_SETTINGS_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.VIDEO_SETTINGS_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SCREENSHOT_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoCaptureTargetScreenshotCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SCREENSHOT_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SCREENSHOT_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu = new CommandMenu(this.bundle.getString(this.MOUSE_MENU_NAME), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            MouseMenuCommand var3x = (MouseMenuCommand)this.getCommand();
            this.setToolTipText(var3x.getToolTip());
         }
      };
      if (var2) {
         this.menu.setEnabled(false);
      } else {
         this.menu.addMenuListener(this);
         this.menu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.menu.addObservable(this.scrContext.getOpenPortsObservable());
         this.menu.setCommand(new MouseMenuCommand(this.scrContext));
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SYNCHRONIZE_MOUSE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new DoSynchronizeMouseCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SYNCHRONIZE_MOUSE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SYNCHRONIZE_MOUSE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItemSingleMouseMode = new CommandMenuItem(this.bundle.getString(this.SINGLE_MOUSE_CURSOR_ACTION_NAME), this.scrContext);
      this.menuItemSingleMouseMode.addActionListener(this);
      this.menuItemSingleMouseMode.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItemSingleMouseMode.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItemSingleMouseMode.setCommand(new ShowSingleCursorInstructionCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItemSingleMouseMode.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SINGLE_MOUSE_CURSOR_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItemSingleMouseMode.setMnemonic(new Character(this.bundle.getString(this.SINGLE_MOUSE_CURSOR_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItemSingleMouseMode);
      this.menu.addSeparator();
      this.mouseButtonGroup = new ButtonGroup();
      this.radioMenuItemAbsoluteMouse = new CommandRadioMenuItem(this.bundle.getString(this.ABSOLUTE_MOUSE_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addRadioAbsoluteMouseMenuItem(this.radioMenuItemAbsoluteMouse);
      this.radioMenuItemAbsoluteMouse.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.radioMenuItemAbsoluteMouse.addObservable(this.scrContext.getOpenPortsObservable());
      this.radioMenuItemAbsoluteMouse.setCommand(new DoAbsoluteMouseCommand(this.scrContext));
      this.radioMenuItemAbsoluteMouse.addActionListener(this);
      this.mouseButtonGroup.add(this.radioMenuItemAbsoluteMouse);
      this.menu.add(this.radioMenuItemAbsoluteMouse);
      this.radioMenuItemIntelligentMouse = new CommandRadioMenuItem(this.bundle.getString(this.INTELLIGENT_MOUSE_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addRadioIntelligentMouseMenuItem(this.radioMenuItemIntelligentMouse);
      this.radioMenuItemIntelligentMouse.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.radioMenuItemIntelligentMouse.addObservable(this.scrContext.getOpenPortsObservable());
      this.radioMenuItemIntelligentMouse.setCommand(new DoIntelligentMouseCommand(this.scrContext));
      this.radioMenuItemIntelligentMouse.addActionListener(this);
      this.mouseButtonGroup.add(this.radioMenuItemIntelligentMouse);
      this.menu.add(this.radioMenuItemIntelligentMouse);
      this.radioMenuItemStandardMouse = new CommandRadioMenuItem(this.bundle.getString(this.STANDARD_MOUSE_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addRadioStandardMouseMenuItem(this.radioMenuItemStandardMouse);
      this.radioMenuItemStandardMouse.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.radioMenuItemStandardMouse.addObservable(this.scrContext.getOpenPortsObservable());
      this.radioMenuItemStandardMouse.setCommand(new DoStandardMouseCommand(this.scrContext));
      this.radioMenuItemStandardMouse.addActionListener(this);
      this.mouseButtonGroup.add(this.radioMenuItemStandardMouse);
      this.menu.add(this.radioMenuItemStandardMouse);
      this.virtualMediaMenu = new CommandMenu(this.bundle.getString(this.VM_ACTION_NAME), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((VirtualMediaMenuCommand)this.getCommand()).getToolTip());
         }
      };
      if (var2) {
         this.virtualMediaMenu.setEnabled(false);
      } else {
         this.virtualMediaMenu.addMenuListener(this);
         this.virtualMediaMenu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.virtualMediaMenu.addObservable(this.scrContext.getOpenPortsObservable());
         this.virtualMediaMenu.setCommand(new VirtualMediaMenuCommand(this.scrContext));
      }

      this.virtualMediaMenu.setOpaque(false);
      this.add(this.virtualMediaMenu);
      this.scrContext.getMainScreenMediator().addVirtualMediaMenu(this.virtualMediaMenu);
      this.virtualMediaLocalMenuItem = new CommandMenuItem(this.bundle.getString(this.VM_CONNECT_LOCAL_NAME), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((ShowVirtualMediaLocalPanelCommand)this.getCommand()).getToolTip());
         }
      };
      this.virtualMediaLocalMenuItem.addActionListener(this);
      this.virtualMediaLocalMenuItem.setCommand(new ShowVirtualMediaLocalPanelCommand(this.scrContext));
      this.virtualMediaLocalMenuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.virtualMediaLocalMenuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.VIRTUAL_MEDIA_LOCAL_ACTION_MNEMONIC_INDEX)));
      }

      this.virtualMediaLocalMenuItem
         .setMnemonic(KeyboardUtil.getKeyCode(new Character(this.bundle.getString(this.VIRTUAL_MEDIA_LOCAL_ACTION_MNEMONIC).toCharArray()[0])));
      this.virtualMediaMenu.add(this.virtualMediaLocalMenuItem);
      if (!Platform.isVirtualMediaSupported()) {
         this.virtualMediaMenu.setEnabled(false);
      }

      this.virtualMediaImageMenuItem = new CommandMenuItem(this.bundle.getString(this.VM_CONNECT_IMAGE_NAME), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((ShowVirtualMediaImagePanelCommand)this.getCommand()).getToolTip());
         }
      };
      this.virtualMediaImageMenuItem.addActionListener(this);
      this.virtualMediaImageMenuItem.setCommand(new ShowVirtualMediaImagePanelCommand(this.scrContext));
      this.virtualMediaImageMenuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.virtualMediaImageMenuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.VIRTUAL_MEDIA_IMAGE_ACTION_MNEMONIC_INDEX)));
      }

      this.virtualMediaImageMenuItem
         .setMnemonic(KeyboardUtil.getKeyCode(new Character(this.bundle.getString(this.VIRTUAL_MEDIA_IMAGE_ACTION_MNEMONIC).toCharArray()[0])));
      this.virtualMediaMenu.add(this.virtualMediaImageMenuItem);
      this.menu = new CommandMenu(this.bundle.getString(this.TOOLS_MENU_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.audioMenu = new CommandMenu(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_NAME), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((AudioMenuCommand)this.getCommand()).getToolTip());
         }
      };
      if (var2) {
         this.audioMenu.setEnabled(false);
      } else {
         this.audioMenu.addMenuListener(this);
         this.audioMenu.setCommand(new AudioMenuCommand(this.scrContext));
         this.audioMenu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.audioMenu.addObservable(this.scrContext.getOpenPortsObservable());
         this.audioMenu.addObservable(this.scrContext.getAudioObserver());
      }

      this.audioMenu.setOpaque(false);
      this.add(this.audioMenu);
      this.connectAudioMenuItem = new CommandMenuItem(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            ConnectAudioCommand var3x = (ConnectAudioCommand)this.getCommand();
            if (var3x.isExecutable()) {
               this.setToolTipText(
                  var3x.isConnected()
                     ? RRCMenuBar.this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_DISCONNECT)
                     : RRCMenuBar.this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT)
               );
            } else {
               this.setToolTipText(((ConnectAudioCommand)this.getCommand()).getToolTip());
            }

            this.setText(
               var3x.isConnected()
                  ? RRCMenuBar.this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_DISCONNECT)
                  : RRCMenuBar.this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT)
            );
         }
      };
      this.connectAudioMenuItem.addActionListener(this);
      this.connectAudioMenuItem.setCommand(new ConnectAudioCommand(this.scrContext));
      this.connectAudioMenuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.connectAudioMenuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.connectAudioMenuItem.addObservable(this.scrContext.getAudioObserver());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.connectAudioMenuItem
            .setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT_AUDIO_MNEMONIC_INDEX)));
      }

      this.connectAudioMenuItem
         .setMnemonic(
            KeyboardUtil.getKeyCode(new Character(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT_AUDIO_MNEMONIC).toCharArray()[0]))
         );
      this.audioMenu.add(this.connectAudioMenuItem);
      this.audioSettingsItem = new CommandMenuItem(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_SETTINGS), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            ConnectAudioCommand var3x = (ConnectAudioCommand)RRCMenuBar.this.connectAudioMenuItem.getCommand();
            this.setEnabled(var3x.isExecutable() && ((ConnectAudioCommand)RRCMenuBar.this.connectAudioMenuItem.getCommand()).isConnected());
         }
      };
      this.audioSettingsItem.addActionListener(this);
      this.audioSettingsItem.setCommand(new AudioSettingsCommand(this.scrContext));
      this.audioSettingsItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.audioSettingsItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.audioSettingsItem.addObservable(this.scrContext.getAudioObserver());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.audioSettingsItem
            .setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_SETTINGS_MNEMONIC_INDEX)));
      }

      this.audioSettingsItem
         .setMnemonic(KeyboardUtil.getKeyCode(new Character(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_SETTINGS_MNEMONIC).toCharArray()[0])));
      this.audioMenu.add(this.audioSettingsItem);
      this.smartCardMenu = new CommandMenu(this.bundle.getString(this.SMARTCARD_ACTION_NAME), this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((SmartCardMenuCommand)this.getCommand()).getToolTip());
         }
      };
      if (var2) {
         this.smartCardMenu.setEnabled(false);
      } else {
         this.smartCardMenu.addMenuListener(this);
         this.smartCardMenu.setCommand(new SmartCardMenuCommand(this.scrContext));
         this.smartCardMenu.addObservable(this.scrContext.getSelectedDevicesObservable());
         this.smartCardMenu.addObservable(this.scrContext.getOpenPortsObservable());
         this.smartCardMenu.addObservable(this.scrContext.getSmartCardObserver());
      }

      this.smartCardMenu.setOpaque(false);
      this.add(this.smartCardMenu);
      this.selectCardReaderMenuItem = new CommandMenuItem(this.bundle.getString(this.SMARTCARD_SELECT_CARDREADER_NAME), this.scrContext);
      this.selectCardReaderMenuItem.addActionListener(this);
      this.selectCardReaderMenuItem.setCommand(new SelectCardReaderCommand(this.scrContext));
      this.selectCardReaderMenuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.selectCardReaderMenuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.selectCardReaderMenuItem.addObservable(this.scrContext.getSmartCardObserver());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.selectCardReaderMenuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SMARTCARD_SELECT_CARDREADER_MNEMONIC_INDEX)));
      }

      this.selectCardReaderMenuItem
         .setMnemonic(KeyboardUtil.getKeyCode(new Character(this.bundle.getString(this.SMARTCARD_SELECT_CARDREADER_MNEMONIC).toCharArray()[0])));
      this.smartCardMenu.add(this.selectCardReaderMenuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.OPTIONS_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowOptionsCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.OPTIONS_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.OPTIONS_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.RESTART_DEVICE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new DoRestartDeviceCommand(this.scrContext));
      this.menuItem.setConfirmation(true);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.RESTART_DEVICE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.RESTART_DEVICE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SAVE_USER_CONFIGURATION_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowSaveUserConfigurationCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SAVE_USER_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SAVE_USER_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SAVE_DEVICE_CONFIGURATION_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowSaveDeviceConfigurationCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SAVE_DEVICE_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SAVE_DEVICE_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SAVE_TOTAL_CONFIGURATION_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowSaveTotalConfigurationCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SAVE_TOTAL_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SAVE_TOTAL_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.RESTORE_DEVICE_CONFIGURATION_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowLoadConfigurationCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.RESTORE_DEVICE_CONFIGURATION_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.RESTORE_DEVICE_CONFIGURATION_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SAVE_ACTIVITY_LOG_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowSaveActivityLogCommand(var1));
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SAVE_ACTIVITY_LOG_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SAVE_ACTIVITY_LOG_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.SAVE_DIAGNOSTIC_LOG_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setCommand(new ShowSaveDiagnosticLogCommand(this.scrContext));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.SAVE_DIAGNOSTIC_LOG_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.SAVE_DIAGNOSTIC_LOG_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu.addSeparator();
      this.submenu = new CommandMenu(this.bundle.getString(this.UPDATE_ACTION_NAME), this.scrContext);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.CHANGE_PASSWORD_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowUserPasswordCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.CHANGE_PASSWORD_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.CHANGE_PASSWORD_ACTION_MNEMONIC).toCharArray()[0]));
      this.submenu.add(this.menuItem);
      this.submenu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.UPDATE_DEVICE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowUpdateDeviceCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.UPDATE_DEVICE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.UPDATE_DEVICE_ACTION_MNEMONIC).toCharArray()[0]));
      this.submenu.add(this.menuItem);
      this.submenu2 = new CommandMenu(this.bundle.getString(this.UPDATE_LDAP_ACTION_NAME), this.scrContext);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.UPDATE_LDAP_CERTIFICATE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowUpdateLDAPCertificateCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.submenu2.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.UPDATE_LDAP_KEY_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new ShowUpdateLDAPKeyCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.submenu2.add(this.menuItem);
      this.submenu.add(this.submenu2);
      this.menu.add(this.submenu);
      this.menu.addSeparator();
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.POWER_ON_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoPowerOnCommand(this.scrContext));
      this.menuItem.setConfirmation(true);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.POWER_ON_ACTION_MNEMONIC).toCharArray()[0]));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.POWER_ON_ACTION_MNEMONIC_INDEX)));
      }

      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.POWER_OFF_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoPowerOffCommand(this.scrContext));
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItem.setConfirmation(true);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.POWER_OFF_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.POWER_OFF_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.CYCLE_POWER_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.setCommand(new DoPowerCycleCommand(this.scrContext));
      this.menuItem.setConfirmation(true);
      this.menuItem.addObservable(this.scrContext.getSelectedDevicesObservable());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.CYCLE_POWER_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.CYCLE_POWER_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menu = new CommandMenu(this.bundle.getString(this.VIEW_MENU_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.checkMenuItemToolbar = new CommandCheckMenuItem(this.bundle.getString(this.TOOLBAR_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckToolbarMenuItem(this.checkMenuItemToolbar);
      this.checkMenuItemToolbar.setCommand(new ShowToolbarCommand(this.scrContext));
      this.checkMenuItemToolbar.addActionListener(this);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.checkMenuItemToolbar.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.TOOLBAR_ACTION_MNEMONIC_INDEX)));
      }

      this.checkMenuItemToolbar.setMnemonic(new Character(this.bundle.getString(this.TOOLBAR_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.checkMenuItemToolbar);
      this.checkMenuItemCSToolbar = new CommandCheckMenuItem(this.bundle.getString(this.CS_TOOLBAR_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckCSToolBarMenuItem(this.checkMenuItemCSToolbar);
      this.checkMenuItemCSToolbar.setCommand(new ShowCSToolbarCommand(this.scrContext));
      this.checkMenuItemCSToolbar.addActionListener(this);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.checkMenuItemCSToolbar.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.CS_TOOLBAR_ACTION_MNEMONIC_INDEX)));
      }

      this.checkMenuItemCSToolbar.setMnemonic(KeyboardUtil.getKeyCode(new Character(this.bundle.getString(this.CS_TOOLBAR_ACTION_MNEMONIC).toCharArray()[0])));
      this.menu.add(this.checkMenuItemCSToolbar);
      this.checkMenuItemStatusBar = new CommandCheckMenuItem(this.bundle.getString(this.STATUSBAR_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckStatusBarMenuItem(this.checkMenuItemStatusBar);
      this.checkMenuItemStatusBar.setCommand(new ShowStatusBarCommand(this.scrContext));
      this.checkMenuItemStatusBar.addActionListener(this);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.checkMenuItemStatusBar.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.STATUSBAR_ACTION_MNEMONIC_INDEX)));
      }

      this.checkMenuItemStatusBar.setMnemonic(new Character(this.bundle.getString(this.STATUSBAR_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.checkMenuItemStatusBar);
      this.menu.addSeparator();
      this.checkMenuItemNavigator = new CommandCheckMenuItem(this.bundle.getString(this.NAVIGATOR_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckNavigatorMenuItem(this.checkMenuItemNavigator);
      this.checkMenuItemNavigator.setCommand(new ShowNavigatorCommand(this.scrContext));
      this.checkMenuItemNavigator.addActionListener(this);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.checkMenuItemNavigator.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.NAVIGATOR_ACTION_MNEMONIC_INDEX)));
      }

      this.checkMenuItemNavigator.setMnemonic(new Character(this.bundle.getString(this.NAVIGATOR_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.checkMenuItemNavigator);
      this.checkMenuItemMessage = new CommandCheckMenuItem(this.bundle.getString(this.MESSAGE_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckMessageMenuItem(this.checkMenuItemMessage);
      this.checkMenuItemMessage.setCommand(new ShowMessageCommand(this.scrContext));
      this.checkMenuItemMessage.addActionListener(this);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.checkMenuItemMessage.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.MESSAGE_ACTION_MNEMONIC_INDEX)));
      }

      this.checkMenuItemMessage.setMnemonic(new Character(this.bundle.getString(this.MESSAGE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.checkMenuItemMessage);
      this.menu.addSeparator();
      this.submenu = new CommandMenu(this.bundle.getString(this.SHOW_ACTION_NAME), this.scrContext);
      this.checkShowAllMenuItem = new CommandCheckMenuItem(this.bundle.getString(this.SHOW_ALL_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckAllDevicesMenuItem(this.checkShowAllMenuItem);
      this.checkShowAllMenuItem.setCommand(new ShowAllDevicesCommand(this.scrContext));
      this.checkShowAllMenuItem.addActionListener(this);
      this.submenu.add(this.checkShowAllMenuItem);
      this.checkMenuItemShowWithoutTargets = new CommandCheckMenuItem(this.bundle.getString(this.SHOW_WITHOUT_TARGETS_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckShowWithoutTargetsMenuItem(this.checkMenuItemShowWithoutTargets);
      this.checkMenuItemShowWithoutTargets.setCommand(new ShowWithoutTargetsCommand(this.scrContext));
      this.checkMenuItemShowWithoutTargets.addActionListener(this);
      this.submenu.add(this.checkMenuItemShowWithoutTargets);
      this.checkMenuItemGroups = new CommandCheckMenuItem(this.bundle.getString(this.SHOW_GROUPS_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addGroupsMenuItem(this.checkMenuItemGroups);
      this.checkMenuItemGroups.setCommand(new ShowWithoutGroupsCommand(this.scrContext));
      this.checkMenuItemGroups.addActionListener(this);
      this.submenu.add(this.checkMenuItemGroups);
      this.checkMenuItemShowTools = new CommandCheckMenuItem(this.bundle.getString(this.SHOW_TOOLS_ACTION_NAME), this.scrContext);
      this.scrContext.getMainScreenMediator().addCheckShowToolsMenuItem(this.checkMenuItemShowTools);
      this.checkMenuItemShowTools.setCommand(new ShowToolsCommand(this.scrContext));
      this.checkMenuItemShowTools.addActionListener(this);
      this.submenu.add(this.checkMenuItemShowTools);
      this.menu.add(this.submenu);
      this.submenu = new CommandMenu(this.bundle.getString(this.SORT_ACTION_NAME), this.scrContext);
      this.sortButtonGroup = new ButtonGroup();
      this.checkMenuItemSortByChannelNumber = new CommandCheckMenuItem(this.bundle.getString(this.SORT_BY_CHANNEL_NUMBER_ACTION_NAME), false, this.scrContext);
      this.sortButtonGroup.add(this.checkMenuItemSortByChannelNumber);
      this.scrContext.getMainScreenMediator().addCheckSortByChannelNumberMenuItem(this.checkMenuItemSortByChannelNumber);
      DoSortByChannelCommand var14 = new DoSortByChannelCommand(this.scrContext);
      this.checkMenuItemSortByChannelNumber.setCommand(var14);
      this.checkMenuItemSortByChannelNumber.addActionListener(this);
      this.submenu.add(this.checkMenuItemSortByChannelNumber);
      this.checkMenuItemSortByChannelName = new CommandCheckMenuItem(this.bundle.getString(this.SORT_BY_CHANNEL_NAME_ACTION_NAME), true, this.scrContext);
      this.sortButtonGroup.add(this.checkMenuItemSortByChannelName);
      this.scrContext.getMainScreenMediator().addCheckSortByChannelNameMenuItem(this.checkMenuItemSortByChannelName);
      DoSortByChannelNameCommand var10 = new DoSortByChannelNameCommand(this.scrContext);
      this.checkMenuItemSortByChannelName.setCommand(var10);
      this.checkMenuItemSortByChannelName.addActionListener(this);
      this.submenu.add(this.checkMenuItemSortByChannelName);
      this.checkMenuItemSortByChannelStatus = new CommandCheckMenuItem(this.bundle.getString(this.SORT_BY_CHANNEL_STATUS_ACTION_NAME), false, this.scrContext);
      this.sortButtonGroup.add(this.checkMenuItemSortByChannelStatus);
      this.scrContext.getMainScreenMediator().addCheckSortByChannelStatusMenuItem(this.checkMenuItemSortByChannelStatus);
      DoSortByChannelStatusCommand var11 = new DoSortByChannelStatusCommand(this.scrContext);
      this.checkMenuItemSortByChannelStatus.setCommand(var11);
      this.checkMenuItemSortByChannelStatus.addActionListener(this);
      this.submenu.add(this.checkMenuItemSortByChannelStatus);
      this.menu.add(this.submenu);
      this.menu.addSeparator();
      this.menuItemTargetScreenResolution = new CommandCheckMenuItem(this.bundle.getString(this.TARGET_SCREEN_RESOLUTION_ACTION_NAME), this.scrContext);
      this.menuItemTargetScreenResolution.setCommand(new ShowTargetScreenResolutionCommand(this.scrContext));
      this.menuItemTargetScreenResolution.addActionListener(this);
      this.menuItemTargetScreenResolution.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.menuItemTargetScreenResolution.addObservable(this.scrContext.getOpenPortsObservable());
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItemTargetScreenResolution
            .setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.TARGET_SCREEN_RESOLUTION_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItemTargetScreenResolution.setMnemonic(new Character(this.bundle.getString(this.TARGET_SCREEN_RESOLUTION_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItemTargetScreenResolution);
      this.checkMenuItemScaleVideo = new CommandCheckMenuItem(this.bundle.getString(this.SCALE_VIDEO_ACTION_NAME), this.scrContext);
      this.checkMenuItemScaleVideo.addActionListener(this);
      this.checkMenuItemScaleVideo.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.checkMenuItemScaleVideo.addObservable(this.scrContext.getOpenPortsObservable());
      this.scrContext.getMainScreenMediator().addCheckScaleVideoMenuItem(this.checkMenuItemScaleVideo);
      this.checkMenuItemScaleVideo.setCommand(new ShowVideoScaleCommand(this.scrContext));
      this.menu.add(this.checkMenuItemScaleVideo);
      this.menu = new CommandMenu(this.bundle.getString(this.WINDOW_MENU_NAME), this.scrContext);
      this.menu.setOpaque(false);
      if (var2) {
         this.menu.setEnabled(false);
      } else {
         this.menu.addActionListener(this);
         this.menu.addObservable(this.scrContext.getOpenPortsObservable());
         this.menu.addMenuListener(this);
         this.menu.setCommand(new PopulateWindowMenuCommand(this.scrContext));
      }

      this.add(this.menu);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.CASCADE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new CascadeWindowsCommand(var1));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.CASCADE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.CASCADE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.TILE_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      this.menuItem.addObservable(this.scrContext.getOpenPortsObservable());
      this.menuItem.setCommand(new TileWindowsCommand(var1));
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.TILE_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.TILE_ACTION_MNEMONIC).toCharArray()[0]));
      this.menu.add(this.menuItem);
      this.windowMenu = this.menu;
      this.scrContext.getMainScreenMediator().addWindowMenu(this.windowMenu);
      this.menu = new CommandMenu(this.bundle.getString(this.HELP_MENU_NAME), this.scrContext);
      if (var2) {
         this.menu.setEnabled(false);
      }

      this.menu.setOpaque(false);
      this.add(this.menu);
      this.menuItem = new CommandMenuItem(this.bundle.getString(this.ABOUT_ACTION_NAME), this.scrContext);
      this.menuItem.addActionListener(this);
      if (this.scrContext.getLocale() == Locale.US || this.scrContext.getLocale() == Locale.UK) {
         this.menuItem.setDisplayedMnemonicIndex(Integer.parseInt(this.bundle.getString(this.ABOUT_ACTION_MNEMONIC_INDEX)));
      }

      this.menuItem.setMnemonic(new Character(this.bundle.getString(this.ABOUT_ACTION_MNEMONIC).toCharArray()[0]));
      this.menuItem.setCommand(new ShowAboutCommand(var1));
      this.menu.add(this.menuItem);
   }

   public void dispose() {
      this.scrContext.getMainScreenMediator().removeVirtualMediaMenu(this.virtualMediaMenu);
      this.scrContext.getMainScreenMediator().removeRadioAbsoluteMouseMenuItem(this.radioMenuItemAbsoluteMouse);
      this.scrContext.getMainScreenMediator().removeRadioIntelligentMouseMenuItem(this.radioMenuItemIntelligentMouse);
      this.scrContext.getMainScreenMediator().removeRadioStandardMouseMenuItem(this.radioMenuItemStandardMouse);
      this.scrContext.getMainScreenMediator().removeCheckAllDevicesMenuItem(this.checkShowAllMenuItem);
      this.scrContext.getMainScreenMediator().removeCheckToolbarMenuItem(this.checkMenuItemToolbar);
      this.scrContext.getMainScreenMediator().removeCheckCSToolBarMenuItem(this.checkMenuItemCSToolbar);
      this.scrContext.getMainScreenMediator().removeCheckStatusBarMenuItem(this.checkMenuItemStatusBar);
      this.scrContext.getMainScreenMediator().removeCheckNavigatorMenuItem(this.checkMenuItemNavigator);
      this.scrContext.getMainScreenMediator().removeCheckMessageMenuItem(this.checkMenuItemMessage);
      this.scrContext.getMainScreenMediator().removeCheckShowWithoutTargetsMenuItem(this.checkMenuItemShowWithoutTargets);
      this.scrContext.getMainScreenMediator().removeGroupsMenuItem(this.checkMenuItemGroups);
      this.scrContext.getMainScreenMediator().removeCheckShowToolsMenuItem(this.checkMenuItemShowTools);
      this.scrContext.getMainScreenMediator().removeCheckSortByChannelNumberMenuItem(this.checkMenuItemSortByChannelNumber);
      this.scrContext.getMainScreenMediator().removeCheckSortByChannelStatusMenuItem(this.checkMenuItemSortByChannelStatus);
      this.scrContext.getMainScreenMediator().removeCheckSortByChannelNameMenuItem(this.checkMenuItemSortByChannelName);
      this.scrContext.getMainScreenMediator().removeCheckScaleVideoMenuItem(this.checkMenuItemScaleVideo);
      this.scrContext.getMainScreenMediator().removeKeyboardMenu(this.keyboardMenu);
      this.scrContext.getMainScreenMediator().removeWindowMenu(this.windowMenu);
   }

   public JMenu getSunMacroJMenu(DeviceView var1, ScreenContext var2) {
      RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(var2.getLocale());
      JMenu var5 = new JMenu(var3.getString("SunMacroMenu.name"));
      CommandMenuItem var4 = new CommandMenuItem(var3.getString("SunKey.stop"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 117&&r 117"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.props"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 127&&r 127"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.front"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 128&&r 128"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.open"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 131&&r 131"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.find"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 123&&r 123"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.again"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 118&&r 118"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.undo"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 119&&r 119"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.copy"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 121&&r 121"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.paste"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 122&&r 122"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.cut"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 120&&r 120"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.help"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 129&&r 129"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.compose"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 130&&r 130"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.mute"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 124&&r 124"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.voldown"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 126&&r 126"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      var4 = new CommandMenuItem(var3.getString("SunKey.volup"), var2);
      var4.setCommand(new DoSendFixedMacroCommand(var2, "p 125&&r 125"));
      var4.addActionListener(this);
      var5.add((JMenuItem)var4);
      return var5;
   }

   protected String getClassName(Object var1) {
      String var2 = var1.getClass().getName();
      int var3 = var2.lastIndexOf(".");
      return var2.substring(var3 + 1);
   }

   public void actionPerformed(Object var1, String var2) {
      boolean var3 = false;
      if (var1 instanceof ConfirmableCommandInterface) {
         var3 = ((ConfirmableCommandInterface)var1).getConfirmation();
      }

      if (CommandUtil.isCommandHolder(var1)) {
         if (var3) {
            var3 = CommonPopups.showExitConfirmationDialog(this.scrContext.getApplication().getContentPane(), this.scrContext) != 2;
         }

         if (!var3) {
            boolean var4 = false;
            IApplicationPreferences var5 = this.scrContext.getAppSettings();
            boolean var6 = false;
            String var7 = null;
            if (var1 instanceof CommandCheckMenuItem) {
               if ((CommandCheckMenuItem)var1 == this.checkMenuItemToolbar) {
                  this.checkFullScreen();
                  var4 = this.checkMenuItemToolbar.isSelected();
                  var7 = "showToolbarMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemStatusBar) {
                  this.checkFullScreen();
                  var4 = this.checkMenuItemStatusBar.isSelected();
                  var7 = "showStatusBarMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemNavigator) {
                  this.checkFullScreen();
                  var4 = this.checkMenuItemNavigator.isSelected();
                  var7 = "showNavigatorMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemMessage) {
                  var4 = this.checkMenuItemMessage.isSelected();
                  var6 = true;
                  var5.setViewMessage(var4);
                  var7 = "showMessageMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkShowAllMenuItem) {
                  var4 = this.checkShowAllMenuItem.isSelected();
                  var7 = "showAllDevicesMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemShowWithoutTargets) {
                  var4 = this.checkMenuItemShowWithoutTargets.isSelected();
                  var6 = true;
                  var5.setShowUnassigned(var4);
                  var7 = "showWithoutTargetsMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemGroups) {
                  var4 = this.checkMenuItemGroups.isSelected();
                  var6 = true;
                  var5.setShowGroups(var4);
                  var7 = "showWithoutGroupsMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemShowPowerstrips) {
                  var4 = this.checkMenuItemShowPowerstrips.isSelected();
                  var7 = "showPowerstripsMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemShowTools) {
                  var4 = this.checkMenuItemShowTools.isSelected();
                  var6 = true;
                  var5.setShowTools(var4);
                  var7 = "showToolsMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemSortByChannelNumber) {
                  var4 = this.checkMenuItemSortByChannelNumber.isSelected();
                  var6 = true;
                  var5.setChannelSortMethod(0);
                  var7 = "sortByChannelNumberMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemSortByChannelName) {
                  var4 = this.checkMenuItemSortByChannelName.isSelected();
                  var6 = true;
                  var5.setChannelSortMethod(1);
                  var7 = "sortByChannelNameMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemSortByChannelStatus) {
                  var4 = this.checkMenuItemSortByChannelStatus.isSelected();
                  var6 = true;
                  var5.setChannelSortMethod(2);
                  var7 = "sortByChannelStatusMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemScaleVideo) {
                  var4 = this.checkMenuItemScaleVideo.isSelected();
                  var7 = "scaleVideoMode";
               } else if ((CommandCheckMenuItem)var1 == this.checkMenuItemCSToolbar) {
                  var4 = this.checkMenuItemCSToolbar.isSelected();
                  var6 = true;
                  var5.setShowCSTools(var4);
                  var7 = "showCSToolbarMode";
               } else if ((CommandCheckMenuItem)var1 == this.menuItemTargetScreenResolution) {
                  var4 = this.menuItemTargetScreenResolution.isSelected();
                  var7 = "targetScreenResolutionMode";
               } else {
                  CommandCheckMenuItem var8 = (CommandCheckMenuItem)var1;
                  var4 = var8.isSelected();
                  var7 = "selectedWindowItem";
               }

               if (var6) {
                  this.scrContext.getAppSettings().exportPreferences();
               }
            } else if (var1 instanceof CommandRadioMenuItem) {
               if ((CommandRadioMenuItem)var1 == this.radioMenuItemAbsoluteMouse) {
                  var4 = this.radioMenuItemAbsoluteMouse.isSelected();
                  var7 = "absoluteMouseMode";
               } else if ((CommandRadioMenuItem)var1 == this.radioMenuItemStandardMouse) {
                  var4 = this.radioMenuItemStandardMouse.isSelected();
                  var7 = "standardMouseMode";
               }

               if ((CommandRadioMenuItem)var1 == this.radioMenuItemIntelligentMouse) {
                  var4 = this.radioMenuItemIntelligentMouse.isSelected();
                  var7 = "intelligentMouseMode";
               }
            } else if (var1 instanceof CommandMenuItem && ((CommandMenuItem)var1).getCommand() instanceof DoRunKeyboardMacroCommand) {
               ((CommandMenuItem)var1).getCommand().getContext().setCommandParameter("keyboardMacroName", ((CommandMenuItem)var1).getText());
            }

            CommandHolder var10 = (CommandHolder)var1;
            if (var7 != null) {
               var10.getCommand().getContext(true).setCommandParameter(var7, new Boolean(var4));
            }

            if (var1 == this.virtualMediaLocalMenuItem || var1 == this.virtualMediaImageMenuItem) {
               var10.getCommand().getContext(true);
            }

            if ("SelectedUSBProfile".equals(var2)) {
               CommandRadioMenuItem var9 = (CommandRadioMenuItem)var1;
               var10.getCommand().getContext(true).setCommandParameter("SelectedUSBProfile", var9.getClientProperty("SelectedUSBProfile"));
            }

            if (var1 == this.menuItemUSBProfileHelp) {
               this.menuItemUSBProfileHelp.getCommand().getContext(true).setCommandParameter("HelpTopicIDToDisplay", "USB_PROFILES");
            }

            CommandResult var11 = var10.getCommand().execute();
            if (var11.isSuccess() && !var11.hasErrorDescription()) {
               this.handleCommandResult(var11);
               this.scrContext.getPanelMediator().showPanel(var10.getCommand().getContext());
            } else {
               this.handleCommandResultErrorDescription(var11);
            }

            if (!(var1 instanceof CommandMenu) && var1 != this.menuItemUSBProfileHelp) {
               this.scrContext.resetDefaultFocus();
            }
         }
      }
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      this.actionPerformed(var1.getSource(), var1.getActionCommand());
   }

   protected void handleCommandResult(CommandResult var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   protected void handleCommandResultErrorDescription(CommandResult var1) {
      if (var1 != null) {
         StringBuffer var2 = new StringBuffer("");
         if (var1.getErrorDescription() != null && var1.getErrorDescription().length > 0) {
            for (int var3 = 0; var3 < var1.getErrorDescription().length; var3++) {
               var2.append(var1.getErrorDescription()[var3]);
               var2.append("\n");
            }
         } else if (var1.getStatusMessage() != null) {
            var2.append(var1.getStatusMessage());
         }

         if (!"".equals(var2.toString())) {
            CommonPopups.showCommandResultErrorMessage(var2.toString(), null, this.scrContext);
         }

         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   @Override
   public void menuCanceled(MenuEvent var1) {
   }

   @Override
   public void menuDeselected(MenuEvent var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            RaritanDesktopPane var1x = (RaritanDesktopPane)RRCMenuBar.this.scrContext.getPanelMediator().getParent();
            if (var1x.getSelectedFrame() == null) {
               if (RRCMenuBar.this.focusComponent != null) {
                  RRCMenuBar.this.focusComponent.requestFocusInWindow();
               } else {
                  DefaultKeyboardFocusManager.getCurrentKeyboardFocusManager().focusPreviousComponent();
               }
            }

            RRCMenuBar.this.focusComponent = null;
         }
      });
   }

   @Override
   public void menuSelected(MenuEvent var1) {
      this.focusComponent = DefaultKeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner();
      this.actionPerformed(var1.getSource(), null);
   }

   private void checkFullScreen() {
      if (!this.checkMenuItemToolbar.isSelected() && !this.checkMenuItemStatusBar.isSelected() && !this.checkMenuItemNavigator.isSelected()) {
         this.menuItemTargetScreenResolution.setSelected(true);
         this.scrContext.getMainScreenMediator().getToolBarFullScreenButton().setSelected(true);
      }

      if (this.checkMenuItemToolbar.isSelected() && this.checkMenuItemStatusBar.isSelected() && this.checkMenuItemNavigator.isSelected()) {
         this.menuItemTargetScreenResolution.setSelected(false);
         this.scrContext.getMainScreenMediator().getToolBarFullScreenButton().setSelected(false);
      }

      if (this.menuItemTargetScreenResolution.isSelected()
         && (this.checkMenuItemToolbar.isSelected() || this.checkMenuItemStatusBar.isSelected() || this.checkMenuItemNavigator.isSelected())) {
         this.menuItemTargetScreenResolution.setSelected(false);
      }
   }

   public void setMenuItemTargetScreenResolution(boolean var1) {
      this.menuItemTargetScreenResolution.setSelected(var1);
   }

   public void enableExitMenu(boolean var1) {
      this.exitMenu.setEnabled(var1);
   }

   public void enableMenusInFullScreenMode(boolean var1) {
      if (!MPCUtil.isCCLaunched(this.scrContext)) {
         this.checkMenuItemToolbar.setEnabled(var1);
         this.checkMenuItemCSToolbar.setEnabled(var1);
         this.checkMenuItemStatusBar.setEnabled(var1);
         this.checkMenuItemNavigator.setEnabled(var1);
         this.checkMenuItemMessage.setEnabled(var1);
         this.checkShowAllMenuItem.setEnabled(var1);
         this.checkMenuItemShowWithoutTargets.setEnabled(var1);
         this.checkMenuItemGroups.setEnabled(var1);
         this.checkMenuItemShowTools.setEnabled(var1);
         this.checkMenuItemSortByChannelNumber.setEnabled(var1);
         this.checkMenuItemSortByChannelName.setEnabled(var1);
         this.checkMenuItemSortByChannelStatus.setEnabled(var1);
      }
   }

   public CommandMenu getWindowMenu() {
      return this.windowMenu;
   }
}
