package com.raritan.rrc.ui.components;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.ui.models.StatusEvent;
import com.raritan.rrc.ui.panes.KvmView;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.NameValuePair;
import com.raritan.tools.commands.Command;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.MultyObserverComponentInterface;
import com.raritan.tools.ui.panes.RaritanStatusBarPanel;
import java.awt.AWTEvent;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.Point;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javax.swing.BorderFactory;
import javax.swing.Icon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.Timer;
import nn.pp.audiocore.AudioEventListener;
import nn.pp.common.ResourceLoader;

public class RRCStatusBar extends RaritanStatusBarPanel implements MultyObserverComponentInterface {
   private final HashMap observables = new HashMap();
   public static final int STATUS_NOT_SECURE = 0;
   public static final int STATUS_SECURE = 1;
   private static final long serialVersionUID = 1L;
   private static final int PROGRESS_BAR_MAXIMUM = 100;
   private RaritanPropertyResourceBundle bundle;
   private boolean capsLockOn = false;
   private boolean numLockOn = false;
   private boolean scrollLockOn = false;
   private int concurrentUsers = 0;
   private JLabel videoSensingLabel;
   private JLabel bandwidthUsageLabel;
   private JLabel securityLabel;
   private JPanel audioStatePanel;
   private JLabel playbackStatus;
   private JLabel captureStatus;
   private Timer playbackTimer;
   private Timer captureTimer;
   private JLabel concurrentConnectionsLabel;
   private JLabel capsLockLabel;
   private JLabel numLockLabel;
   private JLabel scrollLockLabel;
   private JProgressBar rfpOperationProgreessBar;
   private CommandButton cancelRFPOperationButton;
   private JPanel progressPanel;
   private boolean isKX = false;
   private RRCStatusBar.KXTimer kxTimer = null;
   private int playbackCount = 0;
   private int captureCount = 0;

   public RRCStatusBar(boolean var1, ScreenContext var2) {
      super(var1, var2);
      this.enableEvents(34334L);
   }

   public void initRFPProgressComponents(boolean var1) {
      this.isKX = var1;
      if (var1) {
         this.kxTimer = new RRCStatusBar.KXTimer();
      } else {
         this.kxTimer = null;
      }

      this.rfpOperationProgreessBar.setMaximum(100);
      this.progressPanel.setVisible(true);
   }

   public void setRFPOperationProgress(int var1) {
      if (!this.isKX) {
         this.rfpOperationProgreessBar.setValue(var1);
      }
   }

   public void hideRFPProgressComponents() {
      if (this.kxTimer != null) {
         this.kxTimer.Stop();
         this.kxTimer = null;
      }

      this.rfpOperationProgreessBar.setValue(0);
      this.progressPanel.setVisible(false);
   }

   @Override
   public void makeLayout() {
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.label = new JLabel();
      this.videoSensingLabel = new JLabel(" ");
      this.videoSensingLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.bandwidthUsageLabel = new JLabel(" ");
      this.bandwidthUsageLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.securityLabel = new JLabel(" ");
      this.securityLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.audioStatePanel = new JPanel(new GridLayout(1, 2));
      this.audioStatePanel.setBorder(BorderFactory.createBevelBorder(1));
      this.playbackStatus = new JLabel((Icon)null, 0);
      this.captureStatus = new JLabel((Icon)null, 0);
      this.audioStatePanel.add(this.playbackStatus);
      this.audioStatePanel.add(this.captureStatus);
      this.concurrentConnectionsLabel = new JLabel(" ");
      this.concurrentConnectionsLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.capsLockLabel = new JLabel(" ");
      this.capsLockLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.numLockLabel = new JLabel(" ");
      this.numLockLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.scrollLockLabel = new JLabel(" ");
      this.scrollLockLabel.setBorder(BorderFactory.createBevelBorder(1));
      this.setLayout(new GridLayout(1, 2));
      JPanel var1 = new JPanel(new BorderLayout());
      var1.add(this.label, "Before");
      this.progressPanel = new JPanel(new FlowLayout());
      this.rfpOperationProgreessBar = new JProgressBar();
      this.cancelRFPOperationButton = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancelRFPOperationButton.setEnabled(false);
      this.progressPanel.add(this.rfpOperationProgreessBar);
      this.progressPanel.setVisible(false);
      var1.add(this.progressPanel, "After");
      this.add(var1);
      JPanel var2 = new JPanel(new GridLayout(1, 2));
      var2.add(this.videoSensingLabel);
      JPanel var3 = new JPanel(new GridLayout(1, 6));
      var3.add(this.bandwidthUsageLabel);
      var3.add(this.securityLabel);
      var3.add(this.audioStatePanel);
      var3.add(this.concurrentConnectionsLabel);
      var3.add(this.capsLockLabel);
      var3.add(this.numLockLabel);
      var3.add(this.scrollLockLabel);
      var2.add(var3);
      this.add(var2);
      this.playbackTimer = new Timer(500, new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            RRCStatusBar.this.togglePlaybackIcon();
         }
      });
      this.captureTimer = new Timer(500, new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            RRCStatusBar.this.toggleCaptureIcon();
         }
      });
   }

   public void setCapsLockStatus(boolean var1) {
      if (var1) {
         this.capsLockLabel.setText(this.bundle.getString("StatusBar.capsLock.label"));
      } else {
         this.capsLockLabel.setText(" ");
      }

      this.capsLockOn = var1;
   }

   public void setNumLockStatus(boolean var1) {
      if (var1) {
         this.numLockLabel.setText(this.bundle.getString("StatusBar.numLock.label"));
      } else {
         this.numLockLabel.setText(" ");
      }

      this.numLockOn = var1;
   }

   public void setScrollsLockStatus(boolean var1) {
      if (var1) {
         this.scrollLockLabel.setText(this.bundle.getString("StatusBar.scrollLock.label"));
      } else {
         this.scrollLockLabel.setText(" ");
      }

      this.scrollLockOn = var1;
   }

   public void setLEDState(boolean var1, boolean var2, boolean var3) {
      this.setScrollsLockStatus(var1);
      this.setNumLockStatus(var2);
      this.setCapsLockStatus(var3);
   }

   public void clearStatusBarLabels() {
      this.videoSensingLabel.setText(" ");
      this.bandwidthUsageLabel.setIcon(null);
      this.securityLabel.setIcon(null);
      this.playbackStatus.setIcon(null);
      this.playbackStatus.setToolTipText(null);
      this.captureStatus.setIcon(null);
      this.captureStatus.setToolTipText(null);
      this.concurrentConnectionsLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("Empty.image")));
      this.capsLockLabel.setText(" ");
      this.capsLockOn = false;
      this.numLockLabel.setText(" ");
      this.numLockOn = false;
      this.scrollLockLabel.setText(" ");
      this.scrollLockOn = false;
      this.playbackTimer.stop();
      this.captureTimer.stop();
   }

   public void initKVMStatusBarLabels(boolean var1, boolean var2, boolean var3) {
      this.setBandwidthUsage(0);
      this.securityLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("lockClosed.image")));
      this.setConcurrentUsers(this.concurrentUsers);
      this.setLEDState(var3, var2, var1);
      this.setPlaybackStatus(AudioEventListener.DeviceState.DISCONNECTED);
      this.setCaptureStatus(AudioEventListener.DeviceState.DISCONNECTED);
   }

   public void showAutoSense(int var1) {
      if (var1 == -1) {
         this.videoSensingLabel.setText(" ");
      } else {
         this.videoSensingLabel.setText(this.bundle.getString("StatusBar.autoSensingVideo.label") + " (" + var1 + ")");
      }
   }

   public void setConcurrentUsers(int var1) {
      this.concurrentUsers = var1;
      if (var1 > 1) {
         this.concurrentConnectionsLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("multipleUsers.image")));
      } else if (var1 == 1) {
         this.concurrentConnectionsLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("singleUser.image")));
      } else {
         this.concurrentConnectionsLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("Empty.image")));
      }
   }

   public void setBandwidthUsage(int var1) {
      switch (var1) {
         case 0:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale0.image")));
            break;
         case 1:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale1.image")));
            break;
         case 2:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale2.image")));
            break;
         case 3:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale3.image")));
            break;
         case 4:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale4.image")));
            break;
         case 5:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale5.image")));
            break;
         case 6:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale6.image")));
            break;
         case 7:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale7.image")));
            break;
         case 8:
            this.bandwidthUsageLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("bandwidthScale8.image")));
      }
   }

   public void setVideoSensingLabel(String var1) {
      this.videoSensingLabel.setText(var1);
   }

   public void setCancelRFPOperationCommand(Command var1) {
      this.cancelRFPOperationButton.addActionListener(this);
      this.cancelRFPOperationButton.setCommand(var1);
      this.cancelRFPOperationButton.setEnabled(false);
   }

   public void setSecurityLabel(int var1) {
      if (var1 == 1) {
         this.securityLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("lockClosed.image")));
      } else if (var1 == 0) {
         this.securityLabel.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("lockOpen.image")));
      }
   }

   public void setPlaybackStatus(AudioEventListener.DeviceState var1) {
      switch (var1) {
         case DISCONNECTED:
            this.playbackTimer.stop();
            this.playbackStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("speakerDisabled.image")));
            this.playbackStatus.setToolTipText(this.bundle.getString("speakerDisabled.tooltip"));
            break;
         case MUTED:
            this.playbackTimer.stop();
            this.playbackStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("speakerOff.image")));
            this.playbackStatus.setToolTipText(this.bundle.getString("speakerOff.tooltip"));
            break;
         case PLAYING:
            this.playbackTimer.start();
            this.playbackStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("speakerOn.image")));
            this.playbackStatus.setToolTipText(this.bundle.getString("speakerOn.tooltip"));
      }
   }

   public void setCaptureStatus(AudioEventListener.DeviceState var1) {
      switch (var1) {
         case DISCONNECTED:
            this.captureTimer.stop();
            this.captureStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("micDisabled.image")));
            this.captureStatus.setToolTipText(this.bundle.getString("micDisabled.tooltip"));
            break;
         case MUTED:
            this.captureTimer.stop();
            this.captureStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("micOff.image")));
            this.captureStatus.setToolTipText(this.bundle.getString("micOff.tooltip"));
            break;
         case PLAYING:
            this.captureTimer.start();
            this.captureStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("micOn.image")));
            this.captureStatus.setToolTipText(this.bundle.getString("micOn.tooltip"));
      }
   }

   private void togglePlaybackIcon() {
      this.playbackStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString(this.playbackCount == 0 ? "speakerOn2.image" : "speakerOn.image")));
      if (++this.playbackCount > 1) {
         this.playbackCount = 0;
      }
   }

   private void toggleCaptureIcon() {
      this.captureStatus.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString(this.captureCount == 0 ? "micOn2.image" : "micOn.image")));
      if (++this.captureCount > 1) {
         this.captureCount = 0;
      }
   }

   @Override
   protected void processEvent(AWTEvent var1) {
      if (var1.getID() == 34334) {
         Object var2 = ((StatusEvent)var1).getMessage();
         if (this.isKX && var2 instanceof NameValuePair) {
            if (!this.isKX) {
               NameValuePair var3 = (NameValuePair)var2;
               Point var4 = (Point)var3.getValue();
               int var5 = (int)((double)var4.x / var4.y * 100.0);
               this.rfpOperationProgreessBar.setValue(var5);
               this.validate();
            }

            return;
         }
      } else {
         super.processEvent(var1);
      }
   }

   public void setTextLabel(String var1) {
      this.label.setText(var1);
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (var2 instanceof ArrayList) {
         Object var3 = ((ArrayList)var2).get(0);
         if (var3 instanceof KvmPort) {
            KvmPort var4 = (KvmPort)var3;
            if (var4.isConnected()) {
               if (var4.getDeviceView() instanceof KvmView) {
                  this.setConcurrentUsers(var4.getConcurrUsers());
               } else if (var4.getDeviceView() instanceof RFBView) {
                  this.setConcurrentUsers(var4.getConcurrUsers());
                  RFBView var5 = (RFBView)var4.getView();
                  if (var5 != null) {
                     this.setCapsLockStatus(var5.isCapsLockOn());
                     this.setNumLockStatus(var5.isNumLockOn());
                     this.setScrollsLockStatus(var5.isScrollLockOn());
                     this.setPlaybackStatus(var5.getPlaybackState());
                     this.setCaptureStatus(var5.getCaptureState());
                  }
               }
            } else {
               this.clearStatusBarLabels();
            }
         } else {
            this.clearStatusBarLabels();
         }
      }
   }

   private class KXTimer implements ActionListener {
      private Timer timer = null;

      public KXTimer() {
         this.timer = new Timer(100, this);
         this.timer.setRepeats(true);
         this.timer.start();
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         int var2 = RRCStatusBar.this.rfpOperationProgreessBar.getValue() + 1;
         if (var2 > RRCStatusBar.this.rfpOperationProgreessBar.getMaximum()) {
            var2 = RRCStatusBar.this.rfpOperationProgreessBar.getMinimum();
         }

         RRCStatusBar.this.rfpOperationProgreessBar.setValue(var2);
      }

      public void Stop() {
         if (this.timer != null) {
            this.timer.stop();
         }
      }
   }
}
