package com.raritan.rrc.ui.components;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.ConnectAudioCommand;
import com.raritan.rrc.ui.commands.DoAutoSenseCommand;
import com.raritan.rrc.ui.commands.DoCalibrateColorCommand;
import com.raritan.rrc.ui.commands.DoCaptureTargetScreenshotCommand;
import com.raritan.rrc.ui.commands.DoEnterOnscreenMenuCommand;
import com.raritan.rrc.ui.commands.DoExitOnscreenMenuCommand;
import com.raritan.rrc.ui.commands.DoRefreshNavigatorCommand;
import com.raritan.rrc.ui.commands.DoRefreshScreenCommand;
import com.raritan.rrc.ui.commands.DoSendCtrlAltDelCommand;
import com.raritan.rrc.ui.commands.DoSynchronizeMouseCommand;
import com.raritan.rrc.ui.commands.SelectCardReaderCommand;
import com.raritan.rrc.ui.commands.ShowAboutCommand;
import com.raritan.rrc.ui.commands.ShowAllDevicesCommand;
import com.raritan.rrc.ui.commands.ShowNavigatorCommand;
import com.raritan.rrc.ui.commands.ShowNewProfileCommand;
import com.raritan.rrc.ui.commands.ShowPropertiesCommand;
import com.raritan.rrc.ui.commands.ShowSingleCursorInstructionCommand;
import com.raritan.rrc.ui.commands.ShowTargetScreenResolutionCommand;
import com.raritan.rrc.ui.commands.ShowVideoScaleCommand;
import com.raritan.rrc.ui.commands.ShowVideoSettingsCommand;
import com.raritan.rrc.ui.commands.SmartCardMenuCommand;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.util.CommandUtil;
import java.awt.Dimension;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.Observable;
import javax.swing.BorderFactory;
import javax.swing.JToolBar;
import javax.swing.border.CompoundBorder;
import nn.pp.common.ResourceLoader;

public class RRCToolBar extends JToolBar implements MouseListener {
   private static final long serialVersionUID = 1550118845028268726L;
   private static final String NEW_PROFILE_IMAGE = "NewProfileAction.image";
   private static final String NEW_PROFILE_TOOLTIP = "NewProfileAction.tooltip";
   private static final String PROPERTIES_IMAGE = "PropertiesAction.image";
   private static final String PROFILE_TOOLTIP = "PropertiesAction.tooltip";
   private static final String VIDEO_SETTINGS_IMAGE = "VideoSettingsAction.image";
   private static final String VIDEO_SETTINGS_TOOLTIP = "VideoSettingsAction.tooltip";
   private static final String COLOR_CALIBRATE_IMAGE = "ColorCalibrateAction.image";
   private static final String COLOR_CALIBRATE_TOOLTIP = "ColorCalribrateAction.tooltip";
   private static final String CAPTURE_SCREENSHOT_IMAGE = "Screenshot.image";
   private static final String CAPTURE_SCREENSHOT_TOOLIP = "Screenshot.tooltip";
   private static final String VIRTUAL_MEDIA_IMAGE = "virtualMedia.toolbar.image";
   private static final String VIRTUAL_MEDIA_TOOLTIP = "virtualMedia.tooltip";
   private static final String SYNCHRONIZE_MOUSE_IMAGE = "SynchronizeMouseAction.image";
   private static final String SYNCHRONIZE_MOUSE_TOOLTIP = "SynchronizeMouseAction.tooltip";
   private static final String REFRESH_SCREEN_IMAGE = "RefreshScreenAction.image";
   private static final String REFRESH_SCREEN_TOOLTIP = "RefreshScreenAction.tooltip";
   private static final String SMARTCARD_SELECT_CARDREADER_IMAGE = "SmartCardSelectCardReader.toolbar.image";
   private static final String AUTO_SENSE_IMAGE = "AutoSenseAction.image";
   private static final String AUTO_SENSE_TOOLTIP = "AutoSenseAction.tooltip";
   private static final String ENTER_ONSCREEN_MENU_IMAGE = "EnterOnScreenMenuAction.image";
   private static final String ENTER_ONSCREEN_MENU_TOOLTIP = "EnterOnScreenMenuAction.tooltip";
   private static final String EXIT_ONSCREEN_MENU_IMAGE = "ExitOnScreenMenuAction.image";
   private static final String EXIT_ONSCREEN_MENU_TOOLTIP = "ExitOnScreenMenuAction.tooltip";
   private static final String SEND_CTRL_ALT_DEL_IMAGE = "SendCtrlAltDeleteAction.image";
   private static final String SEND_CTRL_ALT_DEL_TOOLTIP = "SendCtrlAltDeleteAction.tooltip";
   private static final String SINGLE_MOUSE_CURSOR_IMAGE = "SingleMouseCursorAction.image";
   private static final String SINGLE_MOUSE_CURSOR_TOOLTIP = "SingleMouseCursorAction.tooltip";
   private static final String FULL_SCREEN_IMAGE = "FullScreenAction.image";
   private static final String FULL_SCREEN_TOOLTIP = "FullScreenAction.tooltip";
   private static final String NAVIGATOR_IMAGE = "NavigatorAction.image";
   private static final String NAVIGATOR_TOOLTIP = "NavigatorAction.tooltip";
   private static final String REFRESH_NAVIGATOR_IMAGE = "RefreshNavigatorAction.image";
   private static final String REFRESH_NAVIGATOR_TOOLTIP = "RefreshNavigatorAction.tooltip";
   private static final String BROWSE_IMAGE = "BrowseAction.image";
   private static final String BROWSE_TOOLTIP = "BrowseAction.tooltip";
   private static final String ABOUT_IMAGE = "AboutAction.image";
   private static final String ABOUT_TOOLTIP = "AboutAction.tooltip";
   private static final String SCALE_VIDEO_IMAGE = "ScaleVideoAction.image";
   private static final String SCALE_VIDEO_TOOLTIP = "ScaleVideoAction.tooltip";
   private static final String AUDIO_IMAGE = "Audio.image";
   protected RRCScreenContext scrContext;
   protected RaritanPropertyResourceBundle bundle;
   private CommandButton toolBarButton;
   private CommandButton selectCardReaderButton;
   private CommandToggleButton toolBarFullScreenButton;
   private CommandToggleButton toolBarSingleMouseCursorButton;
   private CommandToggleButton toolBarBrowseAllDevicesButton;
   private CommandToggleButton toolBarNavigatorButton;
   private CommandToggleButton toolBarScaleVideoButton;
   private CommandToggleButton toolBarAudioButton;
   private static Object lastPressed = null;
   private static boolean useLastPressed = false;

   public RRCToolBar(RRCScreenContext var1) {
      this.scrContext = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      Dimension var2 = new Dimension(30, 30);
      Dimension var3 = new Dimension(30, 30);
      Dimension var4 = new Dimension(5, 25);
      CompoundBorder var5 = BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1), BorderFactory.createRaisedBevelBorder());
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("NewProfileAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.setCommand(new ShowNewProfileCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("NewProfileAction.tooltip"));
      this.add(this.toolBarButton);
      this.addSeparator(var4);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("PropertiesAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new ShowPropertiesCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("PropertiesAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("VideoSettingsAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new ShowVideoSettingsCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("VideoSettingsAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("ColorCalibrateAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoCalibrateColorCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("ColorCalribrateAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("Screenshot.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoCaptureTargetScreenshotCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("Screenshot.tooltip"));
      this.add(this.toolBarButton);
      this.addSeparator(var4);
      this.toolBarAudioButton = new CommandToggleButton(this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            ConnectAudioCommand var3x = (ConnectAudioCommand)this.getCommand();
            if (var3x.isExecutable()) {
               this.setToolTipText(
                  var3x.isConnected()
                     ? RRCToolBar.this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_DISCONNECT)
                     : RRCToolBar.this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT)
               );
               this.setSelected(var3x.isConnected());
            } else {
               this.setToolTipText(var3x.getToolTip());
            }
         }
      };
      this.toolBarAudioButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("Audio.image")));
      this.toolBarAudioButton.addMouseListener(this);
      this.toolBarAudioButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarAudioButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarAudioButton.addObservable(this.scrContext.getAudioObserver());
      this.toolBarAudioButton.setCommand(new ConnectAudioCommand(this.scrContext));
      this.toolBarAudioButton.setOpaque(false);
      this.toolBarAudioButton.setMinimumSize(var3);
      this.toolBarAudioButton.setMaximumSize(var3);
      this.toolBarAudioButton.setPreferredSize(var3);
      this.toolBarAudioButton.setToolTipText(this.bundle.getString(MenuItemResourceBundleConstants.AUDIO_CONNECT));
      this.add(this.toolBarAudioButton);
      this.addSeparator(var4);
      this.toolBarButton = new CommandButton(this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            DoSynchronizeMouseCommand var3x = (DoSynchronizeMouseCommand)this.getCommand();
            String var4x = var3x.getTooltipText();
            if (var4x == null) {
               var4x = RRCToolBar.this.bundle.getString("SynchronizeMouseAction.tooltip");
            }

            this.setToolTipText(var4x);
         }
      };
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("SynchronizeMouseAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoSynchronizeMouseCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("SynchronizeMouseAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("RefreshScreenAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoRefreshScreenCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("RefreshScreenAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("AutoSenseAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoAutoSenseCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("AutoSenseAction.tooltip"));
      this.add(this.toolBarButton);
      this.addSeparator(var4);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("EnterOnScreenMenuAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoEnterOnscreenMenuCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("EnterOnScreenMenuAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("ExitOnScreenMenuAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoExitOnscreenMenuCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("ExitOnScreenMenuAction.tooltip"));
      this.add(this.toolBarButton);
      this.selectCardReaderButton = new CommandButton(this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            this.setToolTipText(((SmartCardMenuCommand)this.getCommand()).getToolTip());
         }
      };
      this.selectCardReaderButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("SmartCardSelectCardReader.toolbar.image")));
      this.selectCardReaderButton.addMouseListener(this);
      this.selectCardReaderButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.selectCardReaderButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.selectCardReaderButton.addObservable(this.scrContext.getSmartCardObserver());
      this.selectCardReaderButton.setCommand(new SelectCardReaderCommand(this.scrContext));
      this.selectCardReaderButton.setOpaque(false);
      this.selectCardReaderButton.setMinimumSize(var2);
      this.selectCardReaderButton.setMaximumSize(var2);
      this.selectCardReaderButton.setPreferredSize(var2);
      this.selectCardReaderButton.setBorder(var5);
      this.add(this.selectCardReaderButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("SendCtrlAltDeleteAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarButton.setCommand(new DoSendCtrlAltDelCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("SendCtrlAltDeleteAction.tooltip"));
      this.add(this.toolBarButton);
      this.addSeparator(var4);
      this.toolBarSingleMouseCursorButton = new CommandToggleButton(this.scrContext) {
         @Override
         public void update(Observable var1, Object var2x) {
            super.update(var1, var2x);
            ShowSingleCursorInstructionCommand var3x = (ShowSingleCursorInstructionCommand)this.getCommand();
            String var4x = var3x.getTooltipText();
            if (var4x == null) {
               var4x = RRCToolBar.this.bundle.getString("SingleMouseCursorAction.tooltip");
            }

            this.setToolTipText(var4x);
         }
      };
      this.toolBarSingleMouseCursorButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("SingleMouseCursorAction.image")));
      this.scrContext.getMainScreenMediator().setSingleMouseCursorButton(this.toolBarSingleMouseCursorButton);
      this.toolBarSingleMouseCursorButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarSingleMouseCursorButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarSingleMouseCursorButton.setCommand(new ShowSingleCursorInstructionCommand(this.scrContext));
      this.toolBarSingleMouseCursorButton.setOpaque(false);
      this.toolBarSingleMouseCursorButton.setMinimumSize(var3);
      this.toolBarSingleMouseCursorButton.setMaximumSize(var3);
      this.toolBarSingleMouseCursorButton.setPreferredSize(var3);
      this.toolBarSingleMouseCursorButton.setToolTipText(this.bundle.getString("SingleMouseCursorAction.tooltip"));
      this.toolBarSingleMouseCursorButton.addMouseListener(this);
      this.add(this.toolBarSingleMouseCursorButton);
      this.toolBarFullScreenButton = new CommandToggleButton(this.scrContext);
      this.toolBarFullScreenButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("FullScreenAction.image")));
      this.scrContext.getMainScreenMediator().setToolBarFullScreenButton(this.toolBarFullScreenButton);
      this.toolBarFullScreenButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarFullScreenButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarFullScreenButton.setCommand(new ShowTargetScreenResolutionCommand(this.scrContext));
      this.toolBarFullScreenButton.setOpaque(false);
      this.toolBarFullScreenButton.setMinimumSize(var3);
      this.toolBarFullScreenButton.setMaximumSize(var3);
      this.toolBarFullScreenButton.setPreferredSize(var3);
      this.toolBarFullScreenButton.setToolTipText(this.bundle.getString("FullScreenAction.tooltip"));
      this.toolBarFullScreenButton.addMouseListener(this);
      this.add(this.toolBarFullScreenButton);
      this.toolBarScaleVideoButton = new CommandToggleButton(this.scrContext);
      this.toolBarScaleVideoButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("ScaleVideoAction.image")));
      this.toolBarScaleVideoButton.setCommand(new ShowVideoScaleCommand(this.scrContext));
      this.scrContext.getMainScreenMediator().setScaleVideoButton(this.toolBarScaleVideoButton);
      this.toolBarScaleVideoButton.addObservable(this.scrContext.getSelectedDevicesObservable());
      this.toolBarScaleVideoButton.addObservable(this.scrContext.getOpenPortsObservable());
      this.toolBarScaleVideoButton.addMouseListener(this);
      this.toolBarScaleVideoButton.setOpaque(false);
      this.toolBarScaleVideoButton.setMinimumSize(var3);
      this.toolBarScaleVideoButton.setMaximumSize(var3);
      this.toolBarScaleVideoButton.setPreferredSize(var3);
      this.toolBarScaleVideoButton.setToolTipText(this.bundle.getString("ScaleVideoAction.tooltip"));
      this.add(this.toolBarScaleVideoButton);
      this.addSeparator(var4);
      this.toolBarNavigatorButton = new CommandToggleButton(this.scrContext);
      this.toolBarNavigatorButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("NavigatorAction.image")));
      this.toolBarNavigatorButton.setCommand(new ShowNavigatorCommand(this.scrContext));
      this.scrContext.getMainScreenMediator().setNavigatorButton(this.toolBarNavigatorButton);
      this.toolBarNavigatorButton.addMouseListener(this);
      this.toolBarNavigatorButton.setOpaque(false);
      this.toolBarNavigatorButton.setMinimumSize(var3);
      this.toolBarNavigatorButton.setMaximumSize(var3);
      this.toolBarNavigatorButton.setPreferredSize(var3);
      this.toolBarNavigatorButton.setToolTipText(this.bundle.getString("NavigatorAction.tooltip"));
      this.add(this.toolBarNavigatorButton);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("RefreshNavigatorAction.image")));
      this.scrContext.getMainScreenMediator().setToolBarRefreshButton(this.toolBarButton);
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.setCommand(new DoRefreshNavigatorCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("RefreshNavigatorAction.tooltip"));
      this.add(this.toolBarButton);
      this.toolBarBrowseAllDevicesButton = new CommandToggleButton(this.scrContext);
      this.toolBarBrowseAllDevicesButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("BrowseAction.image")));
      this.scrContext.getMainScreenMediator().setBrowseAllDevicesButton(this.toolBarBrowseAllDevicesButton);
      this.toolBarBrowseAllDevicesButton.setCommand(new ShowAllDevicesCommand(this.scrContext));
      this.toolBarBrowseAllDevicesButton.addMouseListener(this);
      this.toolBarBrowseAllDevicesButton.setOpaque(false);
      this.toolBarBrowseAllDevicesButton.setMinimumSize(var3);
      this.toolBarBrowseAllDevicesButton.setMaximumSize(var3);
      this.toolBarBrowseAllDevicesButton.setPreferredSize(var3);
      this.toolBarBrowseAllDevicesButton.setToolTipText(this.bundle.getString("BrowseAction.tooltip"));
      this.add(this.toolBarBrowseAllDevicesButton);
      this.addSeparator(var4);
      this.toolBarButton = new CommandButton(this.scrContext);
      this.toolBarButton.setIcon(ResourceLoader.loadImageIcon(this.bundle.getString("AboutAction.image")));
      this.toolBarButton.addMouseListener(this);
      this.toolBarButton.setCommand(new ShowAboutCommand(this.scrContext));
      this.toolBarButton.setOpaque(false);
      this.toolBarButton.setMinimumSize(var2);
      this.toolBarButton.setMaximumSize(var2);
      this.toolBarButton.setPreferredSize(var2);
      this.toolBarButton.setBorder(var5);
      this.toolBarButton.setToolTipText(this.bundle.getString("AboutAction.tooltip"));
      this.add(this.toolBarButton);
      this.addSeparator(var4);
   }

   protected void handleCommandResult(CommandResult var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   protected void handleCommandResultErrorDescription(CommandResult var1) {
      if (var1 != null) {
         StringBuffer var2 = new StringBuffer("");
         if (var1.getErrorDescription() != null && var1.getErrorDescription().length > 0) {
            for (int var3 = 0; var3 < var1.getErrorDescription().length; var3++) {
               var2.append(var1.getErrorDescription()[var3]);
               var2.append("\n");
            }
         } else if (var1.getStatusMessage() != null) {
            var2.append(var1.getStatusMessage());
         } else {
            var2.append("No command result info.");
         }

         CommonPopups.showCommandResultErrorMessage(var2.toString(), null, this.scrContext);
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   @Override
   public void mouseClicked(MouseEvent var1) {
   }

   @Override
   public void mouseEntered(MouseEvent var1) {
      if (var1.getSource() == lastPressed) {
         useLastPressed = true;
      }
   }

   @Override
   public void mouseExited(MouseEvent var1) {
      if (var1.getSource() == lastPressed) {
         useLastPressed = false;
      }
   }

   @Override
   public void mousePressed(MouseEvent var1) {
      lastPressed = var1.getSource();
      useLastPressed = true;
   }

   @Override
   public void mouseReleased(MouseEvent var1) {
      Object var2 = var1.getSource();
      if (!(var2 instanceof CommandButton) || ((CommandButton)var2).isEnabled()) {
         if (!(var2 instanceof CommandToggleButton) || ((CommandToggleButton)var2).isEnabled()) {
            if (var2 == lastPressed && useLastPressed) {
               lastPressed = null;
               useLastPressed = false;
               boolean var3 = false;
               if (var2 instanceof ConfirmableCommandInterface) {
                  var3 = ((ConfirmableCommandInterface)var1.getSource()).getConfirmation();
               }

               if (CommandUtil.isCommandHolder(var2)) {
                  if (var3) {
                     var3 = CommonPopups.showExitConfirmationDialog(this.scrContext.getApplication().getContentPane(), this.scrContext) != 2;
                  }

                  if (!var3) {
                     boolean var4 = false;
                     String var5 = null;
                     if (var2 instanceof CommandToggleButton) {
                        if ((CommandToggleButton)var2 == this.toolBarNavigatorButton) {
                           var4 = this.toolBarNavigatorButton.isSelected();
                           var5 = "showNavigatorMode";
                        }

                        if ((CommandToggleButton)var2 == this.toolBarBrowseAllDevicesButton) {
                           var4 = this.toolBarBrowseAllDevicesButton.isSelected();
                           var5 = "showAllDevicesMode";
                        }

                        if ((CommandToggleButton)var2 == this.toolBarSingleMouseCursorButton) {
                           this.toolBarSingleMouseCursorButton.setSelected(!this.toolBarSingleMouseCursorButton.isSelected());
                        }

                        if ((CommandToggleButton)var2 == this.toolBarFullScreenButton) {
                           var4 = this.toolBarFullScreenButton.isSelected();
                           var5 = "showFullScreenMode";
                        }

                        if ((CommandToggleButton)var2 == this.toolBarScaleVideoButton) {
                           var4 = this.toolBarScaleVideoButton.isSelected();
                           var5 = "scaleVideoMode";
                        }
                     }

                     CommandHolder var6 = (CommandHolder)var2;
                     if (var5 != null) {
                        var6.getCommand().getContext(true).setCommandParameter(var5, new Boolean(var4));
                     }

                     CommandResult var7 = var6.getCommand().execute();
                     if (!var7.isSuccess() && var7.hasErrorDescription()) {
                        this.handleCommandResultErrorDescription(var7);
                     } else {
                        this.handleCommandResult(var7);
                        this.scrContext.getPanelMediator().showPanel(var6.getCommand().getContext());
                     }

                     this.scrContext.resetDefaultFocus();
                  }
               }
            } else {
               lastPressed = null;
               useLastPressed = false;
            }
         }
      }
   }
}
