package com.raritan.rrc.ui.components;

import java.awt.Color;
import java.awt.Component;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;

public class TextGroup extends JPanel implements KeyListener {
   public static final int TAB_NEXT = 1;
   public static final int TAB_PREVIOUS = -1;
   public static final Border DEFAULT_BORDER = UIManager.getBorder("TextField.border");
   public static final Color DEFAULT_BACKGROUND = UIManager.getColor("TextField.background");
   public static final Font DEFAULT_FONT = new Font("monospaced", 0, 12);
   public static final Color DEFAULT_MASK_COLOR = Color.gray;
   public static final boolean DEFAULT_DISPLAY_PARTIAL_MASK = true;
   private static Border labelBorder = new EmptyBorder(0, 5, 0, 5);
   private String delimiters;
   private Color maskColor = DEFAULT_MASK_COLOR;
   private boolean displayPartialMask = true;
   private MaskTextField firstField;
   protected List maskTextFields;
   private StringBuffer text = new StringBuffer(16);

   public TextGroup(String var1, String var2) {
      this(var1, var2, null, null);
   }

   public TextGroup(String var1, String var2, FieldValidator var3) {
      this(var1, var2, var3, null);
   }

   public TextGroup(String var1, String var2, FieldValidator[] var3) {
      this(var1, var2, null, var3);
   }

   public TextGroup(String var1, String var2, FieldValidator var3, FieldValidator[] var4) {
      this.delimiters = var2;
      this.setLayout(new FlowLayout(1, 0, 0));
      this.setBorder(DEFAULT_BORDER);
      this.setBackground(DEFAULT_BACKGROUND);
      this.setFont(DEFAULT_FONT);
      this.maskTextFields = new ArrayList();
      StringTokenizer var5 = new StringTokenizer(var1, var2, true);
      int var6 = 0;

      while (var5.hasMoreTokens()) {
         String var7 = var5.nextToken();
         if (var2.indexOf(var7) == -1) {
            FieldValidator var8 = this.getNextValidator(var6, var3, var4);
            this.addTextField(var7, var8);
            var6++;
         } else {
            this.addLabel(var7);
         }
      }
   }

   private FieldValidator getNextValidator(int var1, FieldValidator var2, FieldValidator[] var3) {
      if (var2 != null) {
         return var2;
      } else {
         return var3 != null && var1 < var3.length ? var3[var1] : null;
      }
   }

   public MaskTextField addTextField(String var1, FieldValidator var2) {
      MaskTextField var3 = this.getMaskTextField(var1, var2);
      var3.setFont(null);
      var3.setBorder(null);
      var3.setOpaque(false);
      var3.setForeground(null);
      var3.setParent(this);
      var3.setValidator(var2);
      var3.addKeyListener(this);
      var3.setHorizontalAlignment(0);
      var3.setBorder(labelBorder);
      if (this.maskTextFields.size() == 0) {
         var3.setFocusTraversable(true);
      }

      this.maskTextFields.add(var3);
      super.add(var3);
      return var3;
   }

   protected MaskTextField getMaskTextField(String var1, FieldValidator var2) {
      return new MaskTextField(var1.length(), var1);
   }

   public void setEditable(boolean var1) {
      if (this.maskTextFields != null && this.maskTextFields.size() > 0) {
         for (int var2 = 0; var2 < this.maskTextFields.size(); var2++) {
            JTextField var3 = (JTextField)this.maskTextFields.get(var2);
            var3.setEditable(var1);
         }
      }
   }

   @Override
   public void setEnabled(boolean var1) {
      if (this.maskTextFields != null && this.maskTextFields.size() > 0) {
         for (int var2 = 0; var2 < this.maskTextFields.size(); var2++) {
            JTextField var3 = (JTextField)this.maskTextFields.get(var2);
            var3.setEnabled(var1);
         }
      }
   }

   public JLabel addLabel(String var1) {
      JLabel var2 = new JLabel(var1);
      super.add(var2);
      var2.setFont(null);
      return var2;
   }

   public void setText(String var1) {
      StringTokenizer var2 = new StringTokenizer(var1, this.delimiters, true);
      int var3 = 0;

      while (var2.hasMoreTokens()) {
         String var4 = var2.nextToken();
         if (this.delimiters.indexOf(var4) == -1) {
            if (var3 < this.maskTextFields.size()) {
               this.setText(var3, var4);
            }

            var3++;
         }
      }
   }

   public void setText(int var1, String var2) {
      if (var1 < this.maskTextFields.size()) {
         ((MaskTextField)this.maskTextFields.get(var1)).setText(var2);
      }
   }

   public String getText() {
      return this.getComponentText(true);
   }

   public String getText(int var1) {
      return var1 < this.maskTextFields.size() ? ((MaskTextField)this.maskTextFields.get(var1)).getText() : "";
   }

   public String getData() {
      return this.getComponentText(false);
   }

   public void setMaskColor(Color var1) {
      this.maskColor = var1;
   }

   public Color getMaskColor() {
      return this.maskColor;
   }

   public void setDisplayPartialMask(boolean var1) {
      this.displayPartialMask = var1;
   }

   public boolean isDisplayPartialMask() {
      return this.displayPartialMask;
   }

   private String getComponentText(boolean var1) {
      this.text.setLength(0);
      Component[] var2 = this.getComponents();

      for (int var3 = 0; var3 < var2.length; var3++) {
         if (var2[var3] instanceof JTextField) {
            JTextField var4 = (JTextField)var2[var3];
            this.text.append(var4.getText());
         }

         if (var1 && var2[var3] instanceof JLabel) {
            JLabel var5 = (JLabel)var2[var3];
            this.text.append(var5.getText());
         }
      }

      return this.text.toString();
   }

   public void tab(JTextField var1, int var2) {
      Component[] var3 = this.getComponents();
      int var4 = 0;

      while (var3[var4] != var1) {
         var4++;
      }

      do {
         var4 += var2;
         if (var4 > var3.length - 1 || var4 < 0) {
            return;
         }
      } while (!(var3[var4] instanceof JTextField));

      var3[var4].requestFocus();
   }

   @Override
   public void keyPressed(KeyEvent var1) {
      JTextField var2 = (JTextField)var1.getSource();
      switch (var1.getKeyCode()) {
         case 37:
            if (var2.getCaretPosition() == 0) {
               this.tab(var2, -1);
               var1.consume();
            }
            break;
         case 38:
            this.tab(var2, -1);
            break;
         case 39:
            if (var2.getCaretPosition() == var2.getDocument().getLength()) {
               this.tab(var2, 1);
               var1.consume();
            }
            break;
         case 40:
            this.tab(var2, 1);
         case 41:
         case 42:
         case 43:
         case 44:
         case 45:
         default:
            break;
         case 46:
            this.tab(var2, 1);
      }
   }

   @Override
   public void keyTyped(KeyEvent var1) {
   }

   @Override
   public void keyReleased(KeyEvent var1) {
   }

   public static void main(String[] var0) {
      JFrame var1 = new JFrame();
      var1.setDefaultCloseOperation(3);
      JPanel var2 = new JPanel(new GridLayout(0, 2));
      var1.setContentPane(var2);
      final TextGroup var3 = new TextGroup("YYYY/MM/DD", "/");
      var3.setBackground(Color.yellow);
      var3.setForeground(Color.red);
      var2.add(new JLabel("Date - not validated:"));
      var2.add(var3);
      JButton var4 = new JButton("Validate Date");
      var4.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            System.out.println(var3.getText(0));
            System.out.println(var3.getData());
            String var2x = var3.getText();
            System.out.print(var2x);

            try {
               SimpleDateFormat var3x = new SimpleDateFormat("yyyy/MM/dd");
               var3x.setLenient(false);
               var3x.parse(var2x);
               System.out.println(" is valid");
            } catch (Exception var4x) {
               System.out.println(" is invalid");
            }
         }
      });
      var2.add(new JLabel(""));
      var2.add(var4);
      FieldValidator[] var5 = new FieldValidator[]{new IntegerValidator(1900, 2010), new IntegerValidator(1, 12, 2), new IntegerValidator(1, 31, 2)};
      TextGroup var6 = new TextGroup("YYYY/MM/DD", "/", var5);
      var6.setDisplayPartialMask(false);
      var6.setMaskColor(Color.red);
      var2.add(new JLabel("Date - validated:"));
      var2.add(var6);
      IntegerValidator var7 = new IntegerValidator();
      TextGroup var8 = new TextGroup("(###)___-____", "()-", var7);
      var2.add(new JLabel("Phone Number:"));
      var2.add(var8);
      JIPTextField var9 = new JIPTextField("   .   .   .   ", ".");
      var9.setText("1.2.3");
      var9.setText(3, "4");
      var2.add(new JLabel("IP Address:"));
      var2.add(var9);
      IntegerValidator var10 = new IntegerValidator(-100, 100);
      var10.setSignRequired(2);
      TextGroup var11 = new TextGroup("+   ", "", var10);
      var2.add(new JLabel("Signed Integer:"));
      var2.add(var11);
      MaskTextField var12 = new MaskTextField(6, "");
      var12.setValidator(var7);
      var2.add(new JLabel("Postal Code:"));
      var2.add(var12);
      MaskTextField var13 = new MaskTextField(20, "First Name");
      var13.setMaskColor(Color.blue);
      var13.setDisplayPartialMask(false);
      var2.add(new JLabel("Masked First Name:"));
      var2.add(var13);
      var1.pack();
      var1.setVisible(true);
   }
}
