package com.raritan.rrc.ui.controller;

import com.raritan.protocol.browser.TooManyDevicesException;
import com.raritan.protocol.browser.spi.Browser;
import com.raritan.protocol.browser.spi.DeviceNameAddressProvImpl;
import com.raritan.protocol.csc.RRCDeviceInfo;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.Paragon;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoSortCommand;
import com.raritan.rrc.ui.models.DeviceInfoWrapper;
import com.raritan.rrc.ui.models.DeviceListingModel;
import com.raritan.rrc.ui.models.DeviceListingModelListener;
import com.raritan.rrc.ui.panes.mediator.MainScreenMediator;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.ui.components.CommandCheckMenuItem;
import com.raritan.tools.ui.components.MultyObserverComponentInterface;
import com.raritan.tools.ui.panes.BaseTreePanel;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Observable;
import java.util.Set;
import java.util.TreeSet;
import java.util.Map.Entry;
import javax.swing.SwingUtilities;
import nn.pp.ext.pref.IApplicationPreferences;

public class DeviceTreeController implements PropertyChangeListener, MultyObserverComponentInterface {
   private static DeviceTreeController instance;
   private Browser deviceBrowser;
   private RRCScreenContext scrContext;
   private HashMap observables = new HashMap();
   private IApplicationPreferences appPrefs;
   private BaseTreePanel deviceByIPTreePanel = null;
   public static int SORT_TYPE_CHANNEL = 0;
   public static int SORT_TYPE_NAME = 1;
   public static int SORT_TYPE_STATUS = 2;
   private volatile int sortType = SORT_TYPE_CHANNEL;
   private DoSortCommand sortCommand;
   private volatile boolean stopping = false;
   private Hashtable deviceListingMap = new Hashtable();
   private static Comparator ipAddrComparator = new DeviceTreeController.IPAddrComparator();
   private DeviceListingModel deviceListingModel;
   private static Object objMutex = new Object();
   private static Object mutex = new Object();

   private DeviceTreeController(RRCScreenContext var1) {
      this();
      this.setScreenContext(var1);
      this.appPrefs = this.scrContext.getAppSettings();
      MainScreenMediator var2 = this.scrContext.getMainScreenMediator();
      this.deviceByIPTreePanel = var2.getDeviceByIPTree();
      this.deviceBrowser = new Browser();
      this.deviceBrowser.setQueryInterval(30);
      this.deviceBrowser.setDefaultDiscoveryPort(this.appPrefs.getBroadcastPort());
      if (this.appPrefs.getShowAll()) {
         this.deviceBrowser.setBroadcastEnabled();
      }

      this.sortCommand = new DoSortCommand(var1);
      this.deviceListingModel = new DeviceListingModel(this.deviceBrowser);
      this.deviceListingModel.addDeviceListingModelListener(new DeviceTreeController.DevListingModelListenerImpl());
      this.deviceListingModel.init();
      var1.setDeviceNameAddressProvider(new DeviceNameAddressProvImpl(this.deviceListingModel));
      this.startBrowser();
   }

   private DeviceTreeController() {
      this.observables = new HashMap();
   }

   private void init() {
      Thread var1 = new Thread(new Runnable() {
         @Override
         public void run() {
            DeviceTreeController.this.loadProfiledDevices();
         }
      });
      var1.start();
   }

   public static DeviceTreeController getInstance() {
      synchronized (objMutex) {
         if (instance == null) {
            instance = new DeviceTreeController();
         }
      }

      return instance;
   }

   public static DeviceTreeController getInstance(RRCScreenContext var0) {
      synchronized (mutex) {
         if (instance == null) {
            instance = new DeviceTreeController(var0);
            instance.init();
         }
      }

      return instance;
   }

   public static void clearInstance() {
      instance = null;
   }

   public void setScreenContext(RRCScreenContext var1) {
      this.scrContext = var1;
      if (this.scrContext.getSelectedDevicesObservable() != null) {
         this.addObservable(this.scrContext.getSelectedDevicesObservable());
      }
   }

   private void prepareDevice(IPReach var1) {
      var1.addPropertyChangeListener(this);
      var1.setRootDevice(true);
   }

   public synchronized void removeDevice(IPReach var1) {
      DevicePreferences var2 = var1.getDevPrefs();
      int var3 = var2.getConnectionType();
      if (var3 == 1) {
         this.deviceListingModel.removePhoneProfiledEntry(var2.getPhone());
      } else if (var3 == 2) {
         int var4 = var2.getFindBy();
         switch (var4) {
            case 0:
               this.deviceListingModel.removeIPProfiledEntry(var2.getInetAddess(), var2.getPort());
               break;
            case 1:
               this.deviceListingModel.removeNameProfiledEntry(var2.getName());
               break;
            case 2:
               this.deviceListingModel.removeDNSProfiledEntry(var2.getDnsName(), var2.getPort());
         }
      }
   }

   private void loadProfiledDevices() {
      if (this.scrContext.getApplicationProperty("connection") == null) {
         String[] var1 = DevicePreferences.returnNodes();
         DevicePreferences var2 = null;
         IPReach var3 = null;

         for (int var4 = 0; var4 < var1.length; var4++) {
            var2 = new DevicePreferences();
            var3 = new IPReach();
            var2.importPreferences(var1[var4]);
            if (StringUtils.notNullOrEmpty(var2.getDescription())) {
               var3.setDevPrefs(var2);
               var3.setDescription(var2.getDescription());
               var3.setState("UNAVAILABLE");
               int var5 = var2.getConnectionType();
               switch (var5) {
                  case 1:
                     this.createPhoneProfiledEntry(var2.getPhone(), var3);
                     break;
                  case 2:
                     switch (var2.getFindBy()) {
                        case 0:
                           InetAddress var6 = null;

                           try {
                              var6 = InetAddress.getByName(var2.getIp());
                           } catch (UnknownHostException var10) {
                              assert false : "profiled entries have illegal values for IP field";

                              var10.printStackTrace();
                           }

                           this.createIPProfiledEntry(var6, var2.getPort(), var3);
                           break;
                        case 1:
                           try {
                              this.createNameProfiledEntry(var2.getName(), var3, true);
                           } catch (TooManyDevicesException var9) {
                           }
                           break;
                        case 2:
                           try {
                              this.createDNSProfiledEntry(var2.getDnsName(), var2.getPort(), var3, true);
                           } catch (TooManyDevicesException var8) {
                           }
                     }
               }
            }
         }
      }
   }

   public void refreshTree() {
      this.deviceBrowser.setDefaultDiscoveryPort(this.appPrefs.getBroadcastPort());
      this.deviceBrowser.refreshDevices(this.getDevicesNotToBeUpdated());
   }

   public void stopBroadcastAndUpdateDevices() {
      this.deviceBrowser.stopBroadcastAndUpdateDevices(this.getDevicesNotToBeUpdated());
   }

   public void startBroadcast() {
      this.deviceBrowser.setBroadcastEnabled();
   }

   private Set getDevicesNotToBeUpdated() {
      Map var1 = (Map)this.deviceListingMap.clone();
      Iterator var2 = var1.values().iterator();
      LinkedHashSet var3 = new LinkedHashSet();

      while (var2.hasNext()) {
         DeviceTreeController.DeviceDevInfoHolder var4 = (DeviceTreeController.DeviceDevInfoHolder)var2.next();
         if (var4.device.isConnected()) {
            Iterator var5 = var4.devInfos.iterator();

            while (var5.hasNext()) {
               var3.add(((DeviceInfoWrapper)var5.next()).getDeviceInfo());
            }
         }
      }

      return var3;
   }

   @Override
   public synchronized void propertyChange(PropertyChangeEvent var1) {
      if (!this.stopping) {
         String var2 = var1.getPropertyName();
         boolean var3 = false;
         boolean var4 = false;
         Device var5 = (Device)var1.getSource();
         if (this.deviceByIPTreePanel != null) {
            if ("DEVICE_PORTS_ADD".equals(var2)) {
               this.deviceByIPTreePanel.invokePopulatePorts(var5);
            } else if ("DEVICE_CONNECTION_LOST".equals(var2)) {
               this.deviceByIPTreePanel.removePorts(var5);
               var4 = true;
            } else if ("DEVICE_PORT_VIEW_ADD".equals(var2) || "DEVICE_PORT_VIEW_REMOVE".equals(var2)) {
               var4 = this.sortDeviceView(var5);
            } else if (!"DEVICE_STATE_CHANGED".equals(var2)) {
               if ("DEVICE_ACTIVATED".equals(var2)) {
                  if (this.sortType == SORT_TYPE_STATUS
                     && var5 instanceof Port
                     && ((Port)var5).getDeviceClass().equalsIgnoreCase("KVM")
                     && var5.getState().equalsIgnoreCase("CONNECTED")
                     && ((Port)var5).isActive()) {
                     this.sortCommand.getContext(true).setCommandParameter("sortMode", ((Port)var5).getDevice());
                     this.sortCommand.execute();
                     this.deviceByIPTreePanel.invokePopulatePorts(((Port)var5).getDevice());
                  }
               } else if ("DEVICE_SELECTED".equals(var2)) {
                  this.deviceByIPTreePanel.setSelectedDevice(var5);
               } else if ("DEVICE_DESELECTED".equals(var2)) {
                  this.deviceByIPTreePanel.deselectTree();
               } else if ("DEVICE_NAME_CHANGED".equals(var2)) {
                  if (var5 instanceof Port) {
                     this.sortDeviceView(var5);
                  }
               } else {
                  var3 = true;
               }
            } else {
               if (!(var5 instanceof Port)) {
                  Object var6 = var1.getOldValue();
                  Object var7 = var1.getNewValue();
                  if ("AVAILABLE".equals(var6) && "CONNECTED".equals(var7) || "CONNECTED".equals(var6) && "AVAILABLE".equals(var7)) {
                     this.deviceByIPTreePanel.setDeviceNodeChanged(var5);
                     var4 = true;
                  }

                  if ("AVAILABLE".equals(var7) && "CONNECTED".equals(var6)) {
                     this.updateDeviceOnDisconnect(var5);
                  }
               } else if (var5 instanceof Port) {
                  Object var8 = var1.getOldValue();
                  Object var9 = var1.getNewValue();
                  if ("AVAILABLE".equals(var8) && "UNAVAILABLE".equals(var9)
                     || "UNAVAILABLE".equals(var8) && "AVAILABLE".equals(var9)
                     || "UNAVAILABLE".equals(var8) && "CONNECTED".equals(var9)
                     || "CONNECTED".equals(var8) && "AVAILABLE".equals(var9)) {
                     var4 = this.sortDeviceView(var5);
                  }
               }

               var3 = true;
            }

            if (var3) {
               SwingUtilities.invokeLater(new Runnable() {
                  @Override
                  public void run() {
                     synchronized (DeviceTreeController.getInstance(DeviceTreeController.this.scrContext)) {
                        DeviceTreeController.this.deviceByIPTreePanel.repaint();
                     }
                  }
               });
            }

            if (var4) {
               SwingUtilities.invokeLater(new Runnable() {
                  @Override
                  public void run() {
                     synchronized (DeviceTreeController.getInstance(DeviceTreeController.this.scrContext)) {
                        DeviceTreeController.this.deviceByIPTreePanel.refreshTree();
                     }
                  }
               });
            }
         }
      }
   }

   private boolean sortDeviceView(Device var1) {
      if ((this.sortType == SORT_TYPE_STATUS || this.sortType == SORT_TYPE_NAME)
         && var1 instanceof Port
         && ((Port)var1).getDeviceClass().equalsIgnoreCase("KVM")) {
         this.sortCommand.getContext(true).setCommandParameter("sortMode", ((Port)var1).getDevice());
         this.sortCommand.execute();
         this.deviceByIPTreePanel.invokePopulatePorts(((Port)var1).getDevice());
         return false;
      } else {
         return true;
      }
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         Iterator var1 = this.observables.values().iterator();
         Observable var2 = null;

         while (var1.hasNext()) {
            var2 = (Observable)var1.next();
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (this.scrContext != null && this.deviceByIPTreePanel != null) {
         ArrayList var3 = (ArrayList)this.scrContext.getSelectedDevicesObservable().getComponent();
         if (var3 != null && var3.size() > 0) {
            final Device var4 = (Device)var3.get(0);
            if (SwingUtilities.isEventDispatchThread()) {
               this.deviceByIPTreePanel.setSelectedDevice(var4);
            } else {
               SwingUtilities.invokeLater(new Runnable() {
                  @Override
                  public void run() {
                     DeviceTreeController.this.deviceByIPTreePanel.setSelectedDevice(var4);
                  }
               });
            }
         }
      }
   }

   public void populateParagonPorts(Paragon var1) {
      this.deviceByIPTreePanel.invokePopulatePorts(var1);
   }

   public Browser getDeviceBrowser() {
      return this.deviceBrowser;
   }

   public void stop() {
      this.stopping = true;
      Map var1 = (Map)this.deviceListingMap.clone();

      for (DeviceTreeController.DeviceDevInfoHolder var3 : var1.values()) {
         if (var3.device.isConnected()) {
            var3.device.disconnect();
         }
      }
   }

   public void startBrowser() {
      if (this.scrContext.getApplicationProperty("connection") == null) {
         this.deviceBrowser.setScreenContext(this.scrContext);
         this.deviceBrowser.start();
      }
   }

   public synchronized void showWithoutTargets(boolean var1) {
      CommandCheckMenuItem var2 = this.scrContext.getMainScreenMediator().getCheckShowWithoutTargetsMenuItems().get(0);
      boolean var3 = var2.isSelected();
      this.deviceByIPTreePanel.setShowWithoutTargets(var3);
   }

   public synchronized void showWithoutGroups(boolean var1) {
      this.deviceByIPTreePanel.doGroup(var1);
   }

   public synchronized void showPowerstrips(boolean var1) {
      CommandCheckMenuItem var2 = this.scrContext.getMainScreenMediator().getCheckShowPowerstripsMenuItems().get(0);
      boolean var3 = var2.isSelected();
      this.deviceByIPTreePanel.setShowPowerstrips(var3);
   }

   public synchronized void showTools(boolean var1) {
      CommandCheckMenuItem var2 = this.scrContext.getMainScreenMediator().getCheckShowToolsMenuItems().get(0);
      boolean var3 = var2.isSelected();
      this.deviceByIPTreePanel.setShowTools(var3);
   }

   public void sort(int var1) {
      this.sortType = var1;
      this.deviceByIPTreePanel.doSort(this.sortType);
   }

   public void setSortType(int var1) {
      this.sortType = var1;
   }

   public void sort(Device var1) {
      if (var1.isConnected() && var1.hasChildren()) {
         var1.sort(this.sortType);
      }
   }

   public void showBold() {
      this.deviceByIPTreePanel.selNodeChanged();
   }

   public void treeNodeChanged(Device var1) {
      this.deviceByIPTreePanel.setDeviceNodeChanged(var1);
   }

   public boolean isProfileByPhoneExists(String var1) {
      return this.deviceListingModel.isProfileByPhoneExists(var1);
   }

   public boolean isProfileByIPExists(InetAddress var1) {
      return this.deviceListingModel.isProfileByIPExists(var1);
   }

   public boolean isProfileByNameExists(String var1) {
      return this.deviceListingModel.isProfileByNameExists(var1);
   }

   public boolean isProfileByDNSExists(String var1) {
      return this.deviceListingModel.isProfileByDNSExists(var1);
   }

   public void createPhoneProfiledEntry(String var1, IPReach var2) {
      var2.setProfiled(true);
      var2.setModemProfiled(true);
      this.deviceListingModel.addPhoneProfiledEntry(var1, var2);
   }

   public void createIPProfiledEntry(InetAddress var1, int var2, IPReach var3) {
      var3.setProfiled(true);
      var3.setModemProfiled(false);
      this.deviceListingModel.addIPProfiledEntry(var1, var2, var3);
   }

   public void createNameProfiledEntry(String var1, IPReach var2, boolean var3) throws TooManyDevicesException {
      var2.setProfiled(true);
      var2.setModemProfiled(false);
      this.deviceListingModel.addNameProfiledEntry(var1, var2, var3);
   }

   public void createDNSProfiledEntry(String var1, int var2, IPReach var3, boolean var4) throws TooManyDevicesException {
      var3.setProfiled(true);
      var3.setModemProfiled(false);
      this.deviceListingModel.addDNSProfiledEntry(var1, var2, var3, var4);
   }

   private void updateDeviceOnDisconnect(final Device var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            Map var1x = (Map)DeviceTreeController.this.deviceListingMap.clone();
            Iterator var2 = var1x.entrySet().iterator();
            String var3 = null;
            DeviceTreeController.DeviceDevInfoHolder var4 = null;

            while (var2.hasNext()) {
               Entry var5 = (Entry)var2.next();
               if (((DeviceTreeController.DeviceDevInfoHolder)var5.getValue()).device == var1) {
                  var3 = (String)var5.getKey();
                  var4 = (DeviceTreeController.DeviceDevInfoHolder)var5.getValue();
                  break;
               }
            }

            if (var3 != null) {
               assert var4 != null;

               if (DeviceTreeController.this.deviceByIPTreePanel.deleteDeviceIfAvailable(var3)) {
                  DeviceTreeController.populateDevice(var4.device, var4.devInfos);
                  DeviceTreeController.setPreferencesOnNonProfiledDevices(var4.device, var4.devInfos);
                  DeviceTreeController.this.deviceByIPTreePanel.addDevice(var3, var4.device);
               }
            }
         }
      });
   }

   private static void setPreferencesOnNonProfiledDevices(Device var0, Set<DeviceInfoWrapper> var1) {
      if (!var0.isProfiled()) {
         Object var2 = var1;
         if (var1.size() > 1) {
            var2 = new TreeSet(ipAddrComparator);
            var2.addAll(var1);
         }

         var0.setDevPrefs(null);
         Iterator var3 = var2.iterator();

         while (var3.hasNext()) {
            RRCDeviceInfo var4 = ((DeviceInfoWrapper)var3.next()).getDeviceInfo();
            DevicePreferences var5 = DevicePreferences.getNode(var4.getHost());
            if (var5 != null) {
               var0.setDevPrefs(var5);
               break;
            }
         }
      }
   }

   private static void populateDevice(Device var0, Set var1) {
      Object var2 = var1;
      ArrayList var3 = new ArrayList();
      if (var1.size() > 1) {
         var2 = new TreeSet(ipAddrComparator);
         var2.addAll(var1);
      }

      if (var0.isProfiled()) {
         DevicePreferences var4 = var0.getDevPrefs();
         Iterator var5 = var2.iterator();

         while (var5.hasNext()) {
            RRCDeviceInfo var6 = ((DeviceInfoWrapper)var5.next()).getDeviceInfo();
            if (var6.getPort() != var4.getPort()) {
               var2 = Collections.EMPTY_SET;
               break;
            }
         }
      }

      var0.setName("");
      var0.setDnsName(null);
      String var8 = null;
      Iterator var9 = var2.iterator();
      boolean var10 = true;

      while (var9.hasNext()) {
         RRCDeviceInfo var7 = ((DeviceInfoWrapper)var9.next()).getDeviceInfo();
         if (var10) {
            var0.setName(var7.getName());
            var0.setIPPort(var7.getPort());
            var8 = var7.getDnsName();
            var10 = false;
         } else if (var8 != null && !var8.equals(var7.getDnsName())) {
            var8 = null;
         }

         var3.add(var7.getInetAddress());
      }

      var0.setAddressList(var3);
      var0.setDnsName(var8);
      if (var2.size() > 0) {
         var0.setState("AVAILABLE");
      } else {
         var0.setState("UNAVAILABLE");
      }
   }

   private class DevListingModelListenerImpl implements DeviceListingModelListener {
      private DevListingModelListenerImpl() {
      }

      @Override
      public void createEntry(final String var1, Set var2) {
         Iterator var3 = var2.iterator();
         if (var3.hasNext()) {
            final IPReach var4 = new IPReach();
            DeviceTreeController.populateDevice(var4, var2);
            var4.setContext(DeviceTreeController.this.scrContext);
            DeviceTreeController.setPreferencesOnNonProfiledDevices(var4, var2);
            DeviceTreeController.this.deviceListingMap.put(var1, new DeviceTreeController.DeviceDevInfoHolder(var4, var2));
            DeviceTreeController.this.prepareDevice(var4);
            SwingUtilities.invokeLater(new Runnable() {
               @Override
               public void run() {
                  DeviceTreeController.this.deviceByIPTreePanel.addDevice(var1, var4);
               }
            });
         }
      }

      @Override
      public void createProfiledEntry(final String var1, Set var2, Object var3) {
         final IPReach var4 = (IPReach)var3;
         DeviceTreeController.populateDevice(var4, var2);
         var4.setContext(DeviceTreeController.this.scrContext);
         DeviceTreeController.this.deviceListingMap.put(var1, new DeviceTreeController.DeviceDevInfoHolder(var4, var2));
         DeviceTreeController.this.prepareDevice(var4);
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               DeviceTreeController.this.deviceByIPTreePanel.addDevice(var1, var4);
            }
         });
      }

      @Override
      public void deleteEntry(final String var1) {
         final DeviceTreeController.DeviceDevInfoHolder var2 = (DeviceTreeController.DeviceDevInfoHolder)DeviceTreeController.this.deviceListingMap
            .remove(var1);

         assert var2 != null;

         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               if (!var2.device.isProfiled() && var2.device.isConnected()) {
                  var2.device.disconnect();
               }

               DeviceTreeController.this.deviceByIPTreePanel.deleteDevice(var1);
            }
         });
      }

      @Override
      public void updateEntry(final String var1, final Set var2) {
         final DeviceTreeController.DeviceDevInfoHolder var3 = (DeviceTreeController.DeviceDevInfoHolder)DeviceTreeController.this.deviceListingMap.get(var1);
         if (var3.device.isConnected()) {
            DeviceTreeController.this.deviceListingMap.put(var1, new DeviceTreeController.DeviceDevInfoHolder(var3.device, var2));
         } else {
            Object var4 = DeviceTreeController.this.deviceListingMap.remove(var1);

            assert var4 != null;

            SwingUtilities.invokeLater(new Runnable() {
               @Override
               public void run() {
                  DeviceTreeController.this.deviceByIPTreePanel.deleteDevice(var1);
                  DeviceTreeController.populateDevice(var3.device, var2);
                  DeviceTreeController.setPreferencesOnNonProfiledDevices(var3.device, var2);
               }
            });
            DeviceTreeController.this.deviceListingMap.put(var1, new DeviceTreeController.DeviceDevInfoHolder(var3.device, var2));
            SwingUtilities.invokeLater(new Runnable() {
               @Override
               public void run() {
                  DeviceTreeController.this.deviceByIPTreePanel.addDevice(var1, var3.device);
               }
            });
         }
      }
   }

   private static class DeviceDevInfoHolder {
      private final Device device;
      private final Set devInfos;

      public DeviceDevInfoHolder(Device var1, Set var2) {
         this.device = var1;
         this.devInfos = var2;
      }
   }

   private static class IPAddrComparator implements Comparator {
      private IPAddrComparator() {
      }

      @Override
      public int compare(Object var1, Object var2) {
         return ((DeviceInfoWrapper)var1).getDeviceInfo().getInetAddress() instanceof Inet6Address ? -1 : 1;
      }
   }
}
