package com.raritan.rrc.ui.models;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DevicePreferences;
import java.net.InetAddress;
import java.util.Iterator;
import java.util.List;

public class DeviceDisplayLabelExtractor {
   private final int type;
   private final String unknown;
   private final String devLabel;
   private final String ipLabel;
   private final String hostLabel;
   private final String scanLabel;
   public static final int VIEWBY_NAME = 0;
   public static final int VIEWBY_IP = 1;
   public static final int VIEWBY_DNS = 2;
   public static final int VIEWBY_SCAN = 3;

   public DeviceDisplayLabelExtractor(int var1, String var2, String var3, String var4, String var5, String var6) {
      this.type = var1;
      this.unknown = var2;
      this.devLabel = var3;
      this.ipLabel = var4;
      this.hostLabel = var5;
      this.scanLabel = var6;
   }

   public Object[] getDisplayComponents(Device var1) {
      Object[] var2 = new Object[2];
      switch (this.type) {
         case 0:
            if (var1.isProfiled()) {
               DevicePreferences var7 = var1.getDevPrefs();
               if (var1.isModemProfiled()) {
                  var2[0] = var7.getDescription();
                  var2[1] = var7.getPhone();
               } else {
                  if (var7.getFindBy() == 1) {
                     var2[0] = var7.getName();
                  } else {
                     var2[0] = var1.getName();
                     if (var2[0] == null || "".equals(var2[0])) {
                        var2[0] = this.unknown;
                     }
                  }

                  var2[1] = var7.getDescription();
               }
            } else {
               var2[0] = var1.getName();
               var2[1] = var1.getAddressList().get(0);
            }
            break;
         case 1:
            if (var1.isProfiled()) {
               DevicePreferences var6 = var1.getDevPrefs();
               if (var1.isModemProfiled()) {
                  var2[0] = var6.getPhone();
                  var2[1] = var6.getDescription();
               } else {
                  if (var6.getFindBy() == 0) {
                     var2[0] = var6.getInetAddess();
                  } else {
                     List var4 = var1.getAddressList();
                     if (var4.size() > 0) {
                        var2[0] = var4.get(0);
                     } else {
                        var2[0] = this.unknown;
                     }
                  }

                  var2[1] = var6.getDescription();
               }
            } else {
               var2[0] = var1.getAddressList().get(0);
               var2[1] = var1.getName();
            }
            break;
         case 2:
            if (var1.isProfiled()) {
               DevicePreferences var5 = var1.getDevPrefs();
               if (var1.isModemProfiled()) {
                  var2[0] = this.unknown;
                  var2[1] = var5.getDescription();
               } else {
                  if (var5.getFindBy() == 2) {
                     var2[0] = var5.getDnsName();
                  } else {
                     var2[0] = var1.getDnsName();
                     if (var2[0] == null) {
                        var2[0] = this.unknown;
                     }
                  }

                  var2[1] = var5.getDescription();
               }
            } else {
               var2[0] = var1.getDnsName();
               if (var2[0] == null) {
                  var2[0] = this.unknown;
               }

               var2[1] = var1.getAddressList().get(0);
            }
            break;
         case 3:
            if (var1 != null) {
               if (var1.isProfiled()) {
                  DevicePreferences var3 = var1.getDevPrefs();
                  if (var1.isModemProfiled()) {
                     var2[0] = var3.getDescription();
                     var2[1] = var3.getPhone();
                  } else {
                     if (var3.getFindBy() == 1) {
                        var2[0] = var3.getName();
                     } else {
                        var2[0] = var1.getName();
                        if (var2[0] == null || "".equals(var2[0])) {
                           var2[0] = this.unknown;
                        }
                     }

                     var2[1] = var3.getDescription();
                  }
               } else {
                  var2[0] = var1.getName();
                  var2[1] = var1.getAddressList().get(0);
               }
            }
      }

      return var2;
   }

   public String getDisplayLabel(Device var1) {
      Object[] var2 = this.getDisplayComponents(var1);

      for (int var3 = 0; var3 < var2.length; var3++) {
         if (var2[var3] instanceof InetAddress) {
            var2[var3] = ((InetAddress)var2[var3]).getHostAddress();
         }
      }

      switch (this.type) {
         case 0:
         case 3:
            if (!var1.isProfiled() || var1.isModemProfiled()) {
               return var2[0] + " [" + var2[1] + "] ";
            }
         case 1:
         case 2:
            return " [" + var2[0] + "] " + var2[1];
         default:
            assert false;

            return null;
      }
   }

   public String getToolTip(Device var1) {
      String var2 = null;
      String var3 = null;
      String var4 = null;
      DevicePreferences var5 = var1.getDevPrefs();
      if (var1.isProfiled()) {
         if (var1.isModemProfiled()) {
            return "";
         }

         if (var5.getFindBy() == 1) {
            var3 = var5.getName();
         } else if (var5.getFindBy() == 0) {
            var2 = "<br>&nbsp;&nbsp;&nbsp;&nbsp;" + var5.getIp();
         } else if (var5.getFindBy() == 2) {
            var4 = var5.getDnsName();
         }
      }

      String var6 = "<html><font>";
      if (var3 == null) {
         var3 = var1.getName();
      }

      boolean var7 = false;
      if (var3 != null && !"".equals(var3)) {
         var6 = var6 + "<b>" + this.devLabel + " </b>" + var3;
         var7 = true;
      }

      if (var2 == null) {
         List var8 = var1.getAddressList();
         if (var8.size() > 0) {
            var2 = "";
         }

         Iterator var9 = var8.iterator();

         while (var9.hasNext()) {
            var2 = var2 + "<br>&nbsp;&nbsp;&nbsp;&nbsp;" + ((InetAddress)var9.next()).getHostAddress();
         }
      }

      if (var2 != null) {
         if (var7) {
            var6 = var6 + "<br>";
         }

         var6 = var6 + "<b>" + this.ipLabel + " </b>" + var2;
      }

      if (var4 == null) {
         var4 = var1.getDnsName();
      }

      if (var4 != null) {
         if (var7 || var2 != null) {
            var6 = var6 + "<br>";
         }

         var6 = var6 + "<b>" + this.hostLabel + " </b>" + var4;
      }

      return var6;
   }
}
