package com.raritan.rrc.ui.models;

import com.raritan.protocol.browser.Browser;
import com.raritan.protocol.browser.BrowserEvent;
import com.raritan.protocol.browser.BrowserEventHandler;
import com.raritan.protocol.browser.TooManyDevicesException;
import com.raritan.protocol.browser.spi.HintAddressEx;
import com.raritan.protocol.csc.RRCDeviceInfo;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Set;

public class DeviceListingModel {
   private final HashMap ipToDeviceInfo = new HashMap();
   private final HashMap listingMap = new HashMap();
   private final Browser browser;
   private final ArrayList listeners = new ArrayList();
   private final DeviceListingModel.NameDeviceInfoHandler nameHandler;
   private final DeviceListingModel.DiscoveredDeviceInfoHandler discoveredHandler;
   private final DeviceListingModel.DNSDeviceInfoHandler dnsHandler;
   private final DeviceListingModel.IDDeviceInfoHandler idHandler;

   public DeviceListingModel(Browser var1) {
      this.browser = var1;
      this.nameHandler = new DeviceListingModel.NameDeviceInfoHandler();
      this.discoveredHandler = new DeviceListingModel.DiscoveredDeviceInfoHandler();
      this.dnsHandler = new DeviceListingModel.DNSDeviceInfoHandler();
      this.idHandler = new DeviceListingModel.IDDeviceInfoHandler();
   }

   public void init() {
      this.browser.addHandler(new DeviceListingModel.ListingModelBrowserEventHanlder());
   }

   public synchronized boolean addIPProfiledEntry(InetAddress var1, int var2, Object var3) {
      if (!this.isProfileByIPExists(var1)) {
         String var4 = getIPProfiledKey(var1);
         if (this.ipToDeviceInfo.containsKey(var1)) {
            RRCDeviceInfo var5 = (RRCDeviceInfo)this.ipToDeviceInfo.get(var1);
            String var6 = var5.getDeviceID();
            String var7;
            if ("".equals(var6)) {
               var7 = getIPDiscoveredKey(var5);
            } else {
               var7 = getIDDiscoveredKey(var5);
            }

            if (this.listingMap.containsKey(var7)) {
               this.discoveredHandler.removeID(var5);
            }

            this.notifyCreateProfiledEntry(var4, var5, var3);
            return true;
         } else {
            try {
               this.browser.addHintAddress(new HintAddressEx(var1.getHostAddress(), var2));
            } catch (UnknownHostException var8) {
            }

            this.notifyCreateProfiledEntry(var4, var3);
            return true;
         }
      } else {
         return false;
      }
   }

   public synchronized boolean removeIPProfiledEntry(InetAddress var1, int var2) {
      if (this.isProfileByIPExists(var1)) {
         this.browser.removeHintAddress(new HintAddressEx(var1.getHostAddress(), var2));
         String var3 = getIPProfiledKey(var1);
         this.notifyDeleteEntry(var3);
         RRCDeviceInfo var4 = (RRCDeviceInfo)this.ipToDeviceInfo.get(var1);
         if (var4 != null) {
            this.addDiscoveredDevice(var4);
         }

         return true;
      } else {
         return false;
      }
   }

   public synchronized boolean isProfileByIPExists(InetAddress var1) {
      String var2 = getIPProfiledKey(var1);
      return this.listingMap.containsKey(var2);
   }

   public synchronized boolean isProfileByDNSExists(String var1) {
      String var2 = getDNSProfiledKey(var1);
      return this.listingMap.containsKey(var2);
   }

   public synchronized boolean addDNSProfiledEntry(String var1, int var2, Object var3, boolean var4) throws TooManyDevicesException {
      assert var1 != null;

      if (!this.isProfileByDNSExists(var1)) {
         String var5 = getDNSProfiledKey(var1);
         Set var6 = this.dnsHandler.getDevInfoSet(var1);
         if (var6 == null || var6.size() <= 0) {
            this.browser.addDNSHint(var1, var2);
            this.notifyCreateProfiledEntry(var5, var3);
            return true;
         }

         if (!this.dnsHandler.isUniqueDNS(var1)) {
            if (!var4) {
               throw new TooManyDevicesException(var1, "More than one device with same dnsname " + var1, null);
            }

            this.removeAllDiscoveredEntries(var6);
            this.notifyCreateProfiledEntry(var5, var3);
            return true;
         }

         Iterator var7 = var6.iterator();
         if (var7.hasNext()) {
            RRCDeviceInfo var8 = ((DeviceInfoWrapper)var7.next()).getDeviceInfo();
            String var9 = var8.getDeviceID();
            String var10;
            Set var11;
            if ("".equals(var9)) {
               var10 = getIPDiscoveredKey(var8);
               var11 = var6;
            } else {
               var10 = getIDDiscoveredKey(var8);
               var11 = this.idHandler.getDevInfoSet(var9, var1);

               assert var11.size() > 0;
            }

            if (this.listingMap.containsKey(var10)) {
               Iterator var12 = var11.iterator();

               while (var12.hasNext() && this.listingMap.containsKey(var10)) {
                  this.discoveredHandler.removeID(((DeviceInfoWrapper)var12.next()).getDeviceInfo());
               }
            }

            this.notifyCreateProfiledEntry(var5, new LinkedHashSet(var11), var3);
            return true;
         }
      }

      return false;
   }

   public synchronized boolean removeDNSProfiledEntry(String var1, int var2) {
      if (this.isProfileByDNSExists(var1)) {
         this.browser.removeDNSHint(var1);
         String var3 = getDNSProfiledKey(var1);
         this.notifyDeleteEntry(var3);
         Set var4 = this.dnsHandler.getDevInfoSet(var1);
         if (var4 != null && var4.size() > 0) {
            this.addDiscoveredDevice(var4);
         }

         return true;
      } else {
         return false;
      }
   }

   public synchronized boolean isProfileByNameExists(String var1) {
      String var2 = getNameProfiledKey(var1);
      return this.listingMap.containsKey(var2);
   }

   public synchronized boolean addNameProfiledEntry(String var1, Object var2, boolean var3) throws TooManyDevicesException {
      if (!this.isProfileByNameExists(var1)) {
         String var4 = getNameProfiledKey(var1);
         Set var5 = this.nameHandler.getDevInfoSet(var1);
         if (var5 == null || var5.size() <= 0) {
            this.notifyCreateProfiledEntry(var4, var2);
            return true;
         }

         if (!this.nameHandler.isUniqueName(var1)) {
            if (!var3) {
               throw new TooManyDevicesException(var1, "More than one device with name " + var1, null);
            }

            this.removeAllDiscoveredEntries(var5);
            this.notifyCreateProfiledEntry(var4, var2);
            return true;
         }

         Iterator var6 = var5.iterator();
         if (var6.hasNext()) {
            RRCDeviceInfo var7 = ((DeviceInfoWrapper)var6.next()).getDeviceInfo();
            String var8 = var7.getDeviceID();
            String var9;
            if ("".equals(var8)) {
               var9 = getIPDiscoveredKey(var7);
            } else {
               var9 = getIDDiscoveredKey(var7);
            }

            if (this.listingMap.containsKey(var9)) {
               Iterator var10 = var5.iterator();

               while (var10.hasNext() && this.listingMap.containsKey(var9)) {
                  this.discoveredHandler.removeID(((DeviceInfoWrapper)var10.next()).getDeviceInfo());
               }
            }

            this.notifyCreateProfiledEntry(var4, new LinkedHashSet(var5), var2);
            return true;
         }
      }

      return false;
   }

   public synchronized boolean removeNameProfiledEntry(String var1) {
      if (this.isProfileByNameExists(var1)) {
         String var2 = getNameProfiledKey(var1);
         this.notifyDeleteEntry(var2);
         Set var3 = this.nameHandler.getDevInfoSet(var1);
         if (var3 != null && var3.size() > 0) {
            this.addDiscoveredDevice(var3);
         }

         return true;
      } else {
         return false;
      }
   }

   private void removeAllDiscoveredEntries(Set var1) {
      Iterator var2 = var1.iterator();

      while (var2.hasNext()) {
         RRCDeviceInfo var3 = ((DeviceInfoWrapper)var2.next()).getDeviceInfo();
         String var4 = var3.getDeviceID();
         String var5;
         if ("".equals(var4)) {
            var5 = getIPDiscoveredKey(var3);
         } else {
            var5 = getIDDiscoveredKey(var3);
         }

         if (this.listingMap.containsKey(var5)) {
            this.discoveredHandler.removeID(var3);
         }
      }
   }

   public synchronized Set getDeviceInfoWrappersForDeviceName(String var1) throws TooManyDevicesException {
      Set var2 = this.nameHandler.getDevInfoSet(var1);
      if (var2 == null || var2.size() <= 0) {
         return Collections.EMPTY_SET;
      } else if (this.nameHandler.isUniqueName(var1)) {
         return new LinkedHashSet(var2);
      } else {
         throw new TooManyDevicesException(var1, "More than one device with name " + var1, null);
      }
   }

   public synchronized boolean addPhoneProfiledEntry(String var1, Object var2) {
      if (!this.isProfileByPhoneExists(var1)) {
         String var3 = getPhoneProfiledKey(var1);
         this.notifyCreateProfiledEntry(var3, var2);
         return true;
      } else {
         return false;
      }
   }

   public synchronized boolean removePhoneProfiledEntry(String var1) {
      String var2 = getPhoneProfiledKey(var1);
      Object var3 = this.listingMap.remove(var2);
      if (var3 != null) {
         this.notifyDeleteEntry(var2);
         return true;
      } else {
         return false;
      }
   }

   public synchronized boolean isProfileByPhoneExists(String var1) {
      String var2 = getPhoneProfiledKey(var1);
      return this.listingMap.containsKey(var2);
   }

   private boolean addDiscoveredDevice(Set var1) {
      Iterator var2 = var1.iterator();
      boolean var3 = false;

      while (var2.hasNext()) {
         var3 |= this.addDiscoveredDevice(((DeviceInfoWrapper)var2.next()).getDeviceInfo());
      }

      return var3;
   }

   private boolean addDiscoveredDevice(RRCDeviceInfo var1) {
      if (!this.isProfileExists(var1)) {
         this.discoveredHandler.addID(var1);
      }

      return false;
   }

   private boolean isProfileExists(RRCDeviceInfo var1) {
      boolean var2 = this.isProfileByIPExists(var1.getInetAddress());
      if (!var2) {
         var2 = this.isProfileByNameExists(var1.getName());
         String var3 = var1.getDnsName();
         if (!var2 && null != var3) {
            var2 = this.isProfileByDNSExists(var3);
         }
      }

      return var2;
   }

   public boolean addDeviceListingModelListener(DeviceListingModelListener var1) {
      if (!this.listeners.contains(var1)) {
         this.listeners.add(var1);
         return true;
      } else {
         return false;
      }
   }

   public boolean removeDeviceListingModelListener(DeviceListingModelListener var1) {
      return this.listeners.remove(var1);
   }

   static String getIPProfiledKey(RRCDeviceInfo var0) {
      return getIPProfiledKey(var0.getInetAddress());
   }

   static String getIPProfiledKey(InetAddress var0) {
      return "prof_ip_" + var0.getHostAddress();
   }

   static String getNameProfiledKey(RRCDeviceInfo var0) {
      return getNameProfiledKey(var0.getName());
   }

   static String getNameProfiledKey(String var0) {
      return "prof_name_" + var0.toLowerCase();
   }

   static String getDNSProfiledKey(RRCDeviceInfo var0) {
      return getDNSProfiledKey(var0.getDnsName());
   }

   static String getDNSProfiledKey(String var0) {
      assert var0 != null;

      return "prof_dns_" + var0.toLowerCase();
   }

   static String getIDDiscoveredKey(RRCDeviceInfo var0) {
      return getIDDiscoveredKey(var0.getDeviceID());
   }

   static String getIDDiscoveredKey(String var0) {
      return "disc_id_" + var0;
   }

   static String getIPDiscoveredKey(RRCDeviceInfo var0) {
      return getIPDiscoveredKey(var0.getInetAddress().getHostAddress());
   }

   static String getIPDiscoveredKey(String var0) {
      return "disc_ip_" + var0;
   }

   static String getPhoneProfiledKey(String var0) {
      return "prof_phone_" + var0;
   }

   private synchronized void onAddPingDevice(RRCDeviceInfo var1) {
      RRCDeviceInfo var2 = this.ipToDeviceInfo.put(var1.getInetAddress(), var1);
      boolean var3 = var2 == null;
      if (var3) {
         this.idHandler.addID(var1);
         boolean var4 = false;
         var4 = this.notifyProfUpdateEntry(getIPProfiledKey(var1), var1);
         var4 |= this.listingMap.get(getNameProfiledKey(var1)) != null;
         this.nameHandler.addName(var1);
         if (null != var1.getDnsName()) {
            var4 |= this.listingMap.get(getDNSProfiledKey(var1)) != null;
            this.dnsHandler.addDNS(var1);
         }

         if (!var4) {
            this.discoveredHandler.addID(var1);
         }
      } else if (isNameOrDnsChanged(var2, var1)) {
         this.idHandler.update(var1);
         boolean var8 = false;
         var8 = this.notifyProfUpdateEntry(getIPProfiledKey(var1), var1);
         var8 |= this.listingMap.get(getNameProfiledKey(var1)) != null;
         this.nameHandler.updateName(var2, var1);
         if (null != var1.getDnsName()) {
            var8 |= this.listingMap.get(getDNSProfiledKey(var1)) != null;
            this.dnsHandler.updateDNS(var2, var1);
         }

         if (!var8) {
            boolean var5 = this.listingMap.get(getIPProfiledKey(var2)) != null
               || this.listingMap.get(getNameProfiledKey(var2)) != null
               || null != var2.getDnsName() && this.listingMap.get(getDNSProfiledKey(var2)) != null;
            if (var5) {
               this.discoveredHandler.addID(var1);
            } else {
               this.discoveredHandler.update(var2, var1);
            }
         }
      }
   }

   public static boolean isNameOrDnsChanged(RRCDeviceInfo var0, RRCDeviceInfo var1) {
      boolean var2 = !var0.getName().equals(var1.getName());
      String var3 = var0.getDnsName();
      String var4 = var1.getDnsName();
      boolean var5 = var4 != null ? var4.equals(var3) : var3 == null;
      boolean var6 = !var5;
      return var2 || var6;
   }

   private synchronized void onDeleteDevice(RRCDeviceInfo var1) {
      this.ipToDeviceInfo.remove(var1.getInetAddress());
      this.idHandler.removeID(var1);
      boolean var2 = false;
      var2 = this.notifyProfUpdateEntry(getIPProfiledKey(var1));
      var2 |= this.listingMap.get(getNameProfiledKey(var1)) != null;
      this.nameHandler.removeName(var1);
      if (null != var1.getDnsName()) {
         var2 |= this.listingMap.get(getDNSProfiledKey(var1)) != null;
         this.dnsHandler.removeDNS(var1);
      }

      if (!var2) {
         this.discoveredHandler.removeID(var1);
      }
   }

   private boolean notifyProfUpdateEntry(String var1) {
      return this.notifyProfUpdateEntry(var1, Collections.EMPTY_SET);
   }

   private boolean notifyProfUpdateEntry(String var1, RRCDeviceInfo var2) {
      LinkedHashSet var3 = new LinkedHashSet();
      var3.add(new DeviceInfoWrapper(var2));
      return this.notifyProfUpdateEntry(var1, var3);
   }

   private boolean notifyProfUpdateEntry(String var1, Set var2) {
      Object var3 = this.listingMap.get(var1);
      if (var3 != null) {
         this.notifyUpdateEntry(var1, var2);
         return true;
      } else {
         return false;
      }
   }

   private void notifyCreateEntry(String var1, RRCDeviceInfo var2) {
      LinkedHashSet var3 = new LinkedHashSet();
      var3.add(new DeviceInfoWrapper(var2));
      this.notifyCreateEntry(var1, var3);
   }

   private void notifyCreateEntry(String var1, Set var2) {
      this.listingMap.put(var1, var2);

      for (DeviceListingModelListener var4 : this.listeners) {
         var4.createEntry(var1, var2);
      }
   }

   private void notifyCreateProfiledEntry(String var1, RRCDeviceInfo var2, Object var3) {
      LinkedHashSet var4 = new LinkedHashSet();
      var4.add(new DeviceInfoWrapper(var2));
      this.notifyCreateProfiledEntry(var1, var4, var3);
   }

   private void notifyCreateProfiledEntry(String var1, Set var2, Object var3) {
      this.listingMap.put(var1, var1);

      for (DeviceListingModelListener var5 : this.listeners) {
         var5.createProfiledEntry(var1, var2, var3);
      }
   }

   private void notifyCreateProfiledEntry(String var1, Object var2) {
      this.notifyCreateProfiledEntry(var1, Collections.EMPTY_SET, var2);
   }

   private void notifyDeleteEntry(String var1) {
      this.listingMap.remove(var1);

      for (DeviceListingModelListener var3 : this.listeners) {
         var3.deleteEntry(var1);
      }
   }

   private void notifyUpdateEntry(String var1, Set var2) {
      for (DeviceListingModelListener var4 : this.listeners) {
         var4.updateEntry(var1, var2);
      }
   }

   private class DNSDeviceInfoHandler {
      private DeviceListingModel.NameDeviceInfoHandler dnsNameHandler = DeviceListingModel.this.new NameDeviceInfoHandler();

      private DNSDeviceInfoHandler() {
      }

      public void addDNS(RRCDeviceInfo var1) {
         if (null != var1.getDnsName()) {
            this.dnsNameHandler.addName(var1, var1.getDnsName(), DeviceListingModel.getDNSProfiledKey(var1));
         }
      }

      public void removeDNS(RRCDeviceInfo var1) {
         if (null != var1.getDnsName()) {
            this.dnsNameHandler.removeName(var1, var1.getDnsName(), DeviceListingModel.getDNSProfiledKey(var1));
         }
      }

      public boolean isUniqueDNS(String var1) {
         return this.dnsNameHandler.isUniqueName(var1);
      }

      public Set getDevInfoSet(String var1) {
         return this.dnsNameHandler.getDevInfoSet(var1);
      }

      public void updateDNS(RRCDeviceInfo var1, RRCDeviceInfo var2) {
         this.removeDNS(var1);
         this.addDNS(var2);
      }
   }

   private class DiscoveredDeviceInfoHandler {
      private HashMap idToDevInfo = new HashMap();

      private DiscoveredDeviceInfoHandler() {
      }

      public void addID(RRCDeviceInfo var1) {
         String var2 = var1.getDeviceID();
         if ("".equals(var2)) {
            DeviceListingModel.this.notifyCreateEntry(DeviceListingModel.getIPDiscoveredKey(var1), var1);
         } else {
            Object var3 = (Set)this.idToDevInfo.get(var2);
            if (var3 == null) {
               var3 = new LinkedHashSet();
               this.idToDevInfo.put(var2, var3);
            }

            if (var3.size() == 0) {
               var3.add(new DeviceInfoWrapper(var1));
               DeviceListingModel.this.notifyCreateEntry(DeviceListingModel.getIDDiscoveredKey(var1), var1);
            } else {
               boolean var4 = var3.add(new DeviceInfoWrapper(var1));

               assert var4;

               DeviceListingModel.this.notifyUpdateEntry(DeviceListingModel.getIDDiscoveredKey(var1), new LinkedHashSet((Collection)var3));
            }
         }
      }

      public void removeID(RRCDeviceInfo var1) {
         String var2 = var1.getDeviceID();
         if ("".equals(var2)) {
            DeviceListingModel.this.notifyDeleteEntry(DeviceListingModel.getIPDiscoveredKey(var1));
         } else {
            Set var3 = (Set)this.idToDevInfo.get(var2);

            assert var3 != null;

            boolean var4 = var3.remove(new DeviceInfoWrapper(var1));
            if (var3.size() == 0) {
               this.idToDevInfo.remove(var2);
               DeviceListingModel.this.notifyDeleteEntry(DeviceListingModel.getIDDiscoveredKey(var1));
            } else {
               DeviceListingModel.this.notifyUpdateEntry(DeviceListingModel.getIDDiscoveredKey(var1), new LinkedHashSet(var3));
            }
         }
      }

      public void update(RRCDeviceInfo var1, RRCDeviceInfo var2) {
         this.removeID(var1);
         this.addID(var2);
      }

      public Set getDevInfoSet(String var1) {
         return (Set)this.idToDevInfo.get(var1);
      }
   }

   private static class IDDeviceInfoHandler {
      private HashMap idToDevInfo = new HashMap();

      private IDDeviceInfoHandler() {
      }

      public void addID(RRCDeviceInfo var1) {
         String var2 = var1.getDeviceID();
         if (!"".equals(var2)) {
            Object var3 = (Set)this.idToDevInfo.get(var2);
            if (var3 == null) {
               var3 = new LinkedHashSet();
               this.idToDevInfo.put(var2, var3);
            }

            boolean var4 = var3.add(new DeviceInfoWrapper(var1));

            assert var4;
         }
      }

      public void removeID(RRCDeviceInfo var1) {
         String var2 = var1.getDeviceID();
         if (!"".equals(var2)) {
            Set var3 = (Set)this.idToDevInfo.get(var2);

            assert var3 != null;

            boolean var4 = var3.remove(new DeviceInfoWrapper(var1));

            assert var4;
         }
      }

      public void update(RRCDeviceInfo var1) {
         this.removeID(var1);
         this.addID(var1);
      }

      public Set getDevInfoSet(String var1, String var2) {
         LinkedHashSet var3 = new LinkedHashSet();
         Set var4 = (Set)this.idToDevInfo.get(var1);

         assert var4 != null;

         for (DeviceInfoWrapper var6 : var4) {
            if (var2.equalsIgnoreCase(var6.getDeviceInfo().getDnsName())) {
               boolean var7 = var3.add(var6);

               assert var7;
            }
         }

         return var3;
      }
   }

   private class ListingModelBrowserEventHanlder implements BrowserEventHandler {
      private ListingModelBrowserEventHanlder() {
      }

      @Override
      public void notify(Browser var1, BrowserEvent var2) {
         RRCDeviceInfo var3 = var2.getDeviceInfo();
         switch (var2.getType()) {
            case 1:
            case 3:
               DeviceListingModel.this.onAddPingDevice(var3);
               break;
            case 2:
               DeviceListingModel.this.onDeleteDevice(var3);
         }
      }
   }

   private class NameDeviceInfoHandler {
      private HashMap nameToDevInfo = new HashMap();

      private NameDeviceInfoHandler() {
      }

      public void addName(RRCDeviceInfo var1) {
         this.addName(var1, var1.getName(), DeviceListingModel.getNameProfiledKey(var1));
      }

      public void addName(RRCDeviceInfo var1, String var2, String var3) {
         String var4 = var2.toLowerCase();
         Object var5 = (Set)this.nameToDevInfo.get(var4);
         if (var5 == null) {
            var5 = new LinkedHashSet();
            this.nameToDevInfo.put(var4, var5);
         }

         boolean var6 = var5.add(new DeviceInfoWrapper(var1));

         assert var6;

         if (this.isUniqueName(var4)) {
            DeviceListingModel.this.notifyProfUpdateEntry(var3, new LinkedHashSet((Collection)var5));
         } else {
            DeviceListingModel.this.notifyProfUpdateEntry(var3, Collections.EMPTY_SET);
         }
      }

      public void removeName(RRCDeviceInfo var1) {
         this.removeName(var1, var1.getName(), DeviceListingModel.getNameProfiledKey(var1));
      }

      public void removeName(RRCDeviceInfo var1, String var2, String var3) {
         String var4 = var2.toLowerCase();
         Set var5 = (Set)this.nameToDevInfo.get(var4);
         boolean var6 = this.isUniqueName(var4);
         boolean var7 = var5.remove(new DeviceInfoWrapper(var1));

         assert var7;

         boolean var8 = this.isUniqueName(var4);
         if (var6 && var8) {
            DeviceListingModel.this.notifyProfUpdateEntry(var3, new LinkedHashSet(var5));
         } else if (!var6 && var8) {
            DeviceListingModel.this.notifyProfUpdateEntry(var3, new LinkedHashSet(var5));
         }
      }

      public void updateName(RRCDeviceInfo var1, RRCDeviceInfo var2) {
         this.removeName(var1);
         this.addName(var2);
      }

      public boolean isUniqueName(String var1) {
         String var2 = var1.toLowerCase();
         Set var3 = (Set)this.nameToDevInfo.get(var2);
         if (var3 != null && var3.size() > 0) {
            if (var3.size() == 1) {
               return true;
            }

            Iterator var4 = var3.iterator();
            if (var4.hasNext()) {
               RRCDeviceInfo var5 = ((DeviceInfoWrapper)var4.next()).getDeviceInfo();
               String var6 = var5.getDeviceID();
               if ("".equals(var6)) {
                  return false;
               }

               while (var4.hasNext()) {
                  RRCDeviceInfo var7 = ((DeviceInfoWrapper)var4.next()).getDeviceInfo();
                  if (!var6.equals(var7.getDeviceID())) {
                     return false;
                  }
               }
            }
         }

         return true;
      }

      public Set getDevInfoSet(String var1) {
         String var2 = var1.toLowerCase();
         return (Set)this.nameToDevInfo.get(var2);
      }
   }
}
