package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.BladeChassis;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.Paragon;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.OKButtonCommand;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.util.Util;
import java.applet.AppletContext;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.Point;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.Map;
import javaclientlib.utils.RRCLogger;
import javax.swing.JButton;
import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;
import javax.swing.event.HyperlinkEvent.EventType;
import javax.swing.text.html.HTMLDocument;
import nn.pp.common.ClipboardHandler;
import nn.pp.common.CommonFunctions;
import nn.pp.common.KXHttpConnection;
import nn.pp.common.ResourceLoader;
import nn.pp.common.ui.helpers.AboutSwingWorker;
import nn.pp.common.ui.helpers.ICopyrightHandler;
import nn.pp.core.JVMVersionInfo;

public class AboutPanel extends AbstractDisplay implements ICopyrightHandler {
   private static final long serialVersionUID = -5187897952459950462L;
   private static final int LICENSE_DIALOG_BORDER_SIZE = 10;
   private static final double LICENSE_DIALOG_PROPORTIONAL_SIZE = 0.8;
   private AboutSwingWorker worker = null;
   private KXHttpConnection conn = null;
   private String baseCopyright = null;
   private JPanel copyrightData = null;
   private JEditorPane licPane = null;
   private JEditorPane pkgPane = null;
   private JEditorPane copyright = null;
   private JScrollPane licJsp = null;
   private JScrollPane pkgJsp = null;
   private JScrollPane copyrightJsp = null;

   public AboutPanel(boolean var1, ScreenContext var2, boolean var3) {
      super(var2);
      this.isDialog = var1;
      this.isNewPanel = var3;
      this.setShell(this.bundle.getString("about.panel.title"));
      this.makeLayout();
   }

   @Override
   public void makeLayout() {
      JPanel var1 = new JPanel(new GridBagLayout());
      int var2 = 1;
      var1.add(
         new JLabel(ResourceLoader.loadImageIcon(this.bundle.getString("RaritanLogo.image"))),
         new GridBagConstraints(0, 0, 1, 1, 1.0, 0.5, 10, 2, new Insets(30, 6, 27, 6), 0, 0)
      );
      var1.add(
         new JLabel(this.bundle.getString("about.label.productname")), new GridBagConstraints(0, var2++, 1, 1, 1.0, 0.1, 10, 0, new Insets(3, 6, 3, 6), 0, 0)
      );
      var1.add(
         new JLabel(this.bundle.getString("about.label.version") + ": " + this.bundle.getString("about.label.build")),
         new GridBagConstraints(0, var2++, 1, 1, 1.0, 0.1, 10, 0, new Insets(3, 6, 3, 6), 0, 0)
      );
      final JPanel var3 = new JPanel(new GridLayout(0, 2));
      Map var4 = JVMVersionInfo.getSystemProperties();
      var3.add(new JLabel(this.bundle.getString("about.label.jvmversion") + ": ", 11));
      var3.add(new JLabel((String)var4.get("JVM Version"), 10));
      var3.add(new JLabel(this.bundle.getString("about.label.jvmvendor") + ": ", 11));
      var3.add(new JLabel((String)var4.get("JVM Vendor"), 10));
      var3.add(new JLabel(this.bundle.getString("about.label.operating.system") + ": ", 11));
      var3.add(new JLabel((String)var4.get("Operating System"), 10));
      var3.add(new JLabel(this.bundle.getString("about.label.operating.system.version") + ": ", 11));
      var3.add(new JLabel((String)var4.get("Operating System Version"), 10));
      var3.add(new JLabel(this.bundle.getString("about.label.system.architecture") + ": ", 11));
      var3.add(new JLabel((String)var4.get("System Architecture"), 10));
      var1.add(var3, new GridBagConstraints(0, var2++, 1, 5, 1.0, 0.1, 10, 0, new Insets(6, 6, 6, 6), 0, 0));
      String var5 = this.getDeviceIP();

      try {
         if (var5 != null) {
            this.licPane = new JEditorPane("text/html", "") {
               @Override
               public Dimension getPreferredScrollableViewportSize() {
                  FontMetrics var1x = this.getFontMetrics(this.getFont());
                  int var2x = var1x.getHeight() * 6;
                  return new Dimension(480, var2x);
               }
            };
            this.licPane.setEditable(false);
            this.licPane.setOpaque(true);
            this.licJsp = new JScrollPane(this.licPane, 22, 30);
            this.pkgPane = new JEditorPane("text/html", "") {
               @Override
               public Dimension getPreferredScrollableViewportSize() {
                  FontMetrics var1x = this.getFontMetrics(this.getFont());
                  int var2x = var1x.getHeight() * 6;
                  return new Dimension(480, var2x);
               }
            };
            this.pkgPane.setEditable(false);
            this.pkgPane.setOpaque(true);
            this.pkgJsp = new JScrollPane(this.pkgPane, 22, 30);
            this.copyright = new JEditorPane() {
               @Override
               public Dimension getPreferredScrollableViewportSize() {
                  FontMetrics var1x = this.getFontMetrics(this.getFont());
                  int var2x = var1x.getHeight() * 6;
                  return new Dimension(480, var2x);
               }
            };
            this.copyright.setText(BASE_COPYRIGHT);
            this.copyright.setEditable(false);
            this.copyright.setOpaque(true);
            this.copyrightJsp = new JScrollPane(this.copyright, 22, 30);
            Font var6 = UIManager.getFont("Label.font");
            if (var6 != null) {
               String var7 = "body { font-family: " + var6.getFamily() + "; " + "font-size: " + var6.getSize() + "pt; }";
               ((HTMLDocument)this.licPane.getDocument()).getStyleSheet().addRule(var7);
               ((HTMLDocument)this.pkgPane.getDocument()).getStyleSheet().addRule(var7);
               ((HTMLDocument)this.pkgPane.getDocument()).getStyleSheet().addRule(var7);
            }

            var1.add(this.licJsp, new GridBagConstraints(0, 5 + var2++, 1, 1, 1.0, 0.2, 10, 2, new Insets(3, 6, 6, 6), 0, 0));
            var1.add(this.pkgJsp, new GridBagConstraints(0, 5 + var2++, 1, 1, 1.0, 0.2, 10, 2, new Insets(3, 6, 6, 6), 0, 0));
            var1.add(this.copyrightJsp, new GridBagConstraints(0, 5 + var2++, 1, 1, 1.0, 0.2, 10, 2, new Insets(3, 6, 6, 6), 0, 0));
            HyperlinkListener var14 = new HyperlinkListener() {
               @Override
               public void hyperlinkUpdate(HyperlinkEvent var1) {
                  if (EventType.ACTIVATED.equals(var1.getEventType())) {
                     AppletContext var2x = AboutPanel.this.scrContext.getAppletContext();
                     if (var2x != null) {
                        var2x.showDocument(var1.getURL(), "_blank");
                     } else {
                        BrowserLaunch.openURL(var1.getURL().toString(), null);
                     }
                  }
               }
            };
            this.licPane.addHyperlinkListener(var14);
            this.pkgPane.addHyperlinkListener(var14);
            this.worker = new AboutSwingWorker(this, CommonFunctions.getLicenseFilePath(), CommonFunctions.getLicenseActionDescr(), var5);
            this.worker.start();
            this.setCursor(waitCursor);
         } else {
            var1.add(
               new JLabel(this.bundle.getString("about.label.copyright")),
               new GridBagConstraints(0, 5 + var2++, 1, 1, 1.0, 0.1, 10, 0, new Insets(3, 6, 3, 6), 0, 0)
            );
         }
      } catch (Exception var8) {
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var8);
         }
      }

      JPanel var13 = new JPanel(new FlowLayout(1));
      var13.add(this.doButtonWidget());
      JButton var15 = new JButton("Copy to Clipboard");
      var13.add(var15);
      var15.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            StringBuffer var2x = new StringBuffer();

            for (byte var3x = 0; var3x < var3.getComponentCount(); var3x += 2) {
               var2x.append(((JLabel)var3.getComponent(var3x)).getText());
               var2x.append(((JLabel)var3.getComponent(var3x + 1)).getText());
               var2x.append("\n");
            }

            ClipboardHandler.getInstance().copyToClipboard(var2x.toString());
         }
      });
      var1.add(var13, new GridBagConstraints(0, 5 + var2++, 1, 1, 1.0, 0.2, 10, 2, new Insets(3, 6, 6, 6), 0, 0));
      this.add(var1);
      this.getShell().pack();
   }

   private String getDeviceIP() {
      ArrayList var1 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
      if (var1 != null && var1.size() != 0) {
         Device var2 = (Device)var1.get(0);
         Device var3 = var2;
         if (var2 instanceof Port) {
            var3 = ((Port)var2).getBaseDevice();
         } else if (var2 instanceof BladeChassis) {
            var3 = ((BladeChassis)var2).getBaseDevice();
         } else if (var2 instanceof Paragon) {
            var3 = ((Paragon)var2).getBaseDevice();
         }

         if (var3.isConnected() || MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext) && var2.isConnected()) {
            DeviceConnector var4 = var3.getDeviceConnector();
            if (var4.hasGNULicenseInfo()) {
               InetAddress var5 = var4.getInetAddress();
               return Util.getURLCompatibleIP(var5);
            }
         }

         return null;
      } else {
         return null;
      }
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.setCommand(new OKButtonCommand(this.scrContext));
      this.ok.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(1));
      var1.add(this.ok);
      return var1;
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillCopyrightInfo(String var1, String var2, String var3) {
      if (var1 != null && var1.length() > 0) {
         this.copyright.setText(BASE_COPYRIGHT + "\n" + var1);
      }

      if (var2 != null && var2.length() > 0) {
         this.pkgPane.setText(var2);
      } else {
         this.pkgPane.setText(NO_PACKAGES);
      }

      if (var3 != null && var3.length() > 0) {
         this.licPane.setText(var3);
      }

      this.setCursor(Cursor.getDefaultCursor());
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            Point var1x = new Point(0, 0);
            AboutPanel.this.licJsp.getViewport().setViewPosition(var1x);
            AboutPanel.this.pkgJsp.getViewport().setViewPosition(var1x);
            AboutPanel.this.copyrightJsp.getViewport().setViewPosition(var1x);
         }
      });
   }
}
