package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoNewProfileCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.util.Constants;
import java.net.InetAddress;
import java.util.List;

public class AddConnectionPanel extends AddModifyConnectionPanel {
   private static final long serialVersionUID = 1L;
   private DevicePreferences devPrefs = null;
   private IPReach device = null;

   public AddConnectionPanel(boolean var1, ScreenContext var2) {
      super(var1, var2);
      this.setShell(this.bundle.getString("AddConnectionDialog.title"));
      this.ok.setCommand(new DoNewProfileCommand(this.scrContext));
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.device = (IPReach)var1.getCommandParameter("devices");
      if (this.device == null) {
         this.devPrefs = new DevicePreferences();
         this.devPrefs.setPort(Integer.parseInt(Constants.NETWORKCONFIG_DEFAULT_PORT));
      } else {
         if (this.device.getDevPrefs() == null) {
            this.devPrefs = new DevicePreferences();
            this.devPrefs.setDescription(this.device.getDescription());
            this.devPrefs.setName(this.device.getName());
            this.devPrefs.setDnsName(this.device.getDnsName());
            List var2 = this.device.getAddressList();

            assert var2.size() > 0;

            this.devPrefs.setIp(((InetAddress)var2.get(0)).getHostAddress());
            this.devPrefs.setPort((int)this.device.getIPPort());
         } else {
            DevicePreferences var3 = this.device.getDevPrefs();
            this.devPrefs = new DevicePreferences();
            this.devPrefs.setDescription(this.device.getDescription());
            this.devPrefs.setProductType(var3.getProductType());
            this.devPrefs.setName(this.device.getName());
            this.devPrefs.setDnsName(this.device.getDnsName());
            this.devPrefs.setIp(var3.getIp());
            this.devPrefs.setPort(Integer.parseInt(Constants.NETWORKCONFIG_DEFAULT_PORT));
            this.devPrefs.setConnectionSpeed(var3.getConnectionSpeed());
            this.devPrefs.setColorDepth(var3.getColorDepth());
            this.devPrefs.setProgressiveUpdate(var3.isProgressiveUpdate());
            this.devPrefs.setFlowControl(var3.isFlowControl());
            this.devPrefs.setSmoothing(var3.getSmoothing());
            this.devPrefs.setFramesPerSecond(var3.getFramesPerSecond());
         }

         this.devPrefs.setConnectionType(2);
         this.devPrefs.setFindBy(this.getProfileBy(((RRCScreenContext)this.scrContext).getCreateProfileBy()));
      }

      this.connectPanel.setCommandKey(var1.getCommandKey());
      this.connectPanel.fillDevicePreferences(this.devPrefs);
      this.compressionPanel.fillDevicePreferences(this.devPrefs);
      this.securityPanel.fillDevicePreferences(this.devPrefs);
      this.addConnectionTabbedPane.setSelectedIndex(0);
      this.connectPanel.setDefaultFocussedComponent();
      this.setG2Panels(false);
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      this.connectPanel.feedDevicePreferences(this.devPrefs);
      this.compressionPanel.feedDevicePreferences(this.devPrefs);
      this.securityPanel.feedDevicePreferences(this.devPrefs);
      var1.setCommandParameter("connectionInfo", this.devPrefs);
      var1.setCommandParameter("devices", this.device);
   }

   public void setG2Panels(boolean var1) {
      this.addConnectionTabbedPane.setEnabledAt(1, var1);
      this.addConnectionTabbedPane.setEnabledAt(2, var1);
   }

   private int getProfileBy(int var1) {
      switch (var1) {
         case 0:
            return 1;
         case 1:
            return 0;
         case 2:
            return 2;
         default:
            return 1;
      }
   }
}
