package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.commands.ShowMacroTextInterpreterCommand;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.util.kbd.KeyboardKey;
import com.util.kbd.KeyboardMappings;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Arrays;
import java.util.Vector;
import javax.swing.BorderFactory;
import javax.swing.DefaultComboBoxModel;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import nn.pp.common.ui.helpers.IMacroCreatorDialog;
import nn.pp.core.T;

public class AddModifyKeyboardMacroPanel extends AbstractDisplay implements ListDataListener, ListSelectionListener, IMacroCreatorDialog {
   protected static final int ALL_KEYS = 0;
   protected static final int LETTERS = 1;
   protected static final int NUMBERS = 2;
   protected static final int NON_GRAPHIC_KEYS = 3;
   protected static final int SHIFT_MODIFIERS = 4;
   protected static final int SYMBOLS = 5;
   protected static final int DIRECTION_KEYS = 6;
   protected static final int FUNCTIONAL = 7;
   protected static final int JAPANESE_KEYS = 8;
   protected static final int KEY_PAD_KEYS = 9;
   protected static final int SPECIAL_FUNCTIONS = 10;
   protected static final int KOREAN_KEYS = 11;
   protected static final int SUN_KEYS = 12;
   private static final long serialVersionUID = 1L;
   protected JTextField nameField;
   protected JComboBox hotKeyComboBox;
   protected JList keysToPressList;
   protected JList macroSequenceList;
   protected JButton addKeyButton;
   protected JButton removeButton;
   protected JButton upButton;
   protected JButton downButton;
   protected JButton clearButton;
   protected AddModifyKeyboardMacroPanel.KeyListActionListener buttonListener;
   protected DefaultComboBoxModel hotKeyCombinationModel;
   protected DefaultComboBoxModel keysToPressModel;
   protected DefaultListModel keysToPressListModel;
   protected DefaultListModel macroSequenceListModel;
   protected final String[] hotKeyCombinationType = new String[11];
   protected final String[] keysToPressType = new String[13];
   protected KeyboardMappings keyboardMappings;
   protected final int[] letters = new int[]{57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82};
   protected final int[] numbers = new int[]{92, 83, 84, 85, 86, 87, 88, 89, 90, 91};
   protected final int[] nonGraphicKeys = new int[]{9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 40};
   protected final int[] shiftModifiers = new int[]{0, 1, 2, 3, 4, 5, 6, 7, 8};
   protected final int[] symbols = new int[]{93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 134};
   protected final int[] directionKeys = new int[]{19, 20, 21, 22, 23, 24, 25, 26, 27, 28};
   protected final int[] functionalKeys = new int[]{45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 135, 136, 137, 138};
   protected final int[] japaneseKeys = new int[]{104, 105, 106, 107, 108, 109, 110, 111, 116};
   protected final int[] keyPadKeys = new int[]{29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44};
   protected final int[] specialFunctions = new int[]{112, 113, 132, 133};
   protected final int[] koreanKeys = new int[]{114, 115};
   protected final int[] sunKeys = new int[]{117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131};
   private CommandButton launchMacroTextInterpreter = null;

   public AddModifyKeyboardMacroPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.keyboardMappings = new KeyboardMappings();
      this.hotKeyCombinationType[0] = this.bundle.getString("NoHotKey.option");
      this.hotKeyCombinationType[1] = this.bundle.getString("CtrlAlt0.option");
      this.hotKeyCombinationType[2] = this.bundle.getString("CtrlAlt1.option");
      this.hotKeyCombinationType[3] = this.bundle.getString("CtrlAlt2.option");
      this.hotKeyCombinationType[4] = this.bundle.getString("CtrlAlt3.option");
      this.hotKeyCombinationType[5] = this.bundle.getString("CtrlAlt4.option");
      this.hotKeyCombinationType[6] = this.bundle.getString("CtrlAlt5.option");
      this.hotKeyCombinationType[7] = this.bundle.getString("CtrlAlt6.option");
      this.hotKeyCombinationType[8] = this.bundle.getString("CtrlAlt7.option");
      this.hotKeyCombinationType[9] = this.bundle.getString("CtrlAlt8.option");
      this.hotKeyCombinationType[10] = this.bundle.getString("CtrlAlt9.option");
      this.hotKeyCombinationModel = new DefaultComboBoxModel<>(this.hotKeyCombinationType);
      this.keysToPressType[0] = this.bundle.getString("AllKeys.option");
      this.keysToPressType[1] = this.bundle.getString("Letters.option");
      this.keysToPressType[2] = this.bundle.getString("Numbers.option");
      this.keysToPressType[3] = this.bundle.getString("NonGraphicKeys.option");
      this.keysToPressType[4] = this.bundle.getString("ShiftModifiers.option");
      this.keysToPressType[5] = this.bundle.getString("Symbols.option");
      this.keysToPressType[6] = this.bundle.getString("DirectionKeys.option");
      this.keysToPressType[7] = this.bundle.getString("F1-F16.option");
      this.keysToPressType[8] = this.bundle.getString("JapaneseKeys.option");
      this.keysToPressType[9] = this.bundle.getString("KeyPadKeys.option");
      this.keysToPressType[10] = this.bundle.getString("SpecialFunctions.option");
      this.keysToPressType[11] = this.bundle.getString("KoreanKeys.option");
      this.keysToPressType[12] = this.bundle.getString("SunKeys.option");
      this.keysToPressModel = new DefaultComboBoxModel<>(this.keysToPressType);
      this.keysToPressModel.addListDataListener(this);
      this.keysToPressListModel = new DefaultListModel();
      this.setKeysToPressModel(0);
      this.macroSequenceListModel = new DefaultListModel();
      this.buttonListener = new AddModifyKeyboardMacroPanel.KeyListActionListener();
      this.makeLayout();
   }

   @Override
   public void makeLayout() {
      this.setLayout(new SpringLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
      JPanel var1 = new JPanel(new SpringLayout());
      var1.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(""), BorderFactory.createEmptyBorder(5, 65, 5, 65)));
      JLabel var2 = new JLabel(this.bundle.getString("MacroName.label"), 11);
      var1.add(var2);
      this.nameField = new JTextField();
      var2.setLabelFor(this.nameField);
      var1.add(this.nameField);
      JLabel var3 = new JLabel(this.bundle.getString("HotKeyCombination.label"), 11);
      var1.add(var3);
      this.hotKeyComboBox = new JComboBox(this.hotKeyCombinationModel);
      var3.setLabelFor(this.hotKeyComboBox);
      var1.add(this.hotKeyComboBox);
      SpringUtilities.makeCompactGrid(var1, 2, 2, 25, 5, 25, 5);
      this.add(var1);
      JPanel var4 = new JPanel(new SpringLayout());
      var4.setBorder(BorderFactory.createTitledBorder(""));
      JPanel var5 = new JPanel();
      var5.setLayout(new GridLayout(2, 1));
      JLabel var6 = new JLabel(this.bundle.getString("KeysToPress.label"));
      var6.setBackground(Color.RED);
      var6.setAlignmentX(0.0F);
      var5.add(var6);
      JComboBox var7 = new JComboBox(this.keysToPressModel);
      var7.setAlignmentX(0.0F);
      var5.add(var7);
      var4.add(var5);
      JPanel var8 = new JPanel(new GridLayout(2, 1));
      JLabel var9 = new JLabel(this.bundle.getString("MacroSequence.label"));
      var8.add(var9);
      this.launchMacroTextInterpreter = new CommandButton(this.scrContext);
      this.launchMacroTextInterpreter.setCommand(new ShowMacroTextInterpreterCommand(this.scrContext));
      this.launchMacroTextInterpreter.setText(T._("Construct Macro From Text"));
      this.launchMacroTextInterpreter.addActionListener(this);
      var8.add(this.launchMacroTextInterpreter);
      var4.add(var8);
      this.keysToPressList = new JList(this.keysToPressListModel);
      this.keysToPressList.addListSelectionListener(this);
      this.keysToPressList.setSelectionMode(0);
      JScrollPane var10 = new JScrollPane(this.keysToPressList, 20, 31);
      var4.add(var10);
      Dimension var11 = var10.getSize();
      this.macroSequenceList = new JList(this.macroSequenceListModel);
      this.macroSequenceList.setSelectionMode(0);
      this.macroSequenceList.addListSelectionListener(this);
      JScrollPane var12 = new JScrollPane(this.macroSequenceList, 20, 31);
      var12.setMinimumSize(var11);
      var12.setMaximumSize(var11);
      var12.setPreferredSize(var11);
      var4.add(var12);
      JPanel var13 = new JPanel(new FlowLayout(1));
      this.addKeyButton = new JButton(this.bundle.getString("AddKey.button"));
      this.addKeyButton.setEnabled(false);
      this.addKeyButton.addActionListener(this.buttonListener);
      var13.add(this.addKeyButton);
      var4.add(var13);
      JPanel var14 = new JPanel(new FlowLayout(1));
      this.removeButton = new JButton(this.bundle.getString("Remove.button"));
      this.removeButton.setEnabled(false);
      this.removeButton.addActionListener(this.buttonListener);
      this.upButton = new JButton("^");
      this.upButton.setEnabled(false);
      this.upButton.addActionListener(this.buttonListener);
      this.downButton = new JButton("v");
      this.downButton.setEnabled(false);
      this.downButton.addActionListener(this.buttonListener);
      var14.add(this.removeButton);
      var14.add(this.upButton);
      var14.add(this.downButton);
      var4.add(var14);
      SpringUtilities.makeCompactGrid(var4, 3, 2, 10, 10, 10, 10);
      this.add(var4);
      JPanel var15 = new JPanel(new FlowLayout(1));
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.setCommand(null);
      this.ok.addActionListener(this);
      var15.add(this.ok);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      var15.add(this.cancel);
      this.clearButton = new JButton(this.bundle.getString("Clear.button"));
      this.clearButton.setEnabled(false);
      this.clearButton.addActionListener(this.buttonListener);
      var15.add(this.clearButton);
      this.add(var15);
      SpringUtilities.makeCompactGrid(this, 3, 1, 6, 6, 6, 6);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            AddModifyKeyboardMacroPanel.this.nameField.grabFocus();
         }
      });
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      if (var1.getCommandKey() == "showMacroTextInterpreterCommand") {
         var1.setCommandParameter("macroTextInterpreter", this.keyboardMappings);
         var1.setCommandParameter("macroTextInterpreterParent", this);
      }
   }

   protected void setKeysToPressModel(int var1) {
      switch (var1) {
         case 0:
            this.keysToPressListModel.clear();
            Vector var2 = new Vector();

            for (int var15 = 0; var15 < this.keyboardMappings.length(); var15++) {
               if (this.isSpecialFunction(var15)) {
                  var2.add(this.keyboardMappings.getItem(var15));
               } else {
                  this.keysToPressListModel.addElement(this.keyboardMappings.getItem(var15));
               }
            }

            for (int var16 = 0; var16 < var2.size(); var16++) {
               this.keysToPressListModel.addElement(var2.get(var16));
            }
            break;
         case 1:
            this.keysToPressListModel.clear();

            for (int var14 = 0; var14 < this.letters.length; var14++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.letters[var14]));
            }
            break;
         case 2:
            this.keysToPressListModel.clear();

            for (int var13 = 0; var13 < this.numbers.length; var13++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.numbers[var13]));
            }
            break;
         case 3:
            this.keysToPressListModel.clear();

            for (int var12 = 0; var12 < this.nonGraphicKeys.length; var12++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.nonGraphicKeys[var12]));
            }
            break;
         case 4:
            this.keysToPressListModel.clear();

            for (int var11 = 0; var11 < this.shiftModifiers.length; var11++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.shiftModifiers[var11]));
            }
            break;
         case 5:
            this.keysToPressListModel.clear();

            for (int var10 = 0; var10 < this.symbols.length; var10++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.symbols[var10]));
            }
            break;
         case 6:
            this.keysToPressListModel.clear();

            for (int var9 = 0; var9 < this.directionKeys.length; var9++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.directionKeys[var9]));
            }
            break;
         case 7:
            this.keysToPressListModel.clear();

            for (int var8 = 0; var8 < this.functionalKeys.length; var8++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.functionalKeys[var8]));
            }
            break;
         case 8:
            this.keysToPressListModel.clear();

            for (int var7 = 0; var7 < this.japaneseKeys.length; var7++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.japaneseKeys[var7]));
            }
            break;
         case 9:
            this.keysToPressListModel.clear();

            for (int var6 = 0; var6 < this.keyPadKeys.length; var6++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.keyPadKeys[var6]));
            }
            break;
         case 10:
            this.keysToPressListModel.clear();

            for (int var5 = 0; var5 < this.specialFunctions.length; var5++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.specialFunctions[var5]));
            }
            break;
         case 11:
            this.keysToPressListModel.clear();

            for (int var4 = 0; var4 < this.koreanKeys.length; var4++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.koreanKeys[var4]));
            }
            break;
         case 12:
            this.keysToPressListModel.clear();

            for (int var3 = 0; var3 < this.sunKeys.length; var3++) {
               this.keysToPressListModel.addElement(this.keyboardMappings.getItem(this.sunKeys[var3]));
            }
      }
   }

   @Override
   public void contentsChanged(ListDataEvent var1) {
      if (var1.getSource() instanceof DefaultComboBoxModel) {
         DefaultComboBoxModel var2 = (DefaultComboBoxModel)var1.getSource();
         if (var2 == this.keysToPressModel) {
            Object var3 = var2.getSelectedItem();
            int var4 = var2.getIndexOf(var3);
            this.setKeysToPressModel(var4);
         }
      }
   }

   @Override
   public void intervalAdded(ListDataEvent var1) {
   }

   @Override
   public void intervalRemoved(ListDataEvent var1) {
   }

   @Override
   public void valueChanged(ListSelectionEvent var1) {
      if (var1.getSource() instanceof JList) {
         JList var2 = (JList)var1.getSource();
         if (var2 == this.keysToPressList) {
            this.macroSequenceList.removeListSelectionListener(this);
            this.macroSequenceList.addListSelectionListener(this);
            this.removeButton.setEnabled(false);
            this.upButton.setEnabled(false);
            this.downButton.setEnabled(false);
         } else if (var2 == this.macroSequenceList) {
            this.keysToPressList.removeListSelectionListener(this);
            this.keysToPressList.addListSelectionListener(this);
            this.removeButton.setEnabled(true);
            this.upButton.setEnabled(true);
            this.downButton.setEnabled(true);
         }

         this.addKeyButton.setEnabled(!this.keysToPressList.isSelectionEmpty());
         var2.ensureIndexIsVisible(var2.getSelectedIndex());
      }
   }

   protected int getHotKeyIndex(String var1) {
      for (int var2 = 0; var2 < this.hotKeyCombinationType.length; var2++) {
         if (var1.equals(this.hotKeyCombinationType[var2])) {
            return var2 - 1;
         }
      }

      return -1;
   }

   private boolean isSpecialFunction(int var1) {
      return Arrays.binarySearch(this.specialFunctions, var1) > -1;
   }

   @Override
   public void fillSequenceModel(String var1) {
      String[] var2 = var1.split("&&");
      KeyboardKey var3 = null;
      KeyboardKey var4 = null;
      int var5 = 0;
      Object var6 = null;
      String var7 = this.bundle.getString("press.text");
      String var8 = this.bundle.getString("release.text");

      for (String var12 : var2) {
         var5 = Integer.parseInt(var12.substring(var12.lastIndexOf(" ") + 1));
         var6 = var12.substring(0, var12.lastIndexOf(" "));
         if (var6.equals("p")) {
            var6 = var7;
         } else {
            var6 = var8;
         }

         var3 = this.keyboardMappings.getItem(var5);
         if (var3 != null) {
            var4 = new KeyboardKey(var3.getIndex(), var3.getKeyName(), var3.getKeyCode(), var3.getKeyLocation());
            var4.setString(var6 + " " + var4.getKeyName());
            this.macroSequenceListModel.addElement(var4);
         }
      }

      this.clearButton.setEnabled(!this.macroSequenceListModel.isEmpty());
   }

   class KeyListActionListener implements ActionListener {
      @Override
      public void actionPerformed(ActionEvent var1) {
         if (var1.getSource() instanceof JButton) {
            JButton var2 = (JButton)var1.getSource();
            if (var2 == AddModifyKeyboardMacroPanel.this.addKeyButton) {
               KeyboardKey var3 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.keysToPressList.getSelectedValue();
               KeyboardKey var4 = new KeyboardKey(var3.getIndex(), var3.getKeyName(), var3.getKeyCode(), var3.getKeyLocation());
               if (AddModifyKeyboardMacroPanel.this.isSpecialFunction(var3.getIndex())) {
                  AddModifyKeyboardMacroPanel.this.macroSequenceListModel.addElement(var4);
               } else {
                  var4.setString(AddModifyKeyboardMacroPanel.this.bundle.getString("press.text") + " " + var3);
                  AddModifyKeyboardMacroPanel.this.macroSequenceListModel.addElement(var4);
                  var4 = new KeyboardKey(var3.getIndex(), var3.getKeyName(), var3.getKeyCode(), var3.getKeyLocation());
                  var4.setString(AddModifyKeyboardMacroPanel.this.bundle.getString("release.text") + " " + var3);
                  AddModifyKeyboardMacroPanel.this.macroSequenceListModel.addElement(var4);
                  AddModifyKeyboardMacroPanel.this.clearButton.setEnabled(true);
               }

               if (!AddModifyKeyboardMacroPanel.this.macroSequenceListModel.isEmpty()) {
                  AddModifyKeyboardMacroPanel.this.macroSequenceList
                     .ensureIndexIsVisible(AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getSize() - 1);
               }
            } else if (var2 == AddModifyKeyboardMacroPanel.this.removeButton) {
               KeyboardKey var8 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceList.getSelectedValue();
               if (var8 != null) {
                  String var12 = var8.toString();
                  KeyboardKey var5 = null;
                  Object var6 = null;
                  if (var12.startsWith(AddModifyKeyboardMacroPanel.this.bundle.getString("press.text"))) {
                     var6 = var12.replaceFirst(
                        AddModifyKeyboardMacroPanel.this.bundle.getString("press.text"), AddModifyKeyboardMacroPanel.this.bundle.getString("release.text")
                     );
                  } else {
                     var6 = var12.replaceFirst(
                        AddModifyKeyboardMacroPanel.this.bundle.getString("release.text"), AddModifyKeyboardMacroPanel.this.bundle.getString("press.text")
                     );
                  }

                  if (var6 != null) {
                     for (int var7 = 0; var7 < AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getSize(); var7++) {
                        var5 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var7);
                        if (var6.equals(var5.toString())) {
                           break;
                        }
                     }
                  }

                  if (var8 != null && var5 != null) {
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.removeElement(var5);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.removeElement(var8);
                  }

                  if (AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getSize() == 0) {
                     AddModifyKeyboardMacroPanel.this.clearButton.setEnabled(false);
                  }
               }
            } else if (var2 == AddModifyKeyboardMacroPanel.this.clearButton) {
               AddModifyKeyboardMacroPanel.this.macroSequenceListModel.clear();
               AddModifyKeyboardMacroPanel.this.clearButton.setEnabled(false);
            } else if (var2 == AddModifyKeyboardMacroPanel.this.upButton) {
               int var9 = AddModifyKeyboardMacroPanel.this.macroSequenceList.getSelectedIndex();
               if (var9 > 0) {
                  KeyboardKey var13 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var9 - 1);
                  KeyboardKey var15 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var9);
                  if (var15.getKeyCode() != var13.getKeyCode()
                     || !var15.toString().startsWith(AddModifyKeyboardMacroPanel.this.bundle.getString("release.text"))
                     || !var13.toString().startsWith(AddModifyKeyboardMacroPanel.this.bundle.getString("press.text"))) {
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var9 - 1, var15);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var9, var13);
                     AddModifyKeyboardMacroPanel.this.macroSequenceList.setSelectedIndex(var9 - 1);
                  } else if (var9 > 1) {
                     KeyboardKey var18 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var9 - 2);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var9 - 2, var13);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var9 - 1, var15);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var9, var18);
                     AddModifyKeyboardMacroPanel.this.macroSequenceList.setSelectedIndex(var9 - 1);
                  }
               }
            } else if (var2 == AddModifyKeyboardMacroPanel.this.downButton) {
               int var10 = AddModifyKeyboardMacroPanel.this.macroSequenceList.getSelectedIndex();
               if (var10 < AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getSize() - 1) {
                  KeyboardKey var14 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var10);
                  KeyboardKey var16 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var10 + 1);
                  if (var14.getKeyCode() != var16.getKeyCode()
                     || !var14.toString().startsWith(AddModifyKeyboardMacroPanel.this.bundle.getString("press.text"))
                     || !var16.toString().startsWith(AddModifyKeyboardMacroPanel.this.bundle.getString("release.text"))) {
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var10 + 1, var14);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var10, var16);
                     AddModifyKeyboardMacroPanel.this.macroSequenceList.setSelectedIndex(var10 + 1);
                  } else if (var10 < AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getSize() - 2) {
                     KeyboardKey var19 = (KeyboardKey)AddModifyKeyboardMacroPanel.this.macroSequenceListModel.getElementAt(var10 + 2);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var10, var19);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var10 + 1, var14);
                     AddModifyKeyboardMacroPanel.this.macroSequenceListModel.set(var10 + 2, var16);
                     AddModifyKeyboardMacroPanel.this.macroSequenceList.setSelectedIndex(var10 + 1);
                  }
               }
            }
         }
      }
   }
}
