package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.HtmlPort;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.applet.EmbedAppletClassLoader;
import com.raritan.rrc.ui.applet.EmbedAppletDataHolder;
import com.raritan.rrc.ui.applet.EmbedAppletStub;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.util.Util;
import java.awt.CardLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.ArrayList;
import javaclientlib.tr.Constants;
import javax.swing.JApplet;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;

public class AppletView extends DeviceViewAdapter {
   private static final long serialVersionUID = 4778443664182470436L;
   private Device dev = null;
   private ScreenContext scrContext = null;
   private EmbedAppletDataHolder holder = null;
   private boolean loaded = true;
   private Class claz = null;
   private AppletView.HtmlPortThread thread;
   private HtmlPort htmlPort;
   private JApplet applet;
   private EmbedAppletClassLoader classLoader;
   private EmbedAppletStub stub;
   protected RaritanPropertyResourceBundle bundle;
   private static final String LOADING_CARD = "loadingCard";
   private static final String APPLET_CARD = "appletCard";
   private JPanel loadingPanel = null;
   private JPanel appletPanel = null;
   private JProgressBar progress;

   public AppletView(boolean var1, ScreenContext var2) {
      super((RRCScreenContext)var2);
      this.scrContext = var2;
      this.isNewPanel = true;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.htmlPort = (HtmlPort)((ArrayList)((RRCScreenContext)var2).getSelectedDevicesObservable().getComponent()).get(0);
      this.makeLayout();
   }

   @Override
   public void makeLayout() {
      this.setLayout(new CardLayout());
      this.loadingPanel = new JPanel();
      this.loadingPanel.setLayout(new GridBagLayout());
      this.progress = new JProgressBar(0, 500);
      this.progress.setIndeterminate(true);
      this.loadingPanel
         .add(new JLabel(this.bundle.getString("loading.message")), new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
      this.loadingPanel.add(this.progress, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
      this.appletPanel = new JPanel();
      this.add("loadingCard", this.loadingPanel);
      this.add("appletCard", this.appletPanel);
      RaritanDesktopPane var1 = (RaritanDesktopPane)((RRCScreenContext)this.scrContext).getPanelMediator().getParent();
      this.setSize(var1.getSize());
      this.setFocusable(true);
      this.htmlPort.setView(this);
   }

   public void loadApplet(String var1) {
      if (var1 != null && !var1.equals("")) {
         try {
            this.htmlPort.connect();
            URL var2 = new URL(var1);
            this.holder = new EmbedAppletDataHolder();
            this.stub = new EmbedAppletStub((RRCScreenContext)this.scrContext, this.holder, var2);
            if (this.htmlPort.getDevice().getDeviceConnector() != null) {
               String var3 = this.htmlPort.getDevice().getDeviceConnector().getUsername();
               String var4 = this.htmlPort.getDevice().getDeviceConnector().getPassword();
               this.stub.setParameter("jrrc.exit", "1");
               this.stub.setParameter("jrrc.sessionID", this.htmlPort.getSessionId());
            }

            this.stub.setParameter("host", var2.getHost());
            String var14 = String.valueOf(this.htmlPort.getDevice().getIPPort());
            this.stub.setParameter("login.port", var14);
            this.classLoader = new EmbedAppletClassLoader(new URL[]{var2}, null);
            String var15 = Constants.ADMIN_APPLET_CLASSNAME;
            this.claz = this.classLoader.loadClass(var15);
            this.applet = (JApplet)this.claz.newInstance();
            this.applet.setSize((int)this.getSize().getHeight() - 20, (int)this.getSize().getWidth() - 20);
            this.applet.setStub(this.stub);
            if (!this.htmlPort.isConnected()) {
               return;
            }

            URLClassLoader var5 = new URLClassLoader(new URL[]{new URL("file:./")}, null);
            Thread.currentThread().setContextClassLoader(var5);
            this.applet.init();
            this.applet.start();
            this.applet.validate();
            this.appletPanel.setLayout(new GridBagLayout());
            GridBagConstraints var6 = new GridBagConstraints();
            var6.fill = 1;
            var6.gridx = 0;
            var6.gridy = 0;
            var6.weightx = 1.0;
            var6.weighty = 1.0;
            Object var7 = null;
            this.appletPanel.add(this.applet.getRootPane(), var6);
            this.appletPanel.revalidate();
            ((CardLayout)this.getLayout()).show(this, "appletCard");
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel(this.bundle.getString("loaded.message"));
            this.loaded = true;
         } catch (ClassCastException var8) {
         } catch (MalformedURLException var9) {
         } catch (IllegalAccessException var10) {
         } catch (InstantiationException var11) {
         } catch (ClassNotFoundException var12) {
         } catch (NullPointerException var13) {
         }
      }
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.dev = (Device)var1.getCommandParameter("selectedPortDevice");
      if (this.dev != null) {
         ((CardLayout)this.getLayout()).show(this, "loadingCard");
         this.thread = new AppletView.HtmlPortThread(this);
         this.thread.start();
      }
   }

   @Override
   public void feedCommandContext(CommandContext var1) {
      this.stub = null;
      this.classLoader = null;
      this.claz = null;
      this.holder = null;
      if (this.applet != null && this.applet.isVisible()) {
         this.applet.setStub(null);

         try {
            this.applet.destroy();
         } catch (Throwable var3) {
         }

         this.applet = null;
      }

      this.thread.interrupt();
      this.thread = null;
   }

   public JApplet getApplet() {
      return this.applet;
   }

   @Override
   public void setDefaultFocussedComponent() {
      if (this.applet != null) {
         this.applet.requestFocusInWindow();
      }
   }

   @Override
   public boolean hasFocus() {
      return this.getShellInternalFrame() != null && this.getShellInternalFrame().isSelected();
   }

   private class HtmlPortThread extends Thread {
      private AppletView view;

      public HtmlPortThread(AppletView var2) {
         this.setName("KXMThread");
         this.view = var2;
      }

      @Override
      public void run() {
         if (this.view != null) {
            String var1 = "http://";
            DeviceConnector var2 = AppletView.this.dev.getDeviceConnector();
            AppletView.this.loadApplet(
               new String(var1 + Util.getURLCompatibleIP(var2.getInetAddress(), AppletView.this.dev.getHttpsPort()) + "/" + Constants.ADMIN_APPLET_JARFILE)
                  .trim()
            );
         }
      }
   }
}
