package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.commands.DoChangePasswordCommand;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;

public class ChangePasswordPanel extends AbstractDisplay {
   private static final long serialVersionUID = -4093637311772575236L;
   private JPasswordField oldPassTextField;
   private JPasswordField newPassTextField;
   private JPasswordField confirmPassTextField;
   private IPReach device = null;
   private Boolean userFlag;

   public ChangePasswordPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
      this.setShell(this.bundle.getString("changePassword.panel.title"));
   }

   @Override
   public void makeLayout() {
      RaritanPropertyResourceBundle var1 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      JPanel var2 = new JPanel(new SpringLayout());
      var2.setBorder(
         BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var1.getString("info.label")), BorderFactory.createEmptyBorder(5, 5, 5, 5))
      );
      JLabel var3 = new JLabel(var1.getString("oldPassword.label"), 11);
      var2.add(var3);
      this.oldPassTextField = new JPasswordField(10);
      var3.setLabelFor(this.oldPassTextField);
      var2.add(this.oldPassTextField);
      var3 = new JLabel(var1.getString("newPassword.label"), 11);
      var2.add(var3);
      this.newPassTextField = new JPasswordField(10);
      var3.setLabelFor(this.newPassTextField);
      var2.add(this.newPassTextField);
      var3 = new JLabel(var1.getString("confirmNewPassword.label"), 11);
      var2.add(var3);
      this.confirmPassTextField = new JPasswordField(10);
      var3.setLabelFor(this.confirmPassTextField);
      var2.add(this.confirmPassTextField);
      SpringUtilities.makeCompactGrid(var2, 3, 2, 10, 10, 10, 10);
      this.add(var2, "Center");
      this.add(this.doButtonWidget(), "Last");
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.clearAllFields();
      this.device = (IPReach)var1.getCommandParameter("devices");
      this.userFlag = (Boolean)var1.getCommandParameter("userInvokedChangePassword");
      this.setDefaultFocussedComponent();
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      var1.setCommandParameter("userPassword", new String(this.oldPassTextField.getPassword()));
      var1.setCommandParameter("newPassword", new String(this.newPassTextField.getPassword()));
      var1.setCommandParameter("confirmNewPassword", new String(this.confirmPassTextField.getPassword()));
      var1.setCommandParameter("devices", this.device);
      var1.setCommandParameter("userInvokedChangePassword", this.userFlag);
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.setCommand(new DoChangePasswordCommand(this.scrContext));
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(1));
      var1.add(this.ok);
      var1.add(this.cancel);
      return var1;
   }

   private void clearAllFields() {
      this.oldPassTextField.setText("");
      this.newPassTextField.setText("");
      this.confirmPassTextField.setText("");
   }

   @Override
   public void setDefaultFocussedComponent() {
      if (OS.getCurrent() == OS.SOLARIS) {
         this.oldPassTextField.grabFocus();
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               ChangePasswordPanel.this.oldPassTextField.grabFocus();
               ChangePasswordPanel.this.repaint();
               if (OS.getCurrent() == OS.MAC) {
                  ChangePasswordPanel.this.ok.repaint();
               }
            }
         });
      }
   }
}
