package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.ui.models.SliderRangeModel;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.FocusEvent;
import java.util.Hashtable;
import javaclientlib.tr.TRSRVR_COMP_PARAMS;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.border.CompoundBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;

public class CompressionPanel extends AbstractDisplay implements ListDataListener, ChangeListener {
   public static final String COMPRESSION_PANEL_SETTINGS_CHANGED = "COMPRESSION_PANEL_SETTINGS_CHANGED";
   private static final long serialVersionUID = 2008395561540428642L;
   private TRSRVR_COMP_PARAMS compParams;
   private DefaultComboBoxModel connectionSpeedModel;
   private DefaultComboBoxModel colorDepthModel;
   private JComboBox connSpeedComboBox;
   private JComboBox colorDepthComboBox;
   private JCheckBox progressiveUpdateChkBox;
   private JCheckBox internetFlowControlChkBox;
   private SliderRangeModel smoothingModel;
   private final CompressionPanel.ComboData[] connSpeedData = new CompressionPanel.ComboData[12];
   private final CompressionPanel.ComboData[] colorData = new CompressionPanel.ComboData[10];
   private JRadioButton fps5;
   private JRadioButton fps10;
   private JRadioButton fps20;
   private boolean compSettingsModified = false;
   private JSlider smoothing = null;

   public CompressionPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
   }

   private void initComboDataModels() {
      this.connSpeedData[0] = new CompressionPanel.ComboData(this.bundle.getString("AutoDetect.option"), 0);
      this.connSpeedData[1] = new CompressionPanel.ComboData(this.bundle.getString("Ethernet100.option"), 25000000);
      this.connSpeedData[2] = new CompressionPanel.ComboData(this.bundle.getString("Ethernet10.option"), 5000000);
      this.connSpeedData[3] = new CompressionPanel.ComboData(this.bundle.getString("MaxDSL.option"), 1500000);
      this.connSpeedData[4] = new CompressionPanel.ComboData(this.bundle.getString("FastDSL.option"), 1100000);
      this.connSpeedData[5] = new CompressionPanel.ComboData(this.bundle.getString("MediumDSL.option"), 512000);
      this.connSpeedData[6] = new CompressionPanel.ComboData(this.bundle.getString("SlowDSL.option"), 384000);
      this.connSpeedData[7] = new CompressionPanel.ComboData(this.bundle.getString("Cable.option"), 256000);
      this.connSpeedData[8] = new CompressionPanel.ComboData(this.bundle.getString("DualISDN.option"), 128000);
      this.connSpeedData[9] = new CompressionPanel.ComboData(this.bundle.getString("ISPModem.option"), 56000);
      this.connSpeedData[10] = new CompressionPanel.ComboData(this.bundle.getString("FastModem.option"), 33000);
      this.connSpeedData[11] = new CompressionPanel.ComboData(this.bundle.getString("SlowModem.option"), 24000);
      this.colorData[0] = new CompressionPanel.ComboData(this.bundle.getString("AutoSelect.option"), 0);
      this.colorData[1] = new CompressionPanel.ComboData(this.bundle.getString("RGB15.option"), 12);
      this.colorData[2] = new CompressionPanel.ComboData(this.bundle.getString("RGB12.option"), 10);
      this.colorData[3] = new CompressionPanel.ComboData(this.bundle.getString("RGB8.option"), 8);
      this.colorData[4] = new CompressionPanel.ComboData(this.bundle.getString("Color5bit.option"), 7);
      this.colorData[5] = new CompressionPanel.ComboData(this.bundle.getString("Color4bit.option"), 6);
      this.colorData[6] = new CompressionPanel.ComboData(this.bundle.getString("Gray4bit.option"), 5);
      this.colorData[7] = new CompressionPanel.ComboData(this.bundle.getString("Gray3bit.option"), 4);
      this.colorData[8] = new CompressionPanel.ComboData(this.bundle.getString("Gray2bit.option"), 3);
      this.colorData[9] = new CompressionPanel.ComboData(this.bundle.getString("Black&White.option"), 2);
      this.connectionSpeedModel = new DefaultComboBoxModel();

      for (int var1 = 0; var1 < this.connSpeedData.length; var1++) {
         this.connectionSpeedModel.addElement(this.connSpeedData[var1].getName());
      }

      this.connectionSpeedModel.addListDataListener(this);
      this.colorDepthModel = new DefaultComboBoxModel();

      for (int var2 = 0; var2 < this.colorData.length; var2++) {
         this.colorDepthModel.addElement(this.colorData[var2].getName());
      }

      this.colorDepthModel.addListDataListener(this);
   }

   private void initCompressionPanel() {
      this.setLayout(new BorderLayout());
      JPanel var1 = new JPanel(new SpringLayout());
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      String var2 = this.bundle.getString("ConnectionSpeedLabel.name");
      JLabel var3 = new JLabel(var2, 11);
      this.connSpeedComboBox = new JComboBox(this.connectionSpeedModel);
      this.connSpeedComboBox.addActionListener(this);
      var3.setLabelFor(this.connSpeedComboBox);
      var1.add(var3);
      var1.add(this.connSpeedComboBox);
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      var2 = this.bundle.getString("ColorDepthLabel.name");
      var3 = new JLabel(var2, 11);
      this.colorDepthComboBox = new JComboBox(this.colorDepthModel);
      this.colorDepthComboBox.addActionListener(this);
      var3.setLabelFor(this.colorDepthComboBox);
      var1.add(var3);
      var1.add(this.colorDepthComboBox);
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      var2 = this.bundle.getString("ProgressiveUpdateCheckBox.name");
      this.progressiveUpdateChkBox = new JCheckBox(var2);
      this.progressiveUpdateChkBox.setEnabled(false);
      this.progressiveUpdateChkBox.addActionListener(this);
      var1.add(this.progressiveUpdateChkBox);
      var1.add(Box.createVerticalGlue());
      var2 = this.bundle.getString("InternetFlowControlCheckBox.name");
      this.internetFlowControlChkBox = new JCheckBox(var2);
      this.internetFlowControlChkBox.setEnabled(true);
      this.internetFlowControlChkBox.addChangeListener(this);
      var1.add(this.internetFlowControlChkBox);
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      var3 = new JLabel(this.bundle.getString("SmoothingLabel.name"), 11);
      this.smoothingModel = new SliderRangeModel(10, 0, 50, 1);
      this.smoothingModel.addChangeListener(this);
      this.smoothing = new JSlider(this.smoothingModel);
      var3.setLabelFor(this.smoothing);
      var1.add(var3);
      Hashtable var4 = new Hashtable();
      var2 = this.bundle.getString("SmoothingSliderMinLabel.name");
      var4.put(new Integer(this.smoothingModel.getMinimum()), new JLabel(var2));
      var2 = this.bundle.getString("SmoothingSliderMaxLabel.name");
      var4.put(new Integer(this.smoothingModel.getMaximum()), new JLabel(var2));
      this.smoothing.setLabelTable(var4);
      this.smoothing.setPaintLabels(true);
      var1.add(this.smoothing);
      var1.add(Box.createVerticalGlue());
      var1.add(Box.createVerticalGlue());
      SpringUtilities.makeCompactGrid(var1, 11, 2, 6, 6, 6, 6);
      JPanel var5 = new JPanel();
      var5.setLayout(new BoxLayout(var5, 2));
      String var6 = this.bundle.getString("FramesPerSecondGroupPanel.name");
      CompoundBorder var7 = BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var6), BorderFactory.createEmptyBorder(5, 15, 5, 15));
      var5.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(6, 6, 6, 6), var7));
      ButtonGroup var8 = new ButtonGroup();
      var6 = this.bundle.getString("5fps.name");
      this.fps5 = new JRadioButton(var6);
      var8.add(this.fps5);
      this.fps5.addActionListener(this);
      var5.add(this.fps5);
      var5.add(Box.createHorizontalGlue());
      var6 = this.bundle.getString("10fps.name");
      this.fps10 = new JRadioButton(var6);
      var8.add(this.fps10);
      this.fps10.addActionListener(this);
      var5.add(this.fps10);
      var5.add(Box.createHorizontalGlue());
      var6 = this.bundle.getString("20fps.name");
      this.fps20 = new JRadioButton(var6);
      var8.add(this.fps20);
      this.fps20.addActionListener(this);
      var5.add(this.fps20);
      this.add(var1, "North");
      this.add(var5, "Center");
   }

   private int getConnectionSpeedSelection() {
      return this.connectionSpeedModel.getIndexOf(this.connectionSpeedModel.getSelectedItem());
   }

   private int getColorDepthSelection() {
      return this.colorDepthModel.getIndexOf(this.colorDepthModel.getSelectedItem());
   }

   private boolean getProgressiveUpdateSetting() {
      return this.progressiveUpdateChkBox.isSelected();
   }

   private boolean getInternetFlowControlSetting() {
      return this.internetFlowControlChkBox.isSelected();
   }

   public void setCompParams(TRSRVR_COMP_PARAMS var1) {
      this.clearAllFields();
      this.compParams = var1;
      if (this.compParams != null) {
         this.smoothingModel.setValue(this.compParams.getSmoothing());
         int var2 = 0;
         if ((this.compParams.getFlags() & 1) == 0) {
            for (int var3 = 0; var3 < this.connSpeedData.length; var3++) {
               if (this.connSpeedData[var3].getValue() == this.compParams.getSpeed()) {
                  var2 = var3;
                  break;
               }
            }
         }

         String var9 = (String)this.connectionSpeedModel.getElementAt(var2);
         this.connectionSpeedModel.setSelectedItem(var9);
         int var4 = 0;
         if ((this.compParams.getFlags() & 2) == 0) {
            for (int var5 = 0; var5 < this.colorData.length; var5++) {
               if (this.colorData[var5].getValue() == this.compParams.getCCT()) {
                  var4 = var5;
                  break;
               }
            }
         }

         var9 = (String)this.colorDepthModel.getElementAt(var4);
         this.colorDepthModel.setSelectedItem(var9);
         boolean var11 = (this.compParams.getFlags() & 128) != 0;
         this.internetFlowControlChkBox.setSelected(var11);
         boolean var6 = (this.compParams.getFlags() & 32768) != 0;
         this.progressiveUpdateChkBox.setSelected(var6);
         int var7 = this.compParams.getSmoothing();
         this.smoothingModel.setValue(var7);
         int var8 = 0;
         if (this.compParams.getMinFrameTime() > 1) {
            var8 = 200 / this.compParams.getMinFrameTime() - 1;
         }

         switch (var8) {
            case 0:
               this.fps5.setSelected(true);
               break;
            case 1:
               this.fps10.setSelected(true);
               break;
            case 2:
               this.fps20.setSelected(true);
         }
      }
   }

   public TRSRVR_COMP_PARAMS getCompParams() {
      this.compParams = new TRSRVR_COMP_PARAMS();
      int var1 = 0;
      if (this.progressiveUpdateChkBox.isSelected()) {
         var1 |= 32768;
      } else {
         var1 &= -32769;
      }

      var1 |= 24;
      if (this.internetFlowControlChkBox.isSelected()) {
         var1 |= 128;
      } else {
         var1 &= -129;
      }

      this.compParams.setFlags(var1);
      int var2 = this.getColorDepthSelection();
      this.compParams.setCCT((short)this.colorData[var2].getValue());
      this.compParams.setCacheDepth((short)0);
      this.compParams.setCompressMode(2);
      var2 = this.getConnectionSpeedSelection();
      this.compParams.setSpeed(this.connSpeedData[var2].getValue());
      this.compParams.setMinFrameTime(200 / (this.getFramesPerSecond() + 1));
      this.compParams.setMaxFrameTime(0);
      this.compParams.setSmoothing(this.smoothingModel.getValue());
      return this.compParams;
   }

   public void setCompSettingsModified(boolean var1) {
      if (var1 && !this.compSettingsModified) {
         this.compSettingsModified = true;
         this.firePropertyChange("COMPRESSION_PANEL_SETTINGS_CHANGED", null, null);
      } else {
         this.compSettingsModified = var1;
      }
   }

   @Override
   public void setDefaultFocussedComponent() {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            CompressionPanel.this.connSpeedComboBox.grabFocus();
         }
      });
   }

   @Override
   public void stateChanged(ChangeEvent var1) {
      this.setCompSettingsModified(true);
      this.checkApplyButton();
   }

   @Override
   public void intervalAdded(ListDataEvent var1) {
   }

   @Override
   public void intervalRemoved(ListDataEvent var1) {
   }

   @Override
   public void contentsChanged(ListDataEvent var1) {
      this.setCompSettingsModified(true);
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void makeLayout() {
      this.initComboDataModels();
      this.initCompressionPanel();
      this.addFocusListener(this);
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      Object var2 = var1.getSource();
      if (var2 instanceof JComboBox) {
         if (var2 == this.colorDepthComboBox) {
            if (((JComboBox)var2).getSelectedIndex() == 0) {
               this.progressiveUpdateChkBox.setEnabled(false);
            } else {
               this.progressiveUpdateChkBox.setEnabled(true);
            }
         }

         this.checkApplyButton();
      }

      if (var2 instanceof JCheckBox || var2 instanceof JRadioButton) {
         this.checkApplyButton();
      }
   }

   public void fillDevicePreferences(DevicePreferences var1) {
      this.clearAllFields();
      if (var1 != null) {
         int var2 = var1.getConnectionSpeed();
         int var3 = 0;

         for (int var4 = 0; var4 < this.connSpeedData.length; var4++) {
            if (this.connSpeedData[var4].getValue() == var2) {
               var3 = var4;
               break;
            }
         }

         String var11 = (String)this.connectionSpeedModel.getElementAt(var3);
         this.connectionSpeedModel.setSelectedItem(var11);
         int var5 = var1.getColorDepth();
         int var6 = 0;

         for (int var7 = 0; var7 < this.colorData.length; var7++) {
            if (this.colorData[var7].getValue() == var5) {
               var6 = var7;
               break;
            }
         }

         var11 = (String)this.colorDepthModel.getElementAt(var6);
         this.colorDepthModel.setSelectedItem(var11);
         boolean var13 = var1.isProgressiveUpdate();
         this.progressiveUpdateChkBox.setSelected(var13);
         boolean var8 = var1.isFlowControl();
         this.internetFlowControlChkBox.setSelected(var8);
         int var9 = var1.getSmoothing();
         this.smoothingModel.setValue(var9);
         int var10 = var1.getFramesPerSecond();
         switch (var10) {
            case 0:
               this.fps5.setSelected(true);
               break;
            case 1:
               this.fps10.setSelected(true);
               break;
            case 2:
               this.fps20.setSelected(true);
         }
      }
   }

   public void feedDevicePreferences(DevicePreferences var1) {
      if (var1 != null) {
         int var2 = this.getConnectionSpeedSelection();
         var1.setConnectionSpeed(this.connSpeedData[var2].getValue());
         var2 = this.getColorDepthSelection();
         var1.setColorDepth(this.colorData[var2].getValue());
         var1.setProgressiveUpdate(this.progressiveUpdateChkBox.isSelected());
         var1.setFlowControl(this.internetFlowControlChkBox.isSelected());
         var1.setSmoothing(this.smoothingModel.getValue());
         var1.setFramesPerSecond(this.getFramesPerSecond());
      }
   }

   public int getFramesPerSecond() {
      if (this.fps10.isSelected()) {
         return 1;
      } else {
         return this.fps20.isSelected() ? 2 : 0;
      }
   }

   private void clearAllFields() {
      this.connectionSpeedModel.setSelectedItem(this.connSpeedData[0].getName());
      this.colorDepthModel.setSelectedItem(this.colorData[0].getName());
      this.progressiveUpdateChkBox.setSelected(false);
      this.progressiveUpdateChkBox.setEnabled(false);
      this.internetFlowControlChkBox.setSelected(false);
      this.smoothingModel.setValue(0);
      this.fps5.setSelected(true);
   }

   @Override
   public void focusGained(FocusEvent var1) {
      this.setDefaultFocussedComponent();
   }

   public void focusLose(FocusEvent var1) {
      this.connSpeedComboBox.removeFocusListener(this);
   }

   private void checkApplyButton() {
      Container var1 = this.getParent().getParent();
      if (var1 instanceof PropertiesPanel) {
         ((PropertiesPanel)var1).setApplyButton(true);
      } else if (var1 instanceof ModifyConnectionPanel) {
         ((ModifyConnectionPanel)var1).setApplyButton(true);
      }
   }

   public void setEnabledConnSpeedComboBox(boolean var1) {
      this.connSpeedComboBox.setEnabled(var1);
   }

   public void setEnabledProgressiveUpdateChkBox(boolean var1) {
      this.progressiveUpdateChkBox.setEnabled(var1);
   }

   public void setEnabledColorDepthChkBox(boolean var1) {
      this.colorDepthComboBox.setEnabled(var1);
   }

   public void setEnabledInternetFlowControlChkBox(boolean var1) {
      this.internetFlowControlChkBox.setEnabled(var1);
   }

   public void setEnabledSmoothingSlider(boolean var1) {
      this.smoothing.setEnabled(var1);
   }

   private class ComboData {
      private String name;
      private int value;

      public ComboData(String var2, int var3) {
         this.name = var2;
         this.value = var3;
      }

      public String getName() {
         return this.name;
      }

      public int getValue() {
         return this.value;
      }
   }
}
