package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.ProductCodes;
import com.raritan.rrc.ui.RRCApplet;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.NumericField;
import com.raritan.rrc.util.ModemOSSupport;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.rrc.util.StringUtils;
import com.raritan.rrc.util.modem.ModemConnector;
import com.raritan.rrc.util.modem.PPPDConnector;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.util.Constants;
import com.raritan.tools.util.Util;
import java.awt.CardLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.text.MessageFormat;
import java.util.ArrayList;
import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;
import netscape.javascript.JSException;
import netscape.javascript.JSObject;
import nn.pp.common.LimitedLengthDocument;

public class ConnectPanel extends AbstractDisplay implements ListDataListener, KeyListener {
   private static final long serialVersionUID = 2090033975490792355L;
   protected RaritanPropertyResourceBundle bundle;
   private DefaultComboBoxModel connTypeCbModel;
   private DefaultComboBoxModel productsCbModel;
   private DefaultComboBoxModel modemCbModel;
   private final JTextField descriptionField = new JTextField();
   private final JPanel connectionPanel = new JPanel(new CardLayout());
   private final JRadioButton ipAddrRadioButton = new JRadioButton();
   private final JRadioButton nameRadioButton = new JRadioButton();
   private final JRadioButton dnsRadioButton = new JRadioButton();
   private final JTextField ipTextField = new JTextField();
   private final JTextField nameField = new JTextField();
   private final JTextField dnsField = new JTextField();
   private final NumericField phoneNumberField = new NumericField("0");
   private boolean generationOneDevice = false;
   private final JCheckBox defDiscoveryPortNoChkBox = new JCheckBox();
   private final JLabel discoveryPortNoLabel = new JLabel("", 11);
   private final JTextField discoveryPortNoField = new NumericField(Constants.NETWORKCONFIG_DEFAULT_PORT, 5);
   private final JCheckBox defHttpsPortNoChkBox = new JCheckBox();
   private final JLabel httpsPortNoLabel = new JLabel("", 11);
   private final JTextField httpsPortNoField = new NumericField(String.valueOf(Constants.DEFAULT_HTTPS_PORT), 5);
   private final JComboBox modemCbBox = new JComboBox();
   private final JComboBox productsCombo = new JComboBox();
   private final JComboBox connTypeCombo = new JComboBox();
   private final JTextField modemNameField = new JTextField();
   private final String[] connectionType = new String[2];
   private final ArrayList productType = new ArrayList();
   private final ArrayList generationOneList = new ArrayList();
   private final ArrayList generationTwoList = new ArrayList();
   private String commandKey;

   public ConnectPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.connectionType[0] = this.bundle.getString("tcpIpConnectionType");
      this.connectionType[1] = this.bundle.getString("dialUpConnectionType");
      ProductCodes var3 = ProductCodes.getInstance();
      this.productType.add(var3.getProductCode(0));
      this.productType.add(var3.getProductCode(1));
      this.productType.add(var3.getProductCode(2));
      this.productType.add(var3.getProductCode(3));
      this.productType.add(var3.getProductCode(4));
      this.productType.add(var3.getProductCode(5));
      this.productType.add(var3.getProductCode(6));
      this.productType.add(var3.getProductCode(7));
      this.productType.add(var3.getProductCode(8));
      this.generationOneList.add(var3.getProductCode(1));
      this.generationOneList.add(var3.getProductCode(3));
      this.generationOneList.add(var3.getProductCode(5));
      this.generationOneList.add(var3.getProductCode(6));
      this.generationOneList.add(var3.getProductCode(8));
      this.generationTwoList.add(var3.getProductCode(0));
      this.generationTwoList.add(var3.getProductCode(2));
      this.generationTwoList.add(var3.getProductCode(4));
      this.generationTwoList.add(var3.getProductCode(7));
      this.makeLayout();
   }

   private void initComboModel() {
      this.connTypeCbModel = new DefaultComboBoxModel<>(this.connectionType);
      this.productsCbModel = new DefaultComboBoxModel<>(this.productType.toArray());
      this.modemCbModel = new DefaultComboBoxModel();
      this.connTypeCbModel.setSelectedItem(this.connectionType[0]);
   }

   private void clearAllFields() {
      this.descriptionField.setText("");
      this.nameField.setText("");
      this.dnsField.setText("");
      this.phoneNumberField.setText("");
      this.discoveryPortNoField.setText(Constants.NETWORKCONFIG_DEFAULT_PORT);
      this.httpsPortNoField.setText(String.valueOf(((RRCScreenContext)this.scrContext).getAppSettings().getDefaultHttpsPort()));
      this.ipAddrRadioButton.setSelected(true);
      this.defDiscoveryPortNoChkBox.setSelected(true);
      this.defHttpsPortNoChkBox.setSelected(true);
      this.discoveryPortNoField.setEditable(false);
      this.httpsPortNoField.setEditable(false);
      this.connTypeCbModel.setSelectedItem(this.connectionType[0]);
      this.productsCbModel.setSelectedItem(this.productType.get(0));
   }

   @Override
   public void setDefaultFocussedComponent() {
      if (OS.getCurrent() == OS.SOLARIS) {
         if (this.descriptionField.isEnabled()) {
            this.descriptionField.grabFocus();
         } else {
            this.discoveryPortNoField.grabFocus();
         }
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               if (ConnectPanel.this.descriptionField.isEnabled()) {
                  ConnectPanel.this.descriptionField.grabFocus();
               } else {
                  ConnectPanel.this.discoveryPortNoField.grabFocus();
               }

               if (OS.getCurrent() == OS.MAC) {
                  ((JTabbedPane)ConnectPanel.this.getParent()).repaint();
               }
            }
         });
      }
   }

   private void setSelectedFindBy(int var1) {
      if (var1 == 0) {
         this.ipAddrRadioButton.setSelected(true);
         if (this.commandKey.equals("showNewProfileCommand") || this.commandKey.equals("showModifyProfileCommand")) {
            this.ipTextField.setEditable(true);
            this.ipTextField.setEnabled(true);
         }

         this.nameField.setEditable(false);
         this.nameField.setEnabled(false);
         this.dnsField.setEditable(false);
         this.dnsField.setEnabled(false);
      } else if (var1 == 1) {
         this.nameRadioButton.setSelected(true);
         this.ipTextField.setEditable(false);
         this.ipTextField.setEnabled(false);
         this.nameField.setEditable(true);
         this.nameField.setEnabled(true);
         this.dnsField.setEditable(false);
         this.dnsField.setEnabled(false);
      } else if (var1 == 2) {
         this.dnsRadioButton.setSelected(true);
         this.ipTextField.setEditable(false);
         this.ipTextField.setEnabled(false);
         this.nameField.setEditable(false);
         this.nameField.setEnabled(false);
         this.dnsField.setEditable(true);
         this.dnsField.setEnabled(true);
      }
   }

   private int getSelectedFindBy() {
      if (this.nameRadioButton.isSelected()) {
         return 1;
      } else {
         return this.dnsRadioButton.isSelected() ? 2 : 0;
      }
   }

   @Override
   public void intervalAdded(ListDataEvent var1) {
   }

   @Override
   public void intervalRemoved(ListDataEvent var1) {
   }

   @Override
   public void contentsChanged(ListDataEvent var1) {
      if (var1.getSource() instanceof DefaultComboBoxModel) {
         DefaultComboBoxModel var2 = (DefaultComboBoxModel)var1.getSource();
         ((CardLayout)this.connectionPanel.getLayout()).show(this.connectionPanel, (String)var2.getSelectedItem());
         if (((String)var2.getSelectedItem()).equals(this.connectionType[1])) {
            if (ModemOSSupport.isOSSupported()) {
               JSObject var4 = null;
               if (this.scrContext.getApplication() instanceof RRCApplet) {
                  try {
                     var4 = JSObject.getWindow((RRCApplet)this.scrContext.getApplication());
                  } catch (JSException var9) {
                  }
               }

               ModemConnector var3 = ModemConnector.getConnector(var4);
               long var5 = var3.rasEnumDevices();
               Object var7 = null;
               if (OS.getCurrent() == OS.WINDOWS) {
                  this.modemCbModel.removeAllElements();

                  for (int var8 = 0; var8 < var5; var8++) {
                     if (var3.rasGetDeviceType(var8).equals("modem")) {
                        var7 = var3.rasGetDeviceName(var8);
                        if (this.modemCbModel.getIndexOf(var7) == -1) {
                           this.modemCbModel.addElement(var7);
                        }
                     }
                  }

                  if (this.modemCbModel.getSize() == 0) {
                     var7 = this.bundle.getString("modemType");
                     this.modemCbModel.addElement(var7);
                     this.modemCbModel.setSelectedItem(var7);
                  }
               }
            } else {
               CommonPopups.showCommandResultErrorMessage(this.bundle.getString("OSnotsupported.msg"), this, this.scrContext);
            }
         }
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.setVisible(true);
   }

   private static void adjustMaximumSize(JComponent var0) {
      Dimension var1 = var0.getMaximumSize();
      var1.height = var0.getPreferredSize().height;
      var0.setMaximumSize(var1);
   }

   @Override
   public void makeLayout() {
      this.initComboModel();
      this.setLayout(new SpringLayout());
      JPanel var1 = new JPanel(new SpringLayout());
      JLabel var2 = new JLabel(this.bundle.getString("DescriptionLabel.name"), 11);
      var1.add(var2);
      this.descriptionField.setFocusable(true);
      this.descriptionField.setDocument(new LimitedLengthDocument(64));
      var2.setLabelFor(this.descriptionField);
      adjustMaximumSize(this.descriptionField);
      var1.add(this.descriptionField);
      this.descriptionField.addKeyListener(this);
      this.productsCombo.setModel(this.productsCbModel);
      this.productsCombo.setPreferredSize(new Dimension(150, 25));
      this.productsCombo.setMaximumSize(new Dimension(150, 25));
      this.productsCombo.addActionListener(this);
      JLabel var3 = new JLabel(this.bundle.getString("productTypesLabel"), 11);
      var3.setLabelFor(this.productsCombo);
      var1.add(var3);
      var1.add(this.productsCombo);
      var2 = new JLabel(this.bundle.getString("ConnectionTypeLabel.name"), 11);
      var1.add(var2);
      this.connTypeCombo.setModel(this.connTypeCbModel);
      this.connTypeCbModel.addListDataListener(this);
      this.connTypeCombo.setPreferredSize(new Dimension(150, 25));
      this.connTypeCombo.setMaximumSize(new Dimension(150, 25));
      this.connTypeCombo.addActionListener(this);
      var1.add(this.connTypeCombo);
      var2.setLabelFor(this.connTypeCombo);
      SpringUtilities.makeCompactGrid(var1, 3, 2, 6, 6, 6, 6);
      this.add(var1);
      String var4 = this.bundle.getString("FindDeviceByPanel.name");
      JPanel var5 = new JPanel(new SpringLayout());
      var5.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var4), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      ButtonGroup var6 = new ButtonGroup();
      var4 = this.bundle.getString("IpAddressRadioButton.name");
      this.ipAddrRadioButton.setText(var4);
      this.ipAddrRadioButton.addActionListener(this);
      adjustMaximumSize(this.ipAddrRadioButton);
      this.ipAddrRadioButton.setSelected(true);
      var6.add(this.ipAddrRadioButton);
      var5.add(this.ipAddrRadioButton);
      Dimension var7 = this.ipTextField.getPreferredSize();
      this.ipTextField.setPreferredSize(new Dimension(Util.getSizeOfIPV6Component(this.ipTextField.getFontMetrics(this.ipTextField.getFont())), var7.height));
      adjustMaximumSize(this.ipTextField);
      var5.add(this.ipTextField);
      this.ipTextField.addKeyListener(this);
      var4 = this.bundle.getString("DeviceNameRadioButton.name");
      this.nameRadioButton.setText(var4);
      this.nameRadioButton.addActionListener(this);
      var6.add(this.nameRadioButton);
      var5.add(this.nameRadioButton);
      this.nameField.addKeyListener(this);
      this.nameField.setEditable(false);
      adjustMaximumSize(this.nameField);
      var5.add(this.nameField);
      var4 = this.bundle.getString("HostNameRadioButton.name");
      this.dnsRadioButton.setText(var4);
      this.dnsRadioButton.addActionListener(this);
      var6.add(this.dnsRadioButton);
      var5.add(this.dnsRadioButton);
      this.dnsField.addKeyListener(this);
      this.dnsField.setEditable(false);
      adjustMaximumSize(this.dnsField);
      var5.add(this.dnsField);
      SpringUtilities.makeCompactGrid(var5, 3, 2, 5, 6, 5, 6);
      JPanel var8 = new JPanel(new SpringLayout());
      var2 = new JLabel(this.bundle.getString("PhoneNumberLabel.name"), 11);
      var8.add(var2);
      adjustMaximumSize(this.phoneNumberField);
      var8.add(this.phoneNumberField);
      this.phoneNumberField.addKeyListener(this);
      var2 = new JLabel(this.bundle.getString("ModemLabel.name"), 11);
      var8.add(var2);
      OS var9 = OS.getCurrent();
      if (var9 == OS.WINDOWS) {
         this.modemCbBox.setModel(this.modemCbModel);
         this.modemCbBox.setEditable(false);
         this.modemCbBox.addActionListener(this);
         adjustMaximumSize(this.modemCbBox);
         var8.add(this.modemCbBox);
      } else if (var9 != null && var9.isUnixOS()) {
         adjustMaximumSize(this.modemNameField);
         var8.add(this.modemNameField);
         this.modemNameField.addKeyListener(this);
      }

      byte var10 = 2;
      if (var9 != null && var9.isUnixOS()) {
         JPanel var11 = new JPanel();
         var8.add(var11);
         String var12 = MessageFormat.format(this.bundle.getString("DefaultModemUnix.name"), PPPDConnector.getDefaultModem());
         JTextArea var13 = new JTextArea(var12);
         var13.setLineWrap(true);
         var13.setWrapStyleWord(true);
         var13.setEditable(false);
         var13.setAlignmentX(0.5F);
         var13.setBackground(this.getBackground());
         var8.add(var13);
         var10 = 3;
      }

      SpringUtilities.makeCompactGrid(var8, var10, 2, 15, 35, 6, 20);
      this.connectionPanel.add(this.connectionType[0], var5);
      this.connectionPanel.add(this.connectionType[1], var8);
      ((CardLayout)this.connectionPanel.getLayout()).show(this.connectionPanel, this.connectionType[0]);
      this.add(this.connectionPanel);
      var1 = new JPanel(new SpringLayout());
      var4 = this.bundle.getString("DefaultPortNoCheckBox.name") + "                  ";
      this.defHttpsPortNoChkBox.setText(var4);
      this.defHttpsPortNoChkBox.addActionListener(this);
      this.defHttpsPortNoChkBox.setSelected(true);
      var1.add(this.defHttpsPortNoChkBox);
      this.httpsPortNoLabel.setText(this.bundle.getString("HttpsPortNumberLabel.name"));
      var1.add(this.httpsPortNoLabel);
      this.httpsPortNoField.setEditable(false);
      this.httpsPortNoField.setEnabled(false);
      this.httpsPortNoField.setFocusable(true);
      this.httpsPortNoLabel.setEnabled(false);
      this.httpsPortNoField.addKeyListener(this);
      var1.add(this.httpsPortNoField);
      var4 = this.bundle.getString("DefaultPortNoCheckBox.name");
      this.defDiscoveryPortNoChkBox.setText(var4);
      this.defDiscoveryPortNoChkBox.addActionListener(this);
      this.defDiscoveryPortNoChkBox.setSelected(true);
      var1.add(this.defDiscoveryPortNoChkBox);
      this.discoveryPortNoLabel.setText(this.bundle.getString("PortNumberLabel.name"));
      var1.add(this.discoveryPortNoLabel);
      this.discoveryPortNoField.setEditable(false);
      this.discoveryPortNoField.setEnabled(false);
      this.discoveryPortNoField.setFocusable(true);
      this.discoveryPortNoLabel.setEnabled(false);
      this.discoveryPortNoField.addKeyListener(this);
      var1.add(this.discoveryPortNoField);
      SpringUtilities.makeCompactGrid(var1, 2, 3, 6, 6, 6, 6);
      this.add(var1);
      this.addFocusListener(this);
      SpringUtilities.makeCompactGrid(this, 3, 1, 6, 6, 6, 6);
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      Object var2 = var1.getSource();
      this.checkApplyButton();
      if (var2 == this.productsCombo) {
         this.setTabbedPanes();
      }

      if (var2 == this.ipAddrRadioButton) {
         if (this.commandKey.equals("showNewProfileCommand") || this.commandKey.equals("showModifyProfileCommand")) {
            this.ipTextField.setEditable(true);
            this.ipTextField.setEnabled(true);
         }

         this.nameField.setEditable(false);
         this.nameField.setEnabled(false);
         this.dnsField.setEditable(false);
         this.dnsField.setEnabled(false);
      } else if (var2 == this.nameRadioButton) {
         this.ipTextField.setEditable(false);
         this.ipTextField.setEnabled(false);
         this.nameField.setEditable(true);
         this.nameField.setEnabled(true);
         this.dnsField.setEditable(false);
         this.dnsField.setEnabled(false);
      } else if (var2 == this.dnsRadioButton) {
         this.ipTextField.setEditable(false);
         this.ipTextField.setEnabled(false);
         this.nameField.setEditable(false);
         this.nameField.setEnabled(false);
         this.dnsField.setEditable(true);
         this.dnsField.setEnabled(true);
      } else if (var2 == this.defDiscoveryPortNoChkBox) {
         boolean var3 = ((JCheckBox)var2).isSelected();
         this.discoveryPortNoLabel.setEnabled(!var3);
         this.discoveryPortNoField.setEnabled(!var3);
         this.discoveryPortNoField.setEditable(!var3);
         if (!this.discoveryPortNoField.isEditable()) {
            this.discoveryPortNoField.setText(Constants.NETWORKCONFIG_DEFAULT_PORT);
         }
      } else if (var2 == this.defHttpsPortNoChkBox) {
         boolean var4 = ((JCheckBox)var2).isSelected();
         this.httpsPortNoLabel.setEnabled(!var4);
         this.httpsPortNoField.setEnabled(!var4);
         this.httpsPortNoField.setEditable(!var4);
         if (!this.httpsPortNoField.isEditable()) {
            this.httpsPortNoField.setText(String.valueOf(((RRCScreenContext)this.scrContext).getAppSettings().getDefaultHttpsPort()));
         }
      }
   }

   private void setTabbedPanes() {
      if (this.generationTwoList.contains(this.productsCombo.getSelectedItem())) {
         this.generationOneDevice = false;
      }

      if (this.generationOneList.contains(this.productsCombo.getSelectedItem())) {
         this.generationOneDevice = true;
      }

      this.enableGeneration2TabbedPanes();
   }

   private void enableGeneration2TabbedPanes() {
      Container var1 = this.getParent().getParent();
      if (var1 instanceof AddConnectionPanel) {
         ((AddConnectionPanel)var1).setG2Panels(this.generationOneDevice);
      } else {
         ((ModifyConnectionPanel)var1).setG2Panels(this.generationOneDevice);
      }
   }

   public void fillDevicePreferences(DevicePreferences var1) {
      this.clearAllFields();
      if (var1 != null) {
         this.descriptionField.setText(var1.getDescription());
         Object var2 = this.connTypeCbModel.getElementAt(2 - var1.getConnectionType());
         this.connTypeCbModel.setSelectedItem(var2);
         ((CardLayout)this.connectionPanel.getLayout()).show(this.connectionPanel, (String)var2);
         String var3 = var1.getProductType();
         if (!"".equals(var3)) {
            this.productsCombo.setSelectedItem(var3);
            this.setTabbedPanes();
         }

         this.setSelectedFindBy(var1.getFindBy());
         String var4 = var1.getIp();
         InetAddress var5 = null;

         try {
            var5 = InetAddress.getByName(var4);
         } catch (UnknownHostException var9) {
         }

         if (var5 != null && !var5.isAnyLocalAddress()) {
            this.ipTextField.setText(var4);
         } else {
            this.ipTextField.setText("");
         }

         this.nameField.setText(var1.getName());
         this.dnsField.setText(var1.getDnsName());
         int var6 = var1.getPort();
         if (var6 != Integer.parseInt(Constants.NETWORKCONFIG_DEFAULT_PORT)) {
            this.discoveryPortNoField.setText(String.valueOf(var6));
            this.defDiscoveryPortNoChkBox.setSelected(false);
            this.discoveryPortNoField.setEditable(true);
            this.discoveryPortNoField.setEnabled(true);
            this.discoveryPortNoLabel.setEnabled(true);
         } else {
            this.discoveryPortNoField.setText(Constants.NETWORKCONFIG_DEFAULT_PORT);
            this.defDiscoveryPortNoChkBox.setSelected(true);
            this.discoveryPortNoField.setEditable(false);
            this.discoveryPortNoField.setEnabled(false);
            this.discoveryPortNoLabel.setEnabled(false);
         }

         int var7 = var1.getHttpsPort();
         if (var7 != ((RRCScreenContext)this.scrContext).getAppSettings().getDefaultHttpsPort()) {
            this.httpsPortNoField.setText(String.valueOf(var7));
            this.defHttpsPortNoChkBox.setSelected(false);
            this.httpsPortNoField.setEditable(true);
            this.httpsPortNoField.setEnabled(true);
            this.httpsPortNoLabel.setEnabled(true);
         } else {
            this.httpsPortNoField.setText(String.valueOf(((RRCScreenContext)this.scrContext).getAppSettings().getDefaultHttpsPort()));
            this.defHttpsPortNoChkBox.setSelected(true);
            this.httpsPortNoField.setEditable(false);
            this.httpsPortNoField.setEnabled(false);
            this.httpsPortNoLabel.setEnabled(false);
         }

         this.phoneNumberField.setText(var1.getPhone());
         if (OS.getCurrent().isUnixOS()) {
            if (StringUtils.notNullOrEmpty(var1.getModem())) {
               this.modemNameField.setText(var1.getModem());
            } else {
               this.modemNameField.setText(PPPDConnector.getDefaultModem());
            }
         } else if (OS.getCurrent() == OS.WINDOWS && StringUtils.notNullOrEmpty(var1.getModem())) {
            if (this.modemCbModel.getIndexOf(var1.getModem()) == -1 && !this.bundle.getString("modemType").equals(var1.getModem())) {
               this.modemCbModel.insertElementAt(var1.getModem(), 0);
            }

            this.modemCbModel.setSelectedItem(var1.getModem());
         }

         if (this.modemCbModel.getSize() == 0) {
            String var8 = this.bundle.getString("modemType");
            this.modemCbModel.addElement(var8);
            this.modemCbModel.setSelectedItem(var8);
         }
      }

      if (this.commandKey.equals("showNewProfileCommand")) {
         this.ipTextField.setEditable(true);
         this.ipTextField.setEnabled(true);
      } else if (this.commandKey.equals("showModifyProfileCommand")) {
         this.descriptionField.setEditable(true);
         this.descriptionField.setEnabled(true);
      } else {
         this.ipTextField.setEditable(false);
         this.ipTextField.setEnabled(false);
      }
   }

   public void feedDevicePreferences(DevicePreferences var1) {
      if (var1 != null) {
         var1.setDescription(this.descriptionField.getText());
         int var2 = this.connTypeCbModel.getIndexOf(this.connTypeCbModel.getSelectedItem());
         var1.setConnectionType(2 - var2);
         var1.setProductType((String)this.productsCombo.getSelectedItem());
         var1.setFindBy(this.getSelectedFindBy());
         var1.setIp("");
         var1.setName("");
         var1.setDnsName("");
         var1.setPhone("");
         var1.setModem("");
         switch (var1.getConnectionType()) {
            case 1:
               var1.setPhone(this.phoneNumberField.getText());
               String var3 = null;
               OS var4 = OS.getCurrent();
               if (var4 == OS.WINDOWS) {
                  var3 = (String)this.modemCbModel.getSelectedItem();
               } else if (var4 != null && var4.isUnixOS()) {
                  var3 = this.modemNameField.getText();
               }

               if (var3 != null && !this.bundle.getString("modemType").equals(var3)) {
                  var1.setModem(var3);
               }
               break;
            case 2:
               switch (this.getSelectedFindBy()) {
                  case 0:
                     var1.setIp(this.ipTextField.getText());
                     break;
                  case 1:
                     var1.setName(this.nameField.getText());
                     break;
                  case 2:
                     var1.setDnsName(this.dnsField.getText());
               }
         }

         int var8 = Integer.parseInt(Constants.NETWORKCONFIG_DEFAULT_PORT);
         if (!this.defDiscoveryPortNoChkBox.isSelected()) {
            try {
               var8 = Integer.parseInt(this.discoveryPortNoField.getText());
            } catch (NumberFormatException var7) {
            }
         }

         var1.setPort(var8);
         int var9 = ((RRCScreenContext)this.scrContext).getAppSettings().getDefaultHttpsPort();
         if (!this.defHttpsPortNoChkBox.isSelected()) {
            try {
               var9 = Integer.parseInt(this.httpsPortNoField.getText());
            } catch (NumberFormatException var6) {
            }
         }

         var1.setHttpsPort(var9);
      }
   }

   public void setCommandKey(String var1) {
      this.commandKey = var1;
   }

   private void checkApplyButton() {
      Container var1 = this.getParent().getParent();
      if (var1 instanceof ModifyConnectionPanel) {
         ((ModifyConnectionPanel)var1).setApplyButton(true);
      }
   }

   @Override
   public void keyPressed(KeyEvent var1) {
   }

   @Override
   public void keyReleased(KeyEvent var1) {
   }

   @Override
   public void keyTyped(KeyEvent var1) {
      this.checkApplyButton();
   }
}
