package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.commands.DoCopyToClipboardCommand;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.Map;
import java.util.Vector;
import javaclientlib.tr.TRRSP_NEW_VIDEO_MODE_DATA;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.Timer;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableColumn;
import javax.swing.table.TableModel;
import nn.pp.rccore.IVideoSettings;
import nn.pp.rccore.RCAdapter;
import nn.pp.rccore.RCCore;

public class ConnectionInfoPanel extends AbstractDisplay {
   private static final long serialVersionUID = -3541216498677992876L;
   private static final int MILLISECONDS_IN_SECOND = 1000;
   private static final int MILLISECONDS_IN_MINUTE = 60000;
   private static final int MILLISECONDS_IN_HOUR = 3600000;
   private static final int MILLISECONDS_IN_DAY = 86400000;
   private final String[] headerItems = this.bundle.getMultyValue("connectioninfo.tableheader.lable");
   private JTable table;
   private DefaultTableModel model;
   private IPReach dev;
   private DeviceConnector devCon;
   private TRRSP_NEW_VIDEO_MODE_DATA videoMode;
   private final String[] labels = new String[24];
   private Timer updateTimer;
   private long lastTime;
   private long lastDataIn;
   private long lastDataOut;
   private DeviceView parentView = null;
   private RCCore rccore = null;
   private RCAdapter adapter = null;

   public ConnectionInfoPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.labels[0] = this.bundle.getString("connectioninfo.devicename.row");
      this.labels[1] = this.bundle.getString("connectioninfo.ipaddress.row");
      this.labels[2] = this.bundle.getString("connectioninfo.port.row");
      this.labels[3] = this.bundle.getString("connectioninfo.datainpersecond.row");
      this.labels[4] = this.bundle.getString("connectioninfo.dataoutpersecond.row");
      this.labels[5] = this.bundle.getString("connectioninfo.connecttime.row");
      this.labels[6] = this.bundle.getString("connectioninfo.horizontalresolution.row");
      this.labels[7] = this.bundle.getString("connectioninfo.verticalresolution.row");
      this.labels[8] = this.bundle.getString("connectioninfo.refreshrate.row");
      this.labels[9] = this.bundle.getString("connectioninfo.protocolversion.row");
      this.labels[10] = this.bundle.getString("connectioninfo.oldestsupportedversion.row");
      this.labels[11] = this.bundle.getString("connectioninfo.hardwareversion.row");
      this.labels[12] = this.bundle.getString("connectioninfo.softwareversion.row");
      this.labels[13] = this.bundle.getString("connectioninfo.postcode.row");
      this.labels[14] = this.bundle.getString("connectioninfo.networkflags.row");
      this.labels[15] = this.bundle.getString("connectioninfo.securityflags.row");
      this.labels[16] = this.bundle.getString("connectioninfo.options.row");
      this.labels[17] = this.bundle.getString("connectioninfo.framegrabberinfo.row");
      this.labels[18] = this.bundle.getString("connectioninfo.kmeinfo.row");
      this.labels[19] = this.bundle.getString("connectioninfo.serialinfo.row");
      this.labels[20] = this.bundle.getString("connectioninfo.videodevicescount.row");
      this.labels[21] = this.bundle.getString("connectioninfo.serialdevicescount.row");
      this.labels[22] = this.bundle.getString("connectioninfo.reserved.row");
      this.labels[23] = this.bundle.getString("connectioninfo.FPS.row");
      this.makeLayout();
      this.setShell(this.bundle.getString("connectioninfo.panel.title"));
   }

   @Override
   public void makeLayout() {
      this.setLayout(new BorderLayout());
      this.model = new DefaultTableModel(this.headerItems, 0);
      this.table = new JTable(this.model);
      TableColumn var1 = this.table.getColumn(this.headerItems[1]);
      int var2 = var1.getWidth();
      var1 = this.table.getColumn(this.headerItems[0]);
      var2 = var1.getWidth();
      this.table.setEnabled(false);
      this.table.setShowGrid(false);
      this.table.setModel(this.model);
      this.table.setRowSelectionAllowed(false);
      this.table.setColumnSelectionAllowed(false);
      JScrollPane var3 = new JScrollPane(this.table);
      var3.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
      this.add(var3, "Center");
      this.add(this.doButtonWidget(), "South");
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("connectioninfo.copytoclipboard.button"), this.scrContext);
      this.ok.setCommand(new DoCopyToClipboardCommand(this.scrContext));
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("connectioninfo.close.button"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(1));
      var1.add(this.ok);
      var1.add(this.cancel);
      return var1;
   }

   private void addRows(Class var1) {
      if (this.model != null && this.model.getRowCount() > 0) {
         for (int var2 = this.model.getRowCount() - 1; var2 >= 0; var2--) {
            this.model.removeRow(var2);
         }
      }

      if (KvmView.class.equals(var1)) {
         for (int var3 = 0; var3 < this.labels.length; var3++) {
            this.model.addRow(new Object[]{new Integer(var3), this.labels[var3], null});
         }
      } else {
         if (!RFBView.class.equals(var1)) {
            throw new IllegalArgumentException("Unknown view " + var1);
         }

         this.model.addRow(new Object[]{new Integer(0), this.labels[0], null});
         this.model.addRow(new Object[]{new Integer(1), this.labels[1], null});
         this.model.addRow(new Object[]{new Integer(2), this.labels[2], null});
         this.model.addRow(new Object[]{new Integer(3), this.labels[3], null});
         this.model.addRow(new Object[]{new Integer(4), this.labels[4], null});
         this.model.addRow(new Object[]{new Integer(5), this.labels[23], null});
         this.model.addRow(new Object[]{new Integer(6), this.labels[5], null});
         this.model.addRow(new Object[]{new Integer(7), this.labels[6], null});
         this.model.addRow(new Object[]{new Integer(8), this.labels[7], null});
         this.model.addRow(new Object[]{new Integer(9), this.labels[8], null});
         this.model.addRow(new Object[]{new Integer(10), this.labels[9], null});
      }
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.dev = (IPReach)var1.getCommandParameter("deviceNode");
      this.devCon = this.dev.getDeviceConnector();
      this.videoMode = (TRRSP_NEW_VIDEO_MODE_DATA)var1.getCommandParameter("VIDEO_MODE");
      this.parentView = (DeviceView)var1.getCommandParameter("DEVICE_VIEW");
      if (this.parentView == null) {
         throw new NullPointerException("Parent view is null in command context");
      } else {
         this.lastTime = System.currentTimeMillis();
         this.lastDataIn = this.devCon.getDataIn();
         this.lastDataOut = this.devCon.getDataOut();
         this.addRows(this.parentView.getClass());
         if (this.parentView instanceof KvmView) {
            this.setKX1StaticData(var1);
            this.updateTable((KvmView)this.parentView);
         } else if (this.parentView instanceof RFBView) {
            this.rccore = ((RFBView)this.parentView).getRCCore();
            this.adapter = new RCAdapter() {
               @Override
               public void videoSettingsUpdated(IVideoSettings var1) {
                  if (var1.getRefreshRate().isSupported()) {
                     if (var1.getRefreshRate().isSupported()) {
                        ConnectionInfoPanel.this.model.setValueAt(var1.getRefreshRate().getValue() + " Hz", 9, 2);
                     }

                     ConnectionInfoPanel.this.rccore.removeVideoEventListener(ConnectionInfoPanel.this.adapter);
                  }
               }

               @Override
               public void deviceNameChanged(String var1) {
                  ConnectionInfoPanel.this.model.setValueAt(var1, 0, 2);
               }
            };
            this.rccore.addVideoEventListener(this.adapter, 8);
            this.rccore.addConnectionEventListener(this.adapter, 128);

            try {
               this.rccore.requestVideoSettingsUpdates();
            } catch (IOException var3) {
               RRCLogger.log(150, "Unable to request Video Settings Updates");
            }

            this.setKX2StaticData(var1);
            this.updateTable((RFBView)this.parentView);
         }

         int var2 = initColumnSizes(this.table);
         var2 += this.table.getIntercellSpacing().width * this.table.getColumnCount();
         var2 += 50;
         this.table.setPreferredScrollableViewportSize(new Dimension(var2, this.table.getRowHeight() * this.table.getRowCount()));
         this.getShell().pack();
         this.startUpdateTimer();
      }
   }

   private void setKX2StaticData(CommandContext var1) {
      Map var2 = (Map)var1.getCommandParameter("STATIC_CONN_INFO");
      if (var2 != null) {
         this.model.setValueAt(this.rccore.getDeviceName(), 0, 2);
         String var3 = (String)var2.get("IP");
         if (var3 != null) {
            this.model.setValueAt(var3, 1, 2);
         } else {
            this.model.setValueAt("", 1, 2);
         }

         var3 = (String)var2.get("PORT");
         if (var3 != null) {
            this.model.setValueAt(var3, 2, 2);
         } else {
            this.model.setValueAt("", 2, 2);
         }

         IVideoSettings var4 = ((RFBView)this.parentView).getVideoSettings();
         this.model.setValueAt("", 7, 2);
         this.model.setValueAt("", 8, 2);
         this.model.setValueAt("", 9, 2);
         if (var4 != null) {
            if (var4.getResolutionX().isSupported()) {
               this.model.setValueAt(String.valueOf(var4.getResolutionX().getValue()), 7, 2);
            }

            if (var4.getResolutionY().isSupported()) {
               this.model.setValueAt(String.valueOf(var4.getResolutionY().getValue()), 8, 2);
            }

            if (var4.getRefreshRate().isSupported()) {
               this.model.setValueAt(var4.getRefreshRate().getValue() + " Hz", 9, 2);
            }
         } else {
            RRCLogger.log(300, 512, "Unable to fetch Video Settings");
         }

         var3 = (String)var2.get("PROTO_VER");
         if (var3 != null) {
            this.model.setValueAt(var3, 10, 2);
         }
      }
   }

   private void setKX1StaticData(CommandContext var1) {
      Map var2 = (Map)var1.getCommandParameter("STATIC_CONN_INFO");
      if (var2 != null) {
         String var3 = (String)var2.get("DESCRIPTION");
         if (var3 != null) {
            this.model.setValueAt(var3, 0, 2);
         } else {
            this.model.setValueAt("", 0, 2);
         }

         var3 = (String)var2.get("IP");
         if (var3 != null) {
            this.model.setValueAt(var3, 1, 2);
         } else {
            this.model.setValueAt("", 1, 2);
         }

         var3 = (String)var2.get("PORT");
         if (var3 != null) {
            this.model.setValueAt(var3, 2, 2);
         } else {
            this.model.setValueAt("", 2, 2);
         }

         var3 = (String)var2.get("SCREEN_SIZE");
         if (var3 != null) {
            Dimension var4 = (Dimension)var3;
            this.model.setValueAt(new Integer(var4.width), 6, 2);
            this.model.setValueAt(new Integer(var4.height), 7, 2);
         } else {
            this.model.setValueAt("", 22, 2);
         }

         var3 = (String)var2.get("PROTO_VER");
         if (var3 != null) {
            this.model.setValueAt(var3, 9, 2);
         } else {
            this.model.setValueAt("", 9, 2);
         }

         var3 = (String)var2.get("OLDEST_PROTO_VER");
         if (var3 != null) {
            this.model.setValueAt(var3, 10, 2);
         } else {
            this.model.setValueAt("", 10, 2);
         }

         var3 = (String)var2.get("HW_VER");
         if (var3 != null) {
            this.model.setValueAt(var3, 11, 2);
         } else {
            this.model.setValueAt("", 11, 2);
         }

         var3 = (String)var2.get("SW_VER");
         if (var3 != null) {
            this.model.setValueAt(var3, 12, 2);
         } else {
            this.model.setValueAt("", 12, 2);
         }

         var3 = (String)var2.get("POST");
         if (var3 != null) {
            this.model.setValueAt(var3, 13, 2);
         } else {
            this.model.setValueAt("", 13, 2);
         }

         var3 = (String)var2.get("NET_FLAGS");
         if (var3 != null) {
            this.model.setValueAt(var3, 14, 2);
         } else {
            this.model.setValueAt("", 14, 2);
         }

         var3 = (String)var2.get("SECURITY_FLAGS");
         if (var3 != null) {
            this.model.setValueAt(var3, 15, 2);
         } else {
            this.model.setValueAt("", 15, 2);
         }

         var3 = (String)var2.get("OPTIONS");
         if (var3 != null) {
            this.model.setValueAt(var3, 16, 2);
         } else {
            this.model.setValueAt("", 16, 2);
         }

         var3 = (String)var2.get("FG_INFO");
         if (var3 != null) {
            this.model.setValueAt(var3, 17, 2);
         } else {
            this.model.setValueAt("", 17, 2);
         }

         var3 = (String)var2.get("KVM_INFO");
         if (var3 != null) {
            this.model.setValueAt(var3, 18, 2);
         } else {
            this.model.setValueAt("", 18, 2);
         }

         var3 = (String)var2.get("SERIAL_INFO");
         if (var3 != null) {
            this.model.setValueAt(var3, 19, 2);
         } else {
            this.model.setValueAt("", 19, 2);
         }

         var3 = (String)var2.get("NUM_VD_DEVICES");
         if (var3 != null) {
            this.model.setValueAt(var3, 20, 2);
         } else {
            this.model.setValueAt("", 20, 2);
         }

         var3 = (String)var2.get("NUM_SERIAL_DEVICES");
         if (var3 != null) {
            this.model.setValueAt(var3, 21, 2);
         } else {
            this.model.setValueAt("", 21, 2);
         }

         var3 = (String)var2.get("RESERVED");
         if (var3 != null) {
            this.model.setValueAt(var3, 22, 2);
         } else {
            this.model.setValueAt("", 22, 2);
         }
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      StringBuffer var2 = new StringBuffer();
      Vector var3 = this.model.getDataVector();

      for (int var4 = 0; var4 < this.model.getRowCount(); var4++) {
         var2.append(((Vector)var3.elementAt(var4)).elementAt(0));
         var2.append(" ");
         var2.append(((Vector)var3.elementAt(var4)).elementAt(1));
         var2.append(" : ");
         var2.append(((Vector)var3.elementAt(var4)).elementAt(2));
         var2.append("\n");
      }

      var1.setCommandParameter("clipboardText", var2.toString());
   }

   private void updateTable(KvmView var1) {
      if (this.dev != null && this.devCon != null && this.videoMode != null) {
         long var2 = System.currentTimeMillis();
         int var4 = this.devCon.getDataIn();
         if (this.lastDataIn <= var4) {
            int var5 = 0;
            long var6 = var4 - this.lastDataIn;
            if (var2 != this.lastTime) {
               var5 = (int)(var6 * 1000L / (var2 - this.lastTime));
            }

            this.model.setValueAt(new Integer(var5), 3, 2);
         }

         this.lastDataIn = var4;
         int var14 = this.devCon.getDataOut();
         if (this.lastDataOut <= var14) {
            int var15 = 0;
            long var7 = var14 - this.lastDataOut;
            if (var2 != this.lastTime) {
               var15 = (int)(var7 * 1000L / (var2 - this.lastTime));
            }

            this.model.setValueAt(new Integer(var15), 4, 2);
         }

         this.lastDataOut = var14;
         this.lastTime = var2;
         long var16 = var2 - this.devCon.lConnectTime;
         int var8 = (int)var16 / 86400000;
         var16 -= var8 * 86400000;
         int var9 = (int)var16 / 3600000;
         var16 -= var9 * 3600000;
         int var10 = (int)var16 / 60000;
         var16 -= var10 * 60000;
         int var11 = (int)var16 / 1000;
         StringBuffer var12 = new StringBuffer();
         if (var8 > 0) {
            var12.append(var8);
            var12.append(" days ");
         }

         if (var9 < 10) {
            var12.append("0");
         }

         var12.append(var9);
         var12.append(":");
         if (var10 < 10) {
            var12.append("0");
         }

         var12.append(var10);
         var12.append(":");
         if (var11 < 10) {
            var12.append("0");
         }

         var12.append(var11);
         this.model.setValueAt(var12.toString(), 5, 2);
         this.model.setValueAt(new Short(this.videoMode.getActualHSize()), 6, 2);
         this.model.setValueAt(new Short(this.videoMode.getActualVSize()), 7, 2);
         short var13 = this.videoMode.getRefresh();
         if (var13 != 0) {
            this.model.setValueAt(new Double(var13 / 100 + var13 % 100 * 0.01) + " Hz", 8, 2);
         } else {
            this.model.setValueAt("0", 8, 2);
         }
      }
   }

   private void updateTable(RFBView var1) {
      if (this.dev != null && this.devCon != null) {
         long var2 = System.currentTimeMillis();
         int var4 = this.rccore.getIncomingTrafficSpeed();
         this.model.setValueAt(this.formatSpeed(var4), 3, 2);
         int var5 = this.rccore.getOutgoingTrafficSpeed();
         this.model.setValueAt(this.formatSpeed(var5), 4, 2);
         this.model.setValueAt(String.valueOf(var1.getFpsCount()), 5, 2);
         long var6 = var2 - this.devCon.lConnectTime;
         int var8 = (int)var6 / 86400000;
         var6 -= var8 * 86400000;
         int var9 = (int)var6 / 3600000;
         var6 -= var9 * 3600000;
         int var10 = (int)var6 / 60000;
         var6 -= var10 * 60000;
         int var11 = (int)var6 / 1000;
         StringBuffer var12 = new StringBuffer();
         if (var8 > 0) {
            var12.append(var8);
            var12.append(" days ");
         }

         if (var9 < 10) {
            var12.append("0");
         }

         var12.append(var9);
         var12.append(":");
         if (var10 < 10) {
            var12.append("0");
         }

         var12.append(var10);
         var12.append(":");
         if (var11 < 10) {
            var12.append("0");
         }

         var12.append(var11);
         this.model.setValueAt(var12.toString(), 6, 2);
      }
   }

   public void startUpdateTimer() {
      this.updateTimer = new Timer(1000, new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            if (ConnectionInfoPanel.this.parentView instanceof KvmView) {
               ConnectionInfoPanel.this.updateTable((KvmView)ConnectionInfoPanel.this.parentView);
            } else if (ConnectionInfoPanel.this.parentView instanceof RFBView) {
               ConnectionInfoPanel.this.updateTable((RFBView)ConnectionInfoPanel.this.parentView);
            }
         }
      });
      this.updateTimer.start();
   }

   public void stopUpdateTimer() {
      if (this.updateTimer != null && this.updateTimer.isRunning()) {
         this.updateTimer.stop();
         this.updateTimer = null;
      }
   }

   @Override
   protected CommandResult executeCommand(Command var1) {
      var1.getContext(true);
      this.setCommandContext(var1.getContext());
      this.feedCommandContext(var1.getContext());
      CommandResult var2 = var1.execute();
      if (var1.getKey().equals("cancelButtonCommand")) {
         this.stopUpdateTimer();
      }

      if (!var2.isSuccess() && var2.hasErrorDescription()) {
         this.handleCommandResultErrorDescription(var2);
      } else if (var1.getKey().equals("doCopyToClipboardCommand")) {
         this.handleCommandResult(var2);
         this.scrContext.getPanelMediator().showPanel(var1.getContext());
      } else {
         this.handleCommandResult(var2);
         this.setVisibleAfterCommand(var1);
         this.scrContext.getPanelMediator().showPanel(var1.getContext());
      }

      return var2;
   }

   private static int initColumnSizes(JTable var0) {
      TableModel var1 = var0.getModel();
      int var2 = 0;
      TableColumn var3 = null;
      Object var4 = null;
      int var5 = 0;
      int var6 = 0;
      int var7 = var0.getColumnCount();
      int var8 = var0.getRowCount();
      TableCellRenderer var9 = var0.getTableHeader().getDefaultRenderer();

      for (int var10 = 0; var10 < var7; var10++) {
         var3 = var0.getColumnModel().getColumn(var10);
         var4 = var9.getTableCellRendererComponent(null, var3.getHeaderValue(), false, false, 0, 0);
         var5 = var4.getPreferredSize().width;
         TableCellRenderer var11 = var0.getDefaultRenderer(var1.getColumnClass(var10));

         for (int var12 = 0; var12 < var8; var12++) {
            var4 = var11.getTableCellRendererComponent(var0, var1.getValueAt(var12, var10), false, false, var12, var10);
            var6 = Math.max(var6, var4.getPreferredSize().width);
         }

         var3.setPreferredWidth(Math.max(var5, var6));
         var2 += var3.getPreferredWidth();
         var6 = 0;
      }

      return var2;
   }

   public String formatSpeed(int var1) {
      String var2;
      if (var1 > 1024) {
         var2 = Integer.toString(var1 / 1024) + " " + this.bundle.getString("connectioninfo.kilobyte");
      } else {
         var2 = Integer.toString(var1) + " " + this.bundle.getString("connectioninfo.byte");
      }

      return var2;
   }
}
