package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DeSelectPortViewCommand;
import com.raritan.rrc.ui.commands.DoDisconnectCommand;
import com.raritan.rrc.ui.commands.PopulateKeyboardMenuCommand;
import com.raritan.rrc.ui.commands.SelectPortViewCommand;
import com.raritan.rrc.ui.components.ContextPopupMenu;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import javaclientlib.tr.TRLIB_UPDATEINFO;
import javaclientlib.tr.TRRSP_NEW_VIDEO_MODE_DATA;
import javaclientlib.tr.TRSRVR_COMP_PARAMS;
import javaclientlib.tr.TRSRVR_VIDEO_PARAMS;
import nn.pp.audiocore.AudioEventListener;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.common.audio.AudioErrorsAndMessageHandler;
import nn.pp.common.smartcard.SmartCardErrorsAndMessagesHandler;

public abstract class DeviceView extends AbstractDisplay implements PropertyChangeListener, FocusListener {
   public static final String DEVICE_VIEW_WINDOW_CLOSED = "DEVICE_VIEW_WINDOW_CLOSED";
   public static final String DEVICE_VIEW_ACTIVATED = "DEVICE_VIEW_ACTIVATED";
   protected Port port = null;
   private boolean bHasFocus = false;
   private int keyCode;
   protected boolean isAbsoluteMouseSupported = false;
   protected boolean isIntelligentMouseSupported = false;
   protected boolean isStandardMouseSupported = false;
   private DeviceView.SmartCardStatusListeners smartCardStatusListeners = new DeviceView.SmartCardStatusListeners();

   public DeviceView(RRCScreenContext var1) {
      super(var1);
      this.port = (Port)((ArrayList)var1.getSelectedDevicesObservable().getComponent()).get(0);
      this.port.setContext(this.scrContext);
      this.port.setDevView(this);
      this.setName(this.port.getViewName());
      this.setShellInternalFrame(this.port.getViewName());
      this.isInternalFrame = true;
      this.setFocusable(true);
      ((RRCScreenContext)this.scrContext).addPortInObservable(this.port);
   }

   protected void closeSelf() throws PropertyVetoException {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      var1.getOpenPortsObservable().setComponent(null);
      var1.removePortInObservable(this.port);
      Device var2 = this.port.getBaseDevice();
      if (var2.getActiveKvmPort() == this.port) {
         var2.setActiveKvmPort(null);
      }

      this.shellInternalFrame.setClosed(true);
   }

   @Override
   public void propertyChange(PropertyChangeEvent var1) {
      String var2 = var1.getPropertyName();
      if ("DEVICE_VIEW_WINDOW_CLOSED".equalsIgnoreCase(var2)) {
         if (this.port.isConnected()) {
            this.port.setDevView(null);
            this.port.disconnect();
         }
      } else if ("DEVICE_VIEW_ACTIVATED".equalsIgnoreCase(var2) && !this.port.isActive()) {
         this.port.setActive(true);
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   @Override
   public void setShellInternalFrame(String var1) {
      RaritanDesktopPane var2 = (RaritanDesktopPane)((RRCScreenContext)this.scrContext).getPanelMediator().getParent();
      this.shellInternalFrame = new RRCShellInternalFrame();
      this.shellInternalFrame.setTitle(var1);
      this.shellInternalFrame.setResizable(this.resizable);
      this.shellInternalFrame.setClosable(true);
      this.shellInternalFrame.pack();
      this.shellInternalFrame.setVisible(false);
      this.shellInternalFrame.setFocusable(true);
      this.shellInternalFrame.getContentPane().add(this);
      this.shellInternalFrame.setResizable(true);
      this.shellInternalFrame.setSize(var2.getSize());
      this.shellInternalFrame.setMaximizable(true);
      this.shellInternalFrame.setIconifiable(true);
      this.shellInternalFrame.setCommand(new DoDisconnectCommand(this.scrContext));
      DoDisconnectCommand var3 = new DoDisconnectCommand(this.scrContext);
      SelectPortViewCommand var4 = new SelectPortViewCommand(this.scrContext);
      DeSelectPortViewCommand var5 = new DeSelectPortViewCommand(this.scrContext);
      var4.getContext().setCommandParameter("selectedPortDevice", this.port);
      var3.getContext().setCommandParameter("selectedPortDevice", this.port);
      var5.getContext().setCommandParameter("selectedPortDevice", this.port);
      ((RRCShellInternalFrame)this.shellInternalFrame).setFrameClosedCommand(var3);
      ((RRCShellInternalFrame)this.shellInternalFrame).setFrameActivatedCommand(var4);
      ((RRCShellInternalFrame)this.shellInternalFrame).setDeviceView(this);
      ((RRCShellInternalFrame)this.shellInternalFrame).setFrameDeActivatedCommand(var5);
   }

   @Override
   public void focusGained(FocusEvent var1) {
      this.bHasFocus = true;
   }

   @Override
   public void focusLost(FocusEvent var1) {
      this.bHasFocus = false;
   }

   @Override
   public boolean hasFocus() {
      return this.bHasFocus;
   }

   public abstract boolean disconnect();

   public abstract void setUpdateFrequency(long var1);

   public abstract boolean isTargetScreenResolution();

   public abstract void removeListeners();

   public abstract void notify(int var1, int var2);

   public abstract void updateNotify(TRLIB_UPDATEINFO var1);

   public abstract void newVideoModeNotify(TRRSP_NEW_VIDEO_MODE_DATA var1);

   public abstract void setSingleCursor(boolean var1);

   public abstract boolean isSingleCursor();

   public abstract boolean isScaleVideoFlag();

   public abstract void setTargetScreenResolution(boolean var1);

   public abstract void autoSenseVideo();

   public abstract void calibrateColor();

   public abstract void enterOnScreenMenu();

   public abstract void exitOnScreenMenu();

   public abstract void synchronizeMouse(boolean var1);

   public abstract void setCompParameters(TRSRVR_COMP_PARAMS var1);

   public abstract void refreshScreen();

   public abstract void ResumeVideo();

   public abstract ContextPopupMenu getContextPopupMenu();

   public abstract void setContextMenuKVMVisible(boolean var1);

   public abstract void sendCtrlAltDelete();

   public abstract void sendAltTab();

   public abstract void sendCtrlNumlock();

   public abstract void sendKVMPopupKey();

   public abstract void updateVideoSettings(TRSRVR_VIDEO_PARAMS var1);

   public abstract void toggleTargetScreenResolution();

   public abstract void setScaleVideoFlag(boolean var1);

   public abstract void setViewFocus();

   public abstract void keyboardTypeChanged(int var1);

   public abstract boolean isCommandOperable(AbstractCommand var1);

   public abstract void customizeTarget(AbstractDisplay var1);

   public abstract void forceRepaint();

   public abstract boolean macroMenuActionPerformed(String var1);

   public abstract ICommandHandler getCommandHandler();

   public abstract void setFullScreenMode(boolean var1);

   public abstract boolean isFullScreenMode();

   public abstract void addCustomMouseMotionListener(MouseMotionListener var1);

   public abstract void removeCustomMouseMotionListener(MouseMotionListener var1);

   public abstract void addCustomMouseListener(MouseListener var1);

   public abstract void removeCustomMouseListener(MouseListener var1);

   public abstract boolean getAbsoluteMouseSupported();

   public abstract boolean getIntelligentMouseSupported();

   public abstract boolean getStandardMouseSupported();

   public abstract void setIsAbsoluteMouseSupported(boolean var1);

   public abstract void setIsIntelligentMouseSupported(boolean var1);

   public abstract void setIsStandardMouseSupported(boolean var1);

   public void startVideo() {
   }

   private KeyboardMacrosPreferences getMacro(int var1) {
      return var1 >= 48 && var1 <= 57 ? PopulateKeyboardMenuCommand.getMacro(var1 - 48) : null;
   }

   public String getKeyCode(KeyEvent var1, boolean var2, boolean var3) {
      this.keyCode = var1.getKeyCode();
      if (var1.isControlDown() && var1.isAltDown() && var2 && var3) {
         KeyboardMacrosPreferences var4 = this.getMacro(this.keyCode);
         if (this.keyCode == ((RRCScreenContext)this.scrContext).getPopupKeyCode() || var4 != null) {
            var3 = false;
            if (var4 != null) {
               return var4.getMacroSequence();
            }
         }
      }

      return String.valueOf(this.keyCode);
   }

   public boolean isSunTarget() {
      return false;
   }

   public boolean sendKeyboardMacro(String var1) {
      return false;
   }

   public boolean allowMaximumSize() {
      return true;
   }

   public SmartCardErrorsAndMessagesHandler getSmartCardErrorsAndMessagesHandler() {
      return null;
   }

   public AudioErrorsAndMessageHandler getAudioErrorsAndMessagesHandler() {
      return null;
   }

   public DeviceView.SmartCardStatusListeners getSmartCardStatusListener() {
      return this.smartCardStatusListeners;
   }

   public RemoteConsoleParameters getRemoteConsoleParameters() {
      return null;
   }

   public int getRfbSessionId() {
      return -1;
   }

   public void setPlaybackState(AudioEventListener.DeviceState var1) {
   }

   public void setCaptureState(AudioEventListener.DeviceState var1) {
   }

   public class SmartCardStatusListeners implements PropertyChangeListener {
      protected boolean connected = false;

      public boolean isConnected() {
         return this.connected;
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
      }
   }
}
