package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.MPCUtil;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import javaclientlib.utils.RRCLogger;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class ErrorHandlerImpl {
   private static ErrorHandlerImpl errorHandlerImpl;
   protected static ResourceBundle bundle;
   private static RRCScreenContext scrContext;

   private ErrorHandlerImpl() {
   }

   public static synchronized void init(ResourceBundle var0, RRCScreenContext var1) {
      getInstance();
      bundle = var0;
      scrContext = var1;
   }

   public static synchronized ErrorHandlerImpl getInstance() {
      if (errorHandlerImpl == null) {
         errorHandlerImpl = new ErrorHandlerImpl();
      }

      return errorHandlerImpl;
   }

   private String replaceTokens(String var1, String[] var2) {
      if (var2 != null && var2.length > 0) {
         return MessageFormat.format(var1, var2);
      } else {
         RRCLogger.log(300, -1, "Tokens are null");
         return null;
      }
   }

   public void handleError(int var1, Component var2, RFBView var3, String var4) {
      this.showMessage(this.getFormatedMessage(var1, var3), var2, 0, bundle.getString("optionpane.error.title") + " " + var4, var3);
   }

   public void handleError(int var1, Component var2, RFBView var3) {
      this.showMessage(this.getFormatedMessage(var1, var3), var2, 0, bundle.getString("optionpane.error.title"), var3);
   }

   private String getFormatedMessage(int var1, RFBView var2) {
      String var3 = Integer.toHexString(var1);
      String var4 = "RFB_PROTO_ERR." + var3;
      String var5 = "[0x" + var3 + "]: ";
      RRCLogger.log(300, 512, "errorCode: " + var1 + ", bundleKey: " + var4);
      var5 = var5 + this.getErrorMessage(var4);
      if (var2 != null) {
         var5 = this.replaceTokens(var5, var2.getTokens(new int[]{var1}));
      } else {
         RRCLogger.log(300, -1, "IErrorHandlerCallback is null");
      }

      return var5;
   }

   public void handleError(int var1, Component var2) {
      String var3 = Integer.toHexString(var1);
      String var4 = "RFB_PROTO_ERR." + var3;
      String var5 = "[0x" + var3 + "]: ";
      RRCLogger.log(300, 512, "errorCode: " + var1 + ", bundleKey: " + var4);
      var5 = var5 + this.getErrorMessage(var4);
      this.showMessage(var5, var2, 0, bundle.getString("optionpane.error.title"), null);
   }

   public void handleError(String var1, Component var2) {
      this.showMessage(this.getErrorMessage(var1), var2, 0, bundle.getString("optionpane.error.title"), null);
   }

   public void handleScanError(int var1, Component var2, String[] var3) {
      String var4 = Integer.toHexString(var1);
      String var5 = "RFB_PROTO_ERR." + var4;
      String var6 = "[0x" + var4 + "]: ";
      RRCLogger.log(300, 512, "errorCode: " + var1 + ", bundleKey: " + var5);
      var6 = var6 + this.getErrorMessage(var5);
      if (var3.length > 0) {
         String var7 = getPortNumbersAsString(var3);
         String[] var8 = new String[]{var7};
         var6 = var6 + this.replaceTokens(var6, var8);
      }
   }

   private String getErrorMessage(String var1) {
      if (bundle == null) {
         RRCLogger.log(300, 512, "bundle is null");
         return var1;
      } else {
         try {
            bundle.getString(var1);
            return bundle.getString(var1);
         } catch (MissingResourceException var3) {
            RRCLogger.log(300, 512, "No mapping found for key " + var1);
            RRCLogger.logException(var3);
            return bundle.getString("RFB_PROTO_UNKNOWN_ERROR");
         }
      }
   }

   private void showMessage(final String var1, Component var2, final int var3, final String var4, final RFBView var5) {
      if (var1 != null) {
         boolean var6 = var2 == scrContext.getApplication().getContentPane();
         final JOptionPane var7 = new JOptionPane(var1, var3);
         JDialog var8 = var7.createDialog(var2, var4);
         if (var2 != null) {
            var8.setLocationRelativeTo(var2);
         }

         var8.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent var1) {
               var7.setValue(0);
            }
         });
         var8.setAlwaysOnTop(true);
         var8.setModal(true);
         var8.setResizable(false);
         var8.setDefaultCloseOperation(2);
         var8.setFocusable(true);
         scrContext.getApplication().addDisposedShell(var8);
         var8.setVisible(true);
         if (var6 && (!(var7.getValue() instanceof Integer) || (Integer)var7.getValue() != 0) && var2 != scrContext.getApplication().getContentPane()) {
            var8.dispose();
            scrContext.getApplication().addDisposedShell(var8);
            SwingUtilities.invokeLater(new Runnable() {
               @Override
               public void run() {
                  ErrorHandlerImpl.this.showMessage(var1, ErrorHandlerImpl.scrContext.getApplication().getContentPane(), var3, var4, var5);
               }
            });
         } else if (var5 != null) {
            JOptionPane.getFrameForComponent(var5).toFront();
         }
      } else {
         RRCLogger.log(300, -1, "message is null, not displaying dialog");
      }
   }

   public void handleWarning(int var1, Component var2, RFBView var3) {
      this.showMessage(this.getFormatedMessage(var1, var3), var2, 2, bundle.getString("optionpane.warning.tite"), var3);
   }

   public void handleInfo(int var1, Component var2, RFBView var3) {
      this.showMessage(this.getFormatedMessage(var1, var3), var2, 1, bundle.getString("optionpane.info.title"), var3);
   }

   public boolean showErrorWithOptionToRemember(Component var1, String var2, String var3) {
      JOptionPane var6 = new JOptionPane();
      JCheckBox var7 = getCheckBox(var6);
      var6.setMessage(new Object[]{var2, var7});
      var6.setMessageType(0);
      JButton var8 = new JButton("OK");
      final JDialog var4 = var6.createDialog(var1, var3);
      MPCUtil.jre17WorkaroundInheritAlwaysOnTop(var4);
      var8.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            var4.dispose();
         }
      });
      var6.setOptions(new Object[]{var8});
      var6.setOptionType(0);
      var4.setVisible(true);
      return (Boolean)var6.getInputValue();
   }

   static JCheckBox getCheckBox(final JOptionPane var0) {
      JCheckBox var1 = new JCheckBox(bundle.getString("DoNotDisplayAgain"));
      ChangeListener var2 = new ChangeListener() {
         @Override
         public void stateChanged(ChangeEvent var1) {
            JCheckBox var2x = (JCheckBox)var1.getSource();
            var0.setInputValue(var2x.isSelected());
         }
      };
      var1.addChangeListener(var2);
      return var1;
   }

   private static String getPortNumbersAsString(String[] var0) {
      String var1 = "";

      for (int var2 = 0; var2 < var0.length; var2++) {
         var1 = var1 + "," + var0[var2];
      }

      int var3 = var1.length();
      return var1.substring(1, var3 - 1);
   }
}
