package com.raritan.rrc.ui.panes;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandFileChooser;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.util.CommandUtil;
import com.raritan.tools.util.io.DefaultFileMapper;
import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.io.File;
import java.text.MessageFormat;

public class FileBrowserPanel extends AbstractDisplay {
   private static final long serialVersionUID = -1301175886685546218L;
   protected CommandFileChooser chooser;
   protected CommandContext prevPanelContext;
   protected String title = "";

   public FileBrowserPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
      this.setShell(null);
   }

   @Override
   public void setCommandContext(CommandContext var1) {
   }

   @Override
   public void makeLayout() {
      this.setLayout(new BorderLayout());
      this.chooser = new CommandFileChooser(this.scrContext);
      this.chooser.addActionListener(this);
      this.add(this.chooser, "North");
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      if (var1.getActionCommand().equals("CancelSelection")) {
         Object var2 = var1.getSource();
         Command var3 = null;
         if (CommandUtil.isCommandHolder(var2)) {
            var3 = ((CommandHolder)var2).getCommand();
         }

         this.setVisibleAfterCommand(var3);
      } else {
         super.actionPerformed(var1);
      }
   }

   @Override
   protected boolean checkPassedCommandConfirm(Object var1) {
      if (this.chooser.getDialogType() == 0) {
         File var2 = this.chooser.getSelectedFile();
         if (!var2.exists()) {
            String var3 = this.bundle.getString("FileChooser.OpenFileNotExists");
            var3 = MessageFormat.format(var3, var2.getName());
            CommonPopups.showWarningDialog(this.bundle.getString("FileChooser.openDialogTitleText"), var3, null, this.scrContext);
            return false;
         }
      }

      return super.checkPassedCommandConfirm(var1);
   }

   @Override
   protected void setVisibleAfterCommand(Command var1) {
      if (var1.equals(this.chooser.getCommand())) {
         this.getShell().setVisible(false);
      } else {
         super.setVisibleAfterCommand(var1);
      }
   }

   public void setTitle(String var1) {
      this.getShell().setTitle(var1);
      this.title = var1;
   }

   @Override
   public void fillComponents(CommandContext var1) {
      if (var1.getCommandParameter("filebrowsercontext") != null) {
         this.prevPanelContext = (CommandContext)var1.getCommandParameter("filebrowsercontext");
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      File var2 = this.chooser.getSelectedFile();
      if (var1.getCommandParameter("selectedFileMapper") == null) {
         var1.setCommandParameter("selectedFileMapper", new DefaultFileMapper());
      }

      var1.setCommandParameter("selectedFile", var2);
   }

   protected boolean confirmFileOverwrite() {
      File var1 = this.chooser.getSelectedFile();
      if (var1 == null) {
         return false;
      } else if (var1.exists()) {
         return CommonPopups.showFileOverwriteConfirmationDialog(null, this.scrContext) == 2;
      } else {
         try {
            if (!var1.createNewFile() || !var1.delete()) {
               var1 = null;
            }
         } catch (Exception var3) {
            var1 = null;
         }

         if (var1 == null) {
            CommonPopups.showInfoDialog(this.title, this.bundle.getString("filebrowser.save.cannotopen"), null, this.scrContext);
         }

         return var1 != null;
      }
   }
}
