package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DeviceHandlerInterface;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.models.SliderRangeModel;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.FocusEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Vector;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;
import nn.pp.core.T;
import nn.pp.rccore.RCCore;

public class G2CompressionPanel extends AbstractDisplay implements ListDataListener, ChangeListener, ItemListener {
   public static final String COMPRESSION_PANEL_SETTINGS_CHANGED = "COMPRESSION_PANEL_SETTINGS_CHANGED";
   private static final Map g2PropertiesMap = new HashMap();
   private static final long serialVersionUID = 2008395561540428642L;
   private DefaultComboBoxModel connectionSpeedModel;
   private DefaultComboBoxModel colorDepthModel;
   public JComboBox connSpeedComboBox;
   public JComboBox colorDepthComboBox;
   private boolean compSettingsModified = false;
   private String portKey;
   private RFBView rfbView;
   private RCCore core;
   private Hashtable<Integer, JLabel> smoothingTextLookup = new Hashtable<>();
   private SliderRangeModel smoothingModel;
   public JSlider smoothing = null;
   public LinkedHashMap<String, RCCore.Compression> allConnSpeeds;
   public LinkedHashMap<String, RCCore.ColorDepth> allColorDepths;

   public G2CompressionPanel(boolean var1, ScreenContext var2, String var3, RFBView var4) {
      super(var2);
      this.isDialog = var1;
      this.portKey = var3;
      this.rfbView = var4;
      this.core = var4.getRCCore();
      this.makeLayout();
   }

   private void initComboDataModels() {
      DeviceHandlerInterface var1 = ((RRCScreenContext)this.scrContext).getSelectedPort().getDevice().getHandler();
      this.allConnSpeeds = var1.initializeAllConnSpeeds(this.bundle);
      this.initializeAllColorDepths();
      Vector var2 = new Vector();

      for (RCCore.Compression var4 : this.core.getSupportedEncodingCompressions()) {
         var2.add(var4);
      }

      this.connectionSpeedModel = new DefaultComboBoxModel();
      if (this.core.isEncodingAutoSupported()) {
         this.connectionSpeedModel.addElement(this.bundle.getString("AutoDetect.option"));
      }

      String[] var5 = this.allConnSpeeds.keySet().toArray(new String[0]);
      int var9 = var5.length;

      for (int var11 = 0; var11 < var9; var11++) {
         if (var2.contains(this.allConnSpeeds.get(var5[var11]))) {
            this.connectionSpeedModel.addElement(var5[var11]);
         }
      }

      this.connectionSpeedModel.addListDataListener(this);
      Vector var6 = new Vector();

      for (RCCore.ColorDepth var8 : this.core.getSupportedEncodingColorDepths()) {
         var6.add(var8);
      }

      this.colorDepthModel = new DefaultComboBoxModel();
      String[] var13 = this.allColorDepths.keySet().toArray(new String[0]);
      var9 = var13.length;

      for (int var12 = 0; var12 < var9; var12++) {
         if (var6.contains(this.allColorDepths.get(var13[var12]))) {
            this.colorDepthModel.addElement(var13[var12]);
         }
      }

      this.colorDepthModel.addListDataListener(this);
   }

   private void initCompressionPanel() {
      this.setLayout(new SpringLayout());
      JPanel var1 = new JPanel(new SpringLayout());
      String var2 = this.bundle.getString("ConnectionSpeedLabel.name");
      JLabel var3 = new JLabel(var2, 11);
      this.connSpeedComboBox = new JComboBox(this.connectionSpeedModel);
      var3.setLabelFor(this.connSpeedComboBox);
      var1.add(var3);
      var1.add(this.connSpeedComboBox);
      var2 = this.bundle.getString("ColorDepthLabel.name");
      var3 = new JLabel(var2, 11);
      this.colorDepthComboBox = new JComboBox(this.colorDepthModel);
      var3.setLabelFor(this.colorDepthComboBox);
      var1.add(var3);
      var1.add(this.colorDepthComboBox);
      var3 = new JLabel(this.bundle.getString("SmoothingLabel.name"), 11);
      this.smoothingModel = new SliderRangeModel(0, 0, 1, 0);
      this.smoothing = new JSlider(this.smoothingModel);
      this.smoothing.setMinorTickSpacing(1);
      this.smoothing.setPaintTicks(true);
      this.smoothing.setSnapToTicks(true);
      var3.setLabelFor(this.smoothing);
      if (this.rfbView != null) {
         String[] var6 = this.allConnSpeeds.keySet().toArray(new String[0]);
         if (this.core.isEncodingAutoSupported() && this.rfbView.getCurrrentCompression() == null) {
            this.connSpeedComboBox.setSelectedItem(this.bundle.getString("AutoDetect.option"));
         } else {
            RCCore.Compression var7 = this.rfbView.getCurrrentCompression();
            if (var7 == null) {
               var7 = this.core.getEncodingCompression();
            }

            int var5 = var6.length;

            for (int var4 = 0; var4 < var5; var4++) {
               if (this.allConnSpeeds.get(var6[var4]) == var7) {
                  this.connSpeedComboBox.setSelectedItem(var6[var4]);
                  break;
               }
            }
         }

         String[] var18 = this.allColorDepths.keySet().toArray(new String[0]);
         RCCore.ColorDepth var8 = this.rfbView.getCurrentColorDepth();
         if (var8 == null) {
            var8 = this.core.getEncodingColorDepth();
         }

         int var15 = var18.length;

         for (int var13 = 0; var13 < var15; var13++) {
            if (this.allColorDepths.get(var18[var13]) == var8) {
               this.colorDepthComboBox.setSelectedItem(var18[var13]);
               break;
            }
         }

         RCCore.Smoothing var9;
         if (this.rfbView.getCurrentSmoothing() == null) {
            var9 = this.core.getSmoothing();
         } else {
            var9 = this.rfbView.getCurrentSmoothing();
         }

         var15 = RCCore.Smoothing.values().length;

         for (int var14 = 0; var14 < var15; var14++) {
            if (var9 == RCCore.Smoothing.values()[var14]) {
               this.smoothing.setValue(var14);
               break;
            }
         }
      }

      this.smoothingTextLookup.put(RCCore.Smoothing.HIGH.eval(), new JLabel(this.bundle.getString("SmoothingSliderMaxLabel.name")));
      this.smoothingTextLookup.put(RCCore.Smoothing.LOW.eval(), new JLabel(this.bundle.getString("SmoothingSliderMinLabel.name")));
      this.smoothing.setLabelTable(this.smoothingTextLookup);
      this.smoothing.setPaintLabels(true);
      this.smoothing.addKeyListener(new KeyAdapter() {
         @Override
         public void keyReleased(KeyEvent var1) {
            if (var1.getKeyCode() == 33 && var1.isControlDown() && var1.isAltDown()) {
               G2CompressionPanel.this.handleSecretCodesToDisableSmoothing();
            }
         }
      });
      this.connSpeedComboBox.addActionListener(this);
      this.connSpeedComboBox.addItemListener(this);
      this.colorDepthComboBox.addActionListener(this);
      this.smoothingModel.addChangeListener(this);
      this.checkSpeed();
      JPanel var17 = new JPanel(new SpringLayout());
      var17.add(this.smoothing);
      SpringUtilities.makeCompactGrid(var17, 1, 1, 6, 6, 6, 6);
      var1.add(var3);
      var1.add(var17);
      SpringUtilities.makeCompactGrid(var1, 3, 2, 6, 6, 6, 6);
      this.add(var1);
   }

   private void handleSecretCodesToDisableSmoothing() {
      int var1 = this.smoothing.getValue();
      this.smoothingTextLookup.clear();
      this.smoothingTextLookup.put(RCCore.Smoothing.NONE.eval(), new JLabel(this.bundle.getString("SmoothingSliderNoneLabel.name")));
      this.smoothingTextLookup.put(RCCore.Smoothing.HIGH.eval(), new JLabel(this.bundle.getString("SmoothingSliderMaxLabel.name")));
      this.smoothingTextLookup.put(RCCore.Smoothing.LOW.eval(), new JLabel(this.bundle.getString("SmoothingSliderMinLabel.name")));
      this.smoothing.setMaximum(2);
      this.smoothing.setLabelTable(this.smoothingTextLookup);
      this.smoothing.setPaintLabels(true);
   }

   public void setCompParams() {
      String var1 = (String)this.connectionSpeedModel.getElementAt(0);
      this.connectionSpeedModel.setSelectedItem(var1);
      var1 = (String)this.colorDepthModel.getElementAt(0);
      this.colorDepthModel.setSelectedItem(var1);
   }

   public void setCompSettingsModified(boolean var1) {
      if (var1 && !this.compSettingsModified) {
         this.compSettingsModified = true;
         this.firePropertyChange("COMPRESSION_PANEL_SETTINGS_CHANGED", null, null);
      } else {
         this.compSettingsModified = var1;
      }
   }

   @Override
   public void setDefaultFocussedComponent() {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            G2CompressionPanel.this.connSpeedComboBox.grabFocus();
         }
      });
   }

   public boolean isSmoothingEnabled() {
      return this.smoothingModel.getValue() > 0;
   }

   public int getSmoothingValue() {
      return this.smoothingModel.getValue();
   }

   @Override
   public void stateChanged(ChangeEvent var1) {
      this.checkApplyButton();
   }

   @Override
   public void intervalAdded(ListDataEvent var1) {
   }

   @Override
   public void intervalRemoved(ListDataEvent var1) {
   }

   @Override
   public void contentsChanged(ListDataEvent var1) {
      this.setCompSettingsModified(true);
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void makeLayout() {
      this.initComboDataModels();
      this.initCompressionPanel();
      SpringUtilities.makeCompactGrid(this, 1, 1, 6, 6, 6, 6);
      this.addFocusListener(this);
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      Object var2 = var1.getSource();
      if (var2 instanceof JComboBox) {
         this.checkApplyButton();
      }
   }

   public void fillDevicePreferences(DevicePreferences var1) {
   }

   public void feedDevicePreferences(DevicePreferences var1) {
   }

   @Override
   public void focusGained(FocusEvent var1) {
      this.setDefaultFocussedComponent();
   }

   public void focusLose(FocusEvent var1) {
      this.connSpeedComboBox.removeFocusListener(this);
   }

   private void checkApplyButton() {
      Container var1 = this.getParent().getParent();
      if (var1 instanceof PropertiesPanel) {
         ((PropertiesPanel)var1).setApplyButton(true);
      } else if (var1 instanceof ModifyConnectionPanel) {
         ((ModifyConnectionPanel)var1).setApplyButton(true);
      } else if (var1 instanceof G2PropertiesPanel) {
         ((G2PropertiesPanel)var1).setApplyButton(true);
      }
   }

   public void setEnabledConnSpeedComboBox(boolean var1) {
      this.connSpeedComboBox.setEnabled(var1);
   }

   public void setEnabledColorDepthChkBox(boolean var1) {
      this.colorDepthComboBox.setEnabled(var1);
   }

   public static void resetPanel(String var0) {
      if (g2PropertiesMap != null && g2PropertiesMap.size() > 0) {
         g2PropertiesMap.remove(var0);
      }
   }

   private void initializeAllColorDepths() {
      this.allColorDepths = new LinkedHashMap<>();
      this.allColorDepths.put(T._("32-Bit RGB Color"), RCCore.ColorDepth.COLOR_32_BIT);
      this.allColorDepths.put(T._("24-Bit RGB Color"), RCCore.ColorDepth.COLOR_24_BIT);
      this.allColorDepths.put(T._("15-Bit RGB Color"), RCCore.ColorDepth.COLOR_16_BIT);
      this.allColorDepths.put(T._("8-Bit RGB Color"), RCCore.ColorDepth.COLOR_8_BIT);
      this.allColorDepths.put(T._("4-Bit Color"), RCCore.ColorDepth.COLOR_4_BIT);
      this.allColorDepths.put(T._("4-Bit Gray"), RCCore.ColorDepth.GREY_4_BIT);
      this.allColorDepths.put(T._("3-Bit Gray"), RCCore.ColorDepth.GREY_3_BIT);
      this.allColorDepths.put(T._("2-Bit Gray"), RCCore.ColorDepth.GREY_2_BIT);
      this.allColorDepths.put(T._("Black and White"), RCCore.ColorDepth.BW_1_BIT);
   }

   @Override
   public void itemStateChanged(ItemEvent var1) {
      if (var1.getSource() == this.connSpeedComboBox) {
         this.checkSpeed();
      }
   }

   private void checkSpeed() {
      this.colorDepthComboBox.setEnabled(!this.connSpeedComboBox.getSelectedItem().equals(this.bundle.getString("AutoDetect.option")));
   }
}
