package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.commands.DoVideoSettingsCommand;
import com.raritan.rrc.ui.models.SettingModel;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.HeadlessException;
import java.awt.event.ActionEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.io.IOException;
import java.util.logging.Level;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.ButtonGroup;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.JSpinner;
import javax.swing.JTabbedPane;
import javax.swing.SpinnerNumberModel;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.JSpinner.DefaultEditor;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nn.pp.rccore.IVideoSettings;
import nn.pp.rccore.RCAdapter;
import nn.pp.rccore.VideoSettings;

public class G2VideoSettingsPanel extends AbstractDisplay implements ChangeListener {
   private SettingModel noiseFilterModel;
   private SpinnerNumberModel clockSettingModel;
   private SpinnerNumberModel phaseSettingModel;
   private SettingModel[] colorSettingModel;
   private SettingModel brightnessRed = null;
   private SettingModel brightnessGreen = null;
   private SettingModel brightnessBlue = null;
   private SettingModel redContrast = null;
   private SettingModel greenContrast = null;
   private SettingModel blueContrast = null;
   private SettingModel hOffSet = null;
   private SettingModel vOffSet = null;
   private JTabbedPane videoSettingTabPane;
   private JSpinner noiseFilterSpinner = null;
   private JSpinner clockSpinner = null;
   private JSpinner phaseSpinner = null;
   private JSpinner[] colorSettingsSpinner = null;
   private boolean videoSettingsModified = false;
   private JRadioButton bestVideo;
   private JRadioButton quickVideo;
   private RaritanPropertyResourceBundle bundle;
   public static final Object mutex = new Object();
   private RFBView rfbView = null;
   private boolean isServerValueUpdated = false;
   private JCheckBox chkPreview;
   private boolean preview = false;
   private JCheckBox chkAutoColorCalib;
   private JSlider noiseSlider = null;
   private IVideoSettings localVidSettings = null;
   private RCAdapter adapter;
   public static final int clockMax = 4096;
   public static final int clockRange = 500;

   public G2VideoSettingsPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.setNewPanel(true);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.adapter = new RCAdapter() {
         @Override
         public void videoSettingsUpdated(IVideoSettings var1) {
            G2VideoSettingsPanel.this.updateVideoParams(var1);
         }
      };
   }

   @Override
   public void makeLayout() {
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      this.initVideoSettingsModel();
      this.initColorSettingsModel();
      JPanel var1 = new JPanel(new SpringLayout());
      String var2 = this.bundle.getString("NoiseFilterGroupPanel.name");
      JPanel var3 = new JPanel(new SpringLayout());
      var3.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      JLabel var4 = new JLabel(this.noiseFilterModel.getName(), 11);
      this.noiseFilterSpinner = new JSpinner(this.noiseFilterModel.getSpinnerModel());
      this.noiseFilterSpinner.setMaximumSize(this.noiseFilterSpinner.getPreferredSize());
      this.noiseFilterSpinner.addChangeListener(this);
      var4.setLabelFor(this.noiseFilterSpinner);
      this.noiseSlider = new JSlider(this.noiseFilterModel.getSliderModel());
      this.noiseSlider.addChangeListener(this);
      if (this.noiseFilterModel.getMaximum() <= 10) {
         this.noiseSlider.setMinorTickSpacing(1);
         this.noiseSlider.setPaintTicks(true);
         this.noiseSlider.setSnapToTicks(true);
      }

      var3.add(var4);
      var3.add(this.noiseFilterSpinner);
      var3.add(this.noiseSlider);
      var1.add(var3);
      SpringUtilities.makeCompactGrid(var3, 1, 3, 6, 6, 6, 6);
      JPanel var5 = new JPanel(new SpringLayout());
      var2 = this.bundle.getString("PLLSettingsGroupPanel.name");
      var5.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      var2 = this.bundle.getString("ClockLabel.name");
      JLabel var6 = new JLabel(var2);
      this.clockSpinner = new JSpinner(this.clockSettingModel);
      this.clockSpinner.addChangeListener(this);
      this.clockSpinner.setMaximumSize(this.clockSpinner.getPreferredSize());
      var6.setLabelFor(this.clockSpinner);
      var5.add(var6);
      var5.add(this.clockSpinner);
      var5.add(Box.createHorizontalStrut(60));
      var2 = this.bundle.getString("PhaseLabel.name");
      var6 = new JLabel(var2);
      this.phaseSpinner = new JSpinner(this.phaseSettingModel);
      this.phaseSpinner.addChangeListener(this);
      this.phaseSpinner.setMaximumSize(this.phaseSpinner.getPreferredSize());
      var6.setLabelFor(this.phaseSpinner);
      var5.add(var6);
      var5.add(this.phaseSpinner);
      var1.add(var5);
      SpringUtilities.makeCompactGrid(var5, 1, 5, 6, 6, 6, 6);
      JPanel var7 = new JPanel();
      var2 = this.bundle.getString("ColorSettingsGroupPanel.name");
      var7.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      var7.setLayout(new SpringLayout());
      byte var8 = 8;
      this.colorSettingsSpinner = new JSpinner[var8];

      for (int var9 = 0; var9 < var8; var9++) {
         var4 = new JLabel(this.colorSettingModel[var9].getName(), 11);
         this.colorSettingsSpinner[var9] = new JSpinner(this.colorSettingModel[var9].getSpinnerModel());
         this.colorSettingsSpinner[var9].addChangeListener(this);
         this.colorSettingsSpinner[var9].setMaximumSize(this.colorSettingsSpinner[var9].getPreferredSize());
         var4.setLabelFor(this.colorSettingsSpinner[var9]);
         JSlider var10 = new JSlider(this.colorSettingModel[var9].getSliderModel());
         if (this.colorSettingModel[var9].getMaximum() <= 10) {
            var10.setMinorTickSpacing(1);
            var10.setPaintTicks(true);
            var10.setSnapToTicks(true);
         }

         var7.add(var4);
         var7.add(this.colorSettingsSpinner[var9]);
         var7.add(var10);
      }

      var7.add(Box.createVerticalGlue());
      var7.add(Box.createVerticalGlue());
      G2VideoSettingsPanel.StateChangeListener var24 = new G2VideoSettingsPanel.StateChangeListener();
      JPanel var25 = new JPanel();
      var25.setLayout(new SpringLayout());
      this.chkPreview = new JCheckBox(this.bundle.getString("RealTimeColorControlCheckBox.name"), false);
      this.chkPreview.addItemListener(var24);
      var25.add(this.chkPreview);
      this.chkAutoColorCalib = new JCheckBox(this.bundle.getString("OptionDialog.doAutoColorCalCheckBox"), false);
      this.chkAutoColorCalib.addItemListener(new G2VideoSettingsPanel.StateChangeListener());
      var25.add(this.chkAutoColorCalib);
      SpringUtilities.makeCompactGrid(var25, 2, 1, 6, 6, 6, 6);
      JPanel var11 = new JPanel();
      ButtonGroup var12 = new ButtonGroup();
      var2 = this.bundle.getString("VideoSenseGroupPanel.name");
      var11.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      var11.setLayout(new GridBagLayout());
      GridBagConstraints var13 = new GridBagConstraints();
      var13.fill = 2;
      var13.anchor = 10;
      var13.gridx = 0;
      var13.gridy = 0;
      var2 = this.bundle.getString("BestVideoMode.name");
      this.bestVideo = new JRadioButton(var2);
      var12.add(this.bestVideo);
      var11.add(this.bestVideo, var13);
      this.bestVideo.addItemListener(var24);
      this.bestVideo.addActionListener(this);
      var13.gridx = 0;
      var13.gridy = 1;
      var2 = this.bundle.getString("QuickVideoMode.name");
      this.quickVideo = new JRadioButton(var2);
      var12.add(this.quickVideo);
      this.quickVideo.addActionListener(this);
      this.quickVideo.addItemListener(var24);
      var11.add(this.quickVideo, var13);
      var7.add(var25);
      SpringUtilities.makeCompactGrid(var7, 9, 3, 6, 6, 6, 6);
      var1.add(var7);
      var1.add(var11);
      SpringUtilities.makeCompactGrid(var1, 4, 1, 6, 6, 6, 6);
      this.videoSettingTabPane = new JTabbedPane();
      var2 = this.bundle.getString("VideoSettingTab.name");
      this.videoSettingTabPane.addTab(var2, var1);
      this.add(this.videoSettingTabPane, "Center");
      this.add(this.doButtonWidget(), "Last");
   }

   private int getClockSettingValue() {
      return (Integer)this.clockSettingModel.getValue();
   }

   private void setClockSettingValue(int var1) {
      this.clockSettingModel.setValue(new Integer(var1));
   }

   private int getPhaseSettingValue() {
      return (Integer)this.phaseSettingModel.getValue();
   }

   private void setPhaseSettingValue(int var1) {
      this.phaseSettingModel.setValue(new Integer(var1));
   }

   private void setVideoSettingsModified(boolean var1) {
      if (var1 && !this.videoSettingsModified) {
         this.videoSettingsModified = true;
      } else {
         this.videoSettingsModified = var1;
      }
   }

   @Override
   public void setDefaultFocussedComponent() {
      JComponent var1 = this.noiseFilterSpinner.getEditor();
      if (var1 instanceof DefaultEditor) {
         JFormattedTextField var2 = ((DefaultEditor)var1).getTextField();
         var2.requestFocusInWindow();
         var2.setCaretPosition(0);
      }
   }

   @Override
   public void stateChanged(ChangeEvent var1) {
      this.setVideoSettingsModified(true);
      if ((var1.getSource() instanceof JSlider || var1.getSource() instanceof JSpinner) && this.rfbView != null && this.isServerValueUpdated) {
         this.apply.setEnabled(true);
         Object var2 = var1.getSource();
         if (var2 == this.clockSpinner) {
            int var3 = this.getClockSettingValue() - this.localVidSettings.getResolutionX().getValue() - 2;
            this.colorSettingModel[6].getSliderModel().setMaximum(var3);
            this.colorSettingModel[6].getSpinnerModel().setMaximum(new Integer(var3));
         }

         if (this.preview) {
            IVideoSettings var5 = this.rfbView.getVideoSettings();
            VideoSettings var4 = new VideoSettings(this.rfbView.getVideoSettings());
            if (var2 == this.noiseFilterSpinner) {
               if (var5.getNoiseFilter().isSupported()) {
                  var4.getNoiseFilter().setValue(this.noiseFilterModel.getValue());
               }

               RRCLogger.log(300, 1, "VSNoiseFilter: " + (short)this.noiseFilterModel.getValue());
            } else if (var2 == this.clockSpinner) {
               if (var5.getClock().isSupported()) {
                  var4.getClock().setValue(this.getClockSettingValue());
               }

               RRCLogger.log(300, 1, "VSClock: " + (short)this.getClockSettingValue());
            } else if (var2 == this.phaseSpinner) {
               if (var5.getPhase().isSupported()) {
                  var4.getPhase().setValue(this.getPhaseSettingValue());
               }

               RRCLogger.log(300, 1, "VSPhase: " + (short)this.getPhaseSettingValue());
            } else if (var2 == this.colorSettingsSpinner[0]) {
               if (var5.getBrightnessRed().isSupported()) {
                  var4.getBrightnessRed().setValue(this.colorSettingModel[0].getValue());
               }

               RRCLogger.log(300, 1, "VSBrightnessRed: " + (short)this.colorSettingModel[0].getValue());
            } else if (var2 == this.colorSettingsSpinner[1]) {
               if (var5.getBrightnessGreen().isSupported()) {
                  var4.getBrightnessGreen().setValue(this.colorSettingModel[1].getValue());
               }

               RRCLogger.log(300, 1, "VSBrightnessGreen: " + (short)this.colorSettingModel[1].getValue());
            } else if (var2 == this.colorSettingsSpinner[2]) {
               if (var5.getBrightnessBlue().isSupported()) {
                  var4.getBrightnessBlue().setValue(this.colorSettingModel[2].getValue());
               }

               RRCLogger.log(300, 1, "VSBrightnessBlue: " + (short)this.colorSettingModel[2].getValue());
            } else if (var2 == this.colorSettingsSpinner[3]) {
               if (var5.getContrastRed().isSupported()) {
                  var4.getContrastRed().setValue(this.colorSettingModel[3].getValue());
               }

               RRCLogger.log(300, 1, "VSContrastRed: " + (short)this.colorSettingModel[3].getValue());
            } else if (var2 == this.colorSettingsSpinner[4]) {
               if (var5.getContrastGreen().isSupported()) {
                  var4.getContrastGreen().setValue(this.colorSettingModel[4].getValue());
               }

               RRCLogger.log(300, 1, "VSContrastGreen: " + (short)this.colorSettingModel[4].getValue());
            } else if (var2 == this.colorSettingsSpinner[5]) {
               if (var5.getContrastBlue().isSupported()) {
                  var4.getContrastBlue().setValue(this.colorSettingModel[5].getValue());
               }

               RRCLogger.log(300, 1, "VSContrastBlue: " + (short)this.colorSettingModel[5].getValue());
            } else if (var2 == this.colorSettingsSpinner[6]) {
               if (var5.getOffsetX().isSupported()) {
                  var4.getOffsetX().setValue(this.colorSettingModel[6].getValue());
               }

               RRCLogger.log(300, 1, "VSXOffset: " + (short)this.colorSettingModel[6].getValue());
            } else if (var2 == this.colorSettingsSpinner[7]) {
               if (var5.getOffsetY().isSupported()) {
                  var4.getOffsetY().setValue(this.colorSettingModel[7].getValue());
               }

               RRCLogger.log(300, 1, "VSYOffset: " + (short)this.colorSettingModel[7].getValue());
            }

            this.rfbView.writeVideoSettings(var4);
         }
      }
   }

   private void applyChangedVDOSettings() {
      IVideoSettings var1 = this.rfbView.getVideoSettings();
      if (var1.getNoiseFilter().isSupported()) {
         var1.getNoiseFilter().setValue(this.noiseFilterModel.getValue());
      }

      if (var1.getPhase().isSupported()) {
         var1.getPhase().setValue(this.getPhaseSettingValue());
      }

      if (var1.getClock().isSupported()) {
         var1.getClock().setValue(this.getClockSettingValue());
      }

      if (var1.getBrightnessRed().isSupported()) {
         var1.getBrightnessRed().setValue(this.colorSettingModel[0].getValue());
      }

      if (var1.getBrightnessGreen().isSupported()) {
         var1.getBrightnessGreen().setValue(this.colorSettingModel[1].getValue());
      }

      if (var1.getBrightnessBlue().isSupported()) {
         var1.getBrightnessBlue().setValue(this.colorSettingModel[2].getValue());
      }

      if (var1.getContrastRed().isSupported()) {
         var1.getContrastRed().setValue(this.colorSettingModel[3].getValue());
      }

      if (var1.getContrastGreen().isSupported()) {
         var1.getContrastGreen().setValue(this.colorSettingModel[4].getValue());
      }

      if (var1.getContrastBlue().isSupported()) {
         var1.getContrastBlue().setValue(this.colorSettingModel[5].getValue());
      }

      if (var1.getOffsetX().isSupported()) {
         var1.getOffsetX().setValue(this.colorSettingModel[6].getValue());
      }

      if (var1.getOffsetY().isSupported()) {
         var1.getOffsetY().setValue(this.colorSettingModel[7].getValue());
      }

      if (var1.getAutoColorCalibration().isSupported()) {
         var1.getAutoColorCalibration().setEnabled(this.chkAutoColorCalib.isSelected());
      }

      if (var1.getAutoAutoAdjust().isSupported()) {
         var1.getAutoAutoAdjust().setEnabled(this.bestVideo.isSelected());
      }

      this.rfbView.writeVideoSettings(var1);
      this.localVidSettings = var1;
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.makeLayout();
      this.setShell(this.bundle.getString("VideoSettingsDialog.title"));
      this.ok.setCommand(new DoVideoSettingsCommand(this.scrContext));
      this.apply.setCommand(new DoVideoSettingsCommand(this.scrContext));
      RFBView var2 = (RFBView)var1.getCommandParameter("DEVICE_VIEW");
      this.rfbView = var2;
      this.localVidSettings = null;
      IVideoSettings var3 = var2.getVideoSettings();
      if (var3 != null) {
         this.updateVideoParams(var3);
         var2.getRCCore().addVideoEventListener(this.adapter, 8);

         try {
            var2.getRCCore().requestVideoSettingsUpdates();
         } catch (IOException var5) {
            RRCLogger.getLogger().log(Level.SEVERE, "IO Exception trying to request Video Settings Updates.", (Throwable)var5);
         }
      } else {
         this.waitAndGetVideoSettings();
      }

      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            G2VideoSettingsPanel.this.noiseFilterSpinner.grabFocus();
            if (OS.getCurrent() == OS.MAC) {
               G2VideoSettingsPanel.this.repaint();
            }
         }
      });
      this.apply.setEnabled(false);
   }

   private void waitAndGetVideoSettings() throws HeadlessException {
      SwingUtilities.invokeLater(
         new Runnable() {
            @Override
            public void run() {
               synchronized (G2VideoSettingsPanel.mutex) {
                  if (G2VideoSettingsPanel.this.rfbView.getVideoSettings() == null) {
                     try {
                        RRCLogger.log(300, 1, "Waiting for video settings");
                        G2VideoSettingsPanel.mutex.wait(5000L);
                        RRCLogger.log(300, 1, "Awake");
                     } catch (InterruptedException var6) {
                        RRCLogger.logException(var6);
                     }

                     IVideoSettings var2 = G2VideoSettingsPanel.this.rfbView.getVideoSettings();
                     if (var2 != null) {
                        G2VideoSettingsPanel.this.updateVideoParams(var2);
                     } else {
                        Object[] var3 = new Object[]{
                           G2VideoSettingsPanel.this.bundle.getString("basescreen.command.retry.text"),
                           G2VideoSettingsPanel.this.bundle.getString("basescreen.command.cancel.text")
                        };
                        int var4 = JOptionPane.showOptionDialog(
                           G2VideoSettingsPanel.this.rfbView,
                           G2VideoSettingsPanel.this.bundle.getString("VDO_SETTINGS.RETRIEVE.ERROR"),
                           G2VideoSettingsPanel.this.bundle.getString("optionpane.error.title"),
                           0,
                           3,
                           null,
                           var3,
                           var3[0]
                        );
                        if (var4 != 1 && var4 != -1) {
                           G2VideoSettingsPanel.this.rfbView.requestVideoSettings();
                           G2VideoSettingsPanel.this.waitAndGetVideoSettings();
                        } else {
                           G2VideoSettingsPanel.this.getShell().setVisible(false);
                        }

                        G2VideoSettingsPanel.this.isServerValueUpdated = true;
                     }
                  } else {
                     G2VideoSettingsPanel.this.updateVideoParams(G2VideoSettingsPanel.this.rfbView.getVideoSettings());
                  }
               }
            }
         }
      );
   }

   private synchronized void updateVideoParams(IVideoSettings var1) {
      if (var1 != null) {
         this.localVidSettings = new VideoSettings(var1);
         if (var1.getOffsetY().isSupported()) {
            int var2 = var1.getOffsetY().getMinValue();
            int var3 = var1.getOffsetY().getMaxValue();
            int var4 = var1.getOffsetY().getValue();
            if (var2 > var4) {
               ;
            }

            if (var3 < var4) {
               ;
            }

            this.colorSettingModel[7].getSliderModel().setMaximum(var1.getOffsetY().getMaxValue());
            this.colorSettingModel[7].getSpinnerModel().setMaximum(var1.getOffsetY().getMaxValue());
         }

         if (var1.getClock().isSupported() && var1.getResolutionX().isSupported() && var1.getOffsetX().isSupported()) {
            int var6 = var1.getClock().getValue() - var1.getResolutionX().getValue() - 2;
            this.colorSettingModel[6].getSliderModel().setMaximum(var6);
            this.colorSettingModel[6].getSpinnerModel().setMaximum(var6);
            int var7 = var1.getClock().getMinValue();
            int var8 = var1.getClock().getMaxValue();
            int var5 = var1.getClock().getValue();
            if (var5 > 4096) {
               var5 = 4096;
            }

            if (var8 > 4096) {
               var8 = 4096;
            }

            if (var8 < var5) {
               var8 = var5;
            }

            if (var7 > var5) {
               var7 = var5;
            }

            this.clockSettingModel.setMinimum(var7);
            this.clockSettingModel.setMaximum(var8);
            this.clockSettingModel.setValue(var5);
         }

         this.resetVideoSettings();
         this.isServerValueUpdated = true;
      }
   }

   private synchronized void resetVideoSettings() {
      if (this.localVidSettings != null) {
         this.noiseFilterModel.setValue(this.localVidSettings.getNoiseFilter().getValue());
         this.setClockSettingValue(this.localVidSettings.getClock().getValue());
         this.setPhaseSettingValue(this.localVidSettings.getPhase().getValue());
         this.brightnessRed.setValue(this.localVidSettings.getBrightnessRed().getValue());
         this.brightnessGreen.setValue(this.localVidSettings.getBrightnessGreen().getValue());
         this.brightnessBlue.setValue(this.localVidSettings.getBrightnessBlue().getValue());
         this.redContrast.setValue(this.localVidSettings.getContrastRed().getValue());
         this.greenContrast.setValue(this.localVidSettings.getContrastGreen().getValue());
         this.blueContrast.setValue(this.localVidSettings.getContrastBlue().getValue());
         this.vOffSet.setValue(this.localVidSettings.getOffsetY().getValue());
         this.hOffSet.setValue(this.localVidSettings.getOffsetX().getValue());
         this.chkAutoColorCalib.setSelected(this.localVidSettings.getAutoColorCalibration().isEnabled());
         if (!this.rfbView.isColorCalibrationSupported()) {
            this.chkAutoColorCalib.setEnabled(false);
         }

         this.bestVideo.setSelected(this.localVidSettings.getAutoAutoAdjust().isEnabled());
         this.quickVideo.setSelected(!this.localVidSettings.getAutoAutoAdjust().isEnabled());
      } else {
         this.noiseFilterModel.setValue(0);
         this.setClockSettingValue(0);
         this.setPhaseSettingValue(0);
         this.brightnessRed.setValue(0);
         this.brightnessGreen.setValue(0);
         this.brightnessBlue.setValue(0);
         this.redContrast.setValue(0);
         this.greenContrast.setValue(0);
         this.blueContrast.setValue(0);
         this.vOffSet.setValue(0);
         this.hOffSet.setValue(0);
         this.chkAutoColorCalib.setSelected(false);
         this.chkAutoColorCalib.setEnabled(false);
         this.bestVideo.setSelected(true);
         this.quickVideo.setSelected(true);
      }
   }

   private void initVideoSettingsModel() {
      String var1 = this.bundle.getString("NoiseFilterLabel.name");
      this.noiseFilterModel = new SettingModel(var1, 0, 0, 7, 1);
      this.noiseFilterModel.addSliderModelListener(this);
      this.clockSettingModel = new SpinnerNumberModel(1, 1, 4096, 1);
      this.clockSettingModel.addChangeListener(this);
      this.phaseSettingModel = new SpinnerNumberModel(0, 0, 31, 1);
      this.phaseSettingModel.addChangeListener(this);
   }

   private void initColorSettingsModel() {
      this.colorSettingModel = new SettingModel[9];
      int var1 = 0;
      String var2 = this.bundle.getString("BrightnessRedLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 127, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.brightnessRed = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("BrightnessGreenLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 127, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.brightnessGreen = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("BrightnessBlueLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 127, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.brightnessBlue = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("ContrastRedLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 255, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.redContrast = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("ContrastGreenLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 255, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.greenContrast = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("ContrastBlueLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 255, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.blueContrast = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("HorizontalOffsetLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 512, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.hOffSet = this.colorSettingModel[var1];
      var1++;
      var2 = this.bundle.getString("VerticalOffsetLabel.name");
      this.colorSettingModel[var1] = new SettingModel(var2, 0, 0, 128, 1);
      this.colorSettingModel[var1].addSliderModelListener(this);
      this.vOffSet = this.colorSettingModel[var1];
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      this.apply = new CommandButton(this.bundle.getString("OptionDialog.applyLabel"), this.scrContext);
      this.apply.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      var1.add(this.apply);
      return var1;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      Object var2 = var1.getSource();
      if (!(var2 instanceof JCheckBox) && !(var2 instanceof JRadioButton)) {
         this.apply.setEnabled(false);
      } else {
         this.apply.setEnabled(true);
      }

      if (this.cancel == var2) {
         if (this.rfbView != null) {
            this.rfbView.resetCurrentVideoSettings();
            this.resetVideoSettings();
            this.apply.setEnabled(false);
            this.rfbView.getRCCore().removeVideoEventListener(this.adapter);
         }
      } else if (this.apply == var2) {
         if (!this.preview) {
            this.applyChangedVDOSettings();
         }

         this.rfbView.saveVideoSettings();
      } else if (var2 == this.ok) {
         if (!this.preview) {
            this.applyChangedVDOSettings();
         }

         this.rfbView.saveVideoSettings();
         this.rfbView.getRCCore().removeVideoEventListener(this.adapter);
      }

      this.saveVideoSettings(var1.getSource());
   }

   private void saveVideoSettings(Object var1) {
      if (var1 instanceof CommandHolder) {
         Command var2 = ((CommandHolder)var1).getCommand();
         this.scrContext.getLogger().logTextDebug("command is " + var2.getKey());
         this.scrContext.getLogger().logTextDebug("cmd.isExecutable() " + var2.isExecutable());
         if (var2.isExecutable()) {
            this.executeCommand(var2);
            if (this.ok != null) {
               this.ok.setEnabled(true);
            }
         }
      }
   }

   public void setEnableNoiseFilter(boolean var1) {
      this.noiseFilterSpinner.setEnabled(var1);
      this.noiseSlider.setEnabled(var1);
   }

   private class StateChangeListener implements ItemListener {
      private StateChangeListener() {
      }

      @Override
      public void itemStateChanged(ItemEvent var1) {
         int var2 = var1.getStateChange();
         Object var3 = var1.getSource();
         if (var3 == G2VideoSettingsPanel.this.chkPreview) {
            if (var2 == 2) {
               G2VideoSettingsPanel.this.preview = false;
            }

            if (var2 == 1) {
               G2VideoSettingsPanel.this.preview = true;
               G2VideoSettingsPanel.this.applyChangedVDOSettings();
            }
         } else if (var3 == G2VideoSettingsPanel.this.chkAutoColorCalib
            || var3 == G2VideoSettingsPanel.this.bestVideo
            || var3 == G2VideoSettingsPanel.this.quickVideo) {
            G2VideoSettingsPanel.this.apply.setEnabled(true);
            if (G2VideoSettingsPanel.this.preview) {
               IVideoSettings var4 = G2VideoSettingsPanel.this.rfbView.getVideoSettings();
               VideoSettings var5 = new VideoSettings(G2VideoSettingsPanel.this.rfbView.getVideoSettings());
               if (var3 == G2VideoSettingsPanel.this.chkAutoColorCalib) {
                  if (var4.getAutoColorCalibration().isSupported()) {
                     var5.getAutoColorCalibration().setEnabled(G2VideoSettingsPanel.this.chkAutoColorCalib.isSelected());
                     RRCLogger.log(300, 1, "VSAutoColorCalibration: " + G2VideoSettingsPanel.this.chkAutoColorCalib.isSelected());
                  }
               } else if (var4.getAutoAutoAdjust().isSupported()) {
                  var5.getAutoAutoAdjust().setEnabled(G2VideoSettingsPanel.this.bestVideo.isSelected());
                  RRCLogger.log(300, 1, "VSVideoSensing: " + (G2VideoSettingsPanel.this.bestVideo.isSelected() ? "Best possible" : "Quick sense"));
               }

               G2VideoSettingsPanel.this.rfbView.writeVideoSettings(var5);
            }
         }
      }
   }
}
