package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.ui.commands.DoDeleteKeyboardMacroCommand;
import com.raritan.rrc.ui.commands.DoRunKeyboardMacroCommand;
import com.raritan.rrc.ui.commands.ShowAddKeyboardMacroCommand;
import com.raritan.rrc.ui.commands.ShowModifyKeyboardMacroCommand;
import com.raritan.rrc.ui.panes.mediator.RRCPanelMediator;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.text.MessageFormat;
import javax.swing.BorderFactory;
import javax.swing.DefaultListModel;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SpringLayout;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

public class KeyboardMacroPanel extends AbstractDisplay implements ListSelectionListener {
   private static final long serialVersionUID = 6042828474384257396L;
   protected DefaultListModel macroListModel;
   protected JList macroList;
   protected CommandButton runButton;
   protected CommandButton addButton;
   protected CommandButton removeButton;
   protected CommandButton modifyButton;

   public KeyboardMacroPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.macroListModel = new DefaultListModel();
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.makeLayout();
      this.setShell(this.bundle.getString("KeyboardMacrosDialog.title"));
      ((RRCPanelMediator)this.scrContext.getPanelMediator()).setMainKeyboardMacroPanel(this);
   }

   @Override
   public void makeLayout() {
      this.setLayout(new SpringLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
      this.macroList = new JList(this.macroListModel);
      this.macroList.addListSelectionListener(this);
      JScrollPane var1 = new JScrollPane(this.macroList, 20, 30);
      JPanel var2 = new JPanel(new SpringLayout());
      this.runButton = new CommandButton(this.bundle.getString("RunMacroButton.text"), this.scrContext);
      this.runButton.setCommand(new DoRunKeyboardMacroCommand(this.scrContext));
      this.runButton.setEnabled(false);
      this.runButton.addActionListener(this);
      var2.add(this.runButton);
      this.addButton = new CommandButton(this.bundle.getString("AddMacroButton.text"), this.scrContext);
      this.addButton.setCommand(new ShowAddKeyboardMacroCommand(this.scrContext));
      this.addButton.addActionListener(this);
      var2.add(this.addButton);
      this.removeButton = new CommandButton(this.bundle.getString("RemoveMacroButton.text"), this.scrContext);
      this.removeButton.setCommand(new DoDeleteKeyboardMacroCommand(this.scrContext));
      this.removeButton.setConfirmation(true);
      this.removeButton.setEnabled(false);
      this.removeButton.addActionListener(this);
      var2.add(this.removeButton);
      this.modifyButton = new CommandButton(this.bundle.getString("ModifyMacroButton.text"), this.scrContext);
      this.modifyButton.setCommand(new ShowModifyKeyboardMacroCommand(this.scrContext));
      this.modifyButton.setEnabled(false);
      this.modifyButton.addActionListener(this);
      var2.add(this.modifyButton);
      this.cancel = new CommandButton(this.bundle.getString("CloseButton.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      var2.add(this.cancel);
      SpringUtilities.makeCompactGrid(var2, 5, 1, 5, 5, 5, 5);
      this.add(var1);
      this.add(var2);
      this.add(new JLabel(this.bundle.getString("MacrosLabel.text")));
      this.add(new JLabel(""));
      SpringUtilities.makeCompactGrid(this, 2, 2, 15, 15, 15, 15);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.macroListModel.clear();
      String[] var2 = KeyboardMacrosPreferences.returnNodes();

      for (int var3 = 0; var3 < var2.length; var3++) {
         this.macroListModel.addElement(var2[var3]);
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      var1.setCommandParameter("keyboardMacroName", this.macroList.getSelectedValue());
      var1.setCommandParameter("keyboardMacroNameList", this.macroList.getSelectedValues());
   }

   public void addMacroToList(String var1) {
      this.macroListModel.addElement(var1);
   }

   public void removeMacroFromList(String var1) {
      this.macroListModel.removeElement(var1);
   }

   @Override
   public void valueChanged(ListSelectionEvent var1) {
      Object var2 = var1.getSource();
      if (var2 instanceof JList && var2 == this.macroList) {
         if (this.macroList.getSelectedValue() != null) {
            this.runButton.setEnabled(this.runButton.getCommand().isExecutable());
            this.removeButton.setEnabled(true);
            this.modifyButton.setEnabled(true);
         } else {
            this.runButton.setEnabled(false);
            this.removeButton.setEnabled(false);
            this.modifyButton.setEnabled(false);
         }
      }
   }

   @Override
   protected boolean checkPassedCommandConfirm(Object var1) {
      boolean var2 = true;
      if (var1 instanceof ConfirmableCommandInterface) {
         var2 = !((ConfirmableCommandInterface)var1).getConfirmation();
      }

      if (!var2) {
         if (this.macroList.getSelectedValues().length > 1) {
            StringBuilder var3 = new StringBuilder(this.bundle.getString("confirmation.dialog.command.execution.KeyboardMacroMulti.text1"));

            for (Object var7 : this.macroList.getSelectedValues()) {
               var3.append("\n     " + var7.toString());
            }

            var3.append("\n" + this.bundle.getString("confirmation.dialog.command.execution.KeyboardMacroMulti.text2"));
            var2 = CommonPopups.showConfirmationDialog(
                  this.bundle.getString("confirmation.dialog.command.execution.KeyboardMacro.title"), var3, this, this.scrContext
               )
               == 2;
         } else {
            MessageFormat var8 = new MessageFormat(this.bundle.getString("confirmation.dialog.command.execution.KeyboardMacro.text"));
            var2 = CommonPopups.showConfirmationDialog(
                  this.bundle.getString("confirmation.dialog.command.execution.KeyboardMacro.title"),
                  var8.format(this.macroList.getSelectedValues()),
                  this,
                  this.scrContext
               )
               == 2;
         }
      }

      return var2;
   }
}
