package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Insets;
import java.awt.Rectangle;
import java.util.Locale;
import javaclientlib.clientlib.IKvmData;
import javaclientlib.tr.TRLIB_UPDATEINFO;
import javaclientlib.tr.TRRSP_NEW_VIDEO_MODE_DATA;
import javax.swing.JPanel;

public class KvmPanel extends JPanel implements IKvmData {
   private static final long serialVersionUID = -3617865031948452752L;
   private static final int WHITE = -1;
   protected boolean boolRefreshFullScreen = false;
   private String idsAutosensing;
   private String idsCalibratingColor;
   private String idsNoVideo;
   private String idsVideoRange;
   private int hImageSize = 0;
   private int vImageSize = 0;
   private double xScale = 0.0;
   private double yScale = 0.0;
   private KvmView kvmView = null;
   private Insets objInsets = this.getInsets();
   private int iHeight = this.getHeight();
   private int iWidth = this.getWidth();
   private int iPaintableWidth = this.iWidth - this.objInsets.right - this.objInsets.left - 1;
   private int iPaintableHeight = this.iHeight - this.objInsets.top - this.objInsets.bottom - 1;
   private final Font font = new Font("Verdanna", 0, 30);
   private boolean boolNewVideoMode = false;
   private boolean hasVideo = false;
   private TRLIB_UPDATEINFO updateInfo = null;
   private String mOsdString = "";
   private TRRSP_NEW_VIDEO_MODE_DATA objNewVideoModeData = null;
   private ScreenContext scrContext;
   private String popupMessage = "";

   public KvmPanel(boolean var1, ScreenContext var2) {
      this.scrContext = var2;
      RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.idsAutosensing = var3.getString("KVMPanel.autosensing");
      this.idsCalibratingColor = var3.getString("KVMPanel.colorCalibrating");
      this.idsNoVideo = var3.getString("KVMPanel.noVideoSignal");
      this.idsVideoRange = var3.getString("KVMPanel.videoOutOfRange");
      this.setFocusable(true);
      this.setOpaque(true);
      MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, ((RRCScreenContext)this.scrContext).getSelectedPort());
   }

   public void forceRepaint() {
      this.repaint(0, 0, this.getWidth(), this.getHeight());
   }

   @Override
   public void notify(int var1, int var2) {
      switch (var1) {
         case 0:
            if (var2 != -1) {
               this.setOsdMessage(this.idsAutosensing + " (" + var2 + ")");
            } else if (this.hasVideo) {
               this.setOsdMessage("");
            }

            this.forceRepaint();
         case 1:
         case 2:
         case 6:
         case 7:
         case 8:
         case 9:
         default:
            break;
         case 3:
            this.hasVideo = false;
            if (var2 != 0) {
               this.setOsdMessage(this.idsNoVideo);
            } else {
               this.setOsdMessage("");
            }

            this.forceRepaint();
            break;
         case 4:
            if (var2 != 0) {
               this.setOsdMessage(this.idsVideoRange);
            } else {
               this.hasVideo = true;
               this.setOsdMessage("");
            }

            this.forceRepaint();
            break;
         case 5:
            if (var2 != -1) {
               this.setOsdMessage(this.idsCalibratingColor + " (" + var2 + ")");
            } else {
               this.setOsdMessage("");
            }

            this.forceRepaint();
            break;
         case 10:
            this.setOsdMessage("Access terminated by local user - Local port has priority.");
            this.forceRepaint();
      }
   }

   public void forceExistingVideoModeNotify() {
      if (this.objNewVideoModeData != null) {
         this.newVideoModeNotify(this.objNewVideoModeData);
      }
   }

   @Override
   public void newVideoModeNotify(TRRSP_NEW_VIDEO_MODE_DATA var1) {
      this.objNewVideoModeData = var1;
      this.hImageSize = var1.getActualHSize();
      this.vImageSize = var1.getActualVSize();
      this.setPreferredSize(new Dimension(this.hImageSize, this.vImageSize));
      this.revalidate();
      this.objInsets = this.getInsets();
      this.iHeight = this.getHeight();
      this.iWidth = this.getWidth();
      this.iPaintableWidth = this.iWidth - this.objInsets.right - this.objInsets.left - 1;
      this.iPaintableHeight = this.iHeight - this.objInsets.top - this.objInsets.bottom - 1;
      this.boolNewVideoMode = true;
      if (this.kvmView != null) {
         this.kvmView.unfreezeVideo();
      }
   }

   @Override
   public void updateNotify(TRLIB_UPDATEINFO var1) {
      Rectangle var2 = this.getBitmapPlace();
      this.updateInfo = var1;
      Rectangle var3 = this.updateInfo.getRectangle();
      var3.x = var3.x + var2.x;
      var3.y = var3.y + var2.y;
      if (this.kvmView.isScaleVideoFlag()) {
         this.repaint(0, 0, this.getWidth(), this.getHeight());
      } else {
         this.repaint(var3);
      }
   }

   public Rectangle getBitmapPlace() {
      this.setKvmBorders();
      Dimension var2 = this.kvmView.fixSize(this.getSize());
      Rectangle var1 = new Rectangle(
         this.kvmView.isScaleVideoFlag() ? 0 : (var2.width - this.hImageSize) / 2,
         this.kvmView.isScaleVideoFlag() ? 0 : (var2.height - this.vImageSize) / 2,
         this.kvmView.isScaleVideoFlag() ? var2.width : this.hImageSize,
         this.kvmView.isScaleVideoFlag() ? var2.height : this.vImageSize
      );
      if (var1.x < 0) {
         var1.x = 0;
      }

      if (var1.y < 0) {
         var1.y = 0;
      }

      return var1;
   }

   public Rectangle getBitmapLocation() {
      if (this.kvmView.isScaleVideoFlag()) {
         int var1 = (int)(this.objNewVideoModeData.getActualVSize() / this.yScale + 0.5);
         int var2 = (int)(this.objNewVideoModeData.getActualHSize() / this.xScale + 0.5);
         Rectangle var3 = this.getVisibleRect();
         if (var1 > var3.height) {
            var1 = var3.height;
         }

         if (var2 > var3.width) {
            var2 = var3.width;
         }

         int var4 = var3.height - var1;
         if (var4 < 0) {
            var4 = 0;
         } else {
            var4 >>= 1;
         }

         int var5 = var3.width - var2;
         if (var5 < 0) {
            var5 = 0;
         } else {
            var5 >>= 1;
         }

         return new Rectangle(var5, var4, var2, var1);
      } else {
         return this.getBitmapPlace();
      }
   }

   public Rectangle getBitmapRect() {
      Dimension var2 = this.kvmView.fixSize(this.getSize());
      return new Rectangle(
         this.kvmView.isScaleVideoFlag() ? 0 : (var2.width - this.hImageSize) / 2,
         this.kvmView.isScaleVideoFlag() ? 0 : (var2.height - this.vImageSize) / 2,
         this.kvmView.isScaleVideoFlag() ? var2.width : this.hImageSize,
         this.kvmView.isScaleVideoFlag() ? var2.height : this.vImageSize
      );
   }

   @Override
   public void paint(Graphics var1) {
      super.paint(var1);
      this.paintComponent(var1);
   }

   @Override
   public void paintComponent(Graphics var1) {
      super.paintComponent(var1);
      var1.setColor(Color.DARK_GRAY);
      Image var2 = null;
      if (!this.kvmView.isVideoFrozen() && this.updateInfo != null) {
         var2 = this.updateInfo.getImage();
      }

      if (var2 != null) {
         if (this.kvmView.isScaleVideoFlag()) {
            Rectangle var3 = this.getParent().getBounds();
            var3.x = 0;
            var3.y = 0;
            double var4 = (double)this.objNewVideoModeData.getActualVSize() / this.objNewVideoModeData.getActualHSize();
            this.xScale = (double)this.hImageSize / var3.width;
            this.yScale = (double)this.vImageSize / var3.height;
            if (this.xScale >= this.yScale) {
               int var6 = (int)(var3.width * var4 + 0.5);
               int var7 = var3.height - var6;
               var3.y = var7 >> 1;
               var3.height -= var7;
               this.yScale = (double)this.vImageSize / var3.height;
            } else {
               int var18 = (int)(var3.height / var4 + 0.5);
               int var21 = var3.width - var18;
               var3.x = var21 >> 1;
               var3.width -= var21;
               this.xScale = (double)this.hImageSize / var3.width;
            }

            var1.drawImage(var2, var3.x, var3.y, var3.x + var3.width, var3.y + var3.height, 0, 0, this.hImageSize, this.vImageSize, this);
         } else {
            Rectangle var8 = this.getBitmapPlace();
            Rectangle var13 = var8.intersection(var1.getClipBounds());
            if (!var13.isEmpty()) {
               boolean var5 = var1.drawImage(
                  var2,
                  var13.x,
                  var13.y,
                  var13.x + var13.width,
                  var13.y + var13.height,
                  var13.x - var8.x,
                  var13.y - var8.y,
                  var13.x + var13.width - var8.x,
                  var13.y + var13.height - var8.y,
                  this
               );
               if (!var5) {
                  System.out.println("error in drawImage");
               }
            }
         }
      }

      if (!this.getOsdMessage().equals("")) {
         var1.fillRect(0, 0, this.getWidth(), this.getHeight());
         if (Locale.getDefault().getLanguage().equalsIgnoreCase(Locale.ENGLISH.getLanguage())) {
            var1.setFont(this.font);
         } else {
            Font var9 = var1.getFont();
            var9 = var9.deriveFont(1, var9.getSize() * 2.0F);
            var1.setFont(var9);
         }

         FontMetrics var11 = var1.getFontMetrics();
         int var14 = var11.stringWidth(this.getOsdMessage());
         int var16 = (this.getVisibleRect().width - var14) / 2;
         int var19 = this.getVisibleRect().height / 2;
         var1.setColor(Color.WHITE);
         var1.fillRect(var16, var19 - var11.getHeight() + 5, var14 + 5, var11.getHeight());
         var1.setColor(Color.BLUE);
         var1.drawString(this.getOsdMessage(), var16, var19);
      }

      if (!"".equals(this.popupMessage)) {
         Font var12 = new Font("Verdana", 1, 15);
         FontMetrics var15 = var1.getFontMetrics(var12);
         int var17 = var15.stringWidth(this.getPopupMessage());
         int var20 = this.getVisibleRect().width - var17;
         int var22 = this.getVisibleRect().height;
         var1.drawRect(var20 / 2, var22 - var15.getHeight() - 10 + 5, var17 + 5, var15.getHeight());
         var1.setColor(Color.BLACK);
         var1.fillRect(var20 / 2, var22 - var15.getHeight() - 10 + 5, var17 + 5, var15.getHeight());
         var1.setColor(Color.GREEN);
         var1.setFont(var12);
         var1.drawString(this.getPopupMessage(), var20 / 2, var22 - 10);
         this.repaint();
      }
   }

   public void setOsdMessage(String var1) {
      this.mOsdString = var1;
   }

   private String getOsdMessage() {
      return this.mOsdString;
   }

   public void setPopupMessage(String var1) {
      this.popupMessage = var1;
   }

   public String getPopupMessage() {
      return this.popupMessage;
   }

   public int getPossiblyScaledXCoord(int var1) {
      return (int)(this.kvmView.isScaleVideoFlag() ? var1 * this.xScale : var1);
   }

   public int getPossiblyScaledYCoord(int var1) {
      return (int)(this.kvmView.isScaleVideoFlag() ? var1 * this.yScale : var1);
   }

   private void setKvmBorders() {
      if (this.kvmView.isScaleVideoFlag()) {
         this.kvmView.setHorizontalKvmBorderVisible(false, 0);
         this.kvmView.setVerticalKvmBorderVisible(false, 0);
         this.kvmView.setHorizontalScrollBarVisibility(false);
         this.kvmView.setVerticalScrollBarVisibility(false);
         this.kvmView.setSouthEastLabelVisible(false);
         this.kvmView.knowScrolls(true);
      } else {
         boolean var1 = ((RRCScreenContext)this.scrContext).getAppSettings().isShowScrollBorders();
         boolean var2 = false;
         boolean var3 = false;
         Dimension var4 = this.getSize();
         if (this.kvmView.getScrollPaneSize().getWidth() < var4.getWidth() - 1.0) {
            var2 = true;
            this.kvmView.setHorizontalScrollBarVisibility(true);
            if (var1) {
               int var5 = (int)(var4.getWidth() - this.kvmView.getScrollPaneSize().getWidth());
               if (var5 > 20) {
                  var5 = 20;
               }

               this.kvmView.setHorizontalKvmBorderVisible(true, var5);
            } else {
               this.kvmView.setHorizontalKvmBorderVisible(false, 0);
            }
         } else {
            var2 = false;
            this.kvmView.setHorizontalScrollBarVisibility(false);
            this.kvmView.setHorizontalKvmBorderVisible(false, 0);
         }

         if (this.kvmView.getScrollPaneSize().getHeight() < var4.getHeight() - 1.0) {
            var3 = true;
            this.kvmView.setVerticalScrollBarVisibility(true);
            if (var1) {
               int var8 = (int)(var4.getHeight() - this.kvmView.getScrollPaneSize().getHeight());
               if (var8 > 20) {
                  var8 = 20;
               }

               this.kvmView.setVerticalKvmBorderVisible(true, var8);
            } else {
               this.kvmView.setVerticalKvmBorderVisible(false, 0);
            }
         } else {
            var3 = false;
            this.kvmView.setVerticalScrollBarVisibility(false);
            this.kvmView.setVerticalKvmBorderVisible(false, 0);
         }

         if (var2 && var3) {
            this.kvmView.setSouthEastLabelVisible(true);
         } else {
            this.kvmView.setSouthEastLabelVisible(false);
         }

         this.kvmView.knowScrolls(true);
      }
   }

   protected void setView(KvmView var1) {
      this.kvmView = var1;
   }

   protected void disconnect() {
      this.updateInfo = null;
   }
}
