package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.KvmStream;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.PopulateKeyboardMenuCommand;
import com.raritan.rrc.ui.components.ContextPopupMenu;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.ui.models.NewVideoModeEvent;
import com.raritan.rrc.ui.models.NewVideoModeListener;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.AbstractUIManager;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandCheckMenuItem;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.util.kbd.KeyHIDValue;
import com.util.kbd.KeyboardKey;
import com.util.kbd.KeyboardMappings;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Robot;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionAdapter;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;
import java.beans.PropertyVetoException;
import java.util.StringTokenizer;
import java.util.TimerTask;
import java.util.Vector;
import javaclientlib.clientlib.IKvmData;
import javaclientlib.tr.TRCMD_RESUME_VIDEO_STREAM_DATA;
import javaclientlib.tr.TRLIB_UPDATEINFO;
import javaclientlib.tr.TRRSP_NEW_VIDEO_MODE_DATA;
import javaclientlib.tr.TRSRVR_COMP_PARAMS;
import javaclientlib.tr.TRSRVR_VIDEO_PARAMS;
import javaclientlib.utils.RRCLogger;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;
import javax.swing.Timer;
import nn.pp.common.ResourceLoader;
import nn.pp.ext.pref.IApplicationPreferences;

public class KvmView extends DeviceViewAdapter implements IKvmData, NewVideoModeListener, FocusListener, AdjustmentListener, MouseListener {
   private static final long serialVersionUID = 5760851042261351136L;
   private static final int iAutoScrollBorderSize = 10;
   private boolean targetScreenResolutionFlag = false;
   private static final int MIN_MOUSE_MOVE_TIME = 100;
   private long lLastMouseTicks = 0L;
   private int iLastMouseX = 0;
   private int iLastMouseY = 0;
   private int iLastSendMouseX = 0;
   private int iLastSendMouseY = 0;
   private int iFixMouseX = 0;
   private int iFixMouseY = 0;
   private int iLastMouseDataX = 29000;
   private int iLastMouseDataY = 29000;
   private boolean scrollBarsSet = false;
   private boolean isSingleCursor = false;
   private KvmStream kvmStream;
   private KvmPanel kvmPanel;
   private KvmPort kvmPort;
   private RRCScreenContext scrContext;
   private boolean scaleVideoFlag = false;
   private Timer updateTimer;
   private int lastDataIn;
   private IPReach dev;
   private DeviceConnector devCon;
   private KvmView.KvmResizer kvmResizer = new KvmView.KvmResizer();
   private KvmView.KvmKeyAdapter kvmKeyAdapter = new KvmView.KvmKeyAdapter();
   private KvmView.KvmMouseAdapter kvmMouseAdapter = new KvmView.KvmMouseAdapter();
   private KvmView.KvmMouseMotionAdapter kvmMouseMotionAdapter = new KvmView.KvmMouseMotionAdapter();
   private KvmView.KvmMouseWheelAdapter kvmMouseWheelAdapter = new KvmView.KvmMouseWheelAdapter();
   private JScrollPane jsp;
   private JLabel northLabel;
   private JLabel southLabel;
   private JLabel westLabel;
   private JLabel eastLabel;
   private boolean mousebutton = true;
   private boolean videoFrozen = true;
   private JLabel southEastLabel;
   private JScrollBar verticalScrollBar;
   private JScrollBar horizontalScrollBar;
   private boolean adjustingVertical = false;
   private int adjustmentValue = 0;
   private Timer timer = null;
   private boolean altFlag = false;
   private boolean syncFlag = false;
   RaritanPropertyResourceBundle bundle;
   private ContextPopupMenu contextMenuKvm = null;
   private KvmViewCommandHandler kvmViewCommandHandler = new KvmViewCommandHandler();
   private boolean paused = false;
   boolean altReleased = false;
   boolean ctrlReleased = false;
   private Point oldPos = new Point(0, 0);
   private KvmView.UpdateQueue updQ = new KvmView.UpdateQueue();
   private Timer refreshTimer = null;
   private KvmView.CPainter cPainter;
   int prcount = 0;

   public KvmView(boolean var1, ScreenContext var2, boolean var3) {
      super((RRCScreenContext)var2);
      this.scrContext = (RRCScreenContext)var2;
      this.isNewPanel = var3;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.contextMenuKvm = new ContextPopupMenu(this.scrContext, this);
      this.contextMenuKvm.setOpaque(false);
      this.contextMenuKvm.setVisible(false);
      this.enableInputMethods(false);
      this.setFocusTraversalKeysEnabled(false);
   }

   public void unfreezeVideo() {
      if (this.kvmPanel != null) {
         this.kvmPanel.setOsdMessage("");
      }

      this.videoFrozen = false;
   }

   public void freezeVideo() {
      this.videoFrozen = true;
   }

   public boolean isVideoFrozen() {
      return this.videoFrozen;
   }

   @Override
   public void setUpdateFrequency(long var1) {
      if (this.refreshTimer != null) {
         this.refreshTimer.stop();
      }

      this.cPainter = new KvmView.CPainter();
      this.refreshTimer = new Timer((int)var1, this.cPainter);
      this.refreshTimer.start();
   }

   private void onMouseMove(int var1, int var2, boolean var3) {
      if (this.kvmPanel != null) {
         Rectangle var6 = this.kvmPanel.getBitmapLocation();
         if (var6 != null) {
            if (var6.contains(var1, var2) || var3) {
               int var4 = var1 - var6.x;
               int var5 = var2 - var6.y;
               if (var4 < 0) {
                  var4 = 0;
               } else if (var4 >= var6.width) {
                  var4 = var6.width - 1;
               }

               if (var5 < 0) {
                  var5 = 0;
               } else if (var5 >= var6.height) {
                  var5 = var6.height - 1;
               }

               this.iLastMouseX = var4;
               this.iLastMouseY = var5;
               this.updateMousePosition(true);
            }
         }
      }
   }

   private void onMouseButton(byte var1, int var2, int var3) {
      if (this.kvmPanel != null) {
         this.ResumeVideo();
         this.kvmStream.sendMouseData(var1, (short)var2, (short)var3, (short)0);
         this.mousebutton = false;
      }
   }

   private void sendFilteredMouseData(byte var1, int var2, int var3, int var4) {
      if (var1 == 6) {
         if (var2 == this.iLastMouseDataX && var3 == this.iLastMouseDataY) {
            return;
         }

         this.iLastMouseDataX = var2;
         this.iLastMouseDataY = var3;
         this.syncFlag = true;
      }

      this.ResumeVideo();
      this.kvmStream.sendMouseData(var1, (short)var2, (short)var3, (short)var4);
   }

   @Override
   public void sendCtrlAltDelete() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.setKeyState((short)225, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)225, false, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)229, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)229, false, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)224, true, false);
         this.kvmStream.setKeyState((short)226, true, false);
         this.kvmStream.setKeyState((short)76, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)76, false, false);
         this.kvmStream.setKeyState((short)226, false, false);
         this.kvmStream.setKeyState((short)224, false, false);
         this.kvmStream.flushKeyData();
      } else {
         this.scrContext.getLogger().logTextDebug("Cannot send ctrl+alt+delete kvm stream not connected ");
      }
   }

   @Override
   public void sendAltTab() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.setKeyState((short)225, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)225, false, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)229, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)229, false, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)226, true, false);
         this.kvmStream.setKeyState((short)43, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)226, false, false);
         this.kvmStream.setKeyState((short)43, false, false);
         this.kvmStream.flushKeyData();
      } else {
         this.scrContext.getLogger().logTextDebug("Cannot send LeftAlt+Tab kvm stream not connected ");
      }
   }

   @Override
   public void sendCtrlNumlock() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.setKeyState((short)225, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)225, false, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)229, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)229, false, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)224, true, false);
         this.kvmStream.setKeyState((short)83, true, false);
         this.kvmStream.flushKeyData();
         this.kvmStream.setKeyState((short)83, false, false);
         this.kvmStream.setKeyState((short)224, false, false);
         this.kvmStream.flushKeyData();
      } else {
         this.scrContext.getLogger().logTextDebug("Cannot send ctrl+numlock kvm stream not connected ");
      }
   }

   @Override
   public void sendKVMPopupKey() {
      try {
         if (this.kvmStream.isConnected()) {
            this.kvmStream.setKeyState((short)224, true, false);
            this.kvmStream.setKeyState((short)226, true, false);
            this.kvmStream.flushKeyData();
            if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionA"))) {
               this.kvmStream.setKeyState((short)4, true, false);
               this.kvmStream.setKeyState((short)4, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionB"))) {
               this.kvmStream.setKeyState((short)5, true, false);
               this.kvmStream.setKeyState((short)5, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionC"))) {
               this.kvmStream.setKeyState((short)6, true, false);
               this.kvmStream.setKeyState((short)6, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionD"))) {
               this.kvmStream.setKeyState((short)7, true, false);
               this.kvmStream.setKeyState((short)7, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionE"))) {
               this.kvmStream.setKeyState((short)8, true, false);
               this.kvmStream.setKeyState((short)8, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionF"))) {
               this.kvmStream.setKeyState((short)9, true, false);
               this.kvmStream.setKeyState((short)9, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionG"))) {
               this.kvmStream.setKeyState((short)10, true, false);
               this.kvmStream.setKeyState((short)10, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionH"))) {
               this.kvmStream.setKeyState((short)11, true, false);
               this.kvmStream.setKeyState((short)11, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionI"))) {
               this.kvmStream.setKeyState((short)12, true, false);
               this.kvmStream.setKeyState((short)12, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionJ"))) {
               this.kvmStream.setKeyState((short)13, true, false);
               this.kvmStream.setKeyState((short)13, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionK"))) {
               this.kvmStream.setKeyState((short)14, true, false);
               this.kvmStream.setKeyState((short)14, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionL"))) {
               this.kvmStream.setKeyState((short)15, true, false);
               this.kvmStream.setKeyState((short)15, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionM"))) {
               this.kvmStream.setKeyState((short)16, true, false);
               this.kvmStream.setKeyState((short)16, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionN"))) {
               this.kvmStream.setKeyState((short)17, true, false);
               this.kvmStream.setKeyState((short)17, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionO"))) {
               this.kvmStream.setKeyState((short)18, true, false);
               this.kvmStream.setKeyState((short)18, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionP"))) {
               this.kvmStream.setKeyState((short)19, true, false);
               this.kvmStream.setKeyState((short)19, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionQ"))) {
               this.kvmStream.setKeyState((short)20, true, false);
               this.kvmStream.setKeyState((short)20, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionR"))) {
               this.kvmStream.setKeyState((short)21, true, false);
               this.kvmStream.setKeyState((short)21, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionS"))) {
               this.kvmStream.setKeyState((short)22, true, false);
               this.kvmStream.setKeyState((short)22, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionT"))) {
               this.kvmStream.setKeyState((short)23, true, false);
               this.kvmStream.setKeyState((short)23, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionU"))) {
               this.kvmStream.setKeyState((short)24, true, false);
               this.kvmStream.setKeyState((short)24, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionV"))) {
               this.kvmStream.setKeyState((short)25, true, false);
               this.kvmStream.setKeyState((short)25, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionW"))) {
               this.kvmStream.setKeyState((short)26, true, false);
               this.kvmStream.setKeyState((short)26, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionX"))) {
               this.kvmStream.setKeyState((short)27, true, false);
               this.kvmStream.setKeyState((short)27, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionY"))) {
               this.kvmStream.setKeyState((short)28, true, false);
               this.kvmStream.setKeyState((short)28, false, false);
            } else if (this.scrContext.getAppSettings().getkeyboardMenuHotkey().equals(this.bundle.getString("KeyboardMenuHotkey.OptionZ"))) {
               this.kvmStream.setKeyState((short)29, true, false);
               this.kvmStream.setKeyState((short)29, false, false);
            }

            this.kvmStream.flushKeyData();
            this.kvmStream.setKeyState((short)226, false, false);
            this.kvmStream.setKeyState((short)224, false, false);
            this.kvmStream.flushKeyData();
         } else {
            this.scrContext.getLogger().logTextDebug("Cannot send ctrl+alt+m kvm stream not connected ");
         }
      } catch (Exception var2) {
         var2.printStackTrace();
      }
   }

   @Override
   public void enterOnScreenMenu() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.flushKeyData();
         int var1 = this.scrContext.getAppSettings().getOsuiHotKey();
         switch (var1) {
            case 0:
               this.kvmStream.toogleKeyState((short)71);
               this.kvmStream.toogleKeyState((short)71);
               break;
            case 1:
               this.kvmStream.toogleKeyState((short)83);
               this.kvmStream.toogleKeyState((short)83);
               break;
            case 2:
               this.kvmStream.toogleKeyState((short)57);
               this.kvmStream.toogleKeyState((short)57);
         }

         this.kvmStream.flushKeyData();
      } else {
         this.scrContext.getLogger().logTextDebug("Cannot send Enter OSUI key kvm stream not connected ");
      }
   }

   @Override
   public void exitOnScreenMenu() {
      try {
         if (this.kvmStream.isConnected()) {
            this.kvmStream.flushKeyData();
            this.kvmStream.toogleKeyState((short)41);
            this.kvmStream.flushKeyData();
         } else {
            this.scrContext.getLogger().logTextDebug("Cannot send escapeKey kvm stream not connected ");
         }
      } catch (Exception var2) {
      }
   }

   @Override
   public void synchronizeMouse(boolean var1) {
      if (this.kvmStream.isConnected()) {
         if (var1) {
            this.kvmStream.syncMouse(4);
         } else {
            this.kvmStream.syncMouse(8);
         }

         try {
            Thread.sleep(500L);
         } catch (InterruptedException var3) {
            System.out.println("waiting in synchronizeMouse interrupted");
         }

         this.iLastSendMouseX = 0;
         this.iLastSendMouseY = 0;
      }

      this.syncFlag = false;
   }

   @Override
   public void refreshScreen() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.refreshVideo(0, false);
      }
   }

   @Override
   public void autoSenseVideo() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.refreshVideo(0, true);
      }
   }

   @Override
   public void calibrateColor() {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.refreshVideo(1, false);
      }
   }

   @Override
   public void updateVideoSettings(TRSRVR_VIDEO_PARAMS var1) {
      if (this.kvmStream.isConnected()) {
         this.kvmStream.setVideoParams(var1);
      }
   }

   public void updateMousePosition(boolean var1) {
      if (this.kvmPanel != null) {
         int var2 = this.kvmPanel.getPossiblyScaledXCoord(this.iLastMouseX);
         int var3 = this.kvmPanel.getPossiblyScaledYCoord(this.iLastMouseY);
         if (var2 != this.iLastSendMouseX || var3 != this.iLastSendMouseY) {
            long var4 = System.currentTimeMillis();
            if (var4 - this.lLastMouseTicks >= 100L) {
               this.lLastMouseTicks = var4;
               if (this.kvmPanel != null & ((KvmPort)this.port).isStreamConnected()) {
                  this.sendFilteredMouseData((byte)6, (short)var2, (short)var3, 0);
                  this.iLastSendMouseX = var2;
                  this.iLastSendMouseY = var3;
               }
            }
         }
      }
   }

   @Override
   public void setCompParameters(TRSRVR_COMP_PARAMS var1) {
      if (this.kvmStream.isConnected()) {
         ((IPReach)this.port.getDevice()).getConnectionInfo().setCompParams(var1);
         this.kvmStream.setCompParams(var1);
      }
   }

   @Override
   public ContextPopupMenu getContextPopupMenu() {
      return this.contextMenuKvm;
   }

   @Override
   public void notify(int var1, int var2) {
      label80:
      switch (var1) {
         case 0:
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).showAutoSense(var2);
            if (var2 == -1) {
               boolean var7 = this.scrContext.getAppSettings().isDoAutoColorCal();
               if (var7 && this.dev.getColorCalibSpeed() < 3000 && this.kvmStream.isConnected()) {
                  this.kvmStream.refreshVideo(2, false);
               }

               this.kvmPort.getDevice().getHandler().finishAutoSensing(this.kvmPanel);
            } else {
               this.freezeVideo();
               this.updQ.clear();
            }
            break;
         case 1:
            if (this.kvmPort != null && this.kvmPort.isConnected()) {
               ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setConcurrentUsers(var2);
               this.kvmPort.setConcurrUsers(var2);
            }
            break;
         case 2:
            if (var2 != 0) {
               this.paused = true;
               if (this.kvmPanel != null) {
                  this.kvmPanel.setOsdMessage("Video Paused");
               }
            } else {
               if (this.devCon != null && this.paused && this.devCon.getProtocolVersion() >= 30) {
                  TRCMD_RESUME_VIDEO_STREAM_DATA var6 = new TRCMD_RESUME_VIDEO_STREAM_DATA();
                  var6.setDeviceID(this.kvmStream.getDeviceID());
                  this.devCon.sendTRCmdEx(var6, true, null, 2);
               }

               this.paused = false;
               if (this.kvmPanel != null) {
                  this.kvmPanel.setOsdMessage("");
               }
            }

            if (this.kvmPanel != null) {
               this.kvmPanel.repaint();
            }
            break;
         case 3:
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setBandwidthUsage(0);
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setVideoSensingLabel(this.bundle.getString("StatusBar.noVideo.label"));
            break;
         case 6:
            try {
               CommonPopups.showInfoDialog("Info", this.bundle.getString("FG_RESET_MSG"), null, this.scrContext);
            } catch (Exception var4) {
            }
            break;
         case 1007:
            try {
               switch (this.kvmPort.getDeviceConnector().getServerID().getSecurityFlags() & 3840) {
                  case 256:
                  case 512:
                  default:
                     ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setSecurityLabel(0);
                     break label80;
                  case 1024:
                  case 2048:
                     ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setSecurityLabel(1);
               }
            } catch (Exception var5) {
            }
            break;
         case 1031:
            if (this.scrContext.getSelectedPort() == this.kvmPort) {
               RRCStatusBar var3 = (RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel();
               var3.setLEDState((var2 & 1) != 0, (var2 & 2) != 0, (var2 & 4) != 0);
            }
      }

      if (this.kvmPanel != null) {
         this.kvmPanel.notify(var1, var2);
      }
   }

   @Override
   public void ResumeVideo() {
      if (this.paused) {
         this.notify(2, 0);
         this.paused = false;
      }
   }

   @Override
   public void updateNotify(TRLIB_UPDATEINFO var1) {
      this.updQ.enqueue(var1);
   }

   @Override
   public void newVideoModeNotify(TRRSP_NEW_VIDEO_MODE_DATA var1) {
      this.updQ.clear();
      if (this.kvmPanel != null) {
         this.kvmPanel.newVideoModeNotify(var1);
         this.synchronizeMouse(true);
      }
   }

   @Override
   public void setDefaultFocussedComponent() {
      if (this.kvmPanel != null) {
         this.kvmPanel.requestFocusInWindow();
      }
   }

   @Override
   public void newVideoModePerformed(final NewVideoModeEvent var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            if (KvmView.this.kvmPanel != null) {
               KvmView.this.kvmPanel.newVideoModeNotify(var1.getVideoMode());
            }
         }
      });
   }

   @Override
   public void updateNotifyPerformed(final NewVideoModeEvent var1) {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            if (KvmView.this.kvmPanel != null) {
               KvmView.this.kvmPanel.updateNotify(var1.getUpdateData());
            }
         }
      });
   }

   @Override
   public boolean disconnect() {
      this.stopUpdateTimer();
      this.updQ.clear();
      this.contextMenuKvm.cleanup();
      if (this.kvmPanel != null) {
         this.kvmPanel.disconnect();
         this.kvmPanel = null;
         System.runFinalization();
         System.gc();
      }

      return true;
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.kvmPort = (KvmPort)var1.getCommandParameter("ports");
      if (this.kvmPort == null) {
         this.disconnect();
      } else {
         this.dev = (IPReach)this.kvmPort.getDevice();
         this.devCon = this.dev.getDeviceConnector();
         this.makeLayout();
         this.lastDataIn = this.devCon.getDataIn();
         this.updateSpeed();
         this.focusGained(new FocusEvent(this, 1004));
      }
   }

   @Override
   public void makeLayout() {
      this.kvmPort.setView(this);
      this.kvmStream = (KvmStream)this.kvmPort.getStream();
      this.setLayout(new BorderLayout());
      RaritanDesktopPane var1 = (RaritanDesktopPane)this.scrContext.getPanelMediator().getParent();
      this.kvmPanel = new KvmPanel(false, this.scrContext);
      this.kvmPanel.setView(this);
      this.kvmPanel.setSize(var1.getSize());
      this.kvmPanel.setFocusable(true);
      this.jsp = new JScrollPane();
      this.jsp.setViewportView(this.kvmPanel);
      this.jsp.setHorizontalScrollBarPolicy(31);
      this.jsp.setVerticalScrollBarPolicy(21);
      this.horizontalScrollBar = new JScrollBar(0);
      this.verticalScrollBar = new JScrollBar(1);
      this.horizontalScrollBar.setVisible(false);
      this.verticalScrollBar.setVisible(false);
      this.southEastLabel = new JLabel(ResourceLoader.loadImageIcon(this.bundle.getString("Transparent.image")));
      this.southEastLabel.setBackground(Color.GRAY);
      this.southEastLabel.setPreferredSize(new Dimension(20, 20));
      JPanel var2 = new JPanel(new BorderLayout());
      var2.add(this.horizontalScrollBar, "Center");
      var2.add(this.southEastLabel, "East");
      JPanel var3 = this.createCenterPanel();
      this.setHorizontalKvmBorderVisible(false, 0);
      this.setVerticalKvmBorderVisible(false, 0);
      this.setSouthEastLabelVisible(false);
      this.add(var3, "Center");
      this.add(var2, "South");
      this.add(this.verticalScrollBar, "East");
      this.addComponentListener(this.kvmResizer);
      this.addKeyListener(this.kvmKeyAdapter);
      this.addFocusListener(this);
      this.jsp.addMouseListener(this.kvmMouseAdapter);
      this.jsp.addMouseMotionListener(this.kvmMouseMotionAdapter);
      this.jsp.addMouseWheelListener(this.kvmMouseWheelAdapter);
      this.horizontalScrollBar.addAdjustmentListener(this);
      this.verticalScrollBar.addAdjustmentListener(this);
      if (this.kvmPort.isConnected()) {
         boolean var4 = ((KvmStream)this.kvmPort.getStream()).getCapsLockStatus();
         boolean var5 = ((KvmStream)this.kvmPort.getStream()).getNumLockStatus();
         boolean var6 = ((KvmStream)this.kvmPort.getStream()).getScrollLockStatus();
         ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).initKVMStatusBarLabels(var4, var5, var6);
         ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setBandwidthUsage(1);
         this.startUpdateTimer();
         IApplicationPreferences var7 = this.scrContext.getAppSettings();
         RRCScreenContext var8 = this.scrContext;
         if (var7.isAlwaysOpenSMM()) {
            Port var9 = var8.getSelectedPort();
            if (var9 != null && var9.isConnected() && var9 instanceof KvmPort && !this.port.isMultiMonitorPort()) {
               System.out.println("ALL CHECKS PASS..open SMM");
               ((KvmPort)var9).toggleSingleMouseCursor();
               var8.getMainScreenMediator().selectSingleMouseCursorMode();
            }
         }

         if (var7.isAlwaysOpenScaled()) {
            Port var12 = var8.getSelectedPort();
            if (var12 != null && var12.isConnected() && var12 instanceof KvmPort) {
               var12.getView().setScaleVideoFlag(true);
            }

            for (CommandCheckMenuItem var11 : var8.getMainScreenMediator().getCheckScaleVideoMenuItems()) {
               var11.setSelected(true);
            }

            var8.getMainScreenMediator().getToolBarScaleVideoButton().setSelected(true);
         }

         if (var7.isAlwaysOpenInFS()) {
            this.setTargetScreenResolution(true);
         }
      }

      this.kvmPort.initSingleCursorMode();
   }

   public void startUpdateTimer() {
      this.updateTimer = new Timer(250, new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            if (KvmView.this.isFocusOwner()) {
               KvmView.this.updateMousePosition(false);
               KvmView.this.updateSpeed();
            }

            if (KvmView.this.scrContext.getAppSettings().isAutoSyncMouse() && KvmView.this.syncFlag && KvmView.this.kvmPort.getKvmMouse().isStandardMouse()) {
               long var2 = System.currentTimeMillis();
               if (var2 - KvmView.this.lLastMouseTicks > 15000L) {
                  KvmView.this.synchronizeMouse(true);
               }
            }
         }
      });
      this.updateTimer.start();
   }

   public void stopUpdateTimer() {
      if (this.updateTimer != null && this.updateTimer.isRunning()) {
         this.updateTimer.stop();
         this.updateTimer = null;
      }
   }

   private void updateSpeed() {
      if (this.dev != null && this.devCon != null) {
         int var1 = this.dev.getConnectionInfo().getCompParams().getSpeed();
         int var2 = this.devCon.getDataIn();
         if (var2 >= this.lastDataIn) {
            int var3 = (var2 - this.lastDataIn) * 1000 / 250;
            if (var1 == 0) {
               try {
                  var1 = this.kvmStream.getVideoMode().getCompParams().getSpeed();
               } catch (Exception var6) {
               }
            }

            if (var1 != 0) {
               if (var3 > 0) {
                  var3 = var3 * 8 / (var1 / 8) + 1;
               }

               if (var3 > 8) {
                  var3 = 8;
               }

               try {
                  ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setBandwidthUsage(var3);
               } catch (Exception var5) {
               }
            }
         }

         this.lastDataIn = var2;
      }
   }

   @Override
   public void focusGained(FocusEvent var1) {
      if (this.getShellInternalFrame().isSelected()) {
         MPCUtil.clearUnfocusedMenus(this.scrContext);
         super.focusGained(var1);
         DeviceTreeController.getInstance(this.scrContext).showBold();
         if (this.kvmStream != null) {
            boolean var2 = this.kvmStream.getCapsLockStatus();
            boolean var3 = this.kvmStream.getNumLockStatus();
            boolean var4 = this.kvmStream.getScrollLockStatus();
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).initKVMStatusBarLabels(var2, var3, var4);
         }

         if (var1.getOppositeComponent() != null) {
            for (CommandCheckMenuItem var6 : this.scrContext.getMainScreenMediator().getCheckScaleVideoMenuItems()) {
               var6.setSelected(this.scaleVideoFlag);
            }

            this.scrContext.getMainScreenMediator().getToolBarScaleVideoButton().setSelected(this.scaleVideoFlag);
         }

         if (this.mousebutton) {
            this.updateMousePosition(false);
         } else {
            this.mousebutton = true;
         }

         this.requestFocusInWindow();
      }
   }

   @Override
   public void focusLost(FocusEvent var1) {
      super.focusLost(var1);
      if (this.scrContext != null && this.scrContext.getPanelMediator() != null && this.scrContext.getPanelMediator().getStatusPanel() != null) {
         ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).clearStatusBarLabels();
      }

      if (this.kvmPanel != null) {
         this.kvmPanel.forceRepaint();
      }
   }

   @Override
   public void adjustmentValueChanged(AdjustmentEvent var1) {
      if (this.kvmPanel != null) {
         double var2 = this.horizontalScrollBar.getValue();
         double var4 = this.verticalScrollBar.getValue();
         int var6 = this.kvmPanel.getVisibleRect().x;
         int var7 = this.kvmPanel.getVisibleRect().y;
         var2 = var2 / 90.0 * (this.jsp.getHorizontalScrollBar().getMaximum() - this.kvmPanel.getVisibleRect().getWidth());
         var4 = var4 / 90.0 * (this.jsp.getVerticalScrollBar().getMaximum() - this.kvmPanel.getVisibleRect().getHeight());
         if (var6 != (int)var2) {
            this.jsp.getHorizontalScrollBar().setValue((int)var2);
            int var8 = this.kvmPanel.getVisibleRect().x;
            this.iFixMouseX = var8;
            this.iLastMouseX = this.iLastMouseX + var8 - var6;
         }

         if (var7 != (int)var4) {
            this.jsp.getVerticalScrollBar().setValue((int)var4);
            int var11 = this.kvmPanel.getVisibleRect().y;
            this.iFixMouseY = var11;
            this.iLastMouseY = this.iLastMouseY + var11 - var7;
         }

         this.onMouseMove(this.iLastMouseX, this.iLastMouseY, false);
         if (this.kvmPanel != null) {
            this.kvmPanel.forceRepaint();
         }
      }
   }

   private void sizeAutoScroll(int var1) {
      Dimension var2 = new Dimension(var1, var1);
      this.northLabel.setPreferredSize(var2);
      this.southLabel.setPreferredSize(var2);
      this.eastLabel.setPreferredSize(var2);
      this.westLabel.setPreferredSize(var2);
   }

   private JPanel createCenterPanel() {
      JPanel var1 = new JPanel(new BorderLayout());
      var1.setBackground(Color.GRAY);
      this.northLabel = new JLabel();
      this.southLabel = new JLabel();
      this.westLabel = new JLabel();
      this.eastLabel = new JLabel();
      this.sizeAutoScroll(10);
      this.northLabel.addMouseListener(this);
      this.southLabel.addMouseListener(this);
      this.westLabel.addMouseListener(this);
      this.eastLabel.addMouseListener(this);
      var1.add(this.northLabel, "North");
      var1.add(this.southLabel, "South");
      var1.add(this.westLabel, "West");
      var1.add(this.eastLabel, "East");
      var1.add(this.jsp, "Center");
      return var1;
   }

   protected void setHorizontalScrollBarVisibility(boolean var1) {
      this.horizontalScrollBar.setVisible(var1);
   }

   protected void setVerticalScrollBarVisibility(boolean var1) {
      this.verticalScrollBar.setVisible(var1);
   }

   protected void setHorizontalKvmBorderVisible(boolean var1, int var2) {
      int var3 = (var2 + 1) / 2;
      this.westLabel.setPreferredSize(new Dimension(var3, 10));
      this.eastLabel.setPreferredSize(new Dimension(var3, 10));
      this.westLabel.setVisible(var1);
      this.eastLabel.setVisible(var1);
   }

   protected void setVerticalKvmBorderVisible(boolean var1, int var2) {
      int var3 = (var2 + 1) / 2;
      this.westLabel.setPreferredSize(new Dimension(10, var3));
      this.eastLabel.setPreferredSize(new Dimension(10, var3));
      this.northLabel.setVisible(var1);
      this.southLabel.setVisible(var1);
   }

   protected void setSouthEastLabelVisible(boolean var1) {
      this.southEastLabel.setVisible(var1);
   }

   protected Dimension fixSize(Dimension var1) {
      byte var2 = 0;
      byte var3 = 0;
      if (this.horizontalScrollBar.isVisible()) {
         var3 = 20;
      }

      if (this.verticalScrollBar.isVisible()) {
         var2 = 20;
      }

      return new Dimension((int)var1.getWidth() - var2, (int)var1.getHeight() - var3);
   }

   @Override
   public void mouseClicked(MouseEvent var1) {
   }

   @Override
   public void mouseEntered(MouseEvent var1) {
      Object var2 = var1.getSource();
      if (var2.equals(this.northLabel)) {
         this.adjustingVertical = true;
         this.adjustmentValue = -1;
      }

      if (var2.equals(this.southLabel)) {
         this.adjustingVertical = true;
         this.adjustmentValue = 1;
      }

      if (var2.equals(this.westLabel)) {
         this.adjustingVertical = false;
         this.adjustmentValue = -1;
      }

      if (var2.equals(this.eastLabel)) {
         this.adjustingVertical = false;
         this.adjustmentValue = 1;
      }

      this.timer = new Timer(50, new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            KvmView.this.adjustScrollBars();
         }
      });
      this.timer.start();
   }

   @Override
   public void mouseExited(MouseEvent var1) {
      if (this.timer != null) {
         this.timer.stop();
         this.timer = null;
      }
   }

   @Override
   public void mousePressed(MouseEvent var1) {
   }

   @Override
   public void mouseReleased(MouseEvent var1) {
   }

   private void adjustScrollBars() {
      int var1 = 0;
      if (this.adjustingVertical) {
         var1 = this.verticalScrollBar.getValue();
      } else {
         var1 = this.horizontalScrollBar.getValue();
      }

      var1 += this.adjustmentValue;
      if (var1 < 0) {
         var1 = 0;
      }

      if (this.adjustingVertical) {
         this.verticalScrollBar.setValue(var1);
      } else {
         this.horizontalScrollBar.setValue(var1);
      }
   }

   @Override
   public KvmPanel getKvmPanel() {
      return this.kvmPanel;
   }

   public Dimension getScrollPaneSize() {
      return this.isTargetScreenResolution()
         ? new Dimension(
            (int)this.jsp.getViewport().getSize().getWidth() + this.verticalScrollBar.getSize().width,
            (int)this.jsp.getViewport().getSize().getHeight() + this.horizontalScrollBar.getSize().height
         )
         : new Dimension((int)this.jsp.getSize().getWidth(), (int)this.jsp.getSize().getHeight());
   }

   @Override
   public boolean isScaleVideoFlag() {
      return this.scaleVideoFlag;
   }

   @Override
   public void setScaleVideoFlag(boolean var1) {
      this.scaleVideoFlag = var1;
      this.horizontalScrollBar.setValue(0);
      this.verticalScrollBar.setValue(0);
   }

   @Override
   public boolean isTargetScreenResolution() {
      return this.targetScreenResolutionFlag;
   }

   @Override
   public void setTargetScreenResolution(boolean var1) {
      if (this.kvmPort != null && this.kvmPort.isConnected()) {
         this.iFixMouseX = 0;
         this.iFixMouseY = 0;
         this.jsp.getHorizontalScrollBar().setValue(0);
         this.jsp.getVerticalScrollBar().setValue(0);
         this.horizontalScrollBar.setValue(0);
         this.verticalScrollBar.setValue(0);
         byte var2;
         if (var1) {
            var2 = 0;
         } else {
            this.altFlag = false;
            var2 = 10;
         }

         this.sizeAutoScroll(var2);
         this.targetScreenResolutionFlag = var1;
         AbstractUIManager var3 = this.scrContext.getApplication();
         var3.changeScreen(this.targetScreenResolutionFlag, this.getShellInternalFrame(), this.port, AbstractUIManager.FullScreenTarget.SINGLE);
         this.grabFocus();
         this.kvmPort.initSingleCursorMode();
      }
   }

   @Override
   public void toggleTargetScreenResolution() {
      this.setTargetScreenResolution(!this.isTargetScreenResolution());
   }

   public boolean isAltFlag() {
      return this.altFlag;
   }

   public int getILastSendMouseX() {
      return this.iLastSendMouseX;
   }

   public int getILastSendMouseY() {
      return this.iLastSendMouseY;
   }

   @Override
   public void setContextMenuKVMVisible(boolean var1) {
      if (var1) {
         this.contextMenuKvm.show(this, 10, 10);
      } else {
         this.contextMenuKvm.setVisible(false);
      }
   }

   @Override
   public boolean isSingleCursor() {
      return this.isSingleCursor;
   }

   @Override
   public void setSingleCursor(boolean var1) {
      this.isSingleCursor = var1;
      if (var1) {
         this.oldPos.setLocation(0, 0);
         this.iLastMouseX = 0;
         this.iLastMouseY = 0;
         this.updateMousePosition(true);
         this.resetMouse();
         this.kvmPanel.setCursor(this.scrContext.getApplication().getBlankCursor());
      } else {
         this.kvmPanel.setCursor(this.scrContext.getApplication().getDefaultCursor());
      }
   }

   public boolean positionedLeft(int var1) {
      return var1 <= 0
         && this.horizontalScrollBar != null
         && this.scrollBarsSet
         && (!this.horizontalScrollBar.isVisible() || this.horizontalScrollBar.getValue() == 0);
   }

   public boolean positionedRight(int var1) {
      return this.kvmPanel == null
         ? false
         : this.horizontalScrollBar != null
            && this.scrollBarsSet
            && (!this.horizontalScrollBar.isVisible() || this.horizontalScrollBar.getValue() >= 90)
            && var1 >= this.kvmPanel.getBitmapRect().width - 1;
   }

   public boolean positionedTop(int var1) {
      return var1 <= 0
         && this.verticalScrollBar != null
         && this.scrollBarsSet
         && (!this.verticalScrollBar.isVisible() || this.verticalScrollBar.getValue() == 0);
   }

   public boolean positionedBottom(int var1) {
      return this.kvmPanel == null
         ? false
         : this.verticalScrollBar != null
            && this.scrollBarsSet
            && (!this.verticalScrollBar.isVisible() || this.verticalScrollBar.getValue() >= 90)
            && var1 >= this.kvmPanel.getBitmapRect().height - 1;
   }

   public void knowScrolls(boolean var1) {
      this.scrollBarsSet = var1;
   }

   @Override
   public void removeListeners() {
      this.removeComponentListener(this.kvmResizer);
      this.removeKeyListener(this.kvmKeyAdapter);
      this.jsp.removeMouseListener(this.kvmMouseAdapter);
      this.jsp.removeMouseMotionListener(this.kvmMouseMotionAdapter);
      this.jsp.removeMouseWheelListener(this.kvmMouseWheelAdapter);
      this.refreshTimer.stop();
      this.refreshTimer.removeActionListener(this.cPainter);
      this.cPainter = null;
      this.refreshTimer = null;
      this.updQ = null;
      this.kvmKeyAdapter = null;
      this.kvmMouseAdapter = null;
      this.kvmMouseMotionAdapter = null;
      this.kvmMouseWheelAdapter = null;
      this.kvmResizer = null;
      this.jsp = null;
      this.kvmPanel = null;
   }

   @Override
   public void setViewFocus() {
      try {
         if (this.getShellInternalFrame().isSelected()) {
            this.grabFocus();
         }
      } catch (Exception var2) {
         RRCLogger.logException(var2);
      }
   }

   @Override
   public void forceRepaint() {
      this.kvmPanel.forceRepaint();
   }

   @Override
   public boolean macroMenuActionPerformed(String var1) {
      boolean var2 = false;
      boolean var3 = false;
      boolean var4 = false;
      boolean var5 = false;
      Port var6 = this.scrContext.getSelectedPort();
      if (var6 == null) {
         return false;
      } else {
         this.ResumeVideo();
         if (StringUtils.notNullOrEmpty(var1) && var6.isConnected()) {
            KeyboardMappings var7 = new KeyboardMappings();
            KvmStream var8 = (KvmStream)var6.getStream();
            if (var8.getKeyState((short)224)) {
               var2 = true;
               var8.setKeyState((short)224, false, true);
            }

            if (var8.getKeyState((short)228)) {
               var3 = true;
               var8.setKeyState((short)228, false, true);
            }

            if (var8.getKeyState((short)226)) {
               var4 = true;
               var8.setKeyState((short)226, false, true);
            }

            if (var8.getKeyState((short)230)) {
               var5 = true;
               var8.setKeyState((short)230, false, true);
            }

            StringTokenizer var9 = new StringTokenizer(var1, "&&");

            while (var9.hasMoreTokens()) {
               String var10 = var9.nextToken();
               String var11 = var10.substring(var10.lastIndexOf(" ") + 1);
               int var12 = Integer.parseInt(var11);
               KeyboardKey var13 = var7.getItem(var12);
               if (var13 != null) {
                  short var14 = (short)var13.getKeyCode();
                  if (var10.startsWith("p")) {
                     var8.setKeyState(var14, true, false);
                  } else if (var10.startsWith("r")) {
                     var8.setKeyState(var14, false, false);
                  }

                  var8.flushKeyData();
               }
            }

            if (var2) {
               var8.setKeyState((short)224, true, true);
            }

            if (var3) {
               var8.setKeyState((short)228, true, true);
            }

            if (var4) {
               var8.setKeyState((short)226, true, true);
            }

            if (var5) {
               var8.setKeyState((short)230, true, true);
            }
         }

         this.forceRepaint();
         return true;
      }
   }

   @Override
   public ICommandHandler getCommandHandler() {
      return this.kvmViewCommandHandler;
   }

   public void resetMouse() {
      try {
         if (this.jsp != null) {
            Robot var1 = new Robot();
            Point var2 = this.jsp.getLocationOnScreen();
            int var3 = (int)var2.getX() + this.jsp.getViewport().getSize().width / 2;
            int var4 = (int)var2.getY() + this.jsp.getViewport().getSize().height / 2;
            var1.mouseMove(var3, var4);
         }
      } catch (Exception var5) {
      }
   }

   @Override
   public boolean isFullScreenMode() {
      return this.targetScreenResolutionFlag;
   }

   @Override
   public void setFullScreenMode(boolean var1) {
      this.targetScreenResolutionFlag = var1;
   }

   @Override
   public void addCustomMouseMotionListener(MouseMotionListener var1) {
      this.jsp.addMouseMotionListener(var1);
   }

   @Override
   public void removeCustomMouseMotionListener(MouseMotionListener var1) {
      this.jsp.removeMouseMotionListener(var1);
   }

   @Override
   public boolean getAbsoluteMouseSupported() {
      this.scrContext.getMainScreenMediator().selectAbsoluteMouseModeView(this.kvmPort.getKvmMouse().isAbsoluteMouse());
      return this.kvmPort.getKvmMouse().enableAbsoluteMouse();
   }

   @Override
   public boolean getIntelligentMouseSupported() {
      this.scrContext.getMainScreenMediator().selectIntelligentMouseModeView(this.kvmPort.getKvmMouse().isIntelligentMouse());
      return this.kvmPort.getKvmMouse().enableIntelligentMouse();
   }

   @Override
   public boolean getStandardMouseSupported() {
      this.scrContext.getMainScreenMediator().selectStandardMouseModeView(this.kvmPort.getKvmMouse().isStandardMouse());
      return this.kvmPort.getKvmMouse().enableStandardMouse();
   }

   @Override
   public void startVideo() {
      Thread var1 = new Thread(new Runnable() {
         @Override
         public void run() {
            try {
               Thread.sleep(2000L);
            } catch (InterruptedException var2) {
               RRCLogger.logException(var2);
            }

            MPCUtil.notifyObservers(KvmView.this.scrContext, KvmView.this.kvmPort);
            KvmView.this.setViewFocus();
         }
      });
      var1.start();
   }

   @Override
   public boolean isSunTarget() {
      return this.kvmStream.isTargetType();
   }

   @Override
   public boolean sendKeyboardMacro(String var1) {
      return this.macroMenuActionPerformed(var1);
   }

   private class CPainter implements ActionListener {
      private CPainter() {
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         while (KvmView.this.kvmPanel != null) {
            synchronized (this) {
               if (KvmView.this.kvmPanel != null) {
                  TRLIB_UPDATEINFO var3 = KvmView.this.updQ.dequeue();
                  if (var3 == null) {
                     return;
                  }

                  KvmView.this.kvmPanel.updateNotify(var3);
               }
            }
         }
      }
   }

   class FlashMessage extends TimerTask {
      int num = 1;

      public FlashMessage() {
      }

      @Override
      public void run() {
         if (this.num > 0) {
            String var1 = KvmView.this.bundle.getString("Optiondialog.KeyboardShortcutMenuHotkey");
            KvmView.this.kvmPanel.setPopupMessage(var1 + " : Ctrl+Alt+" + RRCScreenContext.getKvmPopupKey());
            this.num--;
         } else {
            KvmView.this.kvmPanel.setPopupMessage("");
            this.cancel();
            KvmView.this.repaint();
         }
      }
   }

   private class KvmKeyAdapter implements KeyListener {
      private boolean isLeftAltDown = false;
      private boolean useKeyTyped = false;
      private boolean isAltGraphDown = false;
      short hidCode;
      int keyCode;
      int keyLoc;
      char keyChar;

      private KvmKeyAdapter() {
      }

      private int getNumpadKeys(int var1) {
         switch (var1) {
            case 10:
               var1 |= 256;
               break;
            case 12:
            case 65368:
               if (OS.getCurrent() == OS.MAC) {
                  var1 = 144;
               } else {
                  var1 = 101;
               }
               break;
            case 33:
               var1 = 105;
               break;
            case 34:
               var1 = 99;
               break;
            case 35:
               var1 = 97;
               break;
            case 36:
               var1 = 103;
               break;
            case 37:
               var1 = 100;
               break;
            case 38:
               var1 = 104;
               break;
            case 39:
               var1 = 102;
               break;
            case 40:
               var1 = 98;
               break;
            case 127:
               var1 = 110;
               break;
            case 155:
               var1 = 96;
         }

         return var1;
      }

      private KeyboardMacrosPreferences getMacro(int var1) {
         return var1 >= 48 && var1 <= 57 ? PopulateKeyboardMenuCommand.getMacro(var1 - 48) : null;
      }

      private void processMacro(KeyboardMacrosPreferences var1) {
         StringTokenizer var2 = new StringTokenizer(var1.getMacroSequence(), "&&");

         while (var2.hasMoreTokens()) {
            String var3 = var2.nextToken();
            String var4 = var3.substring(var3.lastIndexOf(" ") + 1);
            int var5 = Integer.parseInt(var4);
            KeyboardMappings var6 = new KeyboardMappings();
            KeyboardKey var7 = var6.getItem(var5);
            if (var7 != null) {
               short var8 = (short)var7.getKeyCode();
               if (var3.startsWith("p")) {
                  KvmView.this.kvmStream.setKeyState(var8, true, false);
               } else if (var3.startsWith("r")) {
                  KvmView.this.kvmStream.setKeyState(var8, false, false);
               }

               KvmView.this.kvmStream.flushKeyData();
            }
         }
      }

      private void keyHandling(KeyEvent var1, boolean var2, boolean var3) {
         if (!KvmView.this.contextMenuKvm.isVisible() && KvmView.this.kvmPort.getView().hasFocus()) {
            this.keyCode = var1.getKeyCode();
            this.keyLoc = var1.getKeyLocation();
            this.keyChar = var1.getKeyChar();
            var1.consume();
            if (var1.isAltDown()) {
               KvmView.this.altFlag = true;
               this.setAltGraphDownFlag(var1);
            }

            switch (var1.getKeyLocation()) {
               case 3:
                  this.keyCode = (this.keyCode | 256) & 511;
                  break;
               case 4:
                  this.keyCode = this.getNumpadKeys(this.keyCode);
            }

            if (var1.isControlDown() && var1.isAltDown() && var2 && this.isLeftAltDown) {
               KeyboardMacrosPreferences var4 = this.getMacro(this.keyCode);
               if (this.keyCode == KvmView.this.scrContext.getPopupKeyCode() || var4 != null) {
                  KvmView.this.kvmStream.releaseKeyIfPressed((short)224);
                  KvmView.this.kvmStream.flushKeyData();
                  KvmView.this.kvmStream.releaseKeyIfPressed((short)228);
                  KvmView.this.kvmStream.flushKeyData();
                  KvmView.this.kvmStream.releaseKeyIfPressed((short)226);
                  KvmView.this.kvmStream.flushKeyData();
                  KvmView.this.altFlag = false;
                  this.isLeftAltDown = false;
                  if (this.keyCode == KvmView.this.scrContext.getPopupKeyCode()) {
                     KvmView.this.setContextMenuKVMVisible(true);
                  } else {
                     this.processMacro(var4);
                  }

                  return;
               }
            }

            if (this.isLeftAltDown && var1.getKeyCode() == 18 && !var2) {
               KvmView.this.altReleased = true;
               this.isLeftAltDown = false;
            } else if (KvmView.this.ctrlReleased) {
               KvmView.this.ctrlReleased = false;
               KvmView.this.altReleased = false;
            } else if (var1.getKeyCode() == 17 && !var2) {
               KvmView.this.ctrlReleased = true;
            } else if (KvmView.this.altReleased) {
               KvmView.this.ctrlReleased = false;
               KvmView.this.altReleased = false;
            }

            if (KvmView.this.altReleased && KvmView.this.ctrlReleased) {
               try {
                  java.util.Timer var6 = new java.util.Timer(true);
                  var6.schedule(KvmView.this.new FlashMessage(), 0L, 5000L);
                  KvmView.this.altReleased = false;
                  KvmView.this.ctrlReleased = false;
               } catch (Exception var5) {
               }
            }

            if (KvmView.this.port != null) {
               switch (this.keyCode & 0xFF00) {
                  case 61440:
                     this.keyCode |= 432;
                  case 65280:
                     this.keyCode &= 511;
               }

               label134:
               switch (this.keyCode) {
                  case 0:
                  case 92:
                     switch (this.keyChar) {
                        case '%':
                        case 'Ä':
                        case 'ä':
                        case 'ù':
                           this.keyCode = 222;
                           break label134;
                        case '?':
                        case 'ß':
                           this.keyCode = 301;
                           break label134;
                        case '_':
                           this.keyCode |= 256;
                           break label134;
                        case '²':
                           this.keyCode = 192;
                           break label134;
                        case 'Ö':
                        case 'ö':
                           this.keyCode = 59;
                           break label134;
                        case 'Ü':
                        case 'ü':
                           this.keyCode = 91;
                           break label134;
                        case '\uffff':
                           this.useKeyTyped = var2;
                        default:
                           break label134;
                     }
                  case 18:
                     if (!this.isAltGraphDown && var1.getKeyLocation() == 2 && var2) {
                        this.isLeftAltDown = true;
                     }
                     break;
                  case 20:
                     if (OS.getCurrent() == OS.SOLARIS || OS.getCurrent() == OS.MAC) {
                        var3 = true;
                     }
                     break;
                  case 77:
                     if (OS.getCurrent() == OS.MAC && KeyHIDValue.keyboardLanguage == 4) {
                        switch (this.keyChar) {
                           case ',':
                           case '?':
                           case '¿':
                           case '∞':
                              this.keyCode = 44;
                        }
                     }
                     break;
                  case 144:
                     if (OS.getCurrent() == OS.SOLARIS) {
                        var3 = true;
                     }
                     break;
                  case 192:
                     if (OS.getCurrent() == OS.MAC) {
                        switch (KeyHIDValue.keyboardLanguage) {
                           case 3:
                              if (this.keyChar == 176) {
                                 this.keyCode = 130;
                              }
                              break;
                           case 4:
                              switch (this.keyChar) {
                                 case '#':
                                 case '0':
                                 case '@':
                                 case 'Ÿ':
                                 case '•':
                                 case '\uffff':
                                    this.keyCode = 153;
                              }
                        }
                     }
                     break;
                  case 243:
                  case 244:
                     var2 = !var2;
               }

               if (KeyHIDValue.keyboardLanguage == 2 && this.keyCode == 274 && var1.getModifiersEx() == 640) {
                  KvmView.this.kvmStream.setKeyState((short)224, false, false);
               }

               if (this.keyCode >= KeyHIDValue.HIDMAP.length) {
                  return;
               }

               this.hidCode = KeyHIDValue.HIDMAP[this.keyCode];
               if (this.hidCode > 0) {
                  if (var3) {
                     KvmView.this.kvmStream.setKeyState(this.hidCode, true, false);
                     KvmView.this.kvmStream.setKeyState(this.hidCode, false, false);
                  } else {
                     KvmView.this.kvmStream.setKeyState(this.hidCode, var2, false);
                  }

                  KvmView.this.ResumeVideo();
                  KvmView.this.kvmStream.flushKeyData();
               }
            } else if (!var2) {
               KvmView.this.altFlag = false;
            }
         }
      }

      @Override
      public void keyPressed(KeyEvent var1) {
         this.keyHandling(var1, true, false);
         if (!KvmView.this.contextMenuKvm.isVisible()) {
            ;
         }
      }

      @Override
      public void keyTyped(KeyEvent var1) {
         var1.consume();
         this.keyChar = var1.getKeyChar();
         if (this.useKeyTyped) {
            switch (this.keyChar) {
               case '\\':
                  this.keyCode = 301;
               default:
                  KeyEvent var2 = new KeyEvent(var1.getComponent(), 401, var1.getWhen(), var1.getModifiers(), this.keyCode, this.keyChar);
                  this.keyHandling(var2, true, true);
                  this.useKeyTyped = false;
            }
         }
      }

      @Override
      public void keyReleased(KeyEvent var1) {
         this.keyHandling(var1, false, false);
      }

      private void setAltGraphDownFlag(KeyEvent var1) {
         if (var1.isControlDown() && var1.isAltDown() && var1.getKeyLocation() == 3 && var1.getID() == 401) {
            this.isAltGraphDown = true;
         } else if (var1.getKeyLocation() == 3 && this.isAltGraphDown && var1.getID() == 402) {
            this.isAltGraphDown = false;
         }
      }
   }

   private class KvmMouseAdapter extends MouseAdapter {
      private boolean mouseIn = false;

      private KvmMouseAdapter() {
      }

      @Override
      public void mouseEntered(MouseEvent var1) {
         var1.consume();
         this.mouseIn = true;
         KvmView.this.updateMousePosition(false);
      }

      @Override
      public void mouseExited(MouseEvent var1) {
         this.mouseIn = false;
      }

      @Override
      public void mousePressed(MouseEvent var1) {
         var1.consume();
         if (KvmView.this.kvmPanel != null && this.mouseIn) {
            if (KvmView.this.port != null) {
               if (!KvmView.this.isSingleCursor) {
                  try {
                     KvmView.this.port.getView().getShellInternalFrame().setSelected(true);
                  } catch (PropertyVetoException var6) {
                     RRCLogger.logException(var6);
                  }

                  int var2 = var1.getX();
                  int var3 = var1.getY();
                  Rectangle var4 = KvmView.this.kvmPanel.getBitmapPlace();
                  if (!var4.contains(var2, var3)) {
                     return;
                  }

                  var2 -= var4.x;
                  var3 -= var4.y;
                  if (var2 < 0) {
                     var2 = 0;
                  }

                  if (var3 < 0) {
                     var3 = 0;
                  }

                  int var5 = var1.getModifiersEx();
                  if (KvmView.this.kvmStream.getKeyState(KeyHIDValue.HIDMAP[18]) && (var5 & 512) == 0) {
                     KvmView.this.kvmStream.setKeyState(KeyHIDValue.HIDMAP[18], false, true);
                  }

                  if (KvmView.this.kvmStream.getKeyState(KeyHIDValue.HIDMAP[17]) && (var5 & 128) == 0) {
                     KvmView.this.kvmStream.setKeyState(KeyHIDValue.HIDMAP[17], false, true);
                  }

                  if (KvmView.this.kvmStream.getKeyState(KeyHIDValue.HIDMAP[16]) && (var5 & 64) == 0) {
                     KvmView.this.kvmStream.setKeyState(KeyHIDValue.HIDMAP[16], false, true);
                  }

                  switch (var1.getButton()) {
                     case 1:
                        KvmView.this.onMouseButton((byte)0, var2 + KvmView.this.iFixMouseX, var3 + KvmView.this.iFixMouseY);
                        RRCLogger.log(200, 512, "KVMView: Left mouse button pressed.");
                        break;
                     case 2:
                        KvmView.this.onMouseButton((byte)4, var2 + KvmView.this.iFixMouseX, var3 + KvmView.this.iFixMouseY);
                        RRCLogger.log(200, 512, "KVMView: Middle mouse button pressed.");
                        break;
                     case 3:
                        KvmView.this.onMouseButton((byte)2, var2 + KvmView.this.iFixMouseX, var3 + KvmView.this.iFixMouseY);
                        RRCLogger.log(200, 512, "KVMView: Right mouse button pressed.");
                  }
               } else {
                  int var8 = KvmView.this.jsp.getViewport().getSize().width / 2 - var1.getX();
                  int var10 = KvmView.this.jsp.getViewport().getSize().height / 2 - var1.getY();
                  int var11 = (int)KvmView.this.oldPos.getX() - var8;
                  int var12 = (int)KvmView.this.oldPos.getY() - var10;
                  KvmView.this.oldPos.setLocation(var11, var12);
                  switch (var1.getButton()) {
                     case 1:
                        KvmView.this.onMouseButton((byte)0, var11, var12);
                        RRCLogger.log(200, 512, "KVMView: Left mouse button pressed.");
                        break;
                     case 2:
                        KvmView.this.onMouseButton((byte)4, var11, var12);
                        RRCLogger.log(200, 512, "KVMView: Middle mouse button pressed.");
                        break;
                     case 3:
                        KvmView.this.onMouseButton((byte)2, var11, var12);
                        RRCLogger.log(200, 512, "KVMView: Right mouse button pressed.");
                  }
               }
            }
         }
      }

      @Override
      public void mouseReleased(MouseEvent var1) {
         var1.consume();
         if (this.mouseIn) {
            if (KvmView.this.port != null) {
               if (!KvmView.this.isSingleCursor) {
                  int var2 = var1.getX();
                  int var3 = var1.getY();
                  Rectangle var4 = KvmView.this.kvmPanel.getBitmapPlace();
                  if (!var4.contains(var2, var3)) {
                     return;
                  }

                  var2 -= var4.x;
                  var3 -= var4.y;
                  if (var2 < 0) {
                     var2 = 0;
                  }

                  if (var3 < 0) {
                     var3 = 0;
                  }

                  switch (var1.getButton()) {
                     case 1:
                        KvmView.this.onMouseButton((byte)1, var2 + KvmView.this.iFixMouseX, var3 + KvmView.this.iFixMouseY);
                        RRCLogger.log(200, 512, "KVMView: Left mouse button released.");
                        break;
                     case 2:
                        KvmView.this.onMouseButton((byte)5, var2 + KvmView.this.iFixMouseX, var3 + KvmView.this.iFixMouseY);
                        RRCLogger.log(200, 512, "KVMView: Middle mouse button released.");
                        break;
                     case 3:
                        KvmView.this.onMouseButton((byte)3, var2 + KvmView.this.iFixMouseX, var3 + KvmView.this.iFixMouseY);
                        RRCLogger.log(200, 512, "KVMView: Right mouse button released.");
                  }
               } else {
                  int var7 = KvmView.this.jsp.getViewport().getSize().width / 2 - var1.getX();
                  int var9 = KvmView.this.jsp.getViewport().getSize().height / 2 - var1.getY();
                  int var10 = (int)KvmView.this.oldPos.getX() - var7;
                  int var5 = (int)KvmView.this.oldPos.getY() - var9;
                  KvmView.this.oldPos.setLocation(var10, var5);
                  switch (var1.getButton()) {
                     case 1:
                        KvmView.this.onMouseButton((byte)1, var10, var5);
                        RRCLogger.log(200, 512, "KVMView: Left mouse button released.");
                        break;
                     case 2:
                        KvmView.this.onMouseButton((byte)5, var10, var5);
                        RRCLogger.log(200, 512, "KVMView: Middle mouse button released.");
                        break;
                     case 3:
                        KvmView.this.onMouseButton((byte)3, var10, var5);
                        RRCLogger.log(200, 512, "KVMView: Right mouse button released.");
                  }
               }
            }
         }
      }
   }

   private class KvmMouseMotionAdapter extends MouseMotionAdapter {
      private KvmMouseMotionAdapter() {
      }

      @Override
      public void mouseMoved(MouseEvent var1) {
         var1.consume();
         if (!KvmView.this.contextMenuKvm.isVisible() && KvmView.this.kvmPort.getView().hasFocus() && KvmView.this.port != null) {
            if (KvmView.this.isSingleCursor
               && (var1.getX() != KvmView.this.jsp.getViewport().getSize().width / 2 || var1.getY() != KvmView.this.jsp.getViewport().getSize().height / 2)) {
               int var2 = KvmView.this.jsp.getViewport().getSize().width / 2 - var1.getX();
               int var3 = KvmView.this.jsp.getViewport().getSize().height / 2 - var1.getY();
               int var4 = (int)KvmView.this.oldPos.getX() - var2;
               int var5 = (int)KvmView.this.oldPos.getY() - var3;
               KvmView.this.oldPos.setLocation(var4, var5);
               KvmView.this.iLastMouseX = var4;
               KvmView.this.iLastMouseY = var5;
               KvmView.this.updateMousePosition(true);
               KvmView.this.resetMouse();
               return;
            }

            if (KvmView.this.isSingleCursor
               && var1.getX() == KvmView.this.jsp.getViewport().getSize().width / 2
               && var1.getY() == KvmView.this.jsp.getViewport().getSize().height / 2) {
               return;
            }

            KvmView.this.onMouseMove(
               var1.getX() + KvmView.this.iFixMouseX,
               var1.getY() + KvmView.this.iFixMouseY,
               KvmView.this.kvmPort != null && KvmView.this.kvmPort.getKvmMouse().isStandardMouse()
            );
         }
      }

      @Override
      public void mouseDragged(MouseEvent var1) {
         var1.consume();
         if (KvmView.this.kvmPanel != null) {
            if (!KvmView.this.contextMenuKvm.isVisible()
               && KvmView.this.kvmPort.getView().hasFocus()
               && KvmView.this.port != null
               && var1.getModifiersEx() == 1024) {
               if (KvmView.this.isSingleCursor
                  && (var1.getX() != KvmView.this.jsp.getViewport().getSize().width / 2 || var1.getY() != KvmView.this.jsp.getViewport().getSize().height / 2)) {
                  int var2 = KvmView.this.jsp.getViewport().getSize().width / 2 - var1.getX();
                  int var3 = KvmView.this.jsp.getViewport().getSize().height / 2 - var1.getY();
                  int var4 = (int)KvmView.this.oldPos.getX() - var2;
                  int var5 = (int)KvmView.this.oldPos.getY() - var3;
                  KvmView.this.oldPos.setLocation(var4, var5);
                  KvmView.this.iLastMouseX = var4;
                  KvmView.this.iLastMouseY = var5;
                  KvmView.this.updateMousePosition(true);
                  KvmView.this.resetMouse();
                  return;
               }

               if (KvmView.this.isSingleCursor
                  && var1.getX() == KvmView.this.jsp.getViewport().getSize().width / 2
                  && var1.getY() == KvmView.this.jsp.getViewport().getSize().height / 2) {
                  return;
               }

               KvmView.this.onMouseMove(
                  var1.getX() + KvmView.this.iFixMouseX,
                  var1.getY() + KvmView.this.iFixMouseY,
                  KvmView.this.kvmPort != null && KvmView.this.kvmPort.getKvmMouse().isStandardMouse()
               );
            }
         }
      }
   }

   private class KvmMouseWheelAdapter implements MouseWheelListener {
      private KvmMouseWheelAdapter() {
      }

      @Override
      public void mouseWheelMoved(MouseWheelEvent var1) {
         var1.consume();
         if (KvmView.this.port != null) {
            int var2 = var1.getWheelRotation();
            int var3 = var2 > 0 ? 1 : -1;
            KvmView.this.ResumeVideo();
            KvmView.this.kvmStream.sendMouseData((byte)8, (short)0, (short)0, (short)var3);
         }
      }
   }

   private class KvmResizer extends ComponentAdapter {
      private KvmResizer() {
      }

      @Override
      public void componentResized(ComponentEvent var1) {
         if (KvmView.this.kvmPanel != null && var1.getID() == 101) {
            KvmView.this.kvmPanel.forceRepaint();
            KvmView.this.setViewFocus();
         }
      }

      @Override
      public void componentMoved(ComponentEvent var1) {
         if (KvmView.this.kvmPanel != null) {
            KvmView.this.kvmPanel.setSize(KvmView.this.getWidth(), KvmView.this.getHeight());
            KvmView.this.kvmPanel.forceRepaint();
         }
      }
   }

   private class UpdateQueue {
      private Vector list = new Vector(25);

      private UpdateQueue() {
      }

      public synchronized TRLIB_UPDATEINFO dequeue() {
         return !KvmView.this.videoFrozen && !this.list.isEmpty() ? (TRLIB_UPDATEINFO)this.list.remove(0) : null;
      }

      public synchronized void enqueue(TRLIB_UPDATEINFO var1) {
         boolean var2 = this.list.size() > 0;

         while (var2) {
            var2 = false;
            Rectangle var3 = var1.getRectangle();
            Rectangle var4 = new Rectangle(var3);
            Rectangle var5 = new Rectangle(var3);
            var4.y--;
            var4.height += 2;
            var5.x--;
            var5.width += 2;

            for (int var6 = 0; !var2 && var6 < this.list.size(); var6++) {
               TRLIB_UPDATEINFO var7 = (TRLIB_UPDATEINFO)this.list.get(var6);
               Rectangle var8 = var7.getRectangle();
               if (var8.intersects(var4) || var8.intersects(var5)) {
                  Rectangle var9 = var8.union(var3);
                  var1.setRectangle(var9);
                  this.list.remove(var6);
                  var2 = this.list.size() > 0;
               }
            }
         }

         this.list.add(var1);
      }

      public synchronized void clear() {
         this.list.clear();
      }
   }
}
