package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.KvmStream;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoAbsoluteMouseCommand;
import com.raritan.rrc.ui.commands.DoIntelligentMouseCommand;
import com.raritan.rrc.ui.commands.DoModifyConnectionPropertiesCommand;
import com.raritan.rrc.ui.commands.DoStandardMouseCommand;
import com.raritan.rrc.ui.commands.DoVideoSettingsCommand;
import com.raritan.rrc.ui.commands.MouseMenuCommand;
import com.raritan.rrc.ui.commands.ShowConnectionInfoCommand;
import com.raritan.rrc.ui.commands.ShowVideoSettingsCommand;
import com.raritan.rrc.ui.commands.VirtualMediaMenuCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import java.net.InetAddress;
import java.util.HashMap;
import javaclientlib.tr.TRSRVR_COMP_PARAMS;
import javaclientlib.tr.TRSRVR_SERVER_ID;
import javaclientlib.tr.TRSRVR_TARGET_PARAMS;
import javaclientlib.tr.TRSRVR_VIDEO_PARAMS;

public class KvmViewCommandHandler extends DefaultCommandHandler {
   public static KvmViewCommandHandler kvmViewCommandHandler = new KvmViewCommandHandler();

   @Override
   public void handleCommand(DoAbsoluteMouseCommand var1, ScreenContext var2) {
      boolean var3 = (Boolean)var1.getContext().getCommandParameter("absoluteMouseMode");
      if (var3) {
         KvmPort var4 = (KvmPort)((RRCScreenContext)var2).getSelectedPort();
         ((RRCScreenContext)var2).getMainScreenMediator().selectAbsoluteMouseModeView(true);
         ((KvmStream)var4.getStream()).setTargetParams("Mouse".getBytes(), 2);
      }
   }

   @Override
   public void handleCommand(DoIntelligentMouseCommand var1, ScreenContext var2) {
      boolean var3 = (Boolean)var1.getContext().getCommandParameter("intelligentMouseMode");
      if (var3) {
         KvmPort var4 = (KvmPort)((RRCScreenContext)var2).getSelectedPort();
         ((RRCScreenContext)var2).getMainScreenMediator().selectIntelligentMouseModeView(true);
         if (((KvmStream)var4.getStream()).setTargetParams("Mouse".getBytes(), 1)) {
            Port var5 = ((RRCScreenContext)var2).getSelectedPort();
            if (var5 != null && var5.isConnected() && var5.getDeviceClass().equals("KVM")) {
               DeviceView var6 = var5.getView();
               if (var6 != null) {
                  var6.synchronizeMouse(false);
               }
            }
         }
      }
   }

   @Override
   public void handleCommand(DoStandardMouseCommand var1, ScreenContext var2) {
      boolean var3 = (Boolean)var1.getContext().getCommandParameter("standardMouseMode");
      if (var3) {
         KvmPort var4 = (KvmPort)((RRCScreenContext)var2).getSelectedPort();
         ((RRCScreenContext)var2).getMainScreenMediator().selectStandardMouseModeView(true);
         ((KvmStream)var4.getStream()).setTargetParams("Mouse".getBytes(), 0);
      }
   }

   @Override
   public void handleCommand(MouseMenuCommand var1, ScreenContext var2) {
      var2.getLogger().logTextDebug(" Started ");
      new KvmViewCommandHandler.DoSendGetTargetParamsThread(var2).start();
      var2.getLogger().logTextDebug(" Finished ");
   }

   @Override
   public void handleCommand(VirtualMediaMenuCommand var1, ScreenContext var2) {
      var2.getLogger().logTextDebug(" Started ");
      var2.getLogger().logTextDebug(" Finished ");
   }

   @Override
   public void handleCommand(DoModifyConnectionPropertiesCommand var1, ScreenContext var2) {
      Port var3 = null;
      DevicePreferences var4 = null;
      CommandContext var5 = var1.getContext();

      try {
         TRSRVR_COMP_PARAMS var6 = (TRSRVR_COMP_PARAMS)var5.getCommandParameter("compParams");
         var3 = ((RRCScreenContext)var2).getSelectedPort();
         if (var3 != null) {
            ((KvmPort)var3).getView().setCompParameters(var6);
            Device var7 = (Device)var5.getCommandParameter("deviceNode");
            var4 = var7.getDevPrefs();
            Integer var8 = (Integer)var5.getCommandParameter("framesPerSecond");
            if (var7.getDevPrefs() == null) {
               var4 = new DevicePreferences();
               var7.setDevPrefs(var4);
               DeviceConnector var9 = var7.getDeviceConnector();
               String var10 = var9.getInetAddress().getHostAddress();
               var7.getDevPrefs().setIp(var10);
            }

            var4.setConnectionSpeed(var6.getSpeed());
            var4.setColorDepth(var6.getCCT());
            var4.setProgressiveUpdate((var6.getFlags() & 32768) != 0);
            var4.setFlowControl((var6.getFlags() & 128) != 0);
            var4.setSmoothing(var6.getSmoothing());
            if (var8 != null) {
               var4.setFramesPerSecond(var8);
               var7.getActiveKvmPort().setUpdateFrequency(200 / (var4.getFramesPerSecond() + 1));
               ((KvmStream)var7.getActiveKvmPort().getStream()).setMinFrameUpdateTime(200 / (var4.getFramesPerSecond() + 1));
            } else {
               var4.setFramesPerSecond(0);
            }

            if (var7.isProfiled()) {
               var4.exportPreferences(this.calculateExportKey((IPReach)var7));
            } else {
               DeviceConnector var16 = var7.getDeviceConnector();
               String var17 = var16.getInetAddress().getHostAddress();
               var4.exportPreferences(var17);
            }
         }
      } catch (Exception var14) {
         var14.printStackTrace();
      } finally {
         if (var3 != null && var4 != null) {
            var3.getDeviceConnector().writePrefsToCCnow(var4);
         }
      }
   }

   private String calculateExportKey(IPReach var1) {
      String var2 = var1.getDevPrefs().getIp();
      if (var1.getDevPrefs().getConnectionType() == 2) {
         if (var1.getDevPrefs().getFindBy() == 1) {
            var2 = var1.getDevPrefs().getName();
         } else if (var1.getDevPrefs().getFindBy() == 2) {
            var2 = var1.getDevPrefs().getDnsName();
         }
      } else {
         var2 = var1.getDevPrefs().getPhone();
      }

      return var2;
   }

   @Override
   public void handleCommand(ShowConnectionInfoCommand var1, ScreenContext var2) {
      CommandContext var3 = var1.getContext();
      Port var4 = ((RRCScreenContext)var2).getSelectedPort();
      DeviceView var5 = var4.getView();
      if (var5 != null) {
         IPReach var6 = (IPReach)var3.getCommandParameter("deviceNode");
         DeviceConnector var7 = var6.getDeviceConnector();
         TRSRVR_SERVER_ID var8 = var7.getServerID();
         String var9 = "";
         InetAddress var10 = var7.getInetAddress();
         if (var10 != null) {
            var9 = var10.getHostAddress();
         }

         HashMap var11 = new HashMap();
         var11.put("DESCRIPTION", var6.getDescription());
         var11.put("IP", var9);
         var11.put("PORT", new Integer(var8.getPort()));
         var11.put("PROTO_VER", new Short(var8.getProtocolVersion()));
         var11.put("OLDEST_PROTO_VER", new Short(var8.getOldestProtocolVersion()));
         var11.put("HW_VER", new Short(var8.getHwVersion()));
         var11.put("SW_VER", new Short(var8.getSwVersion()));
         var11.put("POST", new Integer(var8.getPost()));
         var11.put("NET_FLAGS", new Integer(var8.getNetFlags()));
         var11.put("SECURITY_FLAGS", new Integer(var8.getSecurityFlags()));
         var11.put("OPTIONS", new Integer(var8.getOptions()));
         var11.put("FG_INFO", new Integer(var8.getFrameGrabberInfo()));
         var11.put("KVM_INFO", new Integer(var8.getKvmInfo()));
         var11.put("SERIAL_INFO", new Integer(var8.getSerialInfo()));
         var11.put("NUM_VD_DEVICES", new Integer(var8.getNumVideoDevices()));
         var11.put("NUM_SERIAL_DEVICES", new Integer(var8.getNumSerialDevices()));
         var11.put("RESERVED", new Integer(var8.getReserved()));
         var3.setCommandParameter("STATIC_CONN_INFO", var11);
         KvmPort var12 = (KvmPort)var3.getCommandParameter("ports");
         if (var12 != null) {
            var3.setCommandParameter("VIDEO_MODE", ((KvmStream)var12.getStream()).getVideoMode());
         }

         var3.setCommandParameter("DEVICE_VIEW", var5);
      }
   }

   @Override
   public void handleCommand(DoVideoSettingsCommand var1, ScreenContext var2) {
      TRSRVR_VIDEO_PARAMS var3 = (TRSRVR_VIDEO_PARAMS)var1.getContext().getCommandParameter("videoParams");
      Port var4 = ((RRCScreenContext)var2).getSelectedPort();
      KvmView var5 = (KvmView)var4.getView();
      if (var5 != null) {
         var5.updateVideoSettings(var3);
      }
   }

   @Override
   public void handleCommand(ShowVideoSettingsCommand var1, ScreenContext var2) {
      Port var3 = ((RRCScreenContext)var2).getSelectedPort();
      DeviceView var4 = var3.getView();
      if (var3.isConnected()) {
         TRSRVR_VIDEO_PARAMS var5 = new TRSRVR_VIDEO_PARAMS();
         ((KvmStream)var3.getStream()).getVideoParams(var5);
         var1.getContext().setCommandParameter("videoParams", var5);
      }
   }

   private class DoSendGetTargetParamsThread extends Thread {
      private ScreenContext context = null;

      protected DoSendGetTargetParamsThread(ScreenContext var2) {
         this.context = var2;
      }

      @Override
      public void run() {
         KvmPort var1 = (KvmPort)((RRCScreenContext)this.context).getSelectedPort();
         if (var1 != null && var1.isConnected()) {
            TRSRVR_TARGET_PARAMS var2 = new TRSRVR_TARGET_PARAMS();
            var2.setIType("Mouse".getBytes());
            ((KvmStream)var1.getStream()).getTargetParams(var2);
         }
      }
   }
}
