package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoCancelLoginCommand;
import com.raritan.rrc.ui.commands.DoLoginCommand;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.net.InetAddress;
import javaclientlib.tr.TRLIB_USERINFO;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JRadioButton;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.border.EmptyBorder;

public class LoginPanel extends AbstractDisplay {
   public static final int REMEMBER_NOTHING = 0;
   public static final int REMEMBER_USER_NAME = 1;
   public static final int REMEMBER_USER_NAME_AND_PASSWORD = 2;
   private static final long serialVersionUID = 1649116623817205774L;
   protected RaritanPropertyResourceBundle bundle;
   private JTextField serverDescriptionField;
   private JTextField serverNameField;
   private JTextField userNameField;
   private JPasswordField passwordField;
   private JPanel loginPanel;
   private JRadioButton remNothingRadioButton;
   private JRadioButton remUserRadioButton;
   private JRadioButton remUserPassRadioButton;
   private IPReach device;
   private JTextArea notProfiledLabel = new JTextArea();
   private JPanel notProfiledPanel = new JPanel();

   public LoginPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.makeLayout();
      this.setShell(this.bundle.getString("login.dialog.title"));
   }

   public void setServerName(String var1) {
      this.serverNameField.setText(var1);
   }

   public String getServerName() {
      return this.serverNameField.getText();
   }

   public void setDescription(String var1) {
      this.serverDescriptionField.setText(var1);
   }

   public String getDescription() {
      return this.serverDescriptionField.getText();
   }

   public void setUserName(String var1) {
      this.userNameField.setText(var1);
   }

   public String getUserName() {
      return this.userNameField.getText();
   }

   public void setPassword(String var1) {
      this.passwordField.setText(var1);
   }

   public char[] getPassword() {
      return this.passwordField.getPassword();
   }

   private void addAnEmptyRow() {
      this.loginPanel.add(Box.createVerticalGlue());
      this.loginPanel.add(Box.createVerticalGlue());
   }

   private void clearAllFields() {
      this.setServerName("");
      this.setDescription("");
      this.setUserName("");
      this.setPassword("");
   }

   @Override
   public void setDefaultFocussedComponent() {
      if (OS.getCurrent() == OS.SOLARIS) {
         this.userNameField.grabFocus();
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               LoginPanel.this.userNameField.grabFocus();
               if (OS.getCurrent() == OS.MAC) {
                  LoginPanel.this.ok.repaint();
               }
            }
         });
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      this.ok.setEnabled(false);
      byte var2 = 2;
      if (this.remNothingRadioButton.isSelected()) {
         var2 = 0;
      } else if (this.remUserRadioButton.isSelected()) {
         var2 = 1;
      }

      this.device.setSelectedOption(var2);
      this.device.getConnectionInfo().getUserInfo().setName(this.userNameField.getText().getBytes());
      this.device.getConnectionInfo().getUserInfo().setPassword(new String(this.passwordField.getPassword()).getBytes());
      var1.setCommandParameter("devices", this.device);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      Boolean var2 = (Boolean)var1.getCommandParameter("userInvokedChangePassword");
      if (var2 == null || !var2) {
         this.clearAllFields();
      }

      Command var3 = (Command)var1.getCommandParameter("ok_command");
      this.ok.setCommand(var3);
      this.ok.setEnabled(true);
      this.device = (IPReach)var1.getCommandParameter("devices");
      this.remove(this.notProfiledPanel);
      if (this.device.isProfiled()) {
         this.remove(this.notProfiledPanel);
      } else {
         this.add(this.notProfiledPanel, "Center");
      }

      this.notProfiledPanel.revalidate();
      this.serverDescriptionField.setText(this.device.getDescription());
      String var4 = this.device.getName();
      if (this.device.isProfiled()) {
         DevicePreferences var5 = this.device.getDevPrefs();
         if (var5.getConnectionType() == 2 && var5.getFindBy() == 1) {
            var4 = var5.getName();
         }
      }

      if ("".equals(var4)) {
         var4 = this.bundle.getString("TreeDisplay.Unknown");
      }

      this.serverNameField.setText(var4);
      int var10 = this.device.getSelectedOption();
      if (var10 == 0) {
         this.remNothingRadioButton.setSelected(true);
         if (var2 == null || !var2) {
            this.setUserName("");
            this.setPassword("");
         }
      } else if (var10 == 1) {
         this.remUserRadioButton.setSelected(true);
         if (var2 == null || !var2) {
            if (this.device.isProfiled() && StringUtils.notNullOrEmpty(this.device.getDevPrefs().getUserName())) {
               this.userNameField.setText(this.device.getDevPrefs().getUserName());
            } else {
               String var6 = ((InetAddress)this.device.getAddressList().get(0)).getHostAddress();
               TRLIB_USERINFO var7 = (TRLIB_USERINFO)((RRCScreenContext)this.scrContext).getUserInfoMap().get(var6);
               if (var7 != null) {
                  byte[] var8 = var7.getName();
                  if (var8.length != 0 && var8[0] != 0) {
                     this.userNameField.setText(new String(var8));
                  }
               }
            }

            this.setPassword("");
         }
      } else {
         this.remUserPassRadioButton.setSelected(true);
         if (var2 == null || !var2) {
            if (this.device.isProfiled()) {
               if (StringUtils.notNullOrEmpty(this.device.getDevPrefs().getUserName())) {
                  this.userNameField.setText(this.device.getDevPrefs().getUserName());
               }

               if (StringUtils.notNullOrEmpty(this.device.getDevPrefs().getPassword())) {
                  this.passwordField.setText(this.device.getDevPrefs().getPassword());
               }
            } else {
               String var11 = ((InetAddress)this.device.getAddressList().get(0)).getHostAddress();
               TRLIB_USERINFO var12 = (TRLIB_USERINFO)((RRCScreenContext)this.scrContext).getUserInfoMap().get(var11);
               if (var12 != null) {
                  byte[] var13 = var12.getName();
                  byte[] var9 = var12.getPassword();
                  if (var13.length != 0 && var13[0] != 0) {
                     this.userNameField.setText(new String(var13));
                  }

                  if (var9.length != 0 && var9[0] != 0) {
                     this.passwordField.setText(new String(var9));
                  }
               }
            }
         }
      }

      if (StringUtils.notNullOrEmpty((String)var1.getCommandParameter("password"))) {
         this.passwordField.setText((String)var1.getCommandParameter("password"));
      }

      this.setDefaultFocussedComponent();
   }

   @Override
   public void makeLayout() {
      this.loginPanel = new JPanel(new SpringLayout());
      JLabel var1 = new JLabel(this.bundle.getString("login.dialog.description"), 11);
      this.loginPanel.add(var1);
      this.serverDescriptionField = new JTextField(10);
      this.serverDescriptionField.setEditable(false);
      this.serverDescriptionField.setFocusable(false);
      this.loginPanel.add(this.serverDescriptionField);
      this.addAnEmptyRow();
      var1 = new JLabel(this.bundle.getString("login.dialog.name"), 11);
      this.loginPanel.add(var1);
      this.serverNameField = new JTextField(10);
      this.serverNameField.setEditable(false);
      this.serverNameField.setFocusable(false);
      this.loginPanel.add(this.serverNameField);
      this.addAnEmptyRow();
      var1 = new JLabel(this.bundle.getString("login.dialog.username"), 11);
      this.loginPanel.add(var1);
      this.userNameField = new JTextField(10);
      this.userNameField.setFocusable(true);
      this.loginPanel.add(this.userNameField);
      this.addAnEmptyRow();
      var1 = new JLabel(this.bundle.getString("login.dialog.password"), 11);
      this.loginPanel.add(var1);
      this.passwordField = new JPasswordField(10);
      this.loginPanel.add(this.passwordField);
      this.loginPanel.add(Box.createVerticalGlue());
      JPanel var2 = new JPanel(new GridLayout(0, 1));
      ButtonGroup var3 = new ButtonGroup();
      this.remNothingRadioButton = new JRadioButton();
      this.remNothingRadioButton.setText(this.bundle.getString("login.dialog.remNothing"));
      this.remNothingRadioButton.setEnabled(true);
      var3.add(this.remNothingRadioButton);
      var2.add(this.remNothingRadioButton);
      this.remUserRadioButton = new JRadioButton();
      this.remUserRadioButton.setText(this.bundle.getString("login.dialog.remUserName"));
      this.remUserRadioButton.setEnabled(true);
      var3.add(this.remUserRadioButton);
      var2.add(this.remUserRadioButton);
      this.remUserPassRadioButton = new JRadioButton();
      this.remUserPassRadioButton.setText(this.bundle.getString("login.dialog.remUserNamePwd"));
      this.remUserPassRadioButton.setEnabled(true);
      this.remUserPassRadioButton.setSelected(true);
      var3.add(this.remUserPassRadioButton);
      var2.add(this.remUserPassRadioButton);
      this.loginPanel.add(var2);
      this.addAnEmptyRow();
      this.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(""), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      SpringUtilities.makeCompactGrid(this.loginPanel, 9, 2, 15, 6, 15, 6);
      JPanel var4 = this.doButtonWidget();
      var4.setLayout(new FlowLayout(1));
      this.setLayout(new BorderLayout());
      this.add(this.loginPanel, "First");
      this.notProfiledLabel.setEnabled(false);
      this.notProfiledLabel.setText(this.bundle.getString("login.dialog.notProfiledWarning"));
      this.notProfiledLabel.setBackground(this.getBackground());
      this.notProfiledLabel.setDisabledTextColor(this.getForeground());
      this.notProfiledLabel.setBorder(new EmptyBorder(0, 0, 0, 0));
      this.notProfiledPanel.add(this.notProfiledLabel);
      this.add(this.notProfiledPanel, "Center");
      this.add(var4, "Last");
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.addActionListener(this);
      this.ok.setCommand(new DoLoginCommand(this.scrContext));
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new DoCancelLoginCommand(this.scrContext));
      this.cancel.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      return var1;
   }
}
