package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.KeyboardMacrosPreferences;
import com.raritan.rrc.ui.components.JCheckBoxList;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.List;
import java.util.TreeMap;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SpringLayout;

public class MacroSelectionPanel extends AbstractDisplay implements ActionListener, ItemListener {
   private static final long serialVersionUID = 2028595561540428642L;
   private JCheckBoxList macroList;
   private JScrollPane macroScrollPane;
   protected JButton selectAll;
   protected JButton deselectAll;
   protected TreeMap macros;

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      if (var2 == this.selectAll || var2 == this.deselectAll) {
         this.macroList.selectAllCheckBoxes(var2 == this.selectAll);
      }
   }

   @Override
   public void itemStateChanged(ItemEvent var1) {
      this.ok.setEnabled(this.macroList.getSelectedCheckBoxCount() > 0);
   }

   public MacroSelectionPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
   }

   @Override
   public void makeLayout() {
      this.selectAll = new JButton(this.bundle.getString("generic.dialog.selectall.text"));
      this.deselectAll = new JButton(this.bundle.getString("generic.dialog.deselectall.text"));
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
      JPanel var1 = new JPanel(new SpringLayout());
      var1.add(this.selectAll);
      var1.add(this.deselectAll);
      SpringUtilities.makeCompactGrid(var1, 2, 1, 5, 5, 5, 5);
      this.macroScrollPane = new JScrollPane(new JPanel(), 20, 30);
      this.macroScrollPane.setPreferredSize(new Dimension(200, 150));
      JPanel var2 = new JPanel(new SpringLayout());
      var2.add(this.macroScrollPane);
      var2.add(var1);
      SpringUtilities.makeCompactGrid(var2, 1, 2, 15, 15, 15, 15);
      this.add(var2, "Center");
      this.add(this.doButtonWidget(), "Last");
      this.selectAll.addActionListener(this);
      this.deselectAll.addActionListener(this);
   }

   @Override
   public void feedCommandContext(CommandContext var1) {
      List var2 = this.macroList.getSelectedLabels();
      TreeMap var3 = new TreeMap();

      for (int var4 = 0; var4 < var2.size(); var4++) {
         var3.put(var2.get(var4), (KeyboardMacrosPreferences)this.macros.get(var2.get(var4)));
      }

      this.macros = var3;
      var1.setCommandParameter("importExportSelectedMacros", this.macros);
      var1.setCommandParameter("importExportSelectedMacrosCommandParent", this);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.macros = (TreeMap)var1.getCommandParameter("importExportSelectedMacros");
      String[] var2 = this.macros.keySet().toArray(new String[0]);
      JCheckBox[] var3 = new JCheckBox[var2.length];

      for (int var4 = 0; var4 < var2.length; var4++) {
         var3[var4] = new JCheckBox(var2[var4]);
         var3[var4].addItemListener(this);
      }

      this.macroList = new JCheckBoxList(var3);
      this.macroScrollPane.setViewportView(this.macroList);
      this.macroList.selectAllCheckBoxes(true);
      this.ok.setEnabled(true);
   }
}
