package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.commands.DoModifyProfileCommand;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.net.InetAddress;
import java.util.List;
import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

public class ModifyConnectionPanel extends AddModifyConnectionPanel {
   private static final long serialVersionUID = 4310895560293477283L;
   private DevicePreferences devPrefs = null;
   private IPReach device = null;

   public ModifyConnectionPanel(boolean var1, ScreenContext var2) {
      super(var1, var2);
      this.setShell(this.bundle.getString("ModifyConnectionDialog.title"));
      this.ok.setCommand(new DoModifyProfileCommand(this.scrContext));
      this.apply.setCommand(new DoModifyProfileCommand(this.scrContext));
   }

   @Override
   public void makeLayout() {
      RaritanPropertyResourceBundle var1 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      this.addConnectionTabbedPane = new JTabbedPane();
      String var2 = var1.getString("ConnectTab.name");
      this.connectPanel = new ConnectPanel(false, this.scrContext);
      this.addConnectionTabbedPane.add(var2, this.connectPanel);
      this.compressionPanel = new CompressionPanel(false, this.scrContext);
      this.compressionPanel.setFocusable(true);
      var2 = var1.getString("CompressionTab.name");
      this.addConnectionTabbedPane.add(var2, this.compressionPanel);
      this.securityPanel = new SecurityPanel(false, this.scrContext);
      this.securityPanel.setFocusable(true);
      var2 = var1.getString("SecurityTab.name");
      this.addConnectionTabbedPane.add(var2, this.securityPanel);
      this.add(this.addConnectionTabbedPane, "Center");
      this.add(this.doButtonWidget(), "Last");
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.device = (IPReach)var1.getCommandParameter("devices");
      DevicePreferences var2 = this.device.getDevPrefs();
      this.devPrefs = new DevicePreferences();
      this.devPrefs.setDescription(this.device.getDescription());
      this.devPrefs.setConnectionType(var2.getConnectionType());
      this.devPrefs.setProductType(var2.getProductType());
      this.devPrefs.setFindBy(var2.getFindBy());
      switch (var2.getConnectionType()) {
         case 1:
            this.devPrefs.setPhone(var2.getPhone());
            this.devPrefs.setModem(var2.getModem());
            break;
         case 2:
            List var3 = this.device.getAddressList();
            switch (var2.getFindBy()) {
               case 0:
                  this.devPrefs.setIp(var2.getIp());
                  this.devPrefs.setName(this.device.getName());
                  this.devPrefs.setDnsName(this.device.getDnsName());
                  break;
               case 1:
                  this.devPrefs.setName(var2.getName());
                  if (var3.size() > 0) {
                     this.devPrefs.setIp(((InetAddress)var3.get(0)).getHostAddress());
                  }

                  this.devPrefs.setDnsName(this.device.getDnsName());
                  break;
               case 2:
                  this.devPrefs.setDnsName(var2.getDnsName());
                  this.devPrefs.setName(this.device.getName());
                  if (var3.size() > 0) {
                     this.devPrefs.setIp(((InetAddress)var3.get(0)).getHostAddress());
                  }
            }
      }

      this.devPrefs.setPort(var2.getPort());
      this.devPrefs.setHttpsPort(var2.getHttpsPort());
      this.devPrefs.setConnectionSpeed(var2.getConnectionSpeed());
      this.devPrefs.setColorDepth(var2.getColorDepth());
      this.devPrefs.setProgressiveUpdate(var2.isProgressiveUpdate());
      this.devPrefs.setFlowControl(var2.isFlowControl());
      this.devPrefs.setSmoothing(var2.getSmoothing());
      this.devPrefs.setFramesPerSecond(var2.getFramesPerSecond());
      this.devPrefs.setKey(var2.getKey());
      this.devPrefs.setUserName(var2.getUserName());
      this.devPrefs.setPassword(var2.getPassword());
      this.connectPanel.setCommandKey(var1.getCommandKey());
      this.connectPanel.fillDevicePreferences(this.devPrefs);
      this.compressionPanel.fillDevicePreferences(this.devPrefs);
      this.securityPanel.fillDevicePreferences(this.devPrefs);
      this.addConnectionTabbedPane.setSelectedIndex(0);
      this.connectPanel.setDefaultFocussedComponent();
      this.connectPanel.fillComponents(var1);
      this.apply.setEnabled(false);
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      this.connectPanel.feedDevicePreferences(this.devPrefs);
      this.compressionPanel.feedDevicePreferences(this.devPrefs);
      this.securityPanel.feedDevicePreferences(this.devPrefs);
      var1.setCommandParameter("connectionInfo", this.devPrefs);
      var1.setCommandParameter("devices", this.device);
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.addActionListener(this);
      this.apply = new CommandButton(this.bundle.getString("ModifyConnection.applyLabel"), this.scrContext);
      this.apply.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      var1.add(this.apply);
      return var1;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      if (var2 instanceof JComboBox) {
         this.apply.setEnabled(true);
      } else {
         this.apply.setEnabled(false);
      }
   }

   public void setApplyButton(boolean var1) {
      this.apply.setEnabled(var1);
   }

   public void setG2Panels(boolean var1) {
      this.addConnectionTabbedPane.setEnabledAt(1, var1);
      this.addConnectionTabbedPane.setEnabledAt(2, var1);
   }

   @Override
   protected void setVisibleAfterCommand(Command var1) {
      if (var1 != null && this.apply != null && this.ok != null && var1.equals(this.apply.getCommand())) {
         super.setVisibleAfterCommand(this.ok.getCommand());
      } else {
         super.setVisibleAfterCommand(var1);
      }
   }
}
