package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoSaveOptionsCommand;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.util.Util;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GraphicsDevice;
import java.awt.GraphicsEnvironment;
import java.awt.event.ActionEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.List;
import javaclientlib.tr.KeyboardLang;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTabbedPane;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.border.TitledBorder;
import nn.pp.common.ui.MonitorDisplayer;
import nn.pp.ext.pref.IApplicationPreferences;

public class OptionsPanel extends AbstractDisplay implements ItemListener, KeyListener {
   private static final long serialVersionUID = -5374645315512964272L;
   protected RaritanPropertyResourceBundle bundle;
   private JPanel generalPanel;
   private JPanel advancedPanel;
   private JPanel clientSettingsPanel;
   private JPanel scanPanel;
   private JLabel thumbNailSizeLabel;
   private JLabel splitOrientationLabel;
   private JComboBox thumbnailCombo;
   private JComboBox splitCombo;
   private JLabel intervalLabel;
   private JLabel portIntervalLabel;
   private JTextField intervalField;
   private JTextField portsIntervalField;
   private JTabbedPane tabbedPane;
   private JCheckBox showScrollbarChkBox;
   private JCheckBox doAutoColorCalChkBox;
   private JCheckBox autoSyncChkBox;
   private JCheckBox singleCursorChkBox;
   private JRadioButton scrollLockRadioButton;
   private JRadioButton numLockRadioButton;
   private JRadioButton capsLockRadioButton;
   private final KeyboardLang[] keyboardTypes;
   private DefaultComboBoxModel keyboardTypeModel;
   private int oldKeyboardState;
   private JTextField portField;
   private JTextField httpsPortField;
   private JComboBox keyboardTypeComboBox;
   private JComboBox keyboardShortcutMenuComboBox;
   private String[] keyboardMenuShortcutString = new String[26];
   private DefaultComboBoxModel keyboardMenuShortcutModel;
   private JCheckBox chkEnableLogging = null;
   private JLabel lblEnableLogging = null;
   private JPanel pnlEnableLogging = null;
   JPanel monitorPanel;
   private JCheckBox chkEnableIPV6;
   private JLabel detectedMonitorsLabel;
   private JRadioButton standardModeRadioButton;
   private JRadioButton fullScreenModeRadioButton;
   private JRadioButton clientLaunchedRadioButton;
   private JRadioButton detectedMonitorRadioButton;
   private JComboBox preferredMonitorCombo;
   private JCheckBox enableSingleMouse;
   private JCheckBox enableScaling;
   private JCheckBox pinMenu;
   private MonitorDisplayer.DefaultMonitorDisplayerModel mdm;
   private MonitorDisplayer md;
   int monitorCount = 0;
   IApplicationPreferences appPrefs;
   GraphicsDevice[] graphicsDevices;

   public OptionsPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.keyboardTypes = new KeyboardLang[]{
         new KeyboardLang("US/International", 0),
         new KeyboardLang("French (France)", 4),
         new KeyboardLang("German (Germany)", 3),
         new KeyboardLang("Japanese", 1),
         new KeyboardLang("United Kingdom", 2),
         new KeyboardLang("Korean (Korea)", 5),
         new KeyboardLang("French (Belgium)", 6),
         new KeyboardLang("Norwegian (Norway)", 7),
         new KeyboardLang("Danish (Denmark)", 8),
         new KeyboardLang("Swedish (Sweden)", 9),
         new KeyboardLang("German (Switzerland)", 10),
         new KeyboardLang("Hungarian (Hungary)", 11),
         new KeyboardLang("Spanish (Spain)", 12),
         new KeyboardLang("Italian (Italy)", 13),
         new KeyboardLang("Slovenian", 14),
         new KeyboardLang("Portuguese (Portugal)", 15),
         new KeyboardLang("Translation: French-US", 1278),
         new KeyboardLang("Translation: French-US International", 1279)
      };
      this.keyboardTypeModel = new DefaultComboBoxModel<>(this.keyboardTypes);
      this.isDialog = var1;
      this.appPrefs = ((RRCScreenContext)this.scrContext).getAppSettings();
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.keyboardMenuShortcutString[0] = this.bundle.getString("KeyboardMenuHotkey.OptionA");
      this.keyboardMenuShortcutString[1] = this.bundle.getString("KeyboardMenuHotkey.OptionB");
      this.keyboardMenuShortcutString[2] = this.bundle.getString("KeyboardMenuHotkey.OptionC");
      this.keyboardMenuShortcutString[3] = this.bundle.getString("KeyboardMenuHotkey.OptionD");
      this.keyboardMenuShortcutString[4] = this.bundle.getString("KeyboardMenuHotkey.OptionE");
      this.keyboardMenuShortcutString[5] = this.bundle.getString("KeyboardMenuHotkey.OptionF");
      this.keyboardMenuShortcutString[6] = this.bundle.getString("KeyboardMenuHotkey.OptionG");
      this.keyboardMenuShortcutString[7] = this.bundle.getString("KeyboardMenuHotkey.OptionH");
      this.keyboardMenuShortcutString[8] = this.bundle.getString("KeyboardMenuHotkey.OptionI");
      this.keyboardMenuShortcutString[9] = this.bundle.getString("KeyboardMenuHotkey.OptionJ");
      this.keyboardMenuShortcutString[10] = this.bundle.getString("KeyboardMenuHotkey.OptionK");
      this.keyboardMenuShortcutString[11] = this.bundle.getString("KeyboardMenuHotkey.OptionL");
      this.keyboardMenuShortcutString[12] = this.bundle.getString("KeyboardMenuHotkey.OptionM");
      this.keyboardMenuShortcutString[13] = this.bundle.getString("KeyboardMenuHotkey.OptionN");
      this.keyboardMenuShortcutString[14] = this.bundle.getString("KeyboardMenuHotkey.OptionO");
      this.keyboardMenuShortcutString[15] = this.bundle.getString("KeyboardMenuHotkey.OptionP");
      this.keyboardMenuShortcutString[16] = this.bundle.getString("KeyboardMenuHotkey.OptionQ");
      this.keyboardMenuShortcutString[17] = this.bundle.getString("KeyboardMenuHotkey.OptionR");
      this.keyboardMenuShortcutString[18] = this.bundle.getString("KeyboardMenuHotkey.OptionS");
      this.keyboardMenuShortcutString[19] = this.bundle.getString("KeyboardMenuHotkey.OptionT");
      this.keyboardMenuShortcutString[20] = this.bundle.getString("KeyboardMenuHotkey.OptionU");
      this.keyboardMenuShortcutString[21] = this.bundle.getString("KeyboardMenuHotkey.OptionV");
      this.keyboardMenuShortcutString[22] = this.bundle.getString("KeyboardMenuHotkey.OptionW");
      this.keyboardMenuShortcutString[23] = this.bundle.getString("KeyboardMenuHotkey.OptionX");
      this.keyboardMenuShortcutString[24] = this.bundle.getString("KeyboardMenuHotkey.OptionY");
      this.keyboardMenuShortcutString[25] = this.bundle.getString("KeyboardMenuHotkey.OptionZ");
      this.keyboardMenuShortcutModel = new DefaultComboBoxModel<>(this.keyboardMenuShortcutString);
      this.makeLayout();
      this.setShell(this.bundle.getString("OptionDialog.title"));
   }

   @Override
   public void makeLayout() {
      try {
         this.setLayout(new BoxLayout(this, 3));
         this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
         this.tabbedPane = new JTabbedPane();
         String var1 = this.bundle.getString("OptionDialog.name");
         String var2 = this.bundle.getString("OptionDialog.AdvancedTabName");
         String var3 = this.bundle.getString("OptionDialog.settings");
         String var4 = this.bundle.getString("OptionDialog.ScanTabName");
         this.generalPanel = new JPanel(new SpringLayout());
         this.advancedPanel = new JPanel(new SpringLayout());
         this.clientSettingsPanel = new JPanel(new SpringLayout());
         this.scanPanel = new JPanel(new SpringLayout());
         JPanel var5 = new JPanel(new SpringLayout());
         String var6 = this.bundle.getString("OptionDialog.showScrollBordersCheckBox");
         this.showScrollbarChkBox = new JCheckBox(var6);
         this.showScrollbarChkBox.setSelected(true);
         this.showScrollbarChkBox.addItemListener(this);
         var5.add(this.showScrollbarChkBox);
         JLabel var7 = new JLabel(this.bundle.getString("OptionDialog.doAutoSyncCheckBox.info"));
         var7.setForeground(Color.BLUE);
         var6 = this.bundle.getString("OptionDialog.autoSyncCheckBox");
         this.autoSyncChkBox = new JCheckBox(var6);
         this.autoSyncChkBox.setSelected(true);
         this.autoSyncChkBox.addItemListener(this);
         JPanel var8 = new JPanel(new SpringLayout());
         var8.add(this.autoSyncChkBox);
         var8.add(var7);
         SpringUtilities.makeCompactGrid(var8, 1, 2, 1, 1, 1, 1);
         var5.add(var8);
         var6 = this.bundle.getString("OptionDialog.singleModeInstructionsCheckBox");
         this.singleCursorChkBox = new JCheckBox(var6);
         this.singleCursorChkBox.setSelected(true);
         this.singleCursorChkBox.addItemListener(this);
         var5.add(this.singleCursorChkBox);
         var6 = this.bundle.getString("OptionDialog.doAutoColorCalCheckBox");
         this.doAutoColorCalChkBox = new JCheckBox(var6);
         this.doAutoColorCalChkBox.setSelected(true);
         this.doAutoColorCalChkBox.addItemListener(this);
         JLabel var9 = new JLabel(this.bundle.getString("OptionDialog.doAutoColorCalCheckBox.info"));
         var9.setForeground(Color.BLUE);
         JPanel var10 = new JPanel(new SpringLayout());
         var10.add(this.doAutoColorCalChkBox);
         var10.add(var9);
         SpringUtilities.makeCompactGrid(var10, 1, 2, 1, 1, 1, 1);
         var5.add(var10);
         SpringUtilities.makeCompactGrid(var5, 4, 1, 1, 1, 1, 1);
         JPanel var11 = new JPanel(new SpringLayout());
         var11.setBorder(BorderFactory.createTitledBorder(this.bundle.getString("OptionDialog.KeyboardTypeLabel")));
         this.keyboardTypeComboBox = new JComboBox(this.keyboardTypeModel);
         var11.add(this.keyboardTypeComboBox);
         this.keyboardTypeComboBox.addActionListener(this);
         this.keyboardTypeComboBox.setMaximumSize(new Dimension(this.keyboardTypeComboBox.getSize().width, 20));
         SpringUtilities.makeCompactGrid(var11, 1, 1, 15, 15, 15, 15);
         JPanel var12 = new JPanel(new SpringLayout());
         var12.setBorder(BorderFactory.createTitledBorder(this.bundle.getString("Optiondialog.KeyboardShortcutMenuHotkey")));
         this.keyboardShortcutMenuComboBox = new JComboBox(this.keyboardMenuShortcutModel);
         var12.add(this.keyboardShortcutMenuComboBox);
         this.keyboardShortcutMenuComboBox.addActionListener(this);
         this.keyboardShortcutMenuComboBox.setMaximumSize(new Dimension(this.keyboardShortcutMenuComboBox.getSize().width, 20));
         SpringUtilities.makeCompactGrid(var12, 1, 1, 15, 15, 15, 15);
         JPanel var13 = new JPanel(new SpringLayout());
         var13.setBorder(BorderFactory.createTitledBorder(this.bundle.getString("OptionDialog.osuiHotKeyLabel")));
         ButtonGroup var14 = new ButtonGroup();
         this.scrollLockRadioButton = new JRadioButton();
         this.scrollLockRadioButton.setText(this.bundle.getString("OptionDialog.scrollLockRadioButton"));
         this.scrollLockRadioButton.setSelected(true);
         this.scrollLockRadioButton.addActionListener(this);
         var14.add(this.scrollLockRadioButton);
         var13.add(this.scrollLockRadioButton);
         this.numLockRadioButton = new JRadioButton();
         this.numLockRadioButton.setText(this.bundle.getString("OptionDialog.numLockRadioButton"));
         this.numLockRadioButton.addActionListener(this);
         var14.add(this.numLockRadioButton);
         var13.add(this.numLockRadioButton);
         this.capsLockRadioButton = new JRadioButton();
         this.capsLockRadioButton.setText(this.bundle.getString("OptionDialog.capsLockRadioButton"));
         this.capsLockRadioButton.addActionListener(this);
         var14.add(this.capsLockRadioButton);
         var13.add(this.capsLockRadioButton);
         SpringUtilities.makeCompactGrid(var13, 3, 1, 15, 1, 1, 1);
         JPanel var15 = new JPanel(new SpringLayout());
         var15.setBorder(BorderFactory.createTitledBorder(this.bundle.getString("OptionDialog.portConfigurationLabel")));
         JLabel var16 = new JLabel(this.bundle.getString("OptionDialog.httpsPortLabel"));
         var15.add(var16);
         this.httpsPortField = new JTextField();
         this.httpsPortField.addKeyListener(this);
         this.httpsPortField.setMaximumSize(new Dimension(80, 20));
         this.httpsPortField.setPreferredSize(new Dimension(80, 20));
         var15.add(this.httpsPortField);
         var15.add(new JLabel("                          "));
         var16 = new JLabel(this.bundle.getString("OptionDialog.broadcastPortLabel"));
         var15.add(var16);
         this.portField = new JTextField();
         this.portField.addKeyListener(this);
         this.portField.setMaximumSize(new Dimension(80, 20));
         this.portField.setPreferredSize(new Dimension(80, 20));
         var15.add(this.portField);
         var15.add(new JLabel("                          "));
         SpringUtilities.makeCompactGrid(var15, 2, 3, 20, 15, 5, 15);
         JPanel var17 = new JPanel(new SpringLayout());
         var17.setBorder(BorderFactory.createTitledBorder(this.bundle.getString("OptionDialog.IPv6NetworkingTitle")));
         this.chkEnableIPV6 = new JCheckBox(this.bundle.getString("OptionDialog.IPv6EnableLabel"));
         this.chkEnableIPV6.addActionListener(this);
         this.chkEnableIPV6.setEnabled(Util.isIPV6Supported());
         var17.add(this.chkEnableIPV6);
         SpringUtilities.makeCompactGrid(var17, 1, 1, 20, 15, 35, 15);
         this.pnlEnableLogging = new JPanel(new SpringLayout());
         this.pnlEnableLogging.setBorder(BorderFactory.createTitledBorder(this.bundle.getString("OptionDialog.LoggingLabel")));
         this.chkEnableLogging = new JCheckBox(this.bundle.getString("OptionDialog.enableLoggingLabel"));
         this.chkEnableLogging.addActionListener(this);
         this.pnlEnableLogging.add(this.chkEnableLogging);
         SpringUtilities.makeCompactGrid(this.pnlEnableLogging, 1, 1, 20, 15, 35, 15);
         JPanel var18 = new JPanel(new SpringLayout());
         var18.setBorder(new TitledBorder(this.bundle.getString("OptionDialog.settings")));
         this.detectedMonitorsLabel = new JLabel(this.bundle.getString("OptionDialog.DetectedMonitorsLabel"));
         this.standardModeRadioButton = new JRadioButton(this.bundle.getString("OptionDialog.StandardRadioButton"));
         this.standardModeRadioButton.addActionListener(this);
         this.fullScreenModeRadioButton = new JRadioButton(this.bundle.getString("OptionDialog.FullScreenRadioButton"));
         this.fullScreenModeRadioButton.addActionListener(this);
         ButtonGroup var19 = new ButtonGroup();
         ButtonGroup var20 = new ButtonGroup();
         this.clientLaunchedRadioButton = new JRadioButton(this.bundle.getString("OptionDialog.ClientLaunchRadioButton"));
         this.clientLaunchedRadioButton.addActionListener(this);
         this.detectedMonitorRadioButton = new JRadioButton(this.bundle.getString("OptionDialog.DetectedMonitorRadioButton"));
         this.detectedMonitorRadioButton.addActionListener(this);
         var19.add(this.standardModeRadioButton);
         var19.add(this.fullScreenModeRadioButton);
         var18.add(this.standardModeRadioButton);
         var18.add(this.fullScreenModeRadioButton);
         SpringUtilities.makeCompactGrid(var18, 2, 1, 35, 15, 35, 15);
         this.monitorPanel = new JPanel(new SpringLayout());
         this.monitorPanel.setBorder(new TitledBorder(this.bundle.getString("OptionDialog.MonitorBorder")));
         var20.add(this.clientLaunchedRadioButton);
         var20.add(this.detectedMonitorRadioButton);
         this.monitorPanel.add(this.clientLaunchedRadioButton);
         this.monitorPanel.add(this.detectedMonitorRadioButton);
         this.preferredMonitorCombo = new JComboBox();
         this.graphicsDevices = GraphicsEnvironment.getLocalGraphicsEnvironment().getScreenDevices();
         this.monitorCount = this.graphicsDevices.length;
         this.mdm = new MonitorDisplayer.DefaultMonitorDisplayerModel(this.graphicsDevices, 0);
         this.md = new MonitorDisplayer(this.mdm);
         List var21 = this.mdm.getGraphicsDevices();
         Object var22 = null;
         String var23 = this.appPrefs.getMonitorSetting();
         int var24 = -1;
         int var25 = 0;
         if (var23 != null) {
            for (GraphicsDevice var27 : var21) {
               var25++;
               if (var27.getIDstring().equals(var23)) {
                  var24 = var25 - 1;
                  break;
               }
            }
         }

         if (((RRCScreenContext)this.scrContext).isMonitorCountMatch() || var23 == null && this.appPrefs.getMonitorCount() < 0) {
            var22 = new OptionsPanel.MonitorData[var21.size()];
            int var39 = 0;

            for (GraphicsDevice var44 : var21) {
               ((Object[])var22)[var39] = new OptionsPanel.MonitorData(var44, var39 + 1, MonitorDisplayer.getDisplayAlphabet(var39));
               this.preferredMonitorCombo.addItem(((Object[])var22)[var39]);
               var39++;
            }

            if (var23 != null) {
               this.preferredMonitorCombo.setSelectedIndex(var24);
            }

            if (this.preferredMonitorCombo.getSelectedIndex() >= 0) {
               this.mdm.setSelectedDevice(this.preferredMonitorCombo.getSelectedIndex());
               this.md.updateUI();
            }
         } else if (var23 != null) {
            var22 = new OptionsPanel.MonitorData[var21.size() + 1];
            ((Object[])var22)[0] = new OptionsPanel.MonitorData(null, -1, "");
            this.preferredMonitorCombo.addItem(((Object[])var22)[0]);
            int var38 = 1;

            for (GraphicsDevice var28 : var21) {
               ((Object[])var22)[var38] = new OptionsPanel.MonitorData(var28, var38, MonitorDisplayer.getDisplayAlphabet(var38 - 1));
               this.preferredMonitorCombo.addItem(((Object[])var22)[var38]);
               var38++;
            }

            this.preferredMonitorCombo.setSelectedIndex(0);
         }

         this.preferredMonitorCombo.addActionListener(this);
         this.preferredMonitorCombo.addItemListener(this);
         this.monitorPanel.add(this.preferredMonitorCombo);
         this.preferredMonitorCombo.setMaximumSize(new Dimension(this.preferredMonitorCombo.getSize().width, 20));
         this.monitorPanel.add(this.detectedMonitorsLabel);
         this.monitorPanel.add(this.md);
         SpringUtilities.makeCompactGrid(this.monitorPanel, 5, 1, 35, 15, 35, 15);
         JPanel var40 = new JPanel(new SpringLayout());
         var40.setBorder(new TitledBorder(this.bundle.getString("OptionDialog.other")));
         this.enableSingleMouse = new JCheckBox(this.bundle.getString("OptionDialog.smm"));
         this.enableScaling = new JCheckBox(this.bundle.getString("OptionDialog.scale"));
         this.pinMenu = new JCheckBox(this.bundle.getString("OptionDialog.pinmenu"));
         this.enableSingleMouse.addActionListener(this);
         this.enableScaling.addActionListener(this);
         this.pinMenu.addActionListener(this);
         var40.add(this.enableSingleMouse);
         var40.add(this.enableScaling);
         var40.add(this.pinMenu);
         SpringUtilities.makeCompactGrid(var40, 3, 1, 35, 15, 35, 15);
         this.clientSettingsPanel.add(var18);
         this.clientSettingsPanel.add(this.monitorPanel);
         this.clientSettingsPanel.add(var40);
         SpringUtilities.makeCompactGrid(this.clientSettingsPanel, 3, 1, 35, 15, 35, 15);
         this.intervalLabel = new JLabel(this.bundle.getString("OptionDialog.DisplayInterval"));
         this.portIntervalLabel = new JLabel(this.bundle.getString("OptionDialog.PortDisplayInterval"));
         this.intervalField = new JTextField();
         this.intervalField.addKeyListener(this);
         this.portsIntervalField = new JTextField();
         this.portsIntervalField.addKeyListener(this);
         JPanel var43 = new JPanel(new SpringLayout());
         var43.setBorder(new TitledBorder(this.bundle.getString("OptionDialog.ScanIntervals")));
         this.intervalField.setMaximumSize(new Dimension(40, 20));
         this.intervalField.setPreferredSize(new Dimension(40, 20));
         this.portsIntervalField.setMaximumSize(new Dimension(40, 20));
         this.portsIntervalField.setPreferredSize(new Dimension(40, 20));
         var43.add(this.intervalLabel);
         var43.add(this.intervalField);
         var43.add(this.portIntervalLabel);
         var43.add(this.portsIntervalField);
         SpringUtilities.makeCompactGrid(var43, 2, 2, 20, 15, 35, 15);
         this.thumbNailSizeLabel = new JLabel(this.bundle.getString("OptionDialog.ThumbnailSize"));
         this.splitOrientationLabel = new JLabel(this.bundle.getString("OptionDialog.SplitOrientation"));
         String[] var45 = new String[]{"160x120", "320x240"};
         String[] var29 = new String[]{"Horizontal", "Vertical"};
         this.thumbnailCombo = new JComboBox<>(var45);
         this.splitCombo = new JComboBox<>(var29);
         JPanel var30 = new JPanel(new SpringLayout());
         var30.setBorder(new TitledBorder(this.bundle.getString("OptionDialog.Display")));
         this.thumbnailCombo.setMaximumSize(new Dimension(100, 20));
         this.thumbnailCombo.setPreferredSize(new Dimension(100, 20));
         this.thumbnailCombo.addActionListener(this);
         this.splitCombo.setMaximumSize(new Dimension(100, 20));
         this.splitCombo.setPreferredSize(new Dimension(100, 20));
         this.splitCombo.addActionListener(this);
         var30.add(this.thumbNailSizeLabel);
         var30.add(this.thumbnailCombo);
         var30.add(this.splitOrientationLabel);
         var30.add(this.splitCombo);
         SpringUtilities.makeCompactGrid(var30, 2, 2, 20, 15, 35, 15);
         this.generalPanel.add(var5);
         this.generalPanel.add(var11);
         this.generalPanel.add(var12);
         this.advancedPanel.add(var13);
         this.advancedPanel.add(var15);
         this.advancedPanel.add(var17);
         this.advancedPanel.add(this.pnlEnableLogging);
         this.scanPanel.add(var43);
         this.scanPanel.add(var30);
         SpringUtilities.makeCompactGrid(this.generalPanel, 3, 1, 35, 15, 35, 15);
         SpringUtilities.makeCompactGrid(this.advancedPanel, 4, 1, 35, 15, 35, 15);
         SpringUtilities.makeCompactGrid(this.scanPanel, 2, 1, 35, 15, 35, 15);
         this.tabbedPane.add(var1, this.generalPanel);
         this.tabbedPane.add(var2, this.advancedPanel);
         this.tabbedPane.add(var3, this.clientSettingsPanel);
         this.tabbedPane.add(var4, this.scanPanel);
         this.add(this.tabbedPane, "Center");
         this.add(this.doButtonWidget(), "Last");
      } catch (Exception var31) {
         var31.printStackTrace();
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      var1.setCommandParameter("showScrollBorders", new Boolean(this.showScrollbarChkBox.isSelected()));
      var1.setCommandParameter("autoColorCal", new Boolean(this.doAutoColorCalChkBox.isSelected()));
      var1.setCommandParameter("enableLaunchInFullScreenMode", new Boolean(this.fullScreenModeRadioButton.isSelected()));
      if (this.detectedMonitorRadioButton.isSelected()) {
         OptionsPanel.MonitorData var2 = (OptionsPanel.MonitorData)this.preferredMonitorCombo.getSelectedItem();
         String var3 = null;
         GraphicsDevice var4 = var2.getMonitor();
         if (var4 != null) {
            var3 = var4.getIDstring();
         }

         if (var3 == null && this.preferredMonitorCombo.getSelectedItem().toString().equals(this.bundle.getString("OptionDialog.MonitorChanged"))) {
            var1.setCommandParameter("monitorSetting", this.appPrefs.getMonitorSetting());
            var1.setCommandParameter("monitorCount", this.appPrefs.getMonitorCount());
         } else if (var3 != null) {
            this.monitorCount = GraphicsEnvironment.getLocalGraphicsEnvironment().getScreenDevices().length;
            var1.setCommandParameter("monitorSetting", var2.getMonitor().getIDstring());
            var1.setCommandParameter("monitorCount", this.monitorCount);
         }
      } else {
         var1.setCommandParameter("monitorSetting", null);
         var1.setCommandParameter("monitorCount", -1);
      }

      var1.setCommandParameter("showSingleCursorModeInstructions", new Boolean(this.singleCursorChkBox.isSelected()));
      var1.setCommandParameter("enableLogging", new Boolean(this.chkEnableLogging.isSelected()));
      var1.setCommandParameter("autoSyncMouse", new Boolean(this.autoSyncChkBox.isSelected()));
      if (this.scrollLockRadioButton.isSelected()) {
         var1.setCommandParameter("osuiHotKey", new Integer(0));
      } else if (this.numLockRadioButton.isSelected()) {
         var1.setCommandParameter("osuiHotKey", new Integer(1));
      } else if (this.capsLockRadioButton.isSelected()) {
         var1.setCommandParameter("osuiHotKey", new Integer(2));
      }

      int var5 = ((KeyboardLang)this.keyboardTypeModel.getSelectedItem()).getLangNumber();
      if (this.oldKeyboardState != var5) {
         var1.setCommandParameter("keyboardTypeChanged", new Boolean(true));
      } else {
         var1.setCommandParameter("keyboardTypeChanged", new Boolean(false));
      }

      var1.setCommandParameter("keyboardType", new Integer(var5));
      var1.setCommandParameter("broadcastPort", this.portField.getText());
      var1.setCommandParameter("defaultHttpsPort", this.httpsPortField.getText());
      var1.setCommandParameter(
         "KeyboardShortcutMenuHotKey",
         this.keyboardMenuShortcutModel
            .getSelectedItem()
            .toString()
            .replace(this.bundle.getString("KeyboardMenuHotkey.LeftAlt.Indicator"), this.bundle.getString("KeyboardMenuHotkey.Alt.Indicator"))
      );
      var1.setCommandParameter("IPv6NetworkingEnabled", this.chkEnableIPV6.isSelected());
      var1.setCommandParameter("enableSingleMouse", this.enableSingleMouse.isSelected());
      var1.setCommandParameter("enableScaling", this.enableScaling.isSelected());
      var1.setCommandParameter("pinMenu", this.pinMenu.isSelected());
      var1.setCommandParameter("scanDisplayInterval", this.intervalField.getText());
      var1.setCommandParameter("scanDiaplyIntervalPort", this.portsIntervalField.getText());
      var1.setCommandParameter("thumbnailSize", this.thumbnailCombo.getSelectedItem());
      var1.setCommandParameter("splitOrientation", this.splitCombo.getSelectedItem());
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.showScrollbarChkBox.setSelected(this.appPrefs.isShowScrollBorders());
      this.doAutoColorCalChkBox.setSelected(this.appPrefs.isDoAutoColorCal());
      this.autoSyncChkBox.setSelected(this.appPrefs.isAutoSyncMouse());
      this.singleCursorChkBox.setSelected(this.appPrefs.isSingleMouseInstructions());
      this.chkEnableLogging.setSelected(this.appPrefs.isEnableLogging());
      int var2 = this.appPrefs.getOsuiHotKey();
      if (var2 == 0) {
         this.scrollLockRadioButton.setSelected(true);
      } else if (var2 == 1) {
         this.numLockRadioButton.setSelected(true);
      } else if (var2 == 2) {
         this.capsLockRadioButton.setSelected(true);
      }

      this.oldKeyboardState = this.appPrefs.getKeyboardType();
      boolean var3 = false;

      for (int var6 = 0; var6 < this.keyboardTypes.length; var6++) {
         if (this.keyboardTypes[var6].getLangNumber() == this.oldKeyboardState) {
            this.keyboardTypeModel.setSelectedItem(this.keyboardTypes[var6]);
            break;
         }
      }

      this.portField.setText(String.valueOf(this.appPrefs.getBroadcastPort()));
      this.httpsPortField.setText(String.valueOf(this.appPrefs.getDefaultHttpsPort()));
      this.keyboardMenuShortcutModel
         .setSelectedItem(
            this.appPrefs
               .getkeyboardMenuHotkey()
               .replace(this.bundle.getString("KeyboardMenuHotkey.Alt.Indicator"), this.bundle.getString("KeyboardMenuHotkey.LeftAlt.Indicator"))
         );
      this.setEnabledAutoColorCalChkBox(true);
      this.setEnabledAutoSyncChkBox(true);
      this.setEnabledBroadcastPort(true);
      this.setEnabledDefaultHttpsPort(true);
      this.setEnabledKeyboardShortcutMenu(true);
      this.setEnabledKeyboardType(true);
      this.setEnabledKvmSwitchOSUIHotKey(true);
      this.setEnabledScrollbarChkBox(true);
      this.setEnabledSingleCursorChkBox(true);
      this.setEnabledIntervalField(true);
      this.setEnabledPortIntervalField(true);
      this.chkEnableIPV6.setSelected(this.appPrefs.isIPv6NetworkingEnabled());
      boolean var4 = this.appPrefs.isAlwaysOpenInFS();
      this.standardModeRadioButton.setSelected(!var4);
      this.fullScreenModeRadioButton.setSelected(var4);
      this.clientLaunchedRadioButton.setSelected(this.appPrefs.getMonitorSetting() == null);
      this.detectedMonitorRadioButton.setSelected(this.appPrefs.getMonitorSetting() != null);
      this.enableSingleMouse.setSelected(this.appPrefs.isAlwaysOpenSMM());
      this.enableScaling.setSelected(this.appPrefs.isAlwaysOpenScaled());
      this.pinMenu.setSelected(this.appPrefs.isPinMenu());
      if (this.clientLaunchedRadioButton.isSelected()) {
         this.enableMonitorComponents(false);
      }

      GraphicsEnvironment var5 = GraphicsEnvironment.getLocalGraphicsEnvironment();
      ((RRCScreenContext)this.scrContext).setMonitorCountMatch(this.appPrefs.getMonitorCount() == var5.getScreenDevices().length);
      this.populateMonitorCombo(true);
      this.intervalField.setText(Integer.toString(this.appPrefs.getScanDisplayInterval()));
      this.portsIntervalField.setText(Integer.toString(this.appPrefs.getPortScanInterval()));
      this.thumbnailCombo.setSelectedItem(this.appPrefs.getScanThumbnailSize());
      this.splitCombo.setSelectedItem(this.appPrefs.getScanOrientation());
      this.apply.setEnabled(false);
   }

   @Override
   public JPanel doButtonWidget() {
      JPanel var1 = null;
      this.ok = new CommandButton(this.bundle.getString("OptionDialog.okLabel"), this.scrContext);
      this.ok.setCommand(new DoSaveOptionsCommand(this.scrContext));
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("OptionDialog.cancelLabel"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      this.apply = new CommandButton(this.bundle.getString("OptionDialog.applyLabel"), this.scrContext);
      this.apply.setCommand(new DoSaveOptionsCommand(this.scrContext));
      this.apply.addActionListener(this);
      this.apply.setEnabled(false);
      var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      var1.add(this.apply);
      return var1;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      this.scrContext.getLogger().logTextDebug("started");
      if (!(var2 instanceof JRadioButton) && !(var2 instanceof JComboBox) && !(var2 instanceof JCheckBox) && !(var2 instanceof JTextField)) {
         this.apply.setEnabled(false);
      } else {
         this.apply.setEnabled(true);
      }

      if (var1.getSource() == this.detectedMonitorRadioButton) {
         this.enableMonitorComponents(true);
      } else if (var1.getSource() == this.clientLaunchedRadioButton) {
         this.enableMonitorComponents(false);
      }

      this.scrContext.getLogger().logTextDebug("finished");
   }

   @Override
   public void keyPressed(KeyEvent var1) {
   }

   @Override
   public void keyReleased(KeyEvent var1) {
   }

   @Override
   public void keyTyped(KeyEvent var1) {
      Object var2 = var1.getSource();
      if (var2 instanceof JTextField) {
         this.apply.setEnabled(true);
      }
   }

   @Override
   public void itemStateChanged(ItemEvent var1) {
      if (var1.getSource() == this.preferredMonitorCombo) {
         int var2;
         if (!((RRCScreenContext)this.scrContext).isMonitorCountMatch() && (this.appPrefs.getMonitorSetting() != null || this.appPrefs.getMonitorCount() >= 0)) {
            var2 = this.preferredMonitorCombo.getSelectedIndex() - 1;
         } else {
            var2 = this.preferredMonitorCombo.getSelectedIndex();
         }

         this.mdm.setSelectedDevice(var2);
         this.md.updateUI();
      }

      this.apply.setEnabled(true);
   }

   public void setEnabledScrollbarChkBox(boolean var1) {
      this.showScrollbarChkBox.setEnabled(var1);
   }

   public void setEnabledAutoSyncChkBox(boolean var1) {
      this.autoSyncChkBox.setEnabled(var1);
   }

   public void setEnabledSingleCursorChkBox(boolean var1) {
      this.singleCursorChkBox.setEnabled(var1);
   }

   public void setEnabledAutoColorCalChkBox(boolean var1) {
      this.doAutoColorCalChkBox.setEnabled(var1);
   }

   public void setEnabledKvmSwitchOSUIHotKey(boolean var1) {
      this.scrollLockRadioButton.setEnabled(var1);
      this.numLockRadioButton.setEnabled(var1);
      this.capsLockRadioButton.setEnabled(var1);
   }

   public void setEnabledKeyboardType(boolean var1) {
      this.keyboardTypeComboBox.setEnabled(var1);
   }

   public void setEnabledKeyboardShortcutMenu(boolean var1) {
      this.keyboardShortcutMenuComboBox.setEnabled(var1);
   }

   public void setEnabledBroadcastPort(boolean var1) {
      this.portField.setEnabled(var1);
   }

   public void setEnabledDefaultHttpsPort(boolean var1) {
      this.httpsPortField.setEnabled(var1);
   }

   public void setEnabledIntervalField(boolean var1) {
      this.intervalField.setEnabled(var1);
   }

   public void setEnabledPortIntervalField(boolean var1) {
      this.portsIntervalField.setEnabled(var1);
   }

   private void enableMonitorComponents(boolean var1) {
      this.preferredMonitorCombo.setEnabled(var1);
      this.md.setEnabled(var1);
   }

   private void populateMonitorCombo(boolean var1) {
      if (var1) {
         this.preferredMonitorCombo.removeAllItems();
      }

      this.graphicsDevices = GraphicsEnvironment.getLocalGraphicsEnvironment().getScreenDevices();
      this.monitorCount = this.graphicsDevices.length;
      this.mdm = new MonitorDisplayer.DefaultMonitorDisplayerModel(this.graphicsDevices, 0);
      this.md.setModel(this.mdm);
      List var2 = this.mdm.getGraphicsDevices();
      Object var3 = null;
      String var4 = this.appPrefs.getMonitorSetting();
      int var5 = -1;
      int var6 = 0;
      if (var4 != null) {
         for (GraphicsDevice var8 : var2) {
            var6++;
            if (var8.getIDstring().equals(var4)) {
               var5 = var6 - 1;
               break;
            }
         }
      }

      if (!((RRCScreenContext)this.scrContext).isMonitorCountMatch() && (var4 != null || this.appPrefs.getMonitorCount() >= 0)) {
         if (var4 != null) {
            var3 = new OptionsPanel.MonitorData[var2.size() + 1];
            ((Object[])var3)[0] = new OptionsPanel.MonitorData(null, -1, "");
            this.preferredMonitorCombo.addItem(((Object[])var3)[0]);
            int var13 = 1;

            for (GraphicsDevice var16 : var2) {
               ((Object[])var3)[var13] = new OptionsPanel.MonitorData(var16, var13, MonitorDisplayer.getDisplayAlphabet(var13 - 1));
               this.preferredMonitorCombo.addItem(((Object[])var3)[var13]);
               var13++;
            }

            this.preferredMonitorCombo.setSelectedIndex(0);
         }
      } else {
         var3 = new OptionsPanel.MonitorData[var2.size()];
         int var12 = 0;

         for (GraphicsDevice var9 : var2) {
            ((Object[])var3)[var12] = new OptionsPanel.MonitorData(var9, var12 + 1, MonitorDisplayer.getDisplayAlphabet(var12));
            this.preferredMonitorCombo.addItem(((Object[])var3)[var12]);
            var12++;
         }

         if (var4 != null) {
            this.preferredMonitorCombo.setSelectedIndex(var5);
         }

         if (this.preferredMonitorCombo.getSelectedIndex() >= 0) {
            this.mdm.setSelectedDevice(this.preferredMonitorCombo.getSelectedIndex());
            this.md.updateUI();
         }
      }
   }

   private class MonitorData {
      private GraphicsDevice monitor;
      private int monitorNumber;
      private String displayName;

      public MonitorData(GraphicsDevice var2, int var3, String var4) {
         this.monitor = var2;
         this.monitorNumber = var3;
         this.displayName = var4;
      }

      public GraphicsDevice getMonitor() {
         return this.monitor;
      }

      @Override
      public String toString() {
         return this.monitorNumber < 0 ? "Number of Detected Monitors Have Changed" : "Monitor " + this.displayName;
      }
   }
}
