package com.raritan.rrc.ui.panes;

import amp.powerboard.swing.AmpApp;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.PowerPort;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.applet.EmbedAppletClassLoader;
import com.raritan.rrc.ui.applet.EmbedAppletDataHolder;
import com.raritan.rrc.ui.applet.EmbedAppletStub;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.util.Util;
import java.awt.CardLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import javaclientlib.clientlib.ISerialStream;
import javaclientlib.clientlib.TRSerialStream;
import javaclientlib.utils.RRCLogger;
import javax.swing.JApplet;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;

public class PowerPortView extends DeviceViewAdapter {
   private static final long serialVersionUID = 4778443664182470436L;
   private Device dev = null;
   private ScreenContext scrContext = null;
   private EmbedAppletDataHolder holder = null;
   private boolean loaded = false;
   private Class claz = null;
   private PowerPortView.HtmlPortThread thread;
   private PowerPort powerPort;
   private AmpApp applet;
   private EmbedAppletClassLoader classLoader;
   private EmbedAppletStub stub;
   protected RaritanPropertyResourceBundle bundle;
   private static final String LOADING_CARD = "loadingCard";
   private static final String APPLET_CARD = "appletCard";
   private JPanel loadingPanel = null;
   private JPanel appletPanel = null;
   private Method setSerialStreamMethod;
   private Method setDataBytesMethod;
   private JProgressBar progress;

   public PowerPortView(boolean var1, ScreenContext var2) {
      super((RRCScreenContext)var2);
      this.scrContext = var2;
      this.isNewPanel = true;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.powerPort = (PowerPort)((ArrayList)((RRCScreenContext)var2).getSelectedDevicesObservable().getComponent()).get(0);
      this.makeLayout();
   }

   @Override
   public void makeLayout() {
      this.setLayout(new CardLayout());
      this.loadingPanel = new JPanel();
      this.loadingPanel.setLayout(new GridBagLayout());
      this.progress = new JProgressBar(0, 500);
      this.progress.setIndeterminate(true);
      this.loadingPanel
         .add(new JLabel(this.bundle.getString("powerBoardLoading.message")), new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
      this.loadingPanel.add(this.progress, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
      this.appletPanel = new JPanel();
      this.add("loadingCard", this.loadingPanel);
      RaritanDesktopPane var1 = (RaritanDesktopPane)((RRCScreenContext)this.scrContext).getPanelMediator().getParent();
      this.setSize(var1.getSize());
      this.setFocusable(true);
      this.powerPort.setView(this);
   }

   public void loadApplet(String var1) {
      if (var1 != null && !var1.equals("")) {
         try {
            this.loaded = false;
            URL var2 = new URL(var1);
            this.holder = new EmbedAppletDataHolder();
            this.stub = new EmbedAppletStub((RRCScreenContext)this.scrContext, this.holder, var2);
            this.stub.setParameter("Platform", "JavaRRC");
            this.classLoader = new EmbedAppletClassLoader(new URL[]{var2}, this.getClass().getClassLoader());
            String var3 = "amp.powerboard.swing.AmpApp";
            this.claz = this.classLoader.loadClass(var3);

            try {
               this.setSerialStreamMethod = this.claz.getMethod("setSerialStream", ISerialStream.class);
            } catch (SecurityException var5) {
               RRCLogger.logException(var5);
            } catch (NoSuchMethodException var6) {
               RRCLogger.logException(var6);
            }

            this.applet = new AmpApp();
            this.setSerialStream((TRSerialStream)this.powerPort.getStream());
            this.applet.setSize((int)this.getSize().getHeight() - 20, (int)this.getSize().getWidth() - 20);
            this.applet.setStub(this.stub);
            this.applet.init();
            this.applet.start();
            this.applet.validate();
            this.loaded = true;
            this.appletPanel = new JPanel();
            this.appletPanel.setLayout(new GridBagLayout());
            GridBagConstraints var4 = new GridBagConstraints();
            var4.fill = 1;
            var4.gridx = 0;
            var4.gridy = 0;
            var4.weightx = 1.0;
            var4.weighty = 1.0;
            this.appletPanel.add(this.applet.getRootPane(), var4);
            this.add("appletCard", new JScrollPane(this.appletPanel));
            ((CardLayout)this.getLayout()).show(this, "appletCard");
            ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel(this.bundle.getString("powerBoardLoaded.message"));
         } catch (ClassCastException var7) {
         } catch (MalformedURLException var8) {
         } catch (ClassNotFoundException var9) {
         }
      }
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.dev = (Device)var1.getCommandParameter("selectedPortDevice");
      if (this.dev != null) {
         ((CardLayout)this.getLayout()).show(this, "loadingCard");
         this.thread = new PowerPortView.HtmlPortThread(this);
         this.thread.start();
      }
   }

   @Override
   public void feedCommandContext(CommandContext var1) {
      this.stub = null;
      this.classLoader = null;
      this.claz = null;
      this.holder = null;
      if (this.applet != null && this.applet.isVisible()) {
         this.applet.setStub(null);
         this.applet.stop();
         this.applet.destroy();
         this.applet = null;
      }

      this.thread = null;
   }

   public JApplet getApplet() {
      return this.applet;
   }

   public synchronized void serialIn(int var1, byte[] var2) {
      while (!this.loaded) {
      }

      try {
         Object[] var3 = new Object[]{var2};
         if (this.setDataBytesMethod == null) {
            this.setDataBytesMethod = this.claz.getMethod("setDataBytes", var2.getClass());
         }

         this.setDataBytesMethod.invoke(this.applet, var3);
      } catch (InvocationTargetException var4) {
      } catch (IllegalAccessException var5) {
      } catch (NoSuchMethodException var6) {
      }

      this.appletPanel.revalidate();
      this.revalidate();
   }

   public void setSerialStream(TRSerialStream var1) {
      try {
         this.setSerialStreamMethod.invoke(this.applet, var1);
      } catch (InvocationTargetException var3) {
      } catch (IllegalAccessException var4) {
      }
   }

   @Override
   public boolean hasFocus() {
      return this.getShellInternalFrame() != null && this.getShellInternalFrame().isSelected();
   }

   private class HtmlPortThread extends Thread {
      private PowerPortView view;

      public HtmlPortThread(PowerPortView var2) {
         this.setName("PowerPortThread");
         this.view = var2;
      }

      @Override
      public void run() {
         if (this.view != null) {
            DeviceConnector var1 = PowerPortView.this.dev.getDeviceConnector();
            PowerPortView.this.loadApplet(new String("http://" + Util.getURLCompatibleIP(var1.getInetAddress()) + "/AmpPb.jar").trim());
         }
      }
   }
}
