package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.RRCRFPClient;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoRestartDeviceCommand;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.Shell;
import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import javaclientlib.clientlib.TRConnection;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SpringLayout;
import javax.swing.Timer;
import nn.pp.common.ResourceLoader;

public class ProgressPanel extends AbstractDisplay implements ActionListener {
   private static final long serialVersionUID = 71167421089815208L;
   private File file;
   private ProgressPanel.DoUpdateDeviceConfigThread myDoUpdateDeviceConfigThread = null;
   private ProgressPanel.DoRecieveRFPThread doRecieveRFPThread = null;
   private boolean isKX = true;
   private JLabel messageLabel = null;
   private JLabel timerLabel = new JLabel(" ");
   private int timerDuration = 0;
   private long startTime = System.currentTimeMillis();
   private Timer progressTimer = new Timer(1000, null);
   private static SimpleDateFormat df = new SimpleDateFormat("m:ss");

   public ProgressPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
      this.setShell(this.bundle.getString("configuration.title"));
      Shell var3 = this.getShell();
      var3.setModal(true);
      var3.setBlockingDialog(true);
      var3.setCentered();
      var3.setClosable(false);
   }

   public String getMessageLabelText() {
      int var1 = this.timerDuration / 60000;
      StringBuffer var2 = new StringBuffer("<html>");
      var2.append(this.bundle.getString("doNotTurnPowerOff.message.1") + "<br>");
      if (var1 > 0) {
         var2.append(this.bundle.getString("doNotTurnPowerOff.message.kxonly") + " ");
         var2.append(var1 + " " + this.bundle.getString("generic.dialog.minute" + (var1 == 1 ? "" : "s") + ".text") + ".");
      }

      var2.append("<br><br>" + this.bundle.getString("doNotTurnPowerOff.message.2") + "</html>");
      return var2.toString();
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      if (var1.getSource() == this.progressTimer) {
         long var2 = this.startTime + this.timerDuration - System.currentTimeMillis();
         if (var2 < 1000L) {
            this.progressTimer.stop();
            this.timerLabel.setText(this.bundle.getString("doNotTurnPowerOff.message.withtimer") + " 0:00");
         } else {
            this.timerLabel.setText(this.bundle.getString("doNotTurnPowerOff.message.withtimer") + " " + df.format(new Date(var2)));
         }
      }
   }

   public void setTimerDuration(int var1) {
      this.timerDuration = var1 * 60 * 1000;
      if (this.timerDuration < 0) {
         this.timerDuration = 0;
      }
   }

   @Override
   public void makeLayout() {
      this.setLayout(new BorderLayout());
      JPanel var1 = new JPanel(new SpringLayout());
      var1.setBorder(
         BorderFactory.createCompoundBorder(
            BorderFactory.createEmptyBorder(10, 10, 10, 10),
            BorderFactory.createTitledBorder(this.bundle.getString("confirmation.dialog.showupdatedevicecommand.execution.label"))
         )
      );
      var1.add(new JLabel(ResourceLoader.loadImageIcon(this.bundle.getString("info.image"))));
      this.messageLabel = new JLabel(this.getMessageLabelText());
      var1.add(this.messageLabel);
      SpringUtilities.makeCompactGrid(var1, 1, 2, 15, 15, 15, 15);
      this.add(var1, "Center");
      this.timerLabel.setHorizontalAlignment(0);
      this.add(this.timerLabel, "Last");
      this.progressTimer.addActionListener(this);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.file = (File)var1.getCommandParameter("selectedFile");
      RRCRFPClient var2 = RRCRFPClient.getInstance();
      var2.setScreenContext(this.scrContext);
      DeviceConnector var3 = (DeviceConnector)var2.getTRConnection();
      if (var3.getDevice().getHandler().isRFPRecieveThreadNeeded()) {
         this.doRecieveRFPThread = new ProgressPanel.DoRecieveRFPThread();
         this.doRecieveRFPThread.start();
      }

      if (this.myDoUpdateDeviceConfigThread == null) {
         this.myDoUpdateDeviceConfigThread = new ProgressPanel.DoUpdateDeviceConfigThread();
         this.myDoUpdateDeviceConfigThread.start();
         this.getShell().setVisible(true);
      }
   }

   @Override
   public void feedCommandContext(CommandContext var1) {
   }

   public void stopThread() {
      try {
         if (this.doRecieveRFPThread != null) {
            this.doRecieveRFPThread.interrupt();
            this.doRecieveRFPThread = null;
         }

         this.myDoUpdateDeviceConfigThread = null;
         if (this.progressTimer.isRunning()) {
            this.progressTimer.stop();
         }

         this.getShell().setVisible(false);
      } catch (Exception var2) {
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var2);
         }
      }
   }

   public JLabel getMessageLabel() {
      return this.messageLabel;
   }

   public void setMessageLabel(JLabel var1) {
      this.messageLabel = var1;
   }

   public int getTimerDuration() {
      return this.timerDuration;
   }

   public long getStartTime() {
      return this.startTime;
   }

   public void setStartTime(long var1) {
      this.startTime = var1;
   }

   public Timer getProgressTimer() {
      return this.progressTimer;
   }

   public void setProgressTimer(Timer var1) {
      this.progressTimer = var1;
   }

   public boolean isKX() {
      return this.isKX;
   }

   public void setKX(boolean var1) {
      this.isKX = var1;
   }

   private class DoRecieveRFPThread extends Thread {
      protected DoRecieveRFPThread() {
         super("DoRecieveRFPThread");
      }

      @Override
      public void run() {
         DeviceConnector var1 = null;
         ProgressPanel.this.scrContext.getLogger().logStatus(ProgressPanel.this.bundle.getString("info.do.updatedevice"));
         RRCRFPClient var2 = RRCRFPClient.getInstance();
         var2.setScreenContext(ProgressPanel.this.scrContext);
         var2.setShowProgress(true);
         var1 = (DeviceConnector)var2.getTRConnection();
         var1.setUpdateActive(true);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 64, "DoRecieveRFP thread waiting...");
         }

         synchronized (RRCRFPClient.mutex) {
            try {
               RRCRFPClient.mutex.wait();
            } catch (InterruptedException var6) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.logException(var6);
               }

               return;
            }
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 64, "DoRecieveRFP thread awake...");
         }

         var1.readRFPResponseMessage();
      }
   }

   private class DoUpdateDeviceConfigThread extends Thread {
      protected DoUpdateDeviceConfigThread() {
         super("DoUpdateDeviceConfigThread");
      }

      @Override
      public void run() {
         ArrayList var1 = (ArrayList)((RRCScreenContext)ProgressPanel.this.scrContext).getSelectedDevicesObservable().getComponent();
         Device var2 = (Device)var1.get(0);
         ProgressPanel.this.scrContext.getLogger().logStatus(ProgressPanel.this.bundle.getString("info.do.updatedevice"));
         RRCRFPClient var3 = RRCRFPClient.getInstance();
         var3.setScreenContext(ProgressPanel.this.scrContext);
         var3.setShowProgress(false);
         var2.getDeviceConnector().setUpdateActive(true);

         try {
            ProgressPanel.this.setKX(var2.isModelKX());
            if (!ProgressPanel.this.file.exists()) {
               String var12 = ProgressPanel.this.bundle.getString("tr.error.file.not.found") + ":\n" + ProgressPanel.this.file.getPath();
               CommonPopups.showInfoDialog("", var12, null, ProgressPanel.this.scrContext);
               return;
            }

            ProgressPanel.this.setTimerDuration(var2.getUpgradeDuration());
            ProgressPanel.this.getMessageLabel().setText(ProgressPanel.this.getMessageLabelText());
            if (ProgressPanel.this.getTimerDuration() > 0) {
               ProgressPanel.this.setStartTime(System.currentTimeMillis());
               ProgressPanel.this.getProgressTimer().start();
            }

            var3.createRFPConnection();
            boolean var4 = var3.send(ProgressPanel.this.file.getPath(), 0, ProgressPanel.this.isKX());
            ProgressPanel.this.getShell().setVisible(false);
            var2.getDeviceConnector().setUpdateActive(false);
            if (var4) {
               if (var2.isConnected()) {
                  if (var3.getNeedAutoReboot()) {
                     var2.getHandler().waitBeforeAutoReboot();
                     var2.disconnect();
                     CommonPopups.showInfoDialog(
                        ProgressPanel.this.bundle.getString("confirmation.dialog.do.restartdevice.title"),
                        ProgressPanel.this.bundle.getString("success.do.updatedevice.autorestart.confirmation"),
                        null,
                        ProgressPanel.this.scrContext
                     );
                  } else {
                     int var13 = CommonPopups.showConfirmationDialog(
                        ProgressPanel.this.bundle.getString("confirmation.dialog.do.restartdevice.title"),
                        ProgressPanel.this.bundle.getString("success.do.updatedevice.confirmation"),
                        null,
                        ProgressPanel.this.scrContext
                     );
                     if (var13 == 2) {
                        DoRestartDeviceCommand var6 = new DoRestartDeviceCommand(ProgressPanel.this.scrContext);
                        var6.getContext().setCommandParameter("devices", var2);
                        var6.execute();
                     }
                  }
               }

               CommonPopups.showInfoDialog(
                  ProgressPanel.this.bundle.getString("confirmation.dialog.do.restartdevice.title"),
                  ProgressPanel.this.bundle.getString("success.do.updatedevice"),
                  null,
                  ProgressPanel.this.scrContext
               );
               ProgressPanel.this.scrContext.getLogger().logStatus(ProgressPanel.this.bundle.getString("success.do.updatedevice"));
               ((RRCStatusBar)ProgressPanel.this.scrContext.getPanelMediator().getStatusPanel())
                  .setTextLabel(ProgressPanel.this.bundle.getString("success.do.updatedevice"));
               return;
            }

            var3.closeRFPConnection();
            String var5 = var3.showError(TRConnection.getLastError()) + ProgressPanel.this.bundle.getString("error.do.updatedevice.notupdated");
            CommonPopups.showInfoDialog(ProgressPanel.this.bundle.getString("error.do.updatedevice.title"), var5, null, ProgressPanel.this.scrContext);
            ProgressPanel.this.scrContext.getLogger().logStatus(ProgressPanel.this.bundle.getString("error.do.updatedevice"));
            ProgressPanel.this.scrContext
               .getLogger()
               .logTextInfo("[" + var2.getNameIP() + "]: " + ProgressPanel.this.bundle.getString("error.do.updatedevice"));
         } catch (Exception var10) {
            RRCLogger.logException(var10);
            ProgressPanel.this.getShell().setVisible(false);
            ProgressPanel.this.getShell().dispose();
            CommonPopups.showCommandResultErrorMessage(ProgressPanel.this.bundle.getString("error.do.updatedevice"), null, ProgressPanel.this.scrContext);
            ProgressPanel.this.scrContext.getLogger().logStatus(ProgressPanel.this.bundle.getString("error.ioexception.updatedevice") + var10.getMessage());
            return;
         } finally {
            if (var2.getDeviceConnector() != null) {
               var2.getDeviceConnector().setPingDevice(true);
               var2.getDeviceConnector().setUpdateActive(false);
            }

            ProgressPanel.this.stopThread();
         }
      }
   }
}
