package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.ui.commands.DoModifyConnectionPropertiesCommand;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import javaclientlib.tr.TRSRVR_COMP_PARAMS;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

public class PropertiesPanel extends AbstractDisplay {
   private static final long serialVersionUID = -7174472063575603330L;
   private CompressionPanel compressionPanel;
   private JTabbedPane addConnectionTabbedPane;
   private IPReach dev;

   public PropertiesPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
      this.setShell(this.bundle.getString("PropertiesDialog.title"));
   }

   @Override
   public void makeLayout() {
      RaritanPropertyResourceBundle var1 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.setLayout(new BoxLayout(this, 3));
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      this.addConnectionTabbedPane = new JTabbedPane();
      this.compressionPanel = new CompressionPanel(false, this.scrContext);
      String var2 = var1.getString("CompressionTab.name");
      this.addConnectionTabbedPane.add(var2, this.compressionPanel);
      this.add(this.addConnectionTabbedPane, "Center");
      this.add(this.doButtonWidget(), "Last");
      this.ok.setCommand(new DoModifyConnectionPropertiesCommand(this.scrContext));
      this.apply.setCommand(new DoModifyConnectionPropertiesCommand(this.scrContext));
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      var1.setCommandParameter("deviceNode", this.dev);
      TRSRVR_COMP_PARAMS var2 = this.compressionPanel.getCompParams();
      var1.setCommandParameter("compParams", var2);
      int var3 = this.compressionPanel.getFramesPerSecond();
      var1.setCommandParameter("framesPerSecond", new Integer(var3));
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.dev = (IPReach)var1.getCommandParameter("deviceNode");
      TRSRVR_COMP_PARAMS var2 = (TRSRVR_COMP_PARAMS)var1.getCommandParameter("compParams");
      this.compressionPanel.setCompParams(var2);
      this.compressionPanel.setDefaultFocussedComponent();
      this.apply.setEnabled(false);
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      this.apply = new CommandButton(this.bundle.getString("OptionDialog.applyLabel"), this.scrContext);
      this.apply.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      var1.add(this.apply);
      return var1;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      this.scrContext.getLogger().logTextDebug("started");
      if (var2 instanceof JComboBox) {
         this.apply.setEnabled(true);
      } else {
         this.apply.setEnabled(false);
      }

      this.scrContext.getLogger().logTextDebug("finished");
   }

   public void setApplyButton(boolean var1) {
      this.apply.setEnabled(var1);
   }

   public void setEnabledConnSpeedComboBox(boolean var1) {
      this.compressionPanel.setEnabledConnSpeedComboBox(var1);
   }

   public void setEnabledProgressiveUpdateChkBox(boolean var1) {
      this.compressionPanel.setEnabledProgressiveUpdateChkBox(var1);
   }

   public void setEnabledColorDepthChkBox(boolean var1) {
      this.compressionPanel.setEnabledColorDepthChkBox(var1);
   }

   public void setEnabledInternetFlowControlChkBox(boolean var1) {
      this.compressionPanel.setEnabledInternetFlowControlChkBox(var1);
   }

   public void setEnabledSmoothingSlider(boolean var1) {
      this.compressionPanel.setEnabledSmoothingSlider(var1);
   }
}
