package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoAbsoluteMouseCommand;
import com.raritan.rrc.ui.commands.DoIntelligentMouseCommand;
import com.raritan.rrc.ui.commands.DoModifyConnectionPropertiesCommand;
import com.raritan.rrc.ui.commands.DoStandardMouseCommand;
import com.raritan.rrc.ui.commands.DoVideoSettingsCommand;
import com.raritan.rrc.ui.commands.MouseMenuCommand;
import com.raritan.rrc.ui.commands.ShowConnectionInfoCommand;
import com.raritan.rrc.ui.commands.ShowVideoSettingsCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaImagePanelCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaLocalPanelCommand;
import com.raritan.rrc.ui.commands.VirtualMediaMenuCommand;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import java.io.IOException;
import java.net.InetAddress;
import java.util.HashMap;
import javaclientlib.tr.TRSRVR_VIDEO_PARAMS;
import javaclientlib.utils.RRCLogger;
import nn.pp.rccore.RCCore;

public class RFBViewCommandHandler extends DefaultCommandHandler {
   public static RFBViewCommandHandler rFBViewCommandHandler = new RFBViewCommandHandler();

   @Override
   public void handleCommand(DoAbsoluteMouseCommand var1, ScreenContext var2) {
      RFBView var3 = (RFBView)this.getCurrentView(var2);
      if (var3 != null) {
         var3.setMouseAbsolute();
         ((RRCScreenContext)var2).getMainScreenMediator().selectAbsoluteMouseModeView(true);
      } else {
         RRCLogger.log(100, 1, "Unable to handle DoAbsoluteMouseCommand, view is null");
      }
   }

   @Override
   public void handleCommand(DoIntelligentMouseCommand var1, ScreenContext var2) {
      RFBView var3 = (RFBView)this.getCurrentView(var2);
      if (var3 != null) {
         var3.setMouseIntelligent();
         ((RRCScreenContext)var2).getMainScreenMediator().selectIntelligentMouseModeView(true);
      } else {
         RRCLogger.log(100, 1, "Unable to handle DoIntelligentMouseCommand, view is null");
      }
   }

   @Override
   public void handleCommand(DoStandardMouseCommand var1, ScreenContext var2) {
      RFBView var3 = (RFBView)this.getCurrentView(var2);
      if (var3 != null) {
         var3.setMouseStandard();
         ((RRCScreenContext)var2).getMainScreenMediator().selectStandardMouseModeView(true);
      } else {
         RRCLogger.log(100, 1, "Unable to handle DoStandardMouseCommand, view is null");
      }
   }

   @Override
   public void handleCommand(MouseMenuCommand var1, ScreenContext var2) {
      var2.getLogger().logTextDebug(" Started ");
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 1, "Yet to be implemented.");
      }

      var2.getLogger().logTextDebug(" Finished ");
   }

   @Override
   public void handleCommand(VirtualMediaMenuCommand var1, ScreenContext var2) {
      var2.getLogger().logTextDebug(" Started ");
      var2.getLogger().logTextDebug(" Finished ");
   }

   @Override
   public void handleCommand(DoModifyConnectionPropertiesCommand var1, ScreenContext var2) {
      Port var3 = ((RRCScreenContext)var2).getSelectedPort();
      DevicePreferences var4 = null;
      CommandContext var5 = var1.getContext();
      if (var3 != null) {
         Device var6 = (Device)var5.getCommandParameter("deviceNode");
         var4 = var6.getDevPrefs();
         if (var4 == null) {
            var4 = new DevicePreferences();
            var6.setDevPrefs(var4);
            DeviceConnector var7 = var6.getDeviceConnector();
            String var8 = var7.getInetAddress().getHostAddress();
            var6.getDevPrefs().setIp(var8);
         }

         RFBView var16 = (RFBView)((KvmPort)var3).getView();
         RCCore.Compression var17 = (RCCore.Compression)var5.getCommandParameter("g2Compression");
         RCCore.ColorDepth var9 = (RCCore.ColorDepth)var5.getCommandParameter("g2ColorDepth");
         RCCore.Smoothing var10 = (RCCore.Smoothing)var5.getCommandParameter("g2Smoothing");
         var4.setG2ColorDepth(var9);
         var4.setG2ConnectionSpeed(var17);
         var4.setG2Smoothing(var10);
         var16.setCurrentColorDepth(var9);
         var16.setCurrentCompression(var17);
         var16.setCurrentSmoothing(var10);
         RCCore var11 = var16.getRCCore();
         var11.setSmoothing(var10);

         try {
            if (var17 == null && var11.isEncodingAutoSupported()) {
               var11.setEncodingToAuto();
               var16.setAutoSelected(true);
            } else {
               var11.setEncodingCompression(var17, true);
               var11.setEncodingColorDepth(var9, true);
               var16.setAutoSelected(false);
            }
         } catch (IOException var14) {
            RRCLogger.log(150, "IO Exception trying to set color depth and connection speed.", var14);
         }

         if (var6.isProfiled()) {
            var4.exportPreferences(var4.getNodeName());
         } else {
            DeviceConnector var12 = var6.getDeviceConnector();
            String var13 = var12.getInetAddress().getHostAddress();
            var4.exportPreferences(var13);
         }
      }
   }

   @Override
   public void handleCommand(ShowConnectionInfoCommand var1, ScreenContext var2) {
      CommandContext var3 = var1.getContext();
      Port var4 = ((RRCScreenContext)var2).getSelectedPort();
      RFBView var5 = null;
      DeviceView var6 = var4.getView();
      if (var6 != null) {
         var5 = (RFBView)var6;
         var5.requestVideoSettings();

         try {
            Thread.sleep(1000L);
         } catch (InterruptedException var13) {
            RRCLogger.logException(var13);
         }

         IPReach var7 = (IPReach)var3.getCommandParameter("deviceNode");
         HashMap var8 = new HashMap();
         String var9 = "";
         Device var10 = var4.getDevice();
         if (var10 != null) {
            DeviceConnector var11 = var10.getDeviceConnector();
            if (var11 != null) {
               InetAddress var12 = var11.getInetAddress();
               if (var12 != null) {
                  var9 = var12.getHostAddress();
               }
            }
         }

         var8.put("DESCRIPTION", var10.getName());
         var8.put("IP", var9);
         if (var5.getProfile() != null) {
            var8.put("PORT", new Integer(var5.getProfile().primaryPort));
         }

         if (var5.getRCCore() != null) {
            var8.put("PROTO_VER", var5.getRCCore().getProtocolVersion());
         } else if (var5.getProfile() != null) {
            var8.put("PROTO_VER", var5.getProfile().protocol_version == null ? "" : var5.getProfile().protocol_version);
         } else {
            RRCLogger.log(300, 1, "Unable to get protocol version");
         }

         var3.setCommandParameter("STATIC_CONN_INFO", var8);
         var3.setCommandParameter("DEVICE_VIEW", var6);
      } else {
         RRCLogger.log(100, 4, "view is null for ShowConnectionInfoCommand in KVMViewHandler");
      }
   }

   @Override
   public void handleCommand(DoVideoSettingsCommand var1, ScreenContext var2) {
      Port var3 = ((RRCScreenContext)var2).getSelectedPort();
      RFBView var4 = (RFBView)var3.getView();
      if (var4 != null) {
         var4.saveVideoSettings();
      }
   }

   @Override
   public void handleCommand(ShowVideoSettingsCommand var1, ScreenContext var2) {
      Port var3 = ((RRCScreenContext)var2).getSelectedPort();
      RFBView var4 = (RFBView)var3.getView();
      if (var4 != null) {
         var1.getContext().setCommandParameter("DEVICE_VIEW", var4);
         if (var3.isConnected()) {
            TRSRVR_VIDEO_PARAMS var5 = new TRSRVR_VIDEO_PARAMS();
            var4.requestVideoSettings();
            var1.getContext().setCommandParameter("videoParams", var5);

            try {
               Thread.sleep(1000L);
            } catch (InterruptedException var7) {
            }
         }
      }
   }

   @Override
   public void handleCommand(ShowVirtualMediaLocalPanelCommand var1, ScreenContext var2) {
      Port var3 = ((RRCScreenContext)var2).getSelectedPort();
      RFBView var4 = (RFBView)var3.getView();
      if (var4 != null) {
         var1.getContext().setCommandParameter("DEVICE_VIEW", var4);
      }
   }

   @Override
   public void handleCommand(ShowVirtualMediaImagePanelCommand var1, ScreenContext var2) {
      Port var3 = ((RRCScreenContext)var2).getSelectedPort();
      RFBView var4 = (RFBView)var3.getView();
      if (var4 != null) {
         var1.getContext().setCommandParameter("DEVICE_VIEW", var4);
      }
   }
}
