package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

public class RestrictedServiceAgreementPane extends JDialog implements ActionListener {
   private static final long serialVersionUID = 2028595561540428645L;
   protected JTextArea textPad = null;
   private JCheckBox acceptRSACheckBox = null;
   private JButton acceptButton = null;
   private JButton declineButton = null;
   private RRCScreenContext scrContext;
   RaritanPropertyResourceBundle bundle;
   private boolean isRSAAccepted = false;
   private Device device = null;
   private String rsaText = "";
   private String rsaTitle = "";

   public RestrictedServiceAgreementPane(Frame var1, Device var2, RRCScreenContext var3, String var4, String var5) {
      super(var1, true);
      this.setAlwaysOnTop(true);
      this.setModal(true);
      this.scrContext = var3;
      this.device = var2;
      this.rsaText = var4;
      this.rsaTitle = var5;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.makeLayout();
   }

   public void makeLayout() {
      this.setSize(450, 400);
      this.setResizable(false);
      this.setTitle(this.rsaTitle);
      this.textPad = new JTextArea(20, 40);
      this.textPad.setFont(new Font("Verdana", 0, 10));
      this.textPad.setEditable(false);
      this.textPad.setCaretPosition(0);
      this.textPad.setWrapStyleWord(true);
      this.textPad.setLineWrap(true);
      this.textPad.setAutoscrolls(true);
      this.textPad.setText(this.rsaText);
      if (this.device.isRSAAcceptance()) {
         this.acceptRSACheckBox = new JCheckBox(this.bundle.getString("RSACheckBox.Message"));
         this.acceptRSACheckBox.addActionListener(this);
      }

      JPanel var1 = new JPanel();
      var1.setLayout(new BorderLayout());
      JScrollPane var2 = new JScrollPane(this.textPad, 20, 30);
      var1.add(var2, "Center");
      this.setLayout(new BorderLayout());
      var1.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      this.add(var1, "Center");
      if (this.device.isRSAAcceptance()) {
         JPanel var3 = new JPanel();
         var3.add(this.acceptRSACheckBox);
         var1.add(var3, "Last");
      }

      this.add(this.doButtonWidget(), "Last");
   }

   public JPanel doButtonWidget() {
      JPanel var1 = new JPanel();
      if (this.device.isRSAAcceptance()) {
         this.declineButton = new JButton(this.bundle.getString("RSADecline.Message"));
         this.declineButton.addActionListener(this);
         this.declineButton.setEnabled(true);
         var1.add(this.declineButton);
      }

      this.acceptButton = new JButton(this.bundle.getString("RSAAccept.Message"));
      this.acceptButton.addActionListener(this);
      if (this.device.isRSAAcceptance() && !this.acceptRSACheckBox.isSelected()) {
         this.acceptButton.setEnabled(false);
      } else {
         this.acceptButton.setEnabled(true);
      }

      var1.add(this.acceptButton);
      return var1;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      if (var1.getSource() == this.acceptButton) {
         this.device.setRSAAccepted(true);
         this.dispose();
      } else if (var1.getSource() == this.declineButton) {
         this.device.setRSAAccepted(false);
         this.dispose();
      } else if (var1.getSource() == this.acceptRSACheckBox) {
         if (this.acceptRSACheckBox.isSelected()) {
            this.acceptButton.setEnabled(true);
         } else {
            this.acceptButton.setEnabled(false);
         }
      }
   }
}
