package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.Container;
import java.awt.Font;
import java.awt.event.FocusEvent;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.Arrays;
import java.util.Locale;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JTextArea;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;

public class SecurityPanel extends AbstractDisplay implements KeyListener {
   private static final long serialVersionUID = 2841688778594685870L;
   protected RaritanPropertyResourceBundle bundle;
   private JPasswordField privateKeyField;
   private JPasswordField confirmPrivateKeyField;
   private String privateKeyValue;
   private byte[] emptyPrivateKeyArr = new byte[23];

   public SecurityPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.makeLayout();
   }

   public void setPrivateKey(byte[] var1) {
      String var2 = "";
      if (var1 != null && !Arrays.equals(var1, this.emptyPrivateKeyArr)) {
         var2 = new String(var1);
      }

      this.privateKeyField.setText(var2);
      this.confirmPrivateKeyField.setText(var2);
      this.privateKeyValue = var2;
   }

   @Override
   public void setDefaultFocussedComponent() {
      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            SecurityPanel.this.privateKeyField.grabFocus();
         }
      });
   }

   public byte[] getPrivateKey() {
      return this.privateKeyValue == null ? null : this.privateKeyValue.getBytes();
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   @Override
   public void makeLayout() {
      Arrays.fill(this.emptyPrivateKeyArr, 0, 23, (byte)0);
      this.setLayout(new SpringLayout());
      JPanel var1 = new JPanel(new SpringLayout());
      JLabel var2 = new JLabel(this.bundle.getString("PrivateKeyLabel.name"), 11);
      var1.add(var2);
      this.privateKeyField = new JPasswordField(23);
      this.privateKeyField.setText("");
      if (Locale.getDefault().getLanguage().equalsIgnoreCase(Locale.ENGLISH.getLanguage())) {
         this.privateKeyField.setFont(new Font("Monospaced", 0, 12));
      }

      this.privateKeyField.setMaximumSize(this.privateKeyField.getPreferredSize());
      this.privateKeyField.addKeyListener(this);
      var1.add(this.privateKeyField);
      var2 = new JLabel(this.bundle.getString("ConfirmPrivateKeyLabel.name"), 11);
      var1.add(var2);
      this.confirmPrivateKeyField = new JPasswordField(23);
      this.confirmPrivateKeyField.setText("");
      if (Locale.getDefault().getLanguage().equalsIgnoreCase(Locale.ENGLISH.getLanguage())) {
         this.confirmPrivateKeyField.setFont(new Font("Monospaced", 0, 12));
      }

      this.confirmPrivateKeyField.setMaximumSize(this.confirmPrivateKeyField.getPreferredSize());
      var1.add(this.confirmPrivateKeyField);
      this.confirmPrivateKeyField.addKeyListener(this);
      SpringUtilities.makeCompactGrid(var1, 2, 2, 6, 10, 6, 10);
      this.add(var1);
      JTextArea var3 = new JTextArea(this.bundle.getString("PrivateKeyHintLabel.name"));
      var3.setLineWrap(true);
      var3.setWrapStyleWord(true);
      var3.setEditable(false);
      var3.setAlignmentX(0.5F);
      var3.setBackground(this.getBackground());
      this.add(var3);
      this.addFocusListener(this);
      SpringUtilities.makeCompactGrid(this, 2, 1, 25, 35, 6, 30);
   }

   public void fillDevicePreferences(DevicePreferences var1) {
      this.clearAllFields();
      if (var1 != null) {
         this.privateKeyField.setText(var1.getKey());
         this.confirmPrivateKeyField.setText(var1.getKey());
      }
   }

   private void clearAllFields() {
      this.privateKeyField.setText("");
      this.confirmPrivateKeyField.setText("");
   }

   public void feedDevicePreferences(DevicePreferences var1) {
      if (var1 != null) {
         var1.setKey(new String(this.privateKeyField.getPassword()));
         var1.setConfirmKey(new String(this.confirmPrivateKeyField.getPassword()));
      }
   }

   @Override
   public void focusGained(FocusEvent var1) {
      this.setDefaultFocussedComponent();
   }

   public void focusLose(FocusEvent var1) {
      this.privateKeyField.removeFocusListener(this);
   }

   private void checkApplyButton() {
      Container var1 = this.getParent().getParent();
      if (var1 instanceof ModifyConnectionPanel) {
         ((ModifyConnectionPanel)var1).setApplyButton(true);
      }
   }

   @Override
   public void keyPressed(KeyEvent var1) {
      this.checkApplyButton();
   }

   @Override
   public void keyReleased(KeyEvent var1) {
   }

   @Override
   public void keyTyped(KeyEvent var1) {
   }
}
