package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoSendTextToTargetCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import nn.pp.common.ui.helpers.IKVMTargetViewer;
import nn.pp.core.T;

public class SendTextToTargetPanel extends AbstractDisplay implements DocumentListener {
   private static final long serialVersionUID = 2028595561540428645L;
   protected static boolean targetUSIntlSelected = false;
   protected JTextArea textPad = null;
   protected JCheckBox targetIsUSIntl = null;
   private JButton clear = null;
   protected int keyboardType = 0;

   public SendTextToTargetPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.makeLayout();
      this.setShell(
         this instanceof MacroTextInterpreterPanel
            ? this.bundle.getString("CreateAMacroFromTextDialog.title")
            : this.bundle.getString("SendTextToTargetDialog.title")
      );
   }

   @Override
   public void makeLayout() {
      this.textPad = new JTextArea(20, 70);
      this.textPad.setLineWrap(true);
      this.textPad.setFont(new Font("Courier", 0, 18));
      this.textPad.setWrapStyleWord(true);
      this.textPad.setEditable(true);
      this.textPad.setCaretPosition(0);
      this.targetIsUSIntl = new JCheckBox(T._("Target system is set to the US/International keyboard layout"));
      this.targetIsUSIntl.setSelected(targetUSIntlSelected);
      JPanel var1 = new JPanel();
      var1.setLayout(new BorderLayout());
      Port var2 = ((RRCScreenContext)this.scrContext).getSelectedPort();
      if (var2 != null) {
         IKVMTargetViewer var3 = (IKVMTargetViewer)var2.getView();
         if (var3 != null) {
            this.keyboardType = var3.getKeyboardType();
            if (this.keyboardType == 0) {
               JPanel var4 = new JPanel();
               var4.add(this.targetIsUSIntl);
               var1.add(var4, "Last");
            }
         }
      }

      JScrollPane var5 = new JScrollPane(this.textPad, 20, 30);
      var1.add(var5, "Center");
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      this.add(var1, "Center");
      this.add(this.doButtonWidget(), "Last");
   }

   @Override
   public JPanel doButtonWidget() {
      JPanel var1 = super.doButtonWidget();
      this.ok.setCommand(new DoSendTextToTargetCommand(this.scrContext));
      this.clear = new JButton(this.bundle.getString("Clear.button"));
      this.clear.addActionListener(this);
      this.clear.setEnabled(false);
      var1.add(this.clear);
      this.textPad.getDocument().addDocumentListener(this);
      return var1;
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      targetUSIntlSelected = this.targetIsUSIntl.isSelected();
      var1.setCommandParameter("sendTextToTarget", this.textPad.getText());
      var1.setCommandParameter("sendTextToTargetLanguageSelection", targetUSIntlSelected && this.keyboardType == 0 ? 255 : this.keyboardType);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.removeAll();
      this.makeLayout();
      this.getShell().pack();
      this.textPad.setText("");
      this.textPad.requestFocusInWindow();
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      if (var1.getSource() == this.clear) {
         this.clear.setEnabled(false);
         this.textPad.setText("");
      } else {
         super.actionPerformed(var1);
      }
   }

   @Override
   public void changedUpdate(DocumentEvent var1) {
   }

   @Override
   public void insertUpdate(DocumentEvent var1) {
      this.clear.setEnabled(true);
   }

   @Override
   public void removeUpdate(DocumentEvent var1) {
      this.clear.setEnabled(this.textPad.getText().length() > 0);
   }
}
