package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.commands.DoSerialSettingsCommand;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.SpringLayout;

public class SerialSettingsPanel extends AbstractDisplay {
   private static final long serialVersionUID = -4073121172563573173L;
   private static final int HALF_BRIGHT = 1;
   private static final int FULL_BRIGHT = 0;
   protected RaritanPropertyResourceBundle bundle;
   private JRadioButton asciiRadioButton;
   private JRadioButton iso1RadioButton;
   private JRadioButton iso15RadioButton;
   private JRadioButton lineCursorRadioButton;
   private JRadioButton blockCursorRadioButton;

   public SerialSettingsPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.makeLayout();
      this.setShell(this.bundle.getString("SettingsDialog.title"));
      this.ok.setCommand(new DoSerialSettingsCommand(this.scrContext));
   }

   @Override
   public void makeLayout() {
      this.setLayout(new BorderLayout());
      JPanel var1 = new JPanel(new SpringLayout());
      JLabel var2 = new JLabel("<html><b>" + this.bundle.getString("CodeSetPanel.name") + "</b></html>");
      var1.add(var2);
      JPanel var3 = new JPanel(new GridLayout(3, 1));
      ButtonGroup var4 = new ButtonGroup();
      this.asciiRadioButton = new JRadioButton();
      this.asciiRadioButton.setText(this.bundle.getString("USAsciiCodeSetRadioButton.name"));
      this.asciiRadioButton.setSelected(true);
      var4.add(this.asciiRadioButton);
      var3.add(this.asciiRadioButton);
      this.iso1RadioButton = new JRadioButton();
      this.iso1RadioButton.setText(this.bundle.getString("IS088591RadioButton.name"));
      var4.add(this.iso1RadioButton);
      var3.add(this.iso1RadioButton);
      this.iso15RadioButton = new JRadioButton();
      this.iso15RadioButton.setText(this.bundle.getString("IS0885915RadioButton.name"));
      var4.add(this.iso15RadioButton);
      var3.add(this.iso15RadioButton);
      var2 = new JLabel("<html><b>" + this.bundle.getString("CursorTypePanel.name") + "</b></html>");
      var1.add(var2);
      JPanel var5 = new JPanel(new GridLayout(3, 1));
      var4 = new ButtonGroup();
      this.lineCursorRadioButton = new JRadioButton();
      this.lineCursorRadioButton.setText(this.bundle.getString("LineCursorRadioButton.name"));
      this.lineCursorRadioButton.setSelected(true);
      var4.add(this.lineCursorRadioButton);
      var5.add(this.lineCursorRadioButton);
      this.blockCursorRadioButton = new JRadioButton();
      this.blockCursorRadioButton.setText(this.bundle.getString("BlockCursorRadioButton.name"));
      var4.add(this.blockCursorRadioButton);
      var5.add(this.blockCursorRadioButton);
      var1.add(var3);
      var1.add(var5);
      SpringUtilities.makeCompactGrid(var1, 2, 2, 15, 15, 35, 10);
      this.add(var1, "First");
      this.add(this.doButtonWidget(), "Last");
   }

   @Override
   public void fillComponents(CommandContext var1) {
      String var2 = (String)var1.getCommandParameter("codeSet");
      if (var2 == null || var2.equals("US ASCII (True VT100)")) {
         this.asciiRadioButton.setSelected(true);
      } else if (var2.equals("ISO 8859-1 (Latin-1)")) {
         this.iso1RadioButton.setSelected(true);
      } else {
         this.iso15RadioButton.setSelected(true);
      }

      String var3 = (String)var1.getCommandParameter("cursorType");
      int var4 = Integer.parseInt(var3);
      if (var4 == 0) {
         this.blockCursorRadioButton.setSelected(true);
      } else {
         this.lineCursorRadioButton.setSelected(true);
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      if (this.asciiRadioButton.isSelected()) {
         var1.setCommandParameter("codeSet", "US ASCII (True VT100)");
      } else if (this.iso1RadioButton.isSelected()) {
         var1.setCommandParameter("codeSet", "ISO 8859-1 (Latin-1)");
      } else {
         var1.setCommandParameter("codeSet", "ISO 8859-15 (Latin-9)");
      }

      if (this.blockCursorRadioButton.isSelected()) {
         var1.setCommandParameter("cursorType", String.valueOf(0));
      } else {
         var1.setCommandParameter("cursorType", String.valueOf(1));
      }
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      return var1;
   }
}
