package com.raritan.rrc.ui.panes;

import com.raritan.rrc.components.serialconsole.Emulator;
import com.raritan.rrc.components.serialconsole.Terminal;
import com.raritan.rrc.data.SerialPort;
import com.raritan.rrc.data.SerialStream;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Point;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import javaclientlib.clientlib.ISerialStream;
import javaclientlib.utils.RRCLogger;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;
import nn.pp.common.ResourceLoader;

public class SerialView extends DeviceViewAdapter implements ISerialStream, Runnable, AdjustmentListener {
   private static final long serialVersionUID = 2337001065266455708L;
   private Terminal terminal;
   private Emulator emulator;
   private RRCScreenContext scrContext;
   private SerialPort serialPort;
   private JScrollPane jsp;
   private JScrollBar verticalScrollBar;
   private JScrollBar horizontalScrollBar;
   private JPanel terminalPanel;
   private SerialStream serialStream;
   JLabel southEastLabel;

   public SerialView(boolean var1, ScreenContext var2, boolean var3) {
      super((RRCScreenContext)var2);
      this.scrContext = (RRCScreenContext)var2;
      this.isInternalFrame = true;
      this.isNewPanel = true;
      this.setFocusable(true);
      this.makeLayout();
   }

   public Terminal getSerialTerminal() {
      return this.terminal;
   }

   @Override
   public void setDefaultFocussedComponent() {
      boolean var1 = this.terminal.getVDU().requestFocusInWindow();
   }

   @Override
   public void serialIn(int var1, byte[] var2) {
      while (this.emulator == null) {
         try {
            Thread.sleep(10L);
         } catch (InterruptedException var4) {
         }
      }

      if (this.terminal != null) {
         this.emulator.bytesArrived(var2, var1);
      }
   }

   @Override
   public void makeLayout() {
      try {
         this.serialPort = (SerialPort)((ArrayList)this.scrContext.getSelectedDevicesObservable().getComponent()).get(0);
         this.serialPort.connect();
         this.serialPort.setView(this);
         RaritanDesktopPane var1 = (RaritanDesktopPane)this.scrContext.getPanelMediator().getParent();
         this.serialStream = (SerialStream)this.serialPort.getStream();
         this.terminal = new Terminal(this.serialStream, this.serialPort.isAdmin(), this.serialPort.isDiagnosticPort());
         this.emulator = this.terminal.getEmulator();
         this.serialPort.setTerminal(this.terminal);
         this.addFocusListener(this);
         if (!this.serialPort.isAdmin()) {
            this.terminal.setPreferredSize(new Dimension(665, 445));
         } else {
            this.terminal.setPreferredSize(new Dimension(580, 435));
         }

         this.setLayout(new BorderLayout());
         this.addComponentListener(new SerialView.SerialResizer());
         this.jsp = new JScrollPane(this.terminal);
         this.jsp.setHorizontalScrollBarPolicy(31);
         this.jsp.setVerticalScrollBarPolicy(21);
         this.terminalPanel = new JPanel(new FlowLayout(0));
         this.terminalPanel.setBackground(Color.DARK_GRAY);
         this.terminalPanel.add(this.jsp);
         this.horizontalScrollBar = new JScrollBar(0);
         this.verticalScrollBar = new JScrollBar(1);
         this.horizontalScrollBar.setVisible(false);
         this.verticalScrollBar.setVisible(false);
         this.southEastLabel = new JLabel(ResourceLoader.loadImageIcon(this.bundle.getString("Transparent.image")));
         this.southEastLabel.setBackground(Color.GRAY);
         this.southEastLabel.setPreferredSize(new Dimension(20, 20));
         this.southEastLabel.setVisible(false);
         JPanel var2 = new JPanel(new BorderLayout());
         var2.add(this.horizontalScrollBar, "Center");
         var2.add(this.southEastLabel, "East");
         this.add(this.terminalPanel, "Center");
         this.add(var2, "South");
         this.add(this.verticalScrollBar, "East");
         this.horizontalScrollBar.addAdjustmentListener(this);
         this.verticalScrollBar.addAdjustmentListener(this);
         SwingUtilities.invokeLater(this);
      } catch (Exception var3) {
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      this.serialStream = null;
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.grabFocus();
   }

   @Override
   public void run() {
      MPCUtil.notifyObservers(this.scrContext, this.serialPort);
      this.terminal.setSerialStream((SerialStream)this.serialPort.getStream());
      this.setDefaultFocussedComponent();
      if (this.jsp.getVisibleRect().getWidth() < this.terminal.getWidth()) {
         this.horizontalScrollBar.setEnabled(true);
         this.horizontalScrollBar.setVisible(true);
      } else {
         this.horizontalScrollBar.setEnabled(false);
         this.horizontalScrollBar.setVisible(false);
      }

      if (this.jsp.getVisibleRect().getHeight() < this.terminal.getHeight()) {
         this.verticalScrollBar.setEnabled(true);
         this.verticalScrollBar.setVisible(true);
      } else {
         this.verticalScrollBar.setEnabled(false);
         this.verticalScrollBar.setVisible(false);
      }

      if (this.verticalScrollBar.isVisible() && this.horizontalScrollBar.isVisible()) {
         this.southEastLabel.setVisible(true);
      } else {
         this.southEastLabel.setVisible(false);
      }
   }

   @Override
   public void adjustmentValueChanged(AdjustmentEvent var1) {
      double var2 = this.horizontalScrollBar.getValue();
      double var4 = this.verticalScrollBar.getValue();
      var2 = var2 / 90.0 * (this.jsp.getHorizontalScrollBar().getMaximum() - this.terminal.getVisibleRect().getWidth());
      var4 = var4 / 90.0 * (this.jsp.getVerticalScrollBar().getMaximum() - this.terminal.getVisibleRect().getHeight());
      this.jsp.getViewport().setViewPosition(new Point((int)var2, (int)var4));
   }

   @Override
   public boolean serialOut(int var1, byte[] var2) throws Exception {
      return false;
   }

   @Override
   public void setViewFocus() {
      try {
         this.getShellInternalFrame().setSelected(true);
         this.setDefaultFocussedComponent();
      } catch (PropertyVetoException var2) {
         RRCLogger.logException(var2);
      }
   }

   @Override
   public boolean hasFocus() {
      return this.getShellInternalFrame() != null && this.getShellInternalFrame().isSelected();
   }

   private class SerialResizer extends ComponentAdapter {
      private SerialResizer() {
      }

      @Override
      public void componentResized(ComponentEvent var1) {
         if (var1.getID() == 101) {
            if (SerialView.this.jsp.getVisibleRect().getWidth() < SerialView.this.terminal.getWidth()) {
               SerialView.this.horizontalScrollBar.setEnabled(true);
               SerialView.this.horizontalScrollBar.setVisible(true);
            } else {
               SerialView.this.horizontalScrollBar.setEnabled(false);
               SerialView.this.horizontalScrollBar.setVisible(false);
            }

            if (SerialView.this.jsp.getVisibleRect().getHeight() < SerialView.this.terminal.getHeight()) {
               SerialView.this.verticalScrollBar.setEnabled(true);
               SerialView.this.verticalScrollBar.setVisible(true);
            } else {
               SerialView.this.verticalScrollBar.setEnabled(false);
               SerialView.this.verticalScrollBar.setVisible(false);
            }

            if (SerialView.this.verticalScrollBar.isVisible() && SerialView.this.horizontalScrollBar.isVisible()) {
               SerialView.this.southEastLabel.setVisible(true);
            } else {
               SerialView.this.southEastLabel.setVisible(false);
            }
         }
      }

      @Override
      public void componentMoved(ComponentEvent var1) {
         SerialView.this.terminal.repaint();
      }
   }
}
