package com.raritan.rrc.ui.panes;

import com.raritan.rrc.ui.commands.DoVideoSettingsCommand;
import com.raritan.rrc.ui.models.SettingModel;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import javaclientlib.tr.TRSRVR_VIDEO_PARAMS;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.ButtonGroup;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.JSpinner;
import javax.swing.JTabbedPane;
import javax.swing.SpinnerNumberModel;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.JSpinner.DefaultEditor;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public class VideoSettingsPanel extends AbstractDisplay implements ChangeListener {
   private static final long serialVersionUID = 7111096552822079630L;
   private TRSRVR_VIDEO_PARAMS videoParams = null;
   private SettingModel noiseFilterModel;
   private SpinnerNumberModel clockSettingModel;
   private SpinnerNumberModel phaseSettingModel;
   private SettingModel[] colorSettingModel;
   private SettingModel redGain = null;
   private SettingModel redOffset = null;
   private SettingModel greenGain = null;
   private SettingModel greenOffset = null;
   private SettingModel blueGain = null;
   private SettingModel blueOffset = null;
   private SettingModel brightness = null;
   private SettingModel redContrast = null;
   private SettingModel greenContrast = null;
   private SettingModel blueContrast = null;
   private boolean hasGainOffset = true;
   private boolean hasParagonGain = false;
   private SettingModel paragonGain = null;
   private boolean firstTime = true;
   private JTabbedPane videoSettingTabPane;
   private JRadioButton bestVideo;
   private JRadioButton quickVideo;
   private JCheckBox linkColorControlsChk;
   private JSpinner noiseFilterSpinner;
   private boolean videoSettingsModified = false;
   private RaritanPropertyResourceBundle bundle;

   public VideoSettingsPanel(boolean var1, ScreenContext var2) {
      super(var2);
      this.setNewPanel(true);
      this.isDialog = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public void makeLayout() {
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createEmptyBorder(10, 10, 0, 10));
      this.initVideoSettingsModel();
      this.initColorSettingsModel();
      JPanel var1 = new JPanel(new SpringLayout());
      String var2 = this.bundle.getString("NoiseFilterGroupPanel.name");
      JPanel var3 = new JPanel(new SpringLayout());
      var3.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      JLabel var4 = new JLabel(this.noiseFilterModel.getName(), 11);
      this.noiseFilterSpinner = new JSpinner(this.noiseFilterModel.getSpinnerModel());
      this.noiseFilterSpinner.setMaximumSize(this.noiseFilterSpinner.getPreferredSize());
      this.noiseFilterSpinner.addChangeListener(this);
      var4.setLabelFor(this.noiseFilterSpinner);
      JSlider var5 = new JSlider(this.noiseFilterModel.getSliderModel());
      var5.addChangeListener(this);
      if (this.noiseFilterModel.getMaximum() <= 10) {
         var5.setMinorTickSpacing(1);
         var5.setPaintTicks(true);
         var5.setSnapToTicks(true);
      }

      var3.add(var4);
      var3.add(this.noiseFilterSpinner);
      var3.add(var5);
      var1.add(var3);
      SpringUtilities.makeCompactGrid(var3, 1, 3, 6, 6, 6, 6);
      JPanel var6 = new JPanel(new SpringLayout());
      var2 = this.bundle.getString("PLLSettingsGroupPanel.name");
      var6.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      var2 = this.bundle.getString("ClockLabel.name");
      JLabel var7 = new JLabel(var2);
      JSpinner var8 = new JSpinner(this.clockSettingModel);
      var8.addChangeListener(this);
      var8.setMaximumSize(var8.getPreferredSize());
      var7.setLabelFor(var8);
      var6.add(var7);
      var6.add(var8);
      var6.add(Box.createHorizontalStrut(60));
      var2 = this.bundle.getString("PhaseLabel.name");
      var7 = new JLabel(var2);
      var8 = new JSpinner(this.phaseSettingModel);
      var8.addChangeListener(this);
      var8.setMaximumSize(var8.getPreferredSize());
      var7.setLabelFor(var8);
      var6.add(var7);
      var6.add(var8);
      var1.add(var6);
      SpringUtilities.makeCompactGrid(var6, 1, 5, 6, 6, 6, 6);
      JPanel var9 = new JPanel();
      var2 = this.bundle.getString("ColorSettingsGroupPanel.name");
      var9.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      var9.setLayout(new SpringLayout());
      int var10 = this.hasGainOffset ? 6 : 4;

      for (int var11 = 0; var11 < var10; var11++) {
         var4 = new JLabel(this.colorSettingModel[var11].getName(), 11);
         var8 = new JSpinner(this.colorSettingModel[var11].getSpinnerModel());
         var8.addChangeListener(this);
         var8.setMaximumSize(var8.getPreferredSize());
         var4.setLabelFor(var8);
         var5 = new JSlider(this.colorSettingModel[var11].getSliderModel());
         if (this.colorSettingModel[var11].getMaximum() <= 10) {
            var5.setMinorTickSpacing(1);
            var5.setPaintTicks(true);
            var5.setSnapToTicks(true);
         }

         var9.add(var4);
         var9.add(var8);
         var9.add(var5);
      }

      var9.add(Box.createVerticalGlue());
      var9.add(Box.createVerticalGlue());
      var2 = this.bundle.getString("LinkColorControlsCheckBox.name");
      this.linkColorControlsChk = new JCheckBox(var2, false);
      this.linkColorControlsChk.addItemListener(new VideoSettingsPanel.LinkColorCtrlsListener());
      var9.add(this.linkColorControlsChk);
      var1.add(var9);
      SpringUtilities.makeCompactGrid(var9, var10 + 1, 3, 6, 6, 6, 6);
      ButtonGroup var33 = new ButtonGroup();
      JPanel var12 = new JPanel();
      var2 = this.bundle.getString("VideoSenseGroupPanel.name");
      var12.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
      var12.setLayout(new GridBagLayout());
      GridBagConstraints var13 = new GridBagConstraints();
      var13.fill = 2;
      var13.anchor = 10;
      var13.gridx = 0;
      var13.gridy = 0;
      var2 = this.bundle.getString("BestVideoMode.name");
      this.bestVideo = new JRadioButton(var2);
      var33.add(this.bestVideo);
      var12.add(this.bestVideo, var13);
      this.bestVideo.addActionListener(this);
      var13.gridx = 0;
      var13.gridy = 1;
      var2 = this.bundle.getString("QuickVideoMode.name");
      this.quickVideo = new JRadioButton(var2);
      var33.add(this.quickVideo);
      this.quickVideo.addActionListener(this);
      var12.add(this.quickVideo, var13);
      var1.add(var12);
      if (this.hasParagonGain) {
         JPanel var14 = new JPanel();
         var2 = this.bundle.getString("ParagonGainGroupPanel.name");
         var14.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(var2), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
         var14.setLayout(new SpringLayout());
         var4 = new JLabel(this.paragonGain.getName(), 11);
         var8 = new JSpinner(this.paragonGain.getSpinnerModel());
         var8.addChangeListener(this);
         var8.setMaximumSize(var8.getPreferredSize());
         var4.setLabelFor(var8);
         var5 = new JSlider(this.paragonGain.getSliderModel());
         if (this.paragonGain.getMaximum() <= 10) {
            var5.setMinorTickSpacing(1);
            var5.setPaintTicks(true);
            var5.setSnapToTicks(true);
         }

         var14.add(var4);
         var14.add(var8);
         var14.add(var5);
         var1.add(var14);
         SpringUtilities.makeCompactGrid(var14, 1, 3, 6, 6, 6, 6);
      }

      SpringUtilities.makeCompactGrid(var1, 4 + (this.hasParagonGain ? 1 : 0), 1, 6, 6, 6, 6);
      this.videoSettingTabPane = new JTabbedPane();
      var2 = this.bundle.getString("VideoSettingTab.name");
      this.videoSettingTabPane.addTab(var2, var1);
      this.add(this.videoSettingTabPane, "Center");
      this.add(this.doButtonWidget(), "Last");
   }

   private void addColorSettingListeners() {
      if (this.hasGainOffset) {
         this.colorSettingModel[0].addSliderModelListener(this.colorSettingModel[2]);
         this.colorSettingModel[0].addSliderModelListener(this.colorSettingModel[4]);
         this.colorSettingModel[1].addSliderModelListener(this.colorSettingModel[3]);
         this.colorSettingModel[1].addSliderModelListener(this.colorSettingModel[5]);
         this.colorSettingModel[2].addSliderModelListener(this.colorSettingModel[0]);
         this.colorSettingModel[2].addSliderModelListener(this.colorSettingModel[4]);
         this.colorSettingModel[3].addSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[3].addSliderModelListener(this.colorSettingModel[5]);
         this.colorSettingModel[4].addSliderModelListener(this.colorSettingModel[0]);
         this.colorSettingModel[4].addSliderModelListener(this.colorSettingModel[2]);
         this.colorSettingModel[5].addSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[5].addSliderModelListener(this.colorSettingModel[3]);
      } else {
         this.colorSettingModel[1].addSliderModelListener(this.colorSettingModel[2]);
         this.colorSettingModel[1].addSliderModelListener(this.colorSettingModel[3]);
         this.colorSettingModel[2].addSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[2].addSliderModelListener(this.colorSettingModel[3]);
         this.colorSettingModel[3].addSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[3].addSliderModelListener(this.colorSettingModel[2]);
      }
   }

   private void removeColorSettingListeners() {
      if (this.hasGainOffset) {
         this.colorSettingModel[0].removeSliderModelListener(this.colorSettingModel[2]);
         this.colorSettingModel[0].removeSliderModelListener(this.colorSettingModel[4]);
         this.colorSettingModel[1].removeSliderModelListener(this.colorSettingModel[3]);
         this.colorSettingModel[1].removeSliderModelListener(this.colorSettingModel[5]);
         this.colorSettingModel[2].removeSliderModelListener(this.colorSettingModel[0]);
         this.colorSettingModel[2].removeSliderModelListener(this.colorSettingModel[4]);
         this.colorSettingModel[3].removeSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[3].removeSliderModelListener(this.colorSettingModel[5]);
         this.colorSettingModel[4].removeSliderModelListener(this.colorSettingModel[0]);
         this.colorSettingModel[4].removeSliderModelListener(this.colorSettingModel[2]);
         this.colorSettingModel[5].removeSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[5].removeSliderModelListener(this.colorSettingModel[3]);
      } else {
         this.colorSettingModel[1].removeSliderModelListener(this.colorSettingModel[2]);
         this.colorSettingModel[1].removeSliderModelListener(this.colorSettingModel[3]);
         this.colorSettingModel[2].removeSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[2].removeSliderModelListener(this.colorSettingModel[3]);
         this.colorSettingModel[3].removeSliderModelListener(this.colorSettingModel[1]);
         this.colorSettingModel[3].removeSliderModelListener(this.colorSettingModel[2]);
      }
   }

   private int getClockSettingValue() {
      return (Integer)this.clockSettingModel.getValue();
   }

   private void setClockSettingValue(int var1) {
      this.clockSettingModel.setValue(new Integer(var1));
   }

   private int getPhaseSettingValue() {
      return (Integer)this.phaseSettingModel.getValue();
   }

   private void setPhaseSettingValue(int var1) {
      this.phaseSettingModel.setValue(new Integer(var1));
   }

   private int getAutoSenseVideoSetting() {
      return this.bestVideo.isSelected() ? 0 : 1;
   }

   private void setAutoSenseVideoSetting(int var1) {
      if (var1 == 0) {
         this.bestVideo.setSelected(true);
      } else {
         this.quickVideo.setSelected(true);
      }
   }

   private void setVideoSettingsModified(boolean var1) {
      if (var1 && !this.videoSettingsModified) {
         this.videoSettingsModified = true;
      } else {
         this.videoSettingsModified = var1;
      }
   }

   @Override
   public void setDefaultFocussedComponent() {
      JComponent var1 = this.noiseFilterSpinner.getEditor();
      if (var1 instanceof DefaultEditor) {
         JFormattedTextField var2 = ((DefaultEditor)var1).getTextField();
         var2.requestFocusInWindow();
         var2.setCaretPosition(0);
      }
   }

   @Override
   public void stateChanged(ChangeEvent var1) {
      this.setVideoSettingsModified(true);
      this.apply.setEnabled(true);
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
      this.videoParams.setNoiseFilter(this.noiseFilterModel.getValue());
      this.videoParams.setPllDivider(this.getClockSettingValue());
      this.videoParams.setPllOffset(this.getPhaseSettingValue());
      int var2 = 897;
      if (this.hasGainOffset) {
         this.videoParams.setRedGain(this.redGain.getValue());
         this.videoParams.setRedOffset(this.redOffset.getValue());
         this.videoParams.setGreenGain(this.greenGain.getValue());
         this.videoParams.setGreenOffset(this.greenOffset.getValue());
         this.videoParams.setBlueGain(this.blueGain.getValue());
         this.videoParams.setBlueOffset(this.blueOffset.getValue());
         this.videoParams.setAdType(0);
         var2 |= 126;
      } else {
         this.videoParams.setBrightness(this.brightness.getValue());
         this.videoParams.setRedGain(this.redContrast.getValue());
         this.videoParams.setGreenGain(this.greenContrast.getValue());
         this.videoParams.setBlueGain(this.blueContrast.getValue());
         this.videoParams.setAdType(1);
         var2 |= 8234;
      }

      if (this.hasParagonGain) {
         this.videoParams.setAGCGain((byte)(0xFF & this.paragonGain.getValue()));
         var2 |= 4096;
      }

      this.videoParams.setAutoSense(this.getAutoSenseVideoSetting());
      this.videoParams.setSettings(var2);
      var1.setCommandParameter("videoParams", this.videoParams);
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.videoParams = (TRSRVR_VIDEO_PARAMS)var1.getCommandParameter("videoParams");
      if (this.videoParams != null) {
         this.hasGainOffset = (this.videoParams.getSettings() & 8192) == 0;
         this.hasParagonGain = (this.videoParams.getSettings() & 4096) != 0;
         this.makeLayout();
         this.setShell(this.bundle.getString("VideoSettingsDialog.title"));
         this.ok.setCommand(new DoVideoSettingsCommand(this.scrContext));
         this.apply.setCommand(new DoVideoSettingsCommand(this.scrContext));
         this.removeColorSettingListeners();
         this.linkColorControlsChk.setSelected(false);
         if (this.videoParams != null) {
            this.noiseFilterModel.setValue(this.videoParams.getNoiseFilter());
            this.setClockSettingValue(this.videoParams.getPllDivider());
            this.setPhaseSettingValue(this.videoParams.getPllOffset());
            this.setAutoSenseVideoSetting(this.videoParams.getAutoSense());
            if (this.hasGainOffset) {
               this.redGain.setValue(this.videoParams.getRedGain());
               this.greenGain.setValue(this.videoParams.getGreenGain());
               this.blueGain.setValue(this.videoParams.getBlueGain());
               this.redOffset.setValue(this.videoParams.getRedOffset());
               this.greenOffset.setValue(this.videoParams.getGreenOffset());
               this.blueOffset.setValue(this.videoParams.getBlueOffset());
            } else {
               this.brightness.setValue(this.videoParams.getBrightness());
               this.redContrast.setValue(this.videoParams.getRedGain());
               this.greenContrast.setValue(this.videoParams.getGreenGain());
               this.blueContrast.setValue(this.videoParams.getBlueGain());
            }
         }

         if (this.hasParagonGain) {
            this.paragonGain.setValue(this.videoParams.getAGCGain());
         }

         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               VideoSettingsPanel.this.noiseFilterSpinner.grabFocus();
               if (OS.getCurrent() == OS.MAC) {
                  VideoSettingsPanel.this.repaint();
               }
            }
         });
         this.apply.setEnabled(false);
      }
   }

   private void initVideoSettingsModel() {
      String var1 = this.bundle.getString("NoiseFilterLabel.name");
      this.noiseFilterModel = new SettingModel(var1, 0, 0, 7, 1);
      this.noiseFilterModel.addSliderModelListener(this);
      this.clockSettingModel = new SpinnerNumberModel(1, 1, 2999, 1);
      this.clockSettingModel.addChangeListener(this);
      this.phaseSettingModel = new SpinnerNumberModel(0, 0, 31, 1);
      this.phaseSettingModel.addChangeListener(this);
   }

   private void initColorSettingsModel() {
      if (this.hasGainOffset) {
         this.colorSettingModel = new SettingModel[6];
         String var1 = this.bundle.getString("RedGainLabel.name");
         this.colorSettingModel[0] = new SettingModel(var1, 0, 0, 255, 5);
         this.colorSettingModel[0].addSliderModelListener(this);
         this.redGain = this.colorSettingModel[0];
         var1 = this.bundle.getString("RedOffsetLabel.name");
         this.colorSettingModel[1] = new SettingModel(var1, 0, 0, 63, 3);
         this.colorSettingModel[1].addSliderModelListener(this);
         this.redOffset = this.colorSettingModel[1];
         var1 = this.bundle.getString("GreenGainLabel.name");
         this.colorSettingModel[2] = new SettingModel(var1, 0, 0, 255, 5);
         this.colorSettingModel[2].addSliderModelListener(this);
         this.greenGain = this.colorSettingModel[2];
         var1 = this.bundle.getString("GreenOffsetLabel.name");
         this.colorSettingModel[3] = new SettingModel(var1, 0, 0, 63, 3);
         this.colorSettingModel[3].addSliderModelListener(this);
         this.greenOffset = this.colorSettingModel[3];
         var1 = this.bundle.getString("BlueGainLabel.name");
         this.colorSettingModel[4] = new SettingModel(var1, 0, 0, 255, 5);
         this.colorSettingModel[4].addSliderModelListener(this);
         this.blueGain = this.colorSettingModel[4];
         var1 = this.bundle.getString("BlueOffsetLabel.name");
         this.colorSettingModel[5] = new SettingModel(var1, 0, 0, 63, 3);
         this.colorSettingModel[5].addSliderModelListener(this);
         this.blueOffset = this.colorSettingModel[5];
      } else {
         this.colorSettingModel = new SettingModel[4];
         String var7 = this.bundle.getString("BrightnessLabel.name");
         this.colorSettingModel[0] = new SettingModel(var7, 64, 0, 127, 1);
         this.colorSettingModel[0].addSliderModelListener(this);
         this.brightness = this.colorSettingModel[0];
         var7 = this.bundle.getString("RedContrastLabel.name");
         this.colorSettingModel[1] = new SettingModel(var7, 128, 0, 255, 1);
         this.colorSettingModel[1].addSliderModelListener(this);
         this.redContrast = this.colorSettingModel[1];
         var7 = this.bundle.getString("GreenContrastLabel.name");
         this.colorSettingModel[2] = new SettingModel(var7, 128, 0, 255, 1);
         this.colorSettingModel[2].addSliderModelListener(this);
         this.blueContrast = this.colorSettingModel[2];
         var7 = this.bundle.getString("BlueContrastLabel.name");
         this.colorSettingModel[3] = new SettingModel(var7, 128, 0, 255, 1);
         this.colorSettingModel[3].addSliderModelListener(this);
         this.greenContrast = this.colorSettingModel[3];
      }

      if (this.hasParagonGain) {
         String var11 = this.bundle.getString("ParagonGainLabel.name");
         this.paragonGain = new SettingModel(var11, 0, -15, 15, 1);
         this.paragonGain.addSliderModelListener(this);
      }

      this.addColorSettingListeners();
   }

   private void clearFields() {
      this.noiseFilterModel.setValue(0);
      this.setClockSettingValue(0);
      this.setPhaseSettingValue(0);
      if (this.hasGainOffset) {
         this.redGain.setValue(128);
         this.greenGain.setValue(128);
         this.blueGain.setValue(128);
         this.redOffset.setValue(32);
         this.greenOffset.setValue(32);
         this.blueOffset.setValue(32);
      } else {
         this.brightness.setValue(64);
         this.redContrast.setValue(128);
         this.greenContrast.setValue(128);
         this.blueContrast.setValue(128);
      }

      if (this.hasParagonGain) {
         this.paragonGain.setValue(0);
      }

      this.setAutoSenseVideoSetting(1);
   }

   @Override
   public JPanel doButtonWidget() {
      this.ok = new CommandButton(this.bundle.getString("basescreen.command.ok.text"), this.scrContext);
      this.ok.addActionListener(this);
      this.cancel = new CommandButton(this.bundle.getString("basescreen.command.cancel.text"), this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      this.apply = new CommandButton(this.bundle.getString("OptionDialog.applyLabel"), this.scrContext);
      this.apply.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      var1.add(this.apply);
      return var1;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      if (!(var2 instanceof JCheckBox) && !(var2 instanceof JRadioButton)) {
         this.apply.setEnabled(false);
      } else {
         this.apply.setEnabled(true);
      }

      this.scrContext.getLogger().logTextDebug("started");
      this.scrContext.getLogger().logTextDebug("finished");
   }

   public void itemStateChanged(ItemEvent var1) {
   }

   private class LinkColorCtrlsListener implements ItemListener {
      private LinkColorCtrlsListener() {
      }

      @Override
      public void itemStateChanged(ItemEvent var1) {
         int var2 = var1.getStateChange();
         if (var2 == 2) {
            VideoSettingsPanel.this.removeColorSettingListeners();
         }

         if (var2 == 1) {
            VideoSettingsPanel.this.addColorSettingListeners();
         }
      }
   }
}
