package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.rfbbridge.RFBProfile;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.Date;
import java.util.Map;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;

public final class ViewFactory {
   private static ViewFactory aFactory = new ViewFactory();
   public static final String KX20_DEVICE = "KX_2.0";
   public static final String KX1X_DEVICE = "KX_1.X";
   private boolean isCCLaunch = false;
   private int connectionType = -1;

   private ViewFactory() {
   }

   public static ViewFactory getInstance() {
      synchronized (ViewFactory.class) {
         if (aFactory == null) {
            aFactory = new ViewFactory();
         }
      }

      return aFactory;
   }

   public AbstractDisplay getView(ScreenContext var1, String var2, Map var3) throws RRCGeneralException {
      AbstractDisplay var4 = null;
      if ("KX_2.0".equals(var2)) {
         var4 = this.getKX20DeviceView(var1, var3);
      } else {
         var4 = this.getKX1XDeviceView(var1, var3);
      }

      return var4;
   }

   private AbstractDisplay getKX1XDeviceView(ScreenContext var1, Map var2) {
      return new KvmView(false, var1, true);
   }

   private AbstractDisplay getKX20DeviceView(ScreenContext var1, Map var2) throws RRCGeneralException {
      RRCLogger.log(300, 1, "getKX20DeviceView Started");
      if (var1.getApplicationProperty("connection") != null) {
         this.isCCLaunch = true;
      }

      ArrayList var4 = (ArrayList)((RRCScreenContext)var1).getSelectedDevicesObservable().getComponent();
      Port var5 = null;
      if (var4 != null && var4.size() > 0) {
         var5 = (Port)var4.get(0);
      }

      InetAddress var6 = null;
      IPReach var7 = null;
      if (var5 != null) {
         var7 = (IPReach)var5.getDevice();
         if (var7 != null) {
            DeviceConnector var8 = var7.getDeviceConnector();
            if (var8 != null) {
               var6 = var8.getInetAddress();
            }
         }
      }

      if (var7 != null && var6 != null) {
         if (var7.getDevPrefs() != null) {
            this.connectionType = var7.getDevPrefs().getConnectionType();
         }

         RFBProfile var3;
         if (this.isCCLaunch) {
            var3 = this.getRFBProfile(var7.getAppletParameters());
            var3.setRemoteHost(var6.getHostAddress());
            if (var5.getDeviceConnector().getConnectionMap().containsKey("multiIdx")) {
               String var9 = "." + var5.getDeviceConnector().getConnectionMap().get("multiIdx");
               if (var9.equals(".0")) {
                  var9 = "";
               }

               var3.rdmSession = this.formatSessionID(var5, var9);
               var3.portIdRDM = this.getParamValue(var5.getDeviceConnector().getConnectionMap(), "ID" + var9, true);
               var3.proxyModeConnectionID = this.getParamValue(var5.getDeviceConnector().getConnectionMap(), "ConnectionIDHTTPS" + var9, false);
               var3.setRdmSessionMultiPortTag(this.formatSessionID(var5, ""));
            } else {
               String var10 = "\"" + var7.getRdmSessionId() + "\":\"" + var7.getRdmSessionKey() + "\"";
               var3.rdmSession = var10;
               var3.portIdRDM = this.getParamValue(var5.getDeviceConnector().getConnectionMap(), "ID", true);
               var3.proxyModeConnectionID = this.getParamValue(var5.getDeviceConnector().getConnectionMap(), "ConnectionIDHTTPS", false);
               var3.setRdmSessionMultiPortTag(var10);
            }

            var3.proxyUseSSL = this.getParamValue(var5.getDeviceConnector().getConnectionMap(), "useSSLInProxy", false);
            if (var3.proxyModeConnectionID != null) {
               var3.primaryPort = 2400;
            }
         } else {
            var3 = this.getRFBProfile(var7.getAppletParameters());
            var3.targetId = var5.getStripTargetDeviceId();
            String var11 = "\"" + var7.getRdmSessionId() + "\":\"" + var7.getRdmSessionKey() + "\"";
            var3.rdmSession = var11;
            var3.setRdmSessionMultiPortTag(var11);
            var3.setRemoteHost(var6.getHostAddress());
         }

         var3.setRemoteHost(var6.getHostAddress());
         var3.doInitSwitch = true;
         RFBView var12 = new RFBView(var1, var3);
         RRCLogger.log(300, 1, "getKX20DeviceView Finished");
         return var12;
      } else {
         RRCLogger.log(300, 1, "getKX20DeviceView Finished");
         throw new RRCGeneralException("Unable to get IP address for device");
      }
   }

   private String formatSessionID(Port var1, String var2) throws RRCGeneralException {
      return "\""
         + this.getParamValue(var1.getDeviceConnector().getConnectionMap(), "SessionID" + var2, true)
         + "\":\""
         + this.getParamValue(var1.getDeviceConnector().getConnectionMap(), "SessionKey" + var2, true)
         + "\"";
   }

   private RFBProfile getRFBProfile(Map var1) throws RRCGeneralException {
      RFBProfile var2 = null;
      var2 = new RFBProfile();
      if (var1 != null) {
         String var3 = null;

         try {
            var3 = this.getParamValue(var1, "PORT", false);
            if (var3 != null && !"".equals(var3.trim())) {
               var2.primaryPort = Integer.parseInt(var3);
            }
         } catch (NumberFormatException var11) {
            throw new RRCGeneralException("Error parsing primary port " + var3, var11);
         }

         try {
            var3 = this.getParamValue(var1, "SSLPORT", false);
            if (var3 != null && !"".equals(var3.trim())) {
               var2.sslPort = Integer.parseInt(var3);
            }
         } catch (NumberFormatException var8) {
            throw new RRCGeneralException("Error parsing ssl port " + var3, var8);
         }

         var3 = this.getParamValue(var1, "HOST", false);
         var2.setRemoteHost(var3);
         var3 = this.getParamValue(var1, "MOUSESYNC_KEY", false);
         var2.mouseSyncKey = var3;
         var3 = this.getParamValue(var1, "MOUSESYNC_KEYCODE", false);
         var2.mouseSyncKeyCodes = var3;
         var3 = this.getParamValue(var1, "FULLSCREEN_KEYCODE", false);
         var2.fullScreenKeyCodes = var3;
         var3 = this.getParamValue(var1, "WLAN_ENABLED", false);
         var2.wlanEnabled = "yes".equals(var3);
         var3 = this.getParamValue(var1, "EXCLUSIVE_MOUSE", false);
         var2.exclusiveMouse = "yes".equals(var3);
         var2.softKbdMapping = this.getParamValue(var1, "softkbd_mapping", false);
         var2.localKbdMapping = this.getParamValue(var1, "localkbd_mapping", false);
         var2.kbdLayout = this.getParamValue(var1, "KBD_LAYOUT", false);
         var3 = this.getParamValue(var1, "VS_TYPE", false);
         var2.vsTypeFull = "offset".equals(var3);
         String var4 = this.getParamValue(var1, "VS_PERM_STD", false);
         var3 = this.getParamValue(var1, "VS_PERM_ADV", false);
         if (var3 != null && "yes".equals(var3)) {
            var2.vsPerms = 2;
         } else if (var4 != null && "yes".equals(var4)) {
            var2.vsPerms = 1;
         }

         this.setNorBoxValue(var2, var1);
         var2.setProxyHost(this.getParamValue(var1, "PROXY_HOST", false));

         try {
            var3 = this.getParamValue(var1, "PROXY_PORT", false);
            if (var3 != null && !"".equals(var3.trim())) {
               var2.primaryPort = Integer.parseInt(var3);
            }
         } catch (NumberFormatException var7) {
            throw new RRCGeneralException("Error parsing proxy port " + var3, var7);
         }

         if (var2.getProxyHost() != null && var2.proxyPort != 0) {
            var2.useProxy = true;
         } else {
            var2.useProxy = false;
         }

         var3 = this.getParamValue(var1, "SSL", false);
         if (var3 != null && "force".equals(var3)) {
            var2.sslRequired = true;
         } else {
            var2.sslRequired = false;
         }

         if (var3 != null && "try".equals(var3)) {
            var2.noTrialAndError = false;
         } else {
            var2.noTrialAndError = true;
         }

         this.setEncodingValues(var2, var1);
         var3 = this.getParamValue(var1, "DRIVE_REDIRECTION", false);
         if (var3 != null && "yes".equals(var3)) {
            var2.driveRedirection = true;
         } else {
            var2.driveRedirection = false;
         }

         var3 = this.getParamValue(var1, "FORENSIC_CONSOLE", false);
         if (var3 != null && "yes".equals(var3)) {
            var2.forensicConsole = true;
         } else {
            var2.forensicConsole = false;
         }

         var3 = this.getParamValue(var1, "FORENSIC_NOKBD", false);
         if (var3 != null && "yes".equals(var3)) {
            var2.forensicNoKeyboard = true;
         } else {
            var2.forensicNoKeyboard = false;
         }

         var3 = this.getParamValue(var1, "FORENSIC_FILTERKBD", false);
         if (var3 != null && "yes".equals(var3)) {
            var2.forensicFilterKeyboard = true;
         } else {
            var2.forensicFilterKeyboard = false;
         }

         try {
            var3 = this.getParamValue(var1, "DRIVE_REDIRECTION_NO_DRIVES", false);
            if (var3 != null && !"".equals(var3.trim())) {
               var2.driveRedirectionNoDrives = Integer.parseInt(var3);
            }
         } catch (NumberFormatException var10) {
            throw new RRCGeneralException("Error parsing drive redirection port " + var3, var10);
         }

         var2.protocol_version = this.getParamValue(var1, "PROTOCOL_VERSION", false);

         try {
            var3 = this.getParamValue(var1, "CHANNEL_ID", false);
            if (var3 != null && !"".equals(var3.trim())) {
               var2.channelId = Integer.parseInt(var3);
            }
         } catch (NumberFormatException var9) {
            throw new RRCGeneralException("Error parsing channel id " + var3, var9);
         }

         try {
            var3 = this.getParamValue(var1, "TARGET_ID", false);
            if (var3 != null && !"".equals(var3.trim())) {
               var2.targetId = var3;
            }
         } catch (NumberFormatException var6) {
            throw new RRCGeneralException("Error parsing target id " + var3, var6);
         }

         var3 = this.getParamValue(var1, "DO_INIT_SWITCH", false);
         var2.doInitSwitch = var3 != null && "yes".equals(var3);
         var3 = this.getParamValue(var1, "MONITOR_MODE", false);
         var2.initialMoniMode = var3 != null && !"no".equals(var3);
         this.setReplayValues(var2, var1);
         this.setConnectionValues(var2, var1);
      }

      return var2;
   }

   private String getParamValue(Map var1, String var2, boolean var3) throws RRCGeneralException {
      String var4 = "";
      if (var1.get(var2) == null && var3) {
         throw new RRCGeneralException(var2 + " is missing");
      } else {
         return (String)var1.get(var2);
      }
   }

   private void setReplayValues(RFBProfile var1, Map var2) throws RRCGeneralException {
      String var3 = null;

      try {
         var3 = this.getParamValue(var2, "REPLAY_START", false);
         if (var3 != null && !"".equals(var3.trim())) {
            var1.replayStartTime = new Date(Long.parseLong(var3) / 1000L);
         }

         var3 = this.getParamValue(var2, "REPLAY_END", false);
         if (var3 != null && !"".equals(var3.trim())) {
            var1.replayEndTime = new Date(Long.parseLong(var3) / 1000L);
         }

         var3 = this.getParamValue(var2, "REPLAY_CIM", false);
         if (var3 != null && !"".equals(var3.trim())) {
            var1.replayCimId = Integer.parseInt(var3);
         }

         var3 = this.getParamValue(var2, "REPLAY_SESSION", false);
         if (var3 != null && !"".equals(var3.trim())) {
            var1.replaySessionID = Integer.parseInt(var3);
         }
      } catch (NumberFormatException var5) {
         throw new RRCGeneralException("Error parsing replay parameters " + var3, var5);
      }
   }

   private void setConnectionValues(RFBProfile var1, Map var2) throws RRCGeneralException {
      if (this.getParamValue(var2, "connection", false) != null) {
         int var3 = 0;
         int var4 = 0;
         String var8 = null;

         try {
            var8 = this.getParamValue(var2, "connection.TCPPort", false);
            if (var8 != null && !"".equals(var8.trim())) {
               var3 = Integer.parseInt(var8);
            }

            var8 = this.getParamValue(var2, "connection.IPAddress", false);
            if (var8 != null && !"".equals(var8.trim())) {
               var4 = Integer.parseInt(var8);
            }
         } catch (NumberFormatException var10) {
            throw new RRCGeneralException("Error connection parameters " + var8, var10);
         }

         String var5 = "\""
            + this.getParamValue(var2, "connection.SessionID", false)
            + "\":\""
            + this.getParamValue(var2, "connection.SessionKey", false)
            + "\"";
         String var6 = "" + (var4 >> 24 & 0xFF) + "." + (var4 >> 16 & 0xFF) + "." + (var4 >> 8 & 0xFF) + "." + (var4 & 0xFF);
         String var7 = this.getParamValue(var2, "connection.ID", false);
         if (var3 != 0 && var4 != 0) {
            var1.rdmSession = var5;
            var1.setRemoteHost(var6);
            var1.primaryPort = var3;
            var1.portIdRDM = var7;
         }
      }
   }

   private void setNorBoxValue(RFBProfile var1, Map var2) throws RRCGeneralException {
      String var3 = this.getParamValue(var2, "NORBOX", false);
      var1.norbox = var3;
      if (var1.norbox == null || !"ipv4".equals(var1.norbox) && !"ipv6".equals(var1.norbox)) {
         var1.norbox = "no";
      }

      if ("ipv4".equals(var1.norbox)) {
         var1.setNorbox_ipv4target(this.getParamValue(var2, "NORBOX_IPV4TARGET", true));
      }

      if ("ipv6".equals(var1.norbox)) {
         var1.setNorbox_ipv6target(this.getParamValue(var2, "NORBOX_IPV6TARGET", true));
      }

      if ("no".equals(var1.norbox)) {
         var1.setRealRemoteHost(var1.getRemoteHost());
      } else {
         var1.setRealRemoteHost(this.getParamValue(var2, "REAL_HOST", false));
         if (var1.getRealRemoteHost() == null) {
            var1.setRealRemoteHost(var1.getRemoteHost());
         }
      }
   }

   private void setEncodingValues(RFBProfile var1, Map var2) {
      Object var3 = null;
      Object var4 = null;
      Object var5 = null;
      Object var6 = null;
      Object var7 = null;
      boolean var8 = false;

      try {
         var3 = this.getParamValue(var2, "SelEnc", false);
         var4 = this.getParamValue(var2, "FixEnc", false);
         var6 = this.getParamValue(var2, "AdvEncCD", false);
         var5 = this.getParamValue(var2, "AdvEncCR", false);
         var7 = this.getParamValue(var2, "HWENC", false);
         if (var7 != null && "yes".equals(var7)) {
            boolean var16 = true;
         } else {
            boolean var10000 = false;
         }
      } catch (Exception var10) {
      }
   }
}
