package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.VMConfigInfo;
import com.raritan.rrc.data.VMInterfaceInfo;
import com.raritan.rrc.data.VirtualMediaBean;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.Shell;
import com.raritan.tools.util.Util;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.HeadlessException;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;
import java.util.Vector;
import java.util.logging.Level;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import javax.swing.filechooser.FileFilter;
import nn.pp.common.LimitedLengthDocument;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.core.INotificationEvent;
import nn.pp.core.Platform;
import nn.pp.rccore.IVMMountRequestResponse;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.RCException;
import nn.pp.rccore.VMMountRequestResponse;
import nn.pp.vmcore.RedirectableObject;
import nn.pp.vmcore.VMAdapter;
import nn.pp.vmcore.VMCore;
import nn.pp.vmcore.VMException;

public class VirtualMediaImagePanel extends AbstractDisplay implements ActionListener, ItemListener {
   private static final long serialVersionUID = 2677565149168348926L;
   protected RaritanPropertyResourceBundle bundle;
   private String portKey;
   private String host;
   private JPanel generalPanel;
   private DefaultComboBoxModel availableDrivesModel;
   private JButton connectButton;
   private JButton cancelButton;
   private JPanel buttonPanel;
   private JRadioButton localDriveRadio;
   private JRadioButton diskImageRadioButton;
   private JRadioButton remoteImageRadioButton;
   private JComboBox availableDrivesCombo;
   private JComboBox hostsCombo;
   private JComboBox imagesCombo;
   private JTextField usersText;
   private JPasswordField userPwdText;
   private JTextField imageText;
   private JButton browseButton;
   private DefaultComboBoxModel hostsModel;
   private DefaultComboBoxModel imagesModel;
   private JPanel mainPanel;
   private static final int DRIVE_NONE = 0;
   private static final int DRIVE_REDIRECTION = 1;
   private static final int LOCAL_ISO_MOUNT = 2;
   private static final int REMOTE_ISO_MOUNT = 3;
   private static final String RADIO_BUTTON_NONE = "vmpanel.RADIO_BUTTON_NONE";
   private static final String RADIO_BUTTON_DISK_IMAGE = "vmpanel.RADIO_BUTTON_DISK_IMAGE";
   private static final String RADIO_BUTTON_PRE_CONF = "vmpanel.RADIO_BUTTON_PRE_CONF";
   private static final String PANEL_NAME = "vmpanel.IMAGE_PANEL_NAME";
   private static final String WARNING_MESSAGE_ISO = "vmpanel.WARNING_MESSAGE_ISO";
   private static final String PANEL_INFO_MESSAGE = "vmpanel.PANEL_INFO_MESSAGE_2";
   private static final String IMAGE = "vmpanel.image";
   private static final String HOSTS = "vmpanel.hosts";
   private static final String REMOTE_FILE_SERVER_USER_NAME = "vmpanel.username";
   private static final String REMOTE_FILE_SERVER_PASSWORD = "vmpanel.password";
   private static final String DISK_IMAGE_PATH = "vmpanel.diskimagepath";
   private static final String BROWSE = "vmpanel.browse";
   private static final String CANCEL = "vmpanel.cancel";
   private static final String CONNECT = "vmpanel.connect";
   private static final String FILE_DIALOG_NAME = "vmpanel.filedialogname";
   private static final String CONNECT_SUCEESS_MESSAGE = "vmpanel.CONNECT_SUCEESS_MESSAGE";
   private static final String CONNECT_PROGRESS_TITLE = "vmpanel.CONNECT_PROGRESS_TITLE";
   private static final String CONNECT_PROGRESS_MESSAGE = "vmpanel.CONNECT_PROGRESS_MESSAGE";
   private boolean isDriveConnected = false;
   private String driveSelected;
   private int connectionType = 0;
   private JDialog vmConnectionInProgressMsgDialog = null;
   private VirtualMediaBean currentVirtualMediaBean = null;
   private List<RedirectableObject> drives;
   private Hashtable<String, Vector<String>> remoteIsos;
   private VMAdapter vmAdapter;

   @Override
   public void makeLayout() {
      try {
         RRCLogger.log(200, 1024, "Client Platform : " + OS.getCurrent());
         this.mainPanel = new JPanel(new SpringLayout());
         this.generalPanel = new JPanel(new GridBagLayout());
         JPanel var1 = new JPanel(new SpringLayout());
         JLabel var2 = new JLabel(this.bundle.getString("vmpanel.PANEL_INFO_MESSAGE_2"));
         var1.add(var2);
         SpringUtilities.makeCompactGrid(var1, 1, 1, 15, 1, 1, 1);
         ButtonGroup var3 = new ButtonGroup();
         this.localDriveRadio = new JRadioButton();
         this.localDriveRadio.setText(this.bundle.getString("vmpanel.RADIO_BUTTON_NONE"));
         this.localDriveRadio.addActionListener(this);
         var3.add(this.localDriveRadio);
         if (!Platform.isVirtualMediaSupported()) {
            RRCLogger.log(200, 1024, "Client Platform is " + System.getProperty("os.name") + ". Disabling full Local radio button 1 ");
            this.localDriveRadio.setEnabled(false);
         }

         GridBagConstraints var4 = new GridBagConstraints();
         var4.gridx = 0;
         var4.gridy = 0;
         var4.gridwidth = 2;
         var4.gridheight = 1;
         var4.anchor = 23;
         var4.weightx = 1.0;
         var4.fill = 2;
         var4.insets = new Insets(6, 2, 0, 0);
         this.generalPanel.add(this.localDriveRadio, var4);
         this.availableDrivesCombo = new JComboBox();
         this.availableDrivesCombo.addItemListener(this);
         if (!Platform.isVirtualMediaSupported()) {
            RRCLogger.log(200, 1024, "Client Platform is " + System.getProperty("os.name") + ". Disabling Drives combo");
            this.availableDrivesCombo.setEnabled(false);
         }

         var4.gridy = 1;
         var4.gridwidth = 1;
         var4.insets = new Insets(4, 22, 0, 6);
         this.generalPanel.add(this.availableDrivesCombo, var4);
         this.diskImageRadioButton = new JRadioButton();
         this.diskImageRadioButton.setText(this.bundle.getString("vmpanel.RADIO_BUTTON_DISK_IMAGE"));
         this.diskImageRadioButton.addActionListener(this);
         var3.add(this.diskImageRadioButton);
         var4.gridy = 2;
         var4.gridwidth = 2;
         var4.insets = new Insets(20, 2, 0, 0);
         this.generalPanel.add(this.diskImageRadioButton, var4);
         this.imageText = new JTextField();
         this.imageText.setPreferredSize(new Dimension(this.imageText.getPreferredSize().width, 20));
         JLabel var5 = new JLabel(this.bundle.getString("vmpanel.diskimagepath"));
         var4.gridy = 3;
         var4.gridwidth = 2;
         var4.insets = new Insets(4, 22, 0, 0);
         this.generalPanel.add(var5, var4);
         var4.gridy = 4;
         var4.gridwidth = 1;
         var4.insets = new Insets(4, 22, 0, 6);
         this.generalPanel.add(this.imageText, var4);
         this.browseButton = new JButton(this.bundle.getString("vmpanel.browse"));
         this.browseButton.addActionListener(this);
         var4.gridx = 1;
         var4.gridy = 4;
         var4.gridwidth = 1;
         var4.fill = 3;
         var4.insets = new Insets(4, 6, 0, 0);
         this.generalPanel.add(this.browseButton, var4);
         this.remoteImageRadioButton = new JRadioButton();
         this.remoteImageRadioButton.setText(this.bundle.getString("vmpanel.RADIO_BUTTON_PRE_CONF"));
         this.remoteImageRadioButton.addActionListener(this);
         var3.add(this.remoteImageRadioButton);
         var4.gridy = 5;
         var4.gridwidth = 2;
         var4.gridx = 0;
         var4.fill = 2;
         var4.insets = new Insets(20, 2, 0, 0);
         this.generalPanel.add(this.remoteImageRadioButton, var4);
         var5 = new JLabel(this.bundle.getString("vmpanel.hosts"));
         var4.gridy = 6;
         var4.gridwidth = 1;
         var4.insets = new Insets(4, 22, 0, 0);
         this.generalPanel.add(var5, var4);
         this.hostsCombo = new JComboBox() {
            @Override
            public void setSelectedItem(Object var1) {
               super.setSelectedItem(var1);
               this.setToolTipText(var1 != null ? var1.toString() : null);
            }
         };
         this.hostsCombo.addItemListener(this);
         var4.gridy = 7;
         var4.gridwidth = 1;
         var4.insets = new Insets(2, 22, 0, 6);
         this.generalPanel.add(this.hostsCombo, var4);
         Dimension var6 = this.hostsCombo.getPreferredSize();
         var6.width = Util.getSizeOfIPV6Component(this.hostsCombo.getFontMetrics(this.hostsCombo.getFont()));
         this.hostsCombo.setPreferredSize(var6);
         var5 = new JLabel(this.bundle.getString("vmpanel.image"));
         var4.gridy = 6;
         var4.gridx = 1;
         var4.gridwidth = 1;
         var4.insets = new Insets(4, 6, 0, 0);
         this.generalPanel.add(var5, var4);
         this.imagesCombo = new JComboBox();
         this.imagesCombo.addItemListener(this);
         var4.gridy = 7;
         var4.gridx = 1;
         var4.gridwidth = 1;
         var4.insets = new Insets(2, 6, 0, 22);
         this.imagesCombo.setPreferredSize(var6);
         this.generalPanel.add(this.imagesCombo, var4);
         this.usersText = new JTextField();
         this.usersText.setDocument(new LimitedLengthDocument());
         this.usersText.setPreferredSize(new Dimension(this.usersText.getPreferredSize().width, 20));
         this.usersText.addActionListener(this);
         var5 = new JLabel(this.bundle.getString("vmpanel.username"));
         var4.gridy = 8;
         var4.gridx = 0;
         var4.gridwidth = 1;
         var4.insets = new Insets(6, 22, 0, 0);
         this.generalPanel.add(var5, var4);
         var4.gridy = 9;
         var4.gridwidth = 1;
         var4.insets = new Insets(2, 22, 12, 6);
         this.generalPanel.add(this.usersText, var4);
         this.userPwdText = new JPasswordField();
         this.userPwdText.setDocument(new LimitedLengthDocument());
         this.userPwdText.setPreferredSize(new Dimension(this.userPwdText.getWidth(), 20));
         this.userPwdText.setEchoChar('*');
         this.userPwdText.addActionListener(this);
         var5 = new JLabel(this.bundle.getString("vmpanel.password"));
         var4.gridy = 8;
         var4.gridx = 1;
         var4.gridwidth = 1;
         var4.insets = new Insets(6, 6, 0, 0);
         this.generalPanel.add(var5, var4);
         var4.gridy = 9;
         var4.gridx = 1;
         var4.gridwidth = 1;
         var4.insets = new Insets(2, 6, 12, 22);
         this.generalPanel.add(this.userPwdText, var4);
         this.generalPanel.setBorder(BorderFactory.createEtchedBorder());
         var1.setBorder(BorderFactory.createEtchedBorder());
         this.mainPanel.add(var1);
         this.mainPanel.add(this.generalPanel);
         this.mainPanel.add(this.doButtonWidget());
         SpringUtilities.makeCompactGrid(this.mainPanel, 3, 1, 1, 1, 1, 1);
         this.add(this.mainPanel, "Center");
         this.cancelButton.enableInputMethods(false);
         this.browseButton.enableInputMethods(false);
         this.connectButton.enableInputMethods(false);
         this.setVisible(true);
         this.resetDrives();
      } catch (Exception var7) {
         RRCLogger.logException(var7);
      }
   }

   public void populateVMPanel(VirtualMediaBean var1) {
      try {
         this.portKey = var1.getPortKey();
         if (Platform.isVirtualMediaSupported()) {
            this.localDriveRadio.setSelected(true);
            this.availableDrivesCombo.setEnabled(true);
            this.populateComboBoxes();
            if (!this.availableDrivesCombo.isEnabled()) {
               this.localDriveRadio.setEnabled(false);
            }

            this.imageText.setText("");
            boolean var2 = !this.localDriveRadio.isEnabled();
            this.diskImageRadioButton.setSelected(var2);
            this.imageText.setEnabled(var2);
            this.browseButton.setEnabled(var2);
         } else {
            this.localDriveRadio.setEnabled(false);
            this.availableDrivesCombo.setSelectedIndex(-1);
            this.availableDrivesCombo.setEnabled(false);
            this.diskImageRadioButton.setSelected(true);
            this.imageText.setEnabled(true);
            this.imageText.setText("");
            this.browseButton.setEnabled(true);
         }

         this.hostsCombo.setSelectedIndex(-1);
         this.hostsCombo.setEnabled(false);
         this.imagesCombo.setSelectedIndex(-1);
         this.imagesCombo.setEnabled(false);
         this.isDriveConnected = false;
         this.imageText.setText("");
         this.usersText.setText("");
         this.usersText.setEnabled(false);
         this.userPwdText.setText("");
         this.userPwdText.setEnabled(false);
         var1.getRFBView().setVMImagePanel(this);
         this.host = var1.getRFBProfile().getRemoteHost();
         var1.getVmCore().addNotificationListener(this.vmAdapter);
         var1.getVmCore().addVirtualMediaEventListener(this.vmAdapter, 7);
         List var4 = var1.getRFBView().getRemoteIsoList();
         this.remoteImageRadioButton.setEnabled(var4.size() > 0);
      } catch (Exception var3) {
         RRCLogger.log(200, 1024, "Unable to populate VM Panel using VMBean values");
         RRCLogger.logException(var3);
      }
   }

   private static void adjustMaximumSize(JComponent var0) {
      Dimension var1 = var0.getMaximumSize();
      var1.height = var0.getPreferredSize().height;
      var1.width = 160;
      var0.setMaximumSize(var1);
   }

   private void populateComboBoxes() {
      this.drives = this.getAvailableDrives();
      this.availableDrivesModel = new DefaultComboBoxModel();

      for (RedirectableObject var2 : this.drives) {
         this.availableDrivesModel.addElement(var2.getLongName());
      }

      this.availableDrivesCombo.setModel(this.availableDrivesModel);
      this.availableDrivesCombo.setEnabled(this.availableDrivesCombo.getItemCount() > 0);
      if (this.availableDrivesCombo.isEnabled()) {
         this.availableDrivesCombo.setSelectedIndex(0);
      }
   }

   public void populateVMPanelBean(VirtualMediaBean var1) {
      try {
         Map var2 = this.scrContext.getVirtualMediaImageMap();
         if (var1 != null) {
            var2.remove(this.portKey);
            var1.setDriveConnected(true);
            var1.setConnectedDrive(this.driveSelected);
            var1.setConnectionType(this.connectionType);
            var2.put(this.portKey, var1);
         } else {
            RRCLogger.log(200, 1024, "Error populating Bean. vmBean is NULL.");
         }

         this.scrContext.setVitualMediaImageMap(var2);
      } catch (Exception var4) {
         RRCLogger.log(200, 1024, "Error populating Bean");
         RRCLogger.logException(var4);
      }
   }

   public VirtualMediaImagePanel(boolean var1, ScreenContext var2) {
      super(var2);

      try {
         this.isDialog = var1;
         this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
         this.makeLayout();
         this.setShell(this.bundle.getString("vmpanel.IMAGE_PANEL_NAME"));
         this.vmAdapter = new VMAdapter() {
            @Override
            public void disconnected(Exception var1) {
               VirtualMediaImagePanel.this.disconnected(true);
            }

            @Override
            public void receivedNotification(INotificationEvent var1) {
               if (var1.getErrorCode() == 822214661) {
                  VirtualMediaImagePanel.this.connected(822214661);
               } else {
                  ErrorHandlerImpl.getInstance()
                     .handleError(var1.getErrorCode(), VirtualMediaImagePanel.this, VirtualMediaImagePanel.this.currentVirtualMediaBean.getRFBView());
                  if (var1.isQuit() || var1.isError()) {
                     VMCore var2x = null;
                     if (VirtualMediaImagePanel.this.currentVirtualMediaBean != null) {
                        var2x = VirtualMediaImagePanel.this.currentVirtualMediaBean.getVmCore();
                     }

                     if (var2x != null) {
                        var2x.disconnect(true);
                     }

                     if (VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog != null
                        && VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.isShowing()) {
                        VirtualMediaImagePanel.this.hideConnectionInProgressDialog();
                     }

                     VirtualMediaImagePanel.this.connectionType = 0;
                  }
               }
            }

            @Override
            public void driveConnected(boolean var1) {
               if (var1) {
                  VirtualMediaImagePanel.this.connected(838991872);
               }
            }
         };
      } catch (Exception var4) {
         RRCLogger.log(200, 1024, "Error Creating Virtual Media Dialog");
         RRCLogger.logException(var4);
      }
   }

   private void connected(int var1) {
      if (this.vmConnectionInProgressMsgDialog != null && this.vmConnectionInProgressMsgDialog.isShowing()) {
         this.hideConnectionInProgressDialog();
      }

      if (this.isShowing()) {
         this.getShell().getContentPane().removeAll();
         this.getShell().dispose();
      }

      Map var2 = this.scrContext.getVirtualMediaImageMap();
      VirtualMediaBean var3 = null;
      if (var2 != null) {
         var3 = (VirtualMediaBean)var2.get(this.portKey);
      }

      if (var3 != null) {
         this.populateVMPanelBean(var3);
         ((RRCScreenContext)this.scrContext).toggleMenuBar(this.portKey);
         this.showSuccessfulConnectionDialog(var3, var1);
         RRCLogger.log(200, 1024, "Drive Redirection established for Drive1.");
      }
   }

   public List<RedirectableObject> getAvailableDrives() {
      ArrayList var1 = new ArrayList();
      List var2 = RedirectableObject.getAvailableDrives(RRCLogger.getLogger());

      for (int var4 = 0; var4 < var2.size(); var4++) {
         try {
            VMCore.DriveType var3 = ((RedirectableObject)var2.get(var4)).getDriveType(RRCLogger.getLogger());
            if (var3 == VMCore.DriveType.CDROM) {
               var1.add(var2.get(var4));
            }
         } catch (IOException var6) {
            RRCLogger.getLogger()
               .log(
                  Level.WARNING, "IO Exception trying to determine drive type of drive: " + ((RedirectableObject)var2.get(var4)).getLongName(), (Throwable)var6
               );
         } catch (VMException var7) {
            RRCLogger.getLogger()
               .log(
                  Level.WARNING, "VM Exception trying to determine drive type of drive: " + ((RedirectableObject)var2.get(var4)).getLongName(), (Throwable)var7
               );
         }
      }

      return var1;
   }

   public void connectSamba() {
      Map var1 = this.scrContext.getVirtualMediaImageMap();
      if (var1 != null) {
         final VirtualMediaBean var2 = (VirtualMediaBean)var1.get(this.portKey);
         if (var2 != null) {
            this.currentVirtualMediaBean = var2;
         }

         String var3 = "";
         if (this.hostsCombo.getModel().getSelectedItem() != null) {
            var3 = this.hostsCombo.getModel().getSelectedItem().toString();
         }

         String var4 = "";
         if (this.imagesCombo.getModel().getSelectedItem() != null) {
            var4 = this.imagesCombo.getModel().getSelectedItem().toString();
         }

         if (var3.equals("") && var4.equals("")) {
            CommonPopups.showWarningDialog(
               this.bundle.getString("optionpane.warning.tite"), this.bundle.getString("vmpanel.image.error"), this, this.scrContext
            );
            return;
         }

         RRCLogger.log(200, 1024, "Trying to mount Pre-Configured Image for Drive 1");
         final VMMountRequestResponse var7 = new VMMountRequestResponse(
            1, var2.getVmInterfaceInfo().getInterfaceID(), this.usersText.getText(), new String(this.userPwdText.getPassword()), var3, var4
         );
         var2.setSambaRequest(var7);
         this.driveSelected = this.extractImageName(var4);
         this.showConnectionInProgressDialog(true);
         new Thread(new Runnable() {
            @Override
            public void run() {
               try {
                  if (var2.getRFBView() != null) {
                     VirtualMediaImagePanel.this.mountOrUnmountRemoteISO(var7, var2.getRFBView().getRCCore());
                  } else {
                     VirtualMediaImagePanel.this.hideConnectionInProgressDialog();
                     RRCLogger.log(200, 1024, "Error during Pre-configured image mount for Drive 1. View is Null.");
                  }

                  RRCLogger.log(200, 1024, "Pre-configured mount established for Drive 1.");
               } catch (Exception var2x) {
                  var2x.printStackTrace();
                  VirtualMediaImagePanel.this.hideConnectionInProgressDialog();
                  RRCLogger.log(200, 1024, "Error mounting Pre-Configured Image for Drive 1:");
                  RRCLogger.logException(var2x);
                  VirtualMediaImagePanel.this.isDriveConnected = false;
                  VirtualMediaImagePanel.this.connectionType = 0;
                  VirtualMediaImagePanel.this.populateVMPanelBean(var2);
               }
            }
         }).start();
      }
   }

   public void mountOrUnmountRemoteISO(VMMountRequestResponse var1, RCCore var2) {
      try {
         var2.mountOrUnmountRemoteIso(var1);
      } catch (RCException var4) {
         RRCLogger.getLogger().log(Level.SEVERE, "RCException occured.", (Throwable)var4);
      } catch (IOException var5) {
         RRCLogger.getLogger().log(Level.SEVERE, "IOException occured.", (Throwable)var5);
      }
   }

   public void hideDialogAfterSambaResponse(int var1) {
      try {
         this.hideConnectionInProgressDialog();
         Map var2 = this.scrContext.getVirtualMediaImageMap();
         VirtualMediaBean var3 = null;
         if (var2 != null) {
            var3 = (VirtualMediaBean)var2.get(this.portKey);
         }

         if (var3 != null) {
            if (var1 > 0) {
               if (var3.getRFBView() != null) {
                  if (var3.getRFBView().isSambaConnectSuccessful()) {
                     this.isDriveConnected = true;
                     this.connectionType = 3;
                     Shell var4 = this.getShell();
                     var4.setVisible(false);
                     var4.getContentPane().removeAll();
                     var4.dispose();
                     var3.getRFBView().setSambaConnectSuccessful(false);
                     this.populateVMPanelBean(var3);
                     int var5 = 838991872;
                     if (var1 == 2) {
                        var5 = 822214661;
                     }

                     this.showSuccessfulConnectionDialog(var3, var5);
                     RRCLogger.log(200, 1024, "Remote ISO Mount established for port" + this.portKey + " for Image:" + this.driveSelected);
                  }
               } else {
                  RRCLogger.log(200, 1024, "View is NULL when Connecting Remote ISO Mount for port:" + this.portKey);
               }
            } else if (var1 == 0) {
               if (var3.getRFBView() != null) {
                  if (var3.getRFBView().isSambaDisconnectSuccessful()) {
                     this.isDriveConnected = false;
                     this.connectionType = 0;
                     var3.getRFBView().setSambaDisconnectSuccessful(false);
                     this.scrContext.getVirtualMediaImageMap().remove(this.portKey);
                     RRCLogger.log(200, 1024, "Remote ISO Un-Mount established for port" + this.portKey + " for Image:" + this.driveSelected);
                  }
               } else {
                  RRCLogger.log(200, 1024, "View is NULL when Disconnecting Remote ISO Mount for port:" + this.portKey);
               }
            } else {
               RRCLogger.log(200, 1024, "Invalid Response Option for Remote ISO mount for port:" + this.portKey);
            }

            ((RRCScreenContext)this.scrContext).toggleMenuBar(this.portKey);
         } else {
            RRCLogger.log(200, 1024, "vmBean is NULL while disconnecting Remote ISO Mount for port:" + this.portKey);
         }
      } catch (Exception var6) {
         var6.printStackTrace();
      }
   }

   private void showConnectionInProgressDialog(final boolean var1) {
      SwingUtilities.invokeLater(
         new Runnable() {
            @Override
            public void run() {
               if (VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog == null) {
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog = new JDialog(VirtualMediaImagePanel.this.getShell(), true);
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.setSize(440, 110);
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog
                     .setTitle(VirtualMediaImagePanel.this.bundle.getString("vmpanel.CONNECT_PROGRESS_TITLE"));
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.setResizable(false);
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.setDefaultCloseOperation(0);
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.getContentPane().setLayout(new BorderLayout());
                  JPanel var1x = new JPanel(new FlowLayout(1));
                  var1x.add(new JLabel(VirtualMediaImagePanel.this.bundle.getString("vmpanel.CONNECT_PROGRESS_MESSAGE")));
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.setLocationRelativeTo(VirtualMediaImagePanel.this);
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.getContentPane().add(new JLabel(" "), "North");
                  VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.getContentPane().add(var1x);
               }

               VirtualMediaImagePanel.this.vmConnectionInProgressMsgDialog.setVisible(var1);
            }
         }
      );
   }

   private void hideConnectionInProgressDialog() {
      this.vmConnectionInProgressMsgDialog.setVisible(false);
      this.vmConnectionInProgressMsgDialog.dispose();
   }

   private void showSuccessfulConnectionDialog(final VirtualMediaBean var1, int var2) {
      final String var3;
      final String var4;
      switch (var2) {
         case 822214661:
            var3 = this.bundle.getString("optionpane.warning.tite");
            var4 = this.bundle.getString("Usb.Not.Connected");
            break;
         case 838991872:
            var3 = this.bundle.getString("optionpane.success.title");
            var4 = this.bundle.getString("vmpanel.CONNECT_SUCEESS_MESSAGE");
            break;
         default:
            var3 = this.bundle.getString("optionpane.error.title");
            var4 = this.bundle.getString("unknown.msp.status");
      }

      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            CommonPopups.showInfoDialog(var3, var4, var1.getRFBView(), VirtualMediaImagePanel.this.scrContext);
         }
      });
   }

   public void connectDrive() {
      Map var1 = this.scrContext.getVirtualMediaImageMap();
      if ((VirtualMediaBean)var1.get(this.portKey) != null) {
         this.currentVirtualMediaBean = (VirtualMediaBean)var1.get(this.portKey);
      }

      VirtualMediaBean var2 = this.currentVirtualMediaBean;
      this.driveSelected = this.availableDrivesCombo.getModel().getSelectedItem().toString();
      RRCLogger.log(200, 1024, "Trying to do Drive Redirection for Drive:." + this.driveSelected);
      final RedirectableObject var3 = this.drives.get(this.availableDrivesCombo.getSelectedIndex());
      this.showConnectionInProgressDialog(true);
      new Thread(
            new Runnable() {
               @Override
               public void run() {
                  try {
                     VirtualMediaImagePanel.this.mountSelectedDrive(var3);
                     VirtualMediaImagePanel.this.scrContext.addSelectedDrive(VirtualMediaImagePanel.this.driveSelected);
                     VirtualMediaImagePanel.this.connectionType = 1;
                  } catch (Exception var3x) {
                     VirtualMediaImagePanel.this.hideConnectionInProgressDialog();
                     String var2x = var3x.getMessage();
                     if (var2x != null && !var2x.equals("")) {
                        var2x = VirtualMediaImagePanel.this.replaceTokens(var2x, VirtualMediaImagePanel.this.getTokens());
                        CommonPopups.showWarningDialog(
                           VirtualMediaImagePanel.this.bundle.getString("optionpane.warning.tite"),
                           var2x,
                           VirtualMediaImagePanel.this,
                           VirtualMediaImagePanel.this.scrContext
                        );
                     }

                     RRCLogger.log(200, 1024, "Error Connecting Drive Redirection for Drive 1:");
                     RRCLogger.log(200, 1024, var3x.getMessage());
                     VirtualMediaImagePanel.this.isDriveConnected = false;
                     VirtualMediaImagePanel.this.connectionType = 0;
                     VirtualMediaImagePanel.this.disconnected(false);
                  }
               }
            }
         )
         .start();
   }

   protected void mountSelectedDrive(RedirectableObject var1) {
      RFBView var2 = ((VirtualMediaBean)this.scrContext.getVirtualMediaImageMap().get(this.portKey)).getRFBView();

      try {
         if (var2 != null) {
            VMConfigInfo var3 = var2.getPort().getVmConfigInfo();
            VMInterfaceInfo var4 = var3.getVMInterface(1);
            this.currentVirtualMediaBean.getVmCore().setMsIndex(var4.getInterfaceID());
            RemoteConsoleParameters var5 = var2.getRCParameters();
            this.currentVirtualMediaBean
               .getVmCore()
               .connectVMWithRdmSession(
                  var5.host,
                  var5.tcpPort,
                  var5.ssl,
                  var2.getPortUniqueId(),
                  var2.getRfbSessionId(),
                  var1,
                  true,
                  VMCore.LockFailBehavior.ASK,
                  var5.rdmSession,
                  var5.proxyConnectionIdVM,
                  var5.proxyUseSSL
               );
         }
      } catch (Exception var6) {
         var6.printStackTrace();
         RRCLogger.getLogger().log(Level.SEVERE, "Unexpected Error happened during Virtual Media connection.", (Throwable)var6);
         CommonPopups.showWarningDialog(this.bundle.getString("optionpane.warning.tite"), var6.getMessage(), this, this.scrContext);
         this.hideConnectionInProgressDialog();
      }
   }

   public void sambaMountError() {
      this.showConnectionInProgressDialog(false);
   }

   private void connectIso() {
      if (this.imageText.getText().equals("")) {
         CommonPopups.showWarningDialog(this.bundle.getString("optionpane.warning.tite"), this.bundle.getString("vmpanel.iso.error"), this, this.scrContext);
      } else {
         Map var1 = this.scrContext.getVirtualMediaImageMap();
         final VirtualMediaBean var2 = (VirtualMediaBean)var1.get(this.portKey);
         if (var2 == null) {
            var2 = this.currentVirtualMediaBean;
         } else {
            this.currentVirtualMediaBean = var2;
         }

         this.setFileNameInBean(var2, this.imageText);
         RRCLogger.log(200, 1024, "Trying to connect ISO image for Drive 1.");
         File var4 = null;
         boolean var5 = false;
         var4 = new File(var2.getIsoDirectory(), var2.getIsoFilename());
         var5 = var4.exists() && var4.isFile() && var4.canRead() && var2.getIsoFilename().toLowerCase().endsWith(".iso");
         if (!var5) {
            RRCLogger.log(200, 1024, "Error connecting ISO Drive 1:NOT a valid ISO file.");
            CommonPopups.showWarningDialog(
               this.bundle.getString("optionpane.warning.tite"), this.bundle.getString("vmpanel.WARNING_MESSAGE_ISO"), this, this.scrContext
            );
            this.disconnected(false);
         } else {
            final RedirectableObject var6 = RedirectableObject.getIsoImage(new File(var2.getIsoDirectory(), var2.getIsoFilename()));
            this.showConnectionInProgressDialog(true);
            new Thread(
                  new Runnable() {
                     @Override
                     public void run() {
                        try {
                           VirtualMediaImagePanel.this.mountSelectedDrive(var6);
                           RRCLogger.log(200, 1024, "ISO Image redirected for Drive 1.");
                           VirtualMediaImagePanel.this.connectionType = 2;
                           VirtualMediaImagePanel.this.driveSelected = var2.getIsoFilename();
                        } catch (Exception var3) {
                           VirtualMediaImagePanel.this.hideConnectionInProgressDialog();
                           if (var3 instanceof FileNotFoundException) {
                              CommonPopups.showWarningDialog(
                                 VirtualMediaImagePanel.this.bundle.getString("optionpane.warning.tite"),
                                 VirtualMediaImagePanel.this.bundle.getString("vmpanel.WARNING_MESSAGE_ISO"),
                                 VirtualMediaImagePanel.this,
                                 VirtualMediaImagePanel.this.scrContext
                              );
                              return;
                           }

                           String var2x = var3.getMessage();
                           if (var2x != null) {
                              var2x = VirtualMediaImagePanel.this.replaceTokens(var2x, VirtualMediaImagePanel.this.getTokens());
                              CommonPopups.showWarningDialog(
                                 VirtualMediaImagePanel.this.bundle.getString("optionpane.warning.tite"),
                                 var2x,
                                 VirtualMediaImagePanel.this,
                                 VirtualMediaImagePanel.this.scrContext
                              );
                           }

                           RRCLogger.log(200, 1024, "Error Connecting Drive Redirection for Drive 1:");
                           RRCLogger.log(200, 1024, var3.getMessage());
                           VirtualMediaImagePanel.this.isDriveConnected = false;
                           VirtualMediaImagePanel.this.connectionType = 0;
                           VirtualMediaImagePanel.this.disconnected(false);
                        }
                     }
                  }
               )
               .start();
         }
      }
   }

   public void disconnected(boolean var1) {
      RRCLogger.log(200, 1024, "Disconnecting Drive 1 ...");
      if (this.vmConnectionInProgressMsgDialog != null && this.vmConnectionInProgressMsgDialog.isShowing()) {
         this.vmConnectionInProgressMsgDialog.dispose();
      }

      if (this.isShowing()) {
         this.getShell().getContentPane().removeAll();
         this.getShell().dispose();
      }

      Map var2 = this.scrContext.getVirtualMediaImageMap();
      VirtualMediaBean var3 = null;
      if (var2 != null) {
         var3 = (VirtualMediaBean)var2.get(this.portKey);
      }

      if (var3 != null) {
         if (!var1) {
            var3.getVmCore().disconnect(true);
         }

         var3.setDriveConnected(false);
         this.isDriveConnected = false;
         this.imageText.setText("");
         this.connectionType = 0;
         this.driveSelected = "";
         if (var2.containsKey(this.portKey)) {
            var2.remove(this.portKey);
         }

         ((RRCScreenContext)this.scrContext).toggleMenuBar(this.portKey);
         if (var1 && !var3.getSwitchedFlag()) {
            CommonPopups.showWarningDialog(
               this.bundle.getString("vmpanel.disconnect.title"), this.bundle.getString("vmpanel.DEVICE_DISCONNECT_NOTE"), this, this.scrContext
            );
            RRCLogger.log(200, 1024, "Disconnected by the device!");
         } else {
            RRCLogger.log(200, 1024, "Successfully Disconnected Drive Redirection.");
         }

         if (var3.getRFBView() != null) {
            var3.getRFBView().setVMImagePanel(null);
         }
      }
   }

   public void resetDrives() {
      this.localDriveRadio.setSelected(true);
      this.connectButton.setEnabled(true);
      this.availableDrivesCombo.setSelectedIndex(-1);
      this.imageText.setText("");
      this.imagesCombo.setSelectedIndex(-1);
      this.driveOneSetEnabled(false);
   }

   public void resetDrive1() {
      this.localDriveRadio.setSelected(true);
      this.availableDrivesCombo.setSelectedIndex(-1);
      this.usersText.setText("");
      this.userPwdText.setText("");
      this.imageText.setText("");
      this.imagesCombo.setSelectedIndex(-1);
      this.driveOneSetEnabled(false);
   }

   public void driveOneSetEnabled(boolean var1) {
      this.hostsCombo.setEnabled(var1);
      this.imagesCombo.setEnabled(var1);
      this.imageText.setEnabled(var1);
      this.browseButton.setEnabled(var1);
      this.usersText.setEnabled(var1);
      this.userPwdText.setEnabled(var1);
   }

   @Override
   public JPanel doButtonWidget() {
      this.cancelButton = new JButton(this.bundle.getString("vmpanel.cancel"));
      this.connectButton = new JButton(this.bundle.getString("vmpanel.connect"));
      this.buttonPanel = new JPanel(new GridBagLayout());
      GridBagConstraints var1 = new GridBagConstraints();
      var1.gridx = 0;
      var1.gridy = 0;
      var1.gridwidth = 1;
      var1.gridheight = 1;
      var1.fill = 0;
      var1.weightx = 1.0;
      var1.anchor = 13;
      var1.insets = new Insets(10, 0, 10, 10);
      this.connectButton.addActionListener(this);
      this.cancelButton.addActionListener(this);
      this.buttonPanel.add(this.connectButton, var1);
      var1.gridx = 1;
      var1.weightx = 0.0;
      var1.insets = new Insets(10, 0, 10, 22);
      this.buttonPanel.add(this.cancelButton, var1);
      return this.buttonPanel;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      if (var2 instanceof JRadioButton) {
         if (var2 == this.localDriveRadio) {
            this.populateComboBoxes();
            this.availableDrivesCombo.setModel(this.availableDrivesModel);
            this.availableDrivesCombo.setEnabled(true);
            this.connectButton.setEnabled(true);
            this.imageText.setText("");
            this.imageText.setEnabled(false);
            this.browseButton.setEnabled(false);
            this.hostsCombo.removeAllItems();
            this.hostsCombo.setEnabled(false);
            this.imagesCombo.removeAllItems();
            this.imagesCombo.setEnabled(false);
            this.usersText.setText("");
            this.usersText.setEnabled(false);
            this.userPwdText.setText("");
            this.userPwdText.setEnabled(false);
         }

         if (var2 == this.diskImageRadioButton) {
            this.imageText.setEnabled(true);
            this.browseButton.setEnabled(true);
            this.connectButton.setEnabled(true);
            this.availableDrivesCombo.removeAllItems();
            this.availableDrivesCombo.setEnabled(false);
            this.hostsCombo.removeAllItems();
            this.hostsCombo.setEnabled(false);
            this.imagesCombo.removeAllItems();
            this.imagesCombo.setEnabled(false);
            this.usersText.setText("");
            this.usersText.setEnabled(false);
            this.userPwdText.setText("");
            this.userPwdText.setEnabled(false);
         }

         if (var2 == this.remoteImageRadioButton && this.remoteImageRadioButton.isSelected()) {
            this.hostsCombo.setEnabled(true);
            this.imagesCombo.removeAllItems();
            this.imagesCombo.setEnabled(true);
            this.userPwdText.setText("");
            this.userPwdText.setEnabled(true);
            this.userPwdText.setText("");
            this.usersText.setEnabled(true);
            this.connectButton.setEnabled(true);
            this.availableDrivesCombo.removeAllItems();
            this.availableDrivesCombo.setEnabled(false);
            this.imageText.setText("");
            this.imageText.setEnabled(false);
            this.browseButton.setEnabled(false);
            this.populateRemoteIsoInfo();
         }
      }

      if (var2 instanceof JButton) {
         boolean var3 = true;
         Map var4 = this.scrContext.getVirtualMediaImageMap();
         VirtualMediaBean var5 = (VirtualMediaBean)var4.get(this.portKey);
         if (var5 == null) {
            var5 = this.currentVirtualMediaBean;
         } else {
            this.currentVirtualMediaBean = var5;
         }

         if (var2 == this.browseButton) {
            try {
               JFileChooser var6 = new JFileChooser(System.getProperty("user.home")) {
                  @Override
                  protected JDialog createDialog(Component var1) throws HeadlessException {
                     JDialog var2x = super.createDialog(var1);
                     MPCUtil.jre17WorkaroundInheritAlwaysOnTop(var2x);
                     return var2x;
                  }
               };
               var6.setDialogType(0);
               var6.setDialogTitle(this.bundle.getString("vmpanel.filedialogname"));
               var6.setMultiSelectionEnabled(false);
               var6.addChoosableFileFilter(new VirtualMediaImagePanel.isoFileFilter());
               int var7 = var6.showOpenDialog(this);
               if (var7 == 0) {
                  File var8 = var6.getSelectedFile();
                  var6.setCurrentDirectory(var8);
                  var5.setIsoFilename(var8.getName());
                  this.imageText.setText(var8.getAbsolutePath());
                  this.imageText.setToolTipText(var8.getAbsolutePath());
                  var8 = null;
               }
            } catch (Exception var9) {
               RRCLogger.log(200, 1024, var9.getMessage());
            }

            var3 = false;
         }

         if (var2 == this.connectButton) {
            if (!this.isDriveConnected) {
               if (this.localDriveRadio.isSelected()) {
                  if (this.availableDrivesCombo.getModel().getSelectedItem() != null) {
                     this.connectDrive();
                  }
               } else if (this.diskImageRadioButton.isSelected()) {
                  this.connectIso();
               } else if (this.remoteImageRadioButton.isSelected()) {
                  this.connectSamba();
               }
            }

            var3 = true;
         }

         if (var2 == this.cancelButton) {
            this.getShell().setVisible(false);
            this.getShell().dispose();
            var3 = true;
            if (var5 != null && this.vmAdapter != null) {
               var5.getVmCore().removeVirtualMediaEventListener(this.vmAdapter);
               var5.getVmCore().removeNotificationListener(this.vmAdapter);
            }
         }
      }

      if (var2 instanceof JComboBox) {
      }

      this.scrContext.getLogger().logTextDebug("finished");
   }

   private void populateRemoteIsoInfo() {
      this.hostsCombo.removeItemListener(this);
      Map var1 = this.scrContext.getVirtualMediaImageMap();
      VirtualMediaBean var2 = (VirtualMediaBean)var1.get(this.portKey);
      List var3 = var2.getRFBView().getRemoteIsoList();
      this.remoteIsos = new Hashtable<>();

      for (IVMMountRequestResponse var6 : var3) {
         Vector var4 = this.remoteIsos.get(var6.getHost());
         if (var4 == null) {
            var4 = new Vector();
         }

         var4.add(var6.getImage());
         this.remoteIsos.put(var6.getHost(), var4);
      }

      this.hostsModel = new DefaultComboBoxModel();
      String[] var7 = this.remoteIsos.keySet().toArray(new String[0]);

      for (int var8 = 0; var8 < var7.length; var8++) {
         this.hostsModel.addElement(var7[var8]);
      }

      this.hostsCombo.setModel(this.hostsModel);
      if (this.hostsCombo.getItemCount() > 0) {
         this.hostsCombo.setEnabled(true);
         this.imagesCombo.setEnabled(true);
         this.usersText.setEnabled(true);
         this.userPwdText.setEnabled(true);
         this.hostsCombo.addItemListener(this);
         this.itemStateChanged(new ItemEvent(this.hostsCombo, 701, this.hostsCombo, 1));
      }
   }

   private VirtualMediaBean setFileNameInBean(VirtualMediaBean var1, JTextField var2) {
      if (var2 != null && !var2.getText().equals("")) {
         int var3;
         if (System.getProperty("file.separator").equals("/")) {
            var3 = var2.getText().lastIndexOf("/", var2.getText().length());
         } else {
            var3 = var2.getText().lastIndexOf("\\", var2.getText().length());
         }

         if (var3 != -1) {
            var1.setIsoFilename(var2.getText().substring(var3 + 1));
            var1.setIsoDirectory(var2.getText().substring(0, var3));
         }
      }

      return var1;
   }

   public String extractImageName(String var1) {
      String var2 = "";
      if (var1 != null && !var1.equals("")) {
         int var3 = var1.lastIndexOf(47);
         var2 = var1.substring(var3 + 1);
      }

      return var2;
   }

   private void populateImagesCombo2() {
   }

   private void drive1RadioEnable(boolean var1) {
      this.localDriveRadio.setEnabled(Platform.isVirtualMediaSupported() ? var1 : false);
      this.diskImageRadioButton.setEnabled(var1);
      this.remoteImageRadioButton.setEnabled(var1);
   }

   public int get_current_port() {
      Map var1 = this.scrContext.getVirtualMediaImageMap();
      VirtualMediaBean var2 = (VirtualMediaBean)var1.get(this.portKey);
      return var2.getPort();
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   public static void main(String[] var0) {
      VirtualMediaImagePanel var1 = new VirtualMediaImagePanel(true, null);
      var1.makeLayout();
   }

   @Override
   public void itemStateChanged(ItemEvent var1) {
      if (this.remoteImageRadioButton.isSelected()) {
         if (var1.getSource() == this.imagesCombo) {
            String var2 = (String)this.imagesCombo.getModel().getSelectedItem();
            this.imagesCombo.setToolTipText(var2);
         }

         if (var1.getSource() == this.hostsCombo) {
            String var6 = this.hostsCombo.getSelectedItem().toString();
            Vector var3 = this.remoteIsos.get(var6);
            this.hostsCombo.setToolTipText((String)this.hostsCombo.getModel().getSelectedItem());
            this.imagesModel = new DefaultComboBoxModel();

            for (String var5 : var3) {
               this.imagesModel.addElement(var5);
            }

            this.imagesCombo.setModel(this.imagesModel);
         }
      }
   }

   public String[] getTokens() {
      Map var1 = this.scrContext.getVirtualMediaImageMap();
      VirtualMediaBean var2 = null;
      String var3 = "";
      if (var1 != null) {
         var2 = (VirtualMediaBean)var1.get(this.portKey);
      }

      if (var2 != null && var2.getRFBView() != null) {
         var3 = var2.getRFBView().getPortName();
      }

      return new String[]{var3};
   }

   private String replaceTokens(String var1, String[] var2) {
      if (var2 != null && var2.length > 0) {
         return MessageFormat.format(var1, var2);
      } else {
         RRCLogger.log(200, -1, "Tokens are null");
         return null;
      }
   }

   private class isoFileFilter extends FileFilter {
      private isoFileFilter() {
      }

      @Override
      public boolean accept(File var1) {
         return var1.getName().toLowerCase().endsWith(".iso") || var1.isDirectory();
      }

      @Override
      public String getDescription() {
         return VirtualMediaImagePanel.this.bundle.getString("filetype.iso");
      }
   }
}
