package com.raritan.rrc.ui.panes;

import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.VMConfigInfo;
import com.raritan.rrc.data.VMInterfaceInfo;
import com.raritan.rrc.data.VirtualMediaLocalBean;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.OS;
import com.raritan.rrc.util.SpringUtilities;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SpringLayout;
import javax.swing.SwingUtilities;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.core.INotificationEvent;
import nn.pp.core.Platform;
import nn.pp.logging.RemoteConsoleLogger;
import nn.pp.rccore.IKvmPort;
import nn.pp.vmcore.RedirectableObject;
import nn.pp.vmcore.VMAdapter;
import nn.pp.vmcore.VMCore;
import nn.pp.vmcore.VMException;
import nn.pp.vmcore.VirtualMediaEventListener;

public class VirtualMediaLocalPanel extends AbstractDisplay implements ActionListener, ItemListener {
   private static final long serialVersionUID = 2677565149168348926L;
   protected RaritanPropertyResourceBundle bundle;
   private String portKey;
   private String host;
   private JPanel generalPanel;
   private JCheckBox readWriteCheckBoxConn1;
   private boolean overrideReadWrite;
   private DefaultComboBoxModel availableDrivesModel1;
   private VirtualMediaLocalPanel.ComboBoxType availableDrivesCombo1;
   private JButton connectButton;
   private JButton cancelButton;
   private JPanel buttonPanel;
   private JPanel firstPanel;
   private JPanel mainPanel;
   private static final String PANEL_NAME = "vmpanel.LOCAL_PANEL_NAME";
   private static final String WARNING_MESSAGE = "vmpanel.WARNING_MESSAGE";
   private static final String POPUP_OPTION_YES = "vmpanel.POPUP_OPTION_YES";
   private static final String POPUP_OPTION_NO = "vmpanel.POPUP_OPTION_NO";
   private static final String PANEL_INFO_MESSAGE = "vmpanel.PANEL_INFO_MESSAGE";
   private static final String DRIVE_OR_HOST_NAME = "vmpanel.localdrive";
   private static final String READ_WRITE = "vmpanel.readwrite";
   private static final String CANCEL = "vmpanel.cancel";
   private static final String CONNECT = "vmpanel.connect";
   private static final String CONNECT_SUCEESS_MESSAGE = "vmpanel.CONNECT_SUCEESS_MESSAGE";
   private static final String CONNECT_SUCEESS_MESSAGE_LONG = "vmpanel.CONNECT_SUCEESS_MESSAGE_LONG";
   private static final String CONNECT_PROGRESS_TITLE = "vmpanel.CONNECT_PROGRESS_TITLE";
   private static final String CONNECT_PROGRESS_MESSAGE = "vmpanel.CONNECT_PROGRESS_MESSAGE";
   private boolean isDriveConnected = false;
   private String driveSelected;
   private JDialog vmConnectionInProgressMsgDialog = null;
   private VirtualMediaLocalBean currentVirtualMediaBean = null;
   private VMAdapter vmAdapter;
   private List<RedirectableObject> drives;

   @Override
   public void makeLayout() {
      try {
         RRCLogger.log(200, 1024, "Client Platform : " + OS.getCurrent());
         this.mainPanel = new JPanel(new SpringLayout());
         this.generalPanel = new JPanel(new SpringLayout());
         this.firstPanel = new JPanel(new SpringLayout());
         JPanel var1 = new JPanel(new SpringLayout());
         JLabel var2 = new JLabel(this.bundle.getString("vmpanel.PANEL_INFO_MESSAGE"));
         var1.add(var2);
         SpringUtilities.makeCompactGrid(var1, 1, 1, 6, 1, 1, 1);
         JPanel var3 = new JPanel(new SpringLayout());
         this.availableDrivesCombo1 = new VirtualMediaLocalPanel.ComboBoxType();
         this.availableDrivesCombo1.addItemListener(this);
         var3.add(new JLabel(this.bundle.getString("vmpanel.localdrive")));
         var3.add(this.availableDrivesCombo1);
         SpringUtilities.makeCompactGrid(var3, 2, 1, 10, 1, 1, 1);
         JPanel var4 = new JPanel(new SpringLayout());
         String var5 = this.bundle.getString("vmpanel.readwrite");
         this.readWriteCheckBoxConn1 = new JCheckBox(var5);
         this.readWriteCheckBoxConn1.setSelected(false);
         this.readWriteCheckBoxConn1.setEnabled(Platform.isVirtualMediaReadWriteSupported());
         this.readWriteCheckBoxConn1.addActionListener(this);
         var4.add(this.readWriteCheckBoxConn1);
         SpringUtilities.makeCompactGrid(var4, 1, 1, 7, 0, 0, 10);
         this.firstPanel.add(var3);
         SpringUtilities.makeCompactGrid(this.firstPanel, 1, 1, 1, 1, 1, 1);
         this.generalPanel.add(this.firstPanel);
         this.generalPanel.add(var4);
         SpringUtilities.makeCompactGrid(this.generalPanel, 2, 1, 1, 1, 1, 1);
         this.generalPanel.setBorder(BorderFactory.createEtchedBorder());
         var1.setBorder(BorderFactory.createEtchedBorder());
         this.mainPanel.add(var1);
         this.mainPanel.add(this.generalPanel);
         this.mainPanel.add(this.doButtonWidget());
         SpringUtilities.makeCompactGrid(this.mainPanel, 3, 1, 1, 1, 1, 1);
         this.add(this.mainPanel, "Center");
         this.setVisible(true);
         this.cancelButton.enableInputMethods(false);
         this.connectButton.enableInputMethods(false);
         this.resetDrives();
         this.availableDrivesCombo1.addKeyListener(new KeyAdapter() {
            @Override
            public void keyReleased(KeyEvent var1) {
               if (var1.getKeyCode() == 33 && var1.isControlDown() && var1.isAltDown()) {
               }
            }
         });
      } catch (Exception var6) {
         RRCLogger.logException(var6);
      }
   }

   public boolean populateVMPanel(VirtualMediaLocalBean var1) {
      this.overrideReadWrite = false;
      this.drives = this.getAvailableDrives();
      if (this.drives.size() == 0) {
         return false;
      } else {
         try {
            this.portKey = var1.getPortKey();
            this.readWriteCheckBoxConn1.setSelected(false);
            this.isDriveConnected = false;
            KvmPort var2;
            if (var1.getRFBView() != null && (var2 = var1.getRFBView().getPort()) != null) {
               if (var2.getPortPermissionHelper().getVmPermission() == IKvmPort.VmPermission.READWRITE && Platform.isVirtualMediaReadWriteSupported()) {
                  this.readWriteCheckBoxConn1.setSelected(false);
                  this.readWriteCheckBoxConn1.setEnabled(true);
               } else {
                  this.readWriteCheckBoxConn1.setSelected(false);
                  this.readWriteCheckBoxConn1.setEnabled(false);
               }
            }

            var1.getRFBView().setVMLocalPanel(this);
            this.host = var1.getRFBProfile().getRemoteHost();
            if (Platform.isVirtualMediaSupported()) {
               this.populateComboBoxes();
            }

            var1.getVmCore().addNotificationListener(this.vmAdapter);
            var1.getVmCore().addVirtualMediaEventListener(this.vmAdapter, 7);
            return true;
         } catch (Exception var3) {
            var3.printStackTrace();
            RRCLogger.log(200, 1024, "Unable to populate VM Panel using VMBean values");
            RRCLogger.logException(var3);
            return false;
         }
      }
   }

   public List<RedirectableObject> getAvailableDrives() {
      ArrayList var1 = new ArrayList();
      List var2 = RedirectableObject.getAvailableDrives(RRCLogger.getLogger());

      for (int var4 = 0; var4 < var2.size(); var4++) {
         VMCore.DriveType var3 = VMCore.DriveType.UNKNOWN;

         try {
            var3 = ((RedirectableObject)var2.get(var4)).getDriveType(RRCLogger.getLogger());
         } catch (IOException var6) {
            RRCLogger.getLogger()
               .log(
                  Level.WARNING, "IO Exception trying to determine drive type of drive: " + ((RedirectableObject)var2.get(var4)).getLongName(), (Throwable)var6
               );
         } catch (VMException var7) {
            RRCLogger.getLogger()
               .log(
                  Level.WARNING, "VM Exception trying to determine drive type of drive: " + ((RedirectableObject)var2.get(var4)).getLongName(), (Throwable)var7
               );
         }

         if (var3 == VMCore.DriveType.FLOPPY
            || var3 == VMCore.DriveType.REMOVABLE
            || var3 == VMCore.DriveType.HARD_DISK_PARTITION
            || var3 == VMCore.DriveType.HARD_DISK_PARTITION_EXTERNAL
            || var3 == VMCore.DriveType.UNKNOWN) {
            var1.add(var2.get(var4));
         }
      }

      return var1;
   }

   private void populateComboBoxes() throws VMException, IOException {
      this.availableDrivesModel1 = new DefaultComboBoxModel();

      for (RedirectableObject var2 : this.drives) {
         this.availableDrivesModel1.addElement(var2.getLongName());
      }

      this.availableDrivesCombo1.setModel(this.availableDrivesModel1);
      this.availableDrivesCombo1.setEnabled(this.availableDrivesCombo1.getItemCount() > 0);
      if (this.availableDrivesCombo1.isEnabled()) {
         this.availableDrivesCombo1.setSelectedIndex(0);
         VMCore.DriveType var3 = this.drives.get(0).getDriveType(RRCLogger.getLogger());
         if (var3 != VMCore.DriveType.FLOPPY
               && var3 != VMCore.DriveType.REMOVABLE
               && var3 != VMCore.DriveType.HARD_DISK_PARTITION_EXTERNAL
               && !this.overrideReadWrite
            || !Platform.isVirtualMediaReadWriteSupported()) {
            this.readWriteCheckBoxConn1.setSelected(false);
            this.readWriteCheckBoxConn1.setEnabled(false);
         }
      }
   }

   public void populateVMPanelBean() {
      try {
         Map var1 = this.scrContext.getVirtualMediaLocalMap();
         VirtualMediaLocalBean var2 = (VirtualMediaLocalBean)var1.get(this.portKey);
         var1.remove(this.portKey);
         if ((VirtualMediaLocalBean)var1.get(this.portKey) != null) {
            this.currentVirtualMediaBean = (VirtualMediaLocalBean)var1.get(this.portKey);
         }

         var2 = this.currentVirtualMediaBean;
         var2.setReadWriteCheckBoxSelected(this.readWriteCheckBoxConn1.isSelected());
         var2.setDriveConnected(true);
         var2.setConnectedDrive(this.driveSelected);
         var1.put(this.portKey, var2);
         this.scrContext.setVitualMediaLocalMap(var1);
      } catch (Exception var3) {
         var3.printStackTrace();
         RRCLogger.log(200, 1024, "Error populating Bean");
         RRCLogger.logException(var3);
      }
   }

   public VirtualMediaLocalPanel(boolean var1, ScreenContext var2) {
      super(var2);

      try {
         this.isDialog = var1;
         this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
         this.makeLayout();
         this.setShell(this.bundle.getString("vmpanel.LOCAL_PANEL_NAME"));
         this.vmAdapter = new VMAdapter() {
            @Override
            public void disconnected(Exception var1) {
               VirtualMediaLocalPanel.this.disconnected(true);
            }

            @Override
            public void receivedNotification(INotificationEvent var1) {
               if (var1.getErrorCode() == 822214661) {
                  VirtualMediaLocalPanel.this.connected(822214661);
               } else {
                  ErrorHandlerImpl.getInstance()
                     .handleError(var1.getErrorCode(), VirtualMediaLocalPanel.this, VirtualMediaLocalPanel.this.currentVirtualMediaBean.getRFBView());
                  if (var1.isQuit() || var1.isError()) {
                     VMCore var2x = null;
                     if (VirtualMediaLocalPanel.this.currentVirtualMediaBean != null) {
                        var2x = VirtualMediaLocalPanel.this.currentVirtualMediaBean.getVmCore();
                     }

                     if (var2x != null) {
                        var2x.disconnect(true);
                     }

                     if (VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog != null
                        && VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.isShowing()) {
                        VirtualMediaLocalPanel.this.hideConnectionInProgressDialog();
                     }
                  }
               }
            }

            @Override
            public void driveConnected(boolean var1) {
               if (var1) {
                  VirtualMediaLocalPanel.this.connected(838991872);
               }
            }

            @Override
            public VirtualMediaEventListener.LockFailAction driveLockingFailed() {
               return VirtualMediaEventListener.LockFailAction.IGNORE;
            }
         };
      } catch (Exception var4) {
         RRCLogger.log(200, 1024, "Error Creating Virtual Media Dialog");
         RRCLogger.logException(var4);
      }
   }

   private void connected(int var1) {
      if (this.vmConnectionInProgressMsgDialog != null && this.vmConnectionInProgressMsgDialog.isShowing()) {
         this.hideConnectionInProgressDialog();
      }

      if (this.isShowing()) {
         this.getShell().getContentPane().removeAll();
         this.getShell().dispose();
      }

      Map var2 = this.scrContext.getVirtualMediaLocalMap();
      VirtualMediaLocalBean var3 = null;
      if (var2 != null) {
         var3 = (VirtualMediaLocalBean)var2.get(this.portKey);
      }

      if (var3 != null) {
         this.populateVMPanelBean();
         ((RRCScreenContext)this.scrContext).toggleMenuBar(this.portKey);
         this.showSuccessfulConnectionDialog(var3, var1);
         RRCLogger.log(200, 1024, "Drive Redirection established for Drive1.");
      }
   }

   private void showConnectionInProgressDialog(final boolean var1) {
      SwingUtilities.invokeLater(
         new Runnable() {
            @Override
            public void run() {
               if (VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog == null) {
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog = new JDialog(VirtualMediaLocalPanel.this.getShell(), true);
                  MPCUtil.jre17WorkaroundInheritAlwaysOnTop(VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog);
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.setSize(440, 110);
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog
                     .setTitle(VirtualMediaLocalPanel.this.bundle.getString("vmpanel.CONNECT_PROGRESS_TITLE"));
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.setDefaultCloseOperation(0);
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.setResizable(false);
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.getContentPane().setLayout(new BorderLayout());
                  JPanel var1x = new JPanel(new FlowLayout(1));
                  var1x.add(new JLabel(VirtualMediaLocalPanel.this.bundle.getString("vmpanel.CONNECT_PROGRESS_MESSAGE")));
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.setLocationRelativeTo(VirtualMediaLocalPanel.this);
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.getContentPane().add(new JLabel(" "), "North");
                  VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.getContentPane().add(var1x);
               }

               VirtualMediaLocalPanel.this.vmConnectionInProgressMsgDialog.setVisible(var1);
            }
         }
      );
   }

   private void hideConnectionInProgressDialog() {
      this.vmConnectionInProgressMsgDialog.setVisible(false);
      this.vmConnectionInProgressMsgDialog.dispose();
   }

   private void showSuccessfulConnectionDialog(final VirtualMediaLocalBean var1, int var2) {
      final String var3;
      final String var4;
      switch (var2) {
         case 822214661:
            var3 = this.bundle.getString("optionpane.warning.tite");
            var4 = this.bundle.getString("Usb.Not.Connected");
            break;
         case 838991872:
            var3 = this.bundle.getString("optionpane.success.title");
            var4 = this.bundle.getString("vmpanel.CONNECT_SUCEESS_MESSAGE");

            try {
               VMCore.DriveType var5 = this.drives
                  .get(this.availableDrivesCombo1.getSelectedIndex())
                  .getDriveType(RemoteConsoleLogger.getInstance().getLogger());
               if (var5 == VMCore.DriveType.HARD_DISK_FULL
                  || var5 == VMCore.DriveType.HARD_DISK_PARTITION
                  || var5 == VMCore.DriveType.HARD_DISK_FULL_EXTERNAL
                  || var5 == VMCore.DriveType.HARD_DISK_PARTITION_EXTERNAL
                  || var5 == VMCore.DriveType.UNKNOWN) {
                  var4 = var4 + "\n" + this.bundle.getString("vmpanel.CONNECT_SUCEESS_MESSAGE_LONG");
               }
            } catch (Exception var7) {
            }
            break;
         default:
            var3 = this.bundle.getString("optionpane.error.title");
            var4 = this.bundle.getString("unknown.msp.status");
      }

      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            CommonPopups.showInfoDialog(var3, var4, var1.getRFBView(), VirtualMediaLocalPanel.this.scrContext);
         }
      });
   }

   public void connectDrive1() {
      Map var1 = this.scrContext.getVirtualMediaLocalMap();
      if ((VirtualMediaLocalBean)var1.get(this.portKey) != null) {
         this.currentVirtualMediaBean = (VirtualMediaLocalBean)var1.get(this.portKey);
      }

      VirtualMediaLocalBean var2 = this.currentVirtualMediaBean;
      this.driveSelected = this.availableDrivesCombo1.getModel().getSelectedItem().toString();
      boolean var3 = this.readWriteCheckBoxConn1.isSelected();
      RRCLogger.log(200, 1024, "Trying to do Drive Redirection for Drive1:." + this.driveSelected + " with ReadWrite:" + var3);
      if (var3) {
         String[] var4 = new String[]{"vmpanel.POPUP_OPTION_YES", "vmpanel.POPUP_OPTION_NO"};
         int var5 = CommonPopups.showConfirmationDialog(
            this.bundle.getString("optionpane.warning.tite"), this.bundle.getString("vmpanel.WARNING_MESSAGE"), this, this.scrContext, var4
         );
         if (var5 == 2) {
            var3 = true;
         } else {
            this.readWriteCheckBoxConn1.setSelected(false);
            var3 = false;
         }
      }

      final RedirectableObject var8 = this.drives.get(this.availableDrivesCombo1.getSelectedIndex());
      final boolean var9 = this.readWriteCheckBoxConn1.isSelected();
      this.showConnectionInProgressDialog(true);
      new Thread(
            new Runnable() {
               @Override
               public void run() {
                  try {
                     VirtualMediaLocalPanel.this.mountSelectedDrive(var8, var9);
                     VirtualMediaLocalPanel.this.scrContext.addSelectedDrive(VirtualMediaLocalPanel.this.driveSelected);
                  } catch (Exception var3x) {
                     VirtualMediaLocalPanel.this.hideConnectionInProgressDialog();
                     String var2x = var3x.getMessage();
                     if (var2x != null && !var2x.equals("")) {
                        var2x = VirtualMediaLocalPanel.this.replaceTokens(var2x, VirtualMediaLocalPanel.this.getTokens());
                        CommonPopups.showWarningDialog(
                           VirtualMediaLocalPanel.this.bundle.getString("optionpane.warning.tite"),
                           var2x,
                           VirtualMediaLocalPanel.this,
                           VirtualMediaLocalPanel.this.scrContext
                        );
                     }

                     RRCLogger.log(200, 1024, "Error Connecting Drive Redirection for Drive 1:");
                     RRCLogger.log(200, 1024, var3x.getMessage());
                     VirtualMediaLocalPanel.this.isDriveConnected = false;
                     VirtualMediaLocalPanel.this.disconnected(false);
                  }
               }
            }
         )
         .start();
   }

   protected void mountSelectedDrive(RedirectableObject var1, boolean var2) {
      RFBView var3 = ((VirtualMediaLocalBean)this.scrContext.getVirtualMediaLocalMap().get(this.portKey)).getRFBView();
      boolean var4 = !var2;

      try {
         if (var3 != null) {
            VMConfigInfo var5 = var3.getPort().getVmConfigInfo();
            VMInterfaceInfo var6 = var5.getVMInterface(4);
            this.currentVirtualMediaBean.getVmCore().setMsIndex(var6.getInterfaceID());
            RemoteConsoleParameters var7 = var3.getRCParameters();
            this.currentVirtualMediaBean
               .getVmCore()
               .connectVMWithRdmSession(
                  var7.host,
                  var7.tcpPort,
                  var7.ssl,
                  var3.getPortUniqueId(),
                  var3.getRfbSessionId(),
                  var1,
                  var4,
                  VMCore.LockFailBehavior.ASK,
                  var7.rdmSession,
                  var7.proxyConnectionIdVM,
                  var7.proxyUseSSL
               );
         }
      } catch (Exception var8) {
         var8.printStackTrace();
         RRCLogger.getLogger().log(Level.SEVERE, "Unexpected Error happened during Virtual Media connection.", (Throwable)var8);
         CommonPopups.showWarningDialog(this.bundle.getString("optionpane.warning.tite"), var8.getMessage(), this, this.scrContext);
         this.hideConnectionInProgressDialog();
      }
   }

   public void disconnected(boolean var1) {
      RRCLogger.log(200, 1024, "Disconnecting Drive 1 ...");
      if (this.vmConnectionInProgressMsgDialog.isShowing()) {
         this.vmConnectionInProgressMsgDialog.dispose();
      }

      if (this.isShowing()) {
         this.getShell().getContentPane().removeAll();
         this.getShell().dispose();
      }

      Map var2 = this.scrContext.getVirtualMediaLocalMap();
      VirtualMediaLocalBean var3 = null;
      if (var2 != null) {
         var3 = (VirtualMediaLocalBean)var2.get(this.portKey);
      }

      if (var3 != null) {
         if (!var1) {
            var3.getVmCore().disconnect(true);
         }

         var3.setDriveConnected(false);
         this.isDriveConnected = false;
         this.driveSelected = "";
         if (var2.containsKey(this.portKey)) {
            var2.remove(this.portKey);
         }

         ((RRCScreenContext)this.scrContext).toggleMenuBar(this.portKey);
         if (var1 && !var3.getSwitchedFlag()) {
            CommonPopups.showWarningDialog(
               this.bundle.getString("vmpanel.disconnect.title"), this.bundle.getString("vmpanel.DEVICE_DISCONNECT_NOTE"), this, this.scrContext
            );
            RRCLogger.log(200, 1024, "Disconnected by the device!");
         } else {
            RRCLogger.log(200, 1024, "Successfully Disconnected Drive Redirection.");
         }

         if (var3.getRFBView() != null) {
            var3.getRFBView().setVMLocalPanel(null);
         }
      }
   }

   public void resetDrives() {
      this.availableDrivesCombo1.setSelectedIndex(-1);
      this.driveOneSetEnabled(true);
   }

   public void resetDrive1() {
      this.availableDrivesCombo1.setSelectedIndex(-1);
      this.driveOneSetEnabled(true);
   }

   public void driveOneSetEnabled(boolean var1) {
      this.availableDrivesCombo1.setEnabled(var1);
      this.readWriteCheckBoxConn1.setEnabled(var1 && Platform.isVirtualMediaReadWriteSupported());
   }

   @Override
   public JPanel doButtonWidget() {
      this.cancelButton = new JButton(this.bundle.getString("vmpanel.cancel"));
      this.connectButton = new JButton(this.bundle.getString("vmpanel.connect"));
      this.buttonPanel = new JPanel(new SpringLayout());
      this.connectButton.addActionListener(this);
      this.cancelButton.addActionListener(this);
      this.buttonPanel.add(this.connectButton);
      this.buttonPanel.add(this.cancelButton);
      SpringUtilities.makeCompactGrid(this.buttonPanel, 1, 2, 190, 9, 10, 9);
      return this.buttonPanel;
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      super.actionPerformed(var1);
      Object var2 = var1.getSource();
      this.scrContext.getLogger().logTextDebug("started");
      if (var2 instanceof JButton) {
         boolean var3 = true;
         Map var4 = this.scrContext.getVirtualMediaLocalMap();
         VirtualMediaLocalBean var5 = (VirtualMediaLocalBean)var4.get(this.portKey);
         if ((VirtualMediaLocalBean)var4.get(this.portKey) != null) {
            this.currentVirtualMediaBean = (VirtualMediaLocalBean)var4.get(this.portKey);
         }

         var5 = this.currentVirtualMediaBean;
         if (var2 == this.connectButton) {
            if (!var5.isDriveConnected() && this.availableDrivesCombo1.getModel().getSelectedItem() != null) {
               this.connectDrive1();
            }

            var3 = true;
         }

         if (var2 == this.cancelButton) {
            this.getShell().setVisible(false);
            this.getShell().dispose();
            var3 = true;
            if (var5 != null && this.vmAdapter != null) {
               var5.getVmCore().removeVirtualMediaEventListener(this.vmAdapter);
               var5.getVmCore().removeNotificationListener(this.vmAdapter);
            }
         }
      }

      this.scrContext.getLogger().logTextDebug("finished");
   }

   public int get_current_port() {
      Map var1 = this.scrContext.getVirtualMediaLocalMap();
      VirtualMediaLocalBean var2 = (VirtualMediaLocalBean)var1.get(this.portKey);
      return var2.getPort();
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   public static void main(String[] var0) {
      VirtualMediaLocalPanel var1 = new VirtualMediaLocalPanel(true, null);
      var1.makeLayout();
   }

   @Override
   public void itemStateChanged(ItemEvent var1) {
      try {
         Map var2 = this.scrContext.getVirtualMediaLocalMap();
         VirtualMediaLocalBean var3 = (VirtualMediaLocalBean)var2.get(this.portKey);
         if (var1.getSource() == this.availableDrivesCombo1) {
            if (this.availableDrivesCombo1.getSelectedIndex() >= 0) {
               VMCore.DriveType var4 = this.drives.get(this.availableDrivesCombo1.getSelectedIndex()).getDriveType(RRCLogger.getLogger());
               if ((
                     var4 == VMCore.DriveType.FLOPPY
                        || var4 == VMCore.DriveType.REMOVABLE
                        || var4 == VMCore.DriveType.HARD_DISK_PARTITION_EXTERNAL
                        || this.overrideReadWrite
                  )
                  && (Platform.isVirtualMediaReadWriteSupported() || this.overrideReadWrite)) {
                  boolean var5 = true;
                  KvmPort var6;
                  if (var3.getRFBView() != null
                     && (var6 = var3.getRFBView().getPort()) != null
                     && var6.getPortPermissionHelper().getVmPermission() != IKvmPort.VmPermission.READWRITE) {
                     var5 = false;
                  }

                  this.readWriteCheckBoxConn1.setEnabled(var5);
                  if (!var5) {
                     this.readWriteCheckBoxConn1.setSelected(false);
                  }
               } else {
                  this.readWriteCheckBoxConn1.setSelected(false);
                  this.readWriteCheckBoxConn1.setEnabled(false);
               }
            } else {
               KvmPort var9;
               if (var3.getRFBView() != null && (var9 = var3.getRFBView().getPort()) != null) {
                  if (var9.getPortPermissionHelper().getVmPermission() == IKvmPort.VmPermission.READWRITE && Platform.isVirtualMediaReadWriteSupported()) {
                     this.readWriteCheckBoxConn1.setSelected(false);
                     this.readWriteCheckBoxConn1.setEnabled(true);
                  } else {
                     this.readWriteCheckBoxConn1.setSelected(false);
                     this.readWriteCheckBoxConn1.setEnabled(false);
                  }
               }
            }
         }
      } catch (IOException var7) {
      } catch (VMException var8) {
      }
   }

   public void hideDialogAfterSambaResponse(int var1) {
   }

   public String[] getTokens() {
      Map var1 = this.scrContext.getVirtualMediaLocalMap();
      VirtualMediaLocalBean var2 = null;
      String var3 = "";
      if (var1 != null) {
         var2 = (VirtualMediaLocalBean)var1.get(this.portKey);
      }

      if (var2 != null && var2.getRFBView() != null) {
         var3 = var2.getRFBView().getPortName();
      }

      return new String[]{var3};
   }

   private String replaceTokens(String var1, String[] var2) {
      if (var2 != null && var2.length > 0) {
         return MessageFormat.format(var1, var2);
      } else {
         RRCLogger.log(200, -1, "Tokens are null");
         return null;
      }
   }

   class ComboBoxType extends JComboBox {
      @Override
      public Dimension getSize() {
         return new Dimension(200, 20);
      }

      @Override
      public Rectangle getBounds() {
         return new Rectangle(super.getBounds().x, super.getBounds().y, this.getSize().width, this.getSize().height);
      }

      @Override
      public Dimension getMaximumSize() {
         return this.getSize();
      }

      @Override
      public Dimension getPreferredSize() {
         return this.getSize();
      }
   }
}
