package com.raritan.rrc.ui.panes.mediator;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.CommandToggleButton;
import com.raritan.rrc.ui.components.ConnectedServersToolBar;
import com.raritan.rrc.ui.components.RRCToolBar;
import com.raritan.rrc.ui.screens.MainScreen;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.CommandCheckMenuItem;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandRadioMenuItem;
import com.raritan.tools.ui.panes.BaseTreePanel;
import com.raritan.tools.ui.panes.RaritanStatusBarPanel;
import java.util.List;
import java.util.Vector;
import javaclientlib.utils.RRCLogger;
import javax.swing.JPanel;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;
import javax.swing.Timer;

public class MainScreenMediator {
   protected RRCScreenContext scrContext;
   private JToggleButton toolBarSingleMouseCursorButton;
   private CommandToggleButton toolBarNavigatorButton;
   private CommandToggleButton toolBarScaleVideoButton;
   private CommandToggleButton toolBarBrowseAllDevicesButton;
   private CommandToggleButton toolBarFullScreenButton;
   private CommandButton toolBarRefreshButton;
   private JTabbedPane navigator;
   private JPanel message;
   private RRCToolBar toolBar;
   private RaritanStatusBarPanel statusBar;
   private JSplitPane splLeftVertical;
   private JSplitPane splHorizontal;
   private List<CommandRadioMenuItem> radioAbsoluteMouseMenuItems = new Vector<>();
   private List<CommandRadioMenuItem> radioIntelligentMouseMenuItems = new Vector<>();
   private List<CommandRadioMenuItem> radioStandardMouseMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkToolBarMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkStatusBarMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkFullScreenMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkNavigatorMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkMessageMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkAllDevicesMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkScaleVideoMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkShowWithoutTargetsMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkShowPowerstripsMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkShowToolsMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkSortByChannelNumberMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkSortByChannelNameMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkSortByChannelStatusMenuItems = new Vector<>();
   private List<CommandMenu> windowMenus = new Vector<>();
   private List<CommandMenu> keyboardMenus = new Vector<>();
   private List<CommandMenu> virtualMediaMenus = new Vector<>();
   private BaseTreePanel deviceByIPTree;
   Timer busyTimer = null;
   private ConnectedServersToolBar csToolBar;
   private List<CommandCheckMenuItem> checkCSToolBarMenuItems = new Vector<>();
   private List<CommandCheckMenuItem> checkGroupsMenuItems = new Vector<>();

   public MainScreenMediator(RRCScreenContext var1) {
      this.scrContext = var1;
   }

   public void selectToolBarView(boolean var1) {
      if (this.toolBar != null) {
         this.toolBar.setVisible(var1);

         for (CommandCheckMenuItem var3 : this.checkToolBarMenuItems) {
            var3.setSelected(var1);
         }
      } else {
         for (CommandCheckMenuItem var5 : this.checkToolBarMenuItems) {
            var5.setSelected(false);
         }
      }
   }

   public void selectStatusBarView(boolean var1) {
      if (this.statusBar != null) {
         this.statusBar.setVisible(var1);

         for (CommandCheckMenuItem var3 : this.checkStatusBarMenuItems) {
            var3.setSelected(var1);
         }
      } else {
         for (CommandCheckMenuItem var5 : this.checkStatusBarMenuItems) {
            var5.setSelected(false);
         }
      }
   }

   public void selectNavigatorView(boolean var1) {
      if (this.navigator != null) {
         this.navigator.setVisible(var1);
         if (!var1) {
            ((MainScreen)this.splLeftVertical.getParent().getParent())
               .setHorisontal((this.navigator.getSize().getWidth() + 4.0) / (this.splHorizontal.getSize().getWidth() - 7.0));
         }

         for (CommandCheckMenuItem var3 : this.checkMessageMenuItems) {
            var3.setEnabled(var1);
         }

         for (CommandCheckMenuItem var7 : this.checkNavigatorMenuItems) {
            var7.setSelected(var1);
         }

         this.toolBarNavigatorButton.setSelected(var1);
         this.toolBarBrowseAllDevicesButton.setEnabled(var1);

         for (CommandCheckMenuItem var8 : this.checkAllDevicesMenuItems) {
            var8.setEnabled(var1);
         }

         this.toolBarRefreshButton.setEnabled(var1);
      } else {
         for (CommandCheckMenuItem var9 : this.checkNavigatorMenuItems) {
            var9.setSelected(false);
         }

         this.toolBarNavigatorButton.setSelected(false);
      }

      if (this.splLeftVertical != null && this.splHorizontal != null) {
         this.splLeftVertical.setVisible(var1);
         ((MainScreen)this.splLeftVertical.getParent().getParent()).setFirstTimePainting(true);
         this.splLeftVertical.getParent().getParent().validate();
         this.splLeftVertical.getParent().getParent().repaint();
      }
   }

   public void selectMessageView(boolean var1) {
      if (this.message != null) {
         this.message.setVisible(var1);

         for (CommandCheckMenuItem var3 : this.checkMessageMenuItems) {
            var3.setSelected(var1);
         }
      } else {
         for (CommandCheckMenuItem var5 : this.checkMessageMenuItems) {
            var5.setSelected(false);
         }
      }

      if (this.splLeftVertical != null && this.splHorizontal != null) {
         this.message.setVisible(var1);
         if (var1) {
            this.splLeftVertical.setVisible(var1);
            ((MainScreen)this.splLeftVertical.getParent().getParent()).setFirstTimePainting(true);
            this.splLeftVertical.getParent().getParent().repaint();
         }

         this.splLeftVertical.getParent().getParent().validate();
      }
   }

   public void selectSingleMouseCursorMode() {
      if (this.toolBarSingleMouseCursorButton != null) {
         boolean var1 = this.toolBarSingleMouseCursorButton.isSelected();
         this.toolBarSingleMouseCursorButton.setSelected(!var1);
      }
   }

   public void selectAbsoluteMouseModeView(boolean var1) {
      for (CommandRadioMenuItem var3 : this.radioAbsoluteMouseMenuItems) {
         var3.setSelected(var1);
         RRCLogger.log(300, 4, "AbsoluteMouseMenuItem Selecting: " + var1);
      }
   }

   public void enableAbsoluteMouseModeView(boolean var1) {
      for (CommandRadioMenuItem var3 : this.radioAbsoluteMouseMenuItems) {
         var3.setEnabled(var1);
         RRCLogger.log(300, 4, "AbsoluteMouseMenuItem Enabling: " + var1);
      }
   }

   public void selectStandardMouseModeView(boolean var1) {
      for (CommandRadioMenuItem var3 : this.radioStandardMouseMenuItems) {
         var3.setSelected(var1);
         RRCLogger.log(300, 4, "StandardMouseMenuItem Selecting:" + var1);
      }
   }

   public void enableStandardMouseModeView(boolean var1) {
      for (CommandRadioMenuItem var3 : this.radioStandardMouseMenuItems) {
         var3.setEnabled(var1);
         RRCLogger.log(300, 4, "StandardMouseMenuItem Enabling:" + var1);
      }
   }

   public void selectIntelligentMouseModeView(boolean var1) {
      for (CommandRadioMenuItem var3 : this.radioIntelligentMouseMenuItems) {
         var3.setSelected(var1);
         RRCLogger.log(300, 4, "IntelligentMouseMenuItem Selecting:" + var1);
      }
   }

   public void enableIntelligentMouseModeView(boolean var1) {
      for (CommandRadioMenuItem var3 : this.radioIntelligentMouseMenuItems) {
         var3.setEnabled(var1);
         RRCLogger.log(300, 4, "IntelligentMouseMenuItem Enabling:" + var1);
      }
   }

   public void selectScaleVideo(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkScaleVideoMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void selectBrowseAllDevicesView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkAllDevicesMenuItems) {
         var3.setSelected(var1);
      }

      if (this.toolBarBrowseAllDevicesButton != null) {
         this.toolBarBrowseAllDevicesButton.setSelected(var1);
      }
   }

   public void selectShowWithoutTargetsView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkShowWithoutTargetsMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void selectShowWithoutGroupsView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkGroupsMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void selectShowPowerstripsView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkShowPowerstripsMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void selectShowToolsView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkShowToolsMenuItems) {
         var3.setSelected(var1);
      }
   }

   public List<CommandCheckMenuItem> getCheckFullScreenMenuItems() {
      return this.checkFullScreenMenuItems;
   }

   public List<CommandRadioMenuItem> getRadioAbsoluteMouseMenuItems() {
      return this.radioAbsoluteMouseMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckToolbarMenuItems() {
      return this.checkToolBarMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckStatusBarMenuItems() {
      return this.checkStatusBarMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckNavigatorMenuItems() {
      return this.checkNavigatorMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckMessageMenuItems() {
      return this.checkMessageMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckAllDevicesMenuItems() {
      return this.checkAllDevicesMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckShowWithoutTargetsMenuItems() {
      return this.checkShowWithoutTargetsMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckShowGroupsMenuItems() {
      return this.checkGroupsMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckShowPowerstripsMenuItems() {
      return this.checkShowPowerstripsMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckShowToolsMenuItems() {
      return this.checkShowToolsMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckSortByChannelNumberMenuItems() {
      return this.checkSortByChannelNumberMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckSortByChannelNameMenuItems() {
      return this.checkSortByChannelNameMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckSortByChannelStatusMenuItems() {
      return this.checkSortByChannelStatusMenuItems;
   }

   public List<CommandCheckMenuItem> getCheckScaleVideoMenuItems() {
      return this.checkScaleVideoMenuItems;
   }

   public JTabbedPane getTabDevice() {
      return this.navigator;
   }

   public void addRadioAbsoluteMouseMenuItem(CommandRadioMenuItem var1) {
      this.radioAbsoluteMouseMenuItems.add(var1);
   }

   public void removeRadioAbsoluteMouseMenuItem(CommandRadioMenuItem var1) {
      this.radioAbsoluteMouseMenuItems.remove(var1);
   }

   public void addRadioIntelligentMouseMenuItem(CommandRadioMenuItem var1) {
      this.radioIntelligentMouseMenuItems.add(var1);
   }

   public void removeRadioIntelligentMouseMenuItem(CommandRadioMenuItem var1) {
      this.radioIntelligentMouseMenuItems.remove(var1);
   }

   public void addRadioStandardMouseMenuItem(CommandRadioMenuItem var1) {
      this.radioStandardMouseMenuItems.add(var1);
   }

   public void removeRadioStandardMouseMenuItem(CommandRadioMenuItem var1) {
      this.radioStandardMouseMenuItems.remove(var1);
   }

   public void addCheckToolbarMenuItem(CommandCheckMenuItem var1) {
      this.checkToolBarMenuItems.add(var1);
   }

   public void removeCheckToolbarMenuItem(CommandCheckMenuItem var1) {
      this.checkToolBarMenuItems.remove(var1);
   }

   public void addCheckStatusBarMenuItem(CommandCheckMenuItem var1) {
      this.checkStatusBarMenuItems.add(var1);
   }

   public void removeCheckStatusBarMenuItem(CommandCheckMenuItem var1) {
      this.checkStatusBarMenuItems.remove(var1);
   }

   public void addCheckFullScreenMenuItem(CommandCheckMenuItem var1) {
      this.checkFullScreenMenuItems.add(var1);
   }

   public void removeCheckFullScreenMenuItem(CommandCheckMenuItem var1) {
      this.checkFullScreenMenuItems.remove(var1);
   }

   public void addCheckNavigatorMenuItem(CommandCheckMenuItem var1) {
      this.checkNavigatorMenuItems.add(var1);
   }

   public void removeCheckNavigatorMenuItem(CommandCheckMenuItem var1) {
      this.checkNavigatorMenuItems.remove(var1);
   }

   public void addCheckMessageMenuItem(CommandCheckMenuItem var1) {
      this.checkMessageMenuItems.add(var1);
   }

   public void removeCheckMessageMenuItem(CommandCheckMenuItem var1) {
      this.checkMessageMenuItems.remove(var1);
   }

   public void addCheckAllDevicesMenuItem(CommandCheckMenuItem var1) {
      this.checkAllDevicesMenuItems.add(var1);
   }

   public void removeCheckAllDevicesMenuItem(CommandCheckMenuItem var1) {
      this.checkAllDevicesMenuItems.remove(var1);
   }

   public void addCheckShowWithoutTargetsMenuItem(CommandCheckMenuItem var1) {
      this.checkShowWithoutTargetsMenuItems.add(var1);
   }

   public void removeCheckShowWithoutTargetsMenuItem(CommandCheckMenuItem var1) {
      this.checkShowWithoutTargetsMenuItems.remove(var1);
   }

   public void addGroupsMenuItem(CommandCheckMenuItem var1) {
      this.checkGroupsMenuItems.add(var1);
   }

   public void removeGroupsMenuItem(CommandCheckMenuItem var1) {
      this.checkGroupsMenuItems.remove(var1);
   }

   public void addCheckShowPowerstripsMenuItem(CommandCheckMenuItem var1) {
      this.checkShowPowerstripsMenuItems.add(var1);
   }

   public void removeCheckShowPowerstripsMenuItem(CommandCheckMenuItem var1) {
      this.checkShowPowerstripsMenuItems.remove(var1);
   }

   public void addCheckShowToolsMenuItem(CommandCheckMenuItem var1) {
      this.checkShowToolsMenuItems.add(var1);
   }

   public void removeCheckShowToolsMenuItem(CommandCheckMenuItem var1) {
      this.checkShowToolsMenuItems.remove(var1);
   }

   public void addCheckSortByChannelNumberMenuItem(CommandCheckMenuItem var1) {
      this.checkSortByChannelNumberMenuItems.add(var1);
   }

   public void removeCheckSortByChannelNumberMenuItem(CommandCheckMenuItem var1) {
      this.checkSortByChannelNumberMenuItems.remove(var1);
   }

   public void addCheckSortByChannelNameMenuItem(CommandCheckMenuItem var1) {
      this.checkSortByChannelNameMenuItems.add(var1);
   }

   public void removeCheckSortByChannelNameMenuItem(CommandCheckMenuItem var1) {
      this.checkSortByChannelNameMenuItems.remove(var1);
   }

   public void addCheckSortByChannelStatusMenuItem(CommandCheckMenuItem var1) {
      this.checkSortByChannelStatusMenuItems.add(var1);
   }

   public void removeCheckSortByChannelStatusMenuItem(CommandCheckMenuItem var1) {
      this.checkSortByChannelStatusMenuItems.remove(var1);
   }

   public void selectSortByChannelNumberView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkSortByChannelNumberMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void selectSortByChannelNameView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkSortByChannelNameMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void selectSortByChannelStatusView(boolean var1) {
      for (CommandCheckMenuItem var3 : this.checkSortByChannelStatusMenuItems) {
         var3.setSelected(var1);
      }
   }

   public void addCheckScaleVideoMenuItem(CommandCheckMenuItem var1) {
      this.checkScaleVideoMenuItems.add(var1);
   }

   public void removeCheckScaleVideoMenuItem(CommandCheckMenuItem var1) {
      this.checkScaleVideoMenuItems.remove(var1);
   }

   public void setTabDevice(JTabbedPane var1) {
      this.navigator = var1;
   }

   public void setMessagePane(JPanel var1) {
      this.message = var1;
   }

   public void setSingleMouseCursorButton(JToggleButton var1) {
      this.toolBarSingleMouseCursorButton = var1;
   }

   public void setNavigatorButton(CommandToggleButton var1) {
      this.toolBarNavigatorButton = var1;
   }

   public void setScaleVideoButton(CommandToggleButton var1) {
      this.toolBarScaleVideoButton = var1;
   }

   public void setBrowseAllDevicesButton(CommandToggleButton var1) {
      this.toolBarBrowseAllDevicesButton = var1;
   }

   public void setToolBar(RRCToolBar var1) {
      this.toolBar = var1;
   }

   public JToolBar getToolBar() {
      return this.toolBar;
   }

   public void addCheckToolBarMenuItem(CommandCheckMenuItem var1) {
      this.checkToolBarMenuItems.add(var1);
   }

   public void removeCheckToolBarMenuItem(CommandCheckMenuItem var1) {
      this.checkToolBarMenuItems.remove(var1);
   }

   public void setStatusBar(RaritanStatusBarPanel var1) {
      this.statusBar = var1;
   }

   public RaritanStatusBarPanel getStatusBar() {
      return this.statusBar;
   }

   public void setLeftVerticalPane(JSplitPane var1) {
      this.splLeftVertical = var1;
   }

   public JSplitPane getLeftVerticalPane() {
      return this.splLeftVertical;
   }

   public BaseTreePanel getDeviceByIPTree() {
      return this.deviceByIPTree;
   }

   public void setDeviceByIPTree(BaseTreePanel var1) {
      this.deviceByIPTree = var1;
   }

   public List<CommandMenu> getWindowMenus() {
      return this.windowMenus;
   }

   public void addWindowMenu(CommandMenu var1) {
      this.windowMenus.add(var1);
   }

   public void removeWindowMenu(CommandMenu var1) {
      this.windowMenus.remove(var1);
   }

   public void enableWindowMenu(boolean var1) {
      for (CommandMenu var3 : this.windowMenus) {
         var3.setEnabled(var1);
      }
   }

   public List<CommandMenu> getKeyboardMenus() {
      return this.keyboardMenus;
   }

   public void addKeyboardMenu(CommandMenu var1) {
      this.keyboardMenus.add(var1);
   }

   public void removeKeyboardMenu(CommandMenu var1) {
      this.keyboardMenus.remove(var1);
   }

   public List<CommandMenu> getVirtualMediaMenus() {
      return this.virtualMediaMenus;
   }

   public void addVirtualMediaMenu(CommandMenu var1) {
      this.virtualMediaMenus.add(var1);
   }

   public void removeVirtualMediaMenu(CommandMenu var1) {
      this.virtualMediaMenus.remove(var1);
   }

   public CommandButton getToolBarRefreshButton() {
      return this.toolBarRefreshButton;
   }

   public CommandToggleButton getToolBarScaleVideoButton() {
      return this.toolBarScaleVideoButton;
   }

   public void setToolBarRefreshButton(CommandButton var1) {
      this.toolBarRefreshButton = var1;
   }

   public JSplitPane getSplHorizontal() {
      return this.splHorizontal;
   }

   public void setSplHorizontal(JSplitPane var1) {
      this.splHorizontal = var1;
   }

   public CommandToggleButton getToolBarFullScreenButton() {
      return this.toolBarFullScreenButton;
   }

   public void setToolBarFullScreenButton(CommandToggleButton var1) {
      this.toolBarFullScreenButton = var1;
   }

   public ConnectedServersToolBar getCsToolBar() {
      return this.csToolBar;
   }

   public void setCsToolBar(ConnectedServersToolBar var1) {
      this.csToolBar = var1;
   }

   public List<CommandCheckMenuItem> getCheckCSToolBarMenuItems() {
      return this.checkCSToolBarMenuItems;
   }

   public void addCheckCSToolBarMenuItem(CommandCheckMenuItem var1) {
      this.checkCSToolBarMenuItems.add(var1);
   }

   public void removeCheckCSToolBarMenuItem(CommandCheckMenuItem var1) {
      this.checkCSToolBarMenuItems.remove(var1);
   }

   public void selectCSToolBarView(boolean var1) {
      if (this.csToolBar != null) {
         this.csToolBar.setVisible(var1);

         for (CommandCheckMenuItem var3 : this.checkCSToolBarMenuItems) {
            var3.setSelected(var1);
         }
      } else {
         for (CommandCheckMenuItem var5 : this.checkCSToolBarMenuItems) {
            var5.setSelected(false);
         }
      }
   }
}
