package com.raritan.rrc.ui.panes.mediator;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.VMInterfaceInfo;
import com.raritan.rrc.data.VirtualMediaBean;
import com.raritan.rrc.data.VirtualMediaLocalBean;
import com.raritan.rrc.ui.RRCApplet;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.DoSingleMouseModeCommand;
import com.raritan.rrc.ui.commands.ShowTargetScreenResolutionCommand;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.panes.AboutPanel;
import com.raritan.rrc.ui.panes.AddConnectionPanel;
import com.raritan.rrc.ui.panes.AddKeyboardMacroPanel;
import com.raritan.rrc.ui.panes.AppletView;
import com.raritan.rrc.ui.panes.AudioPanel;
import com.raritan.rrc.ui.panes.AudioSettingsPanel;
import com.raritan.rrc.ui.panes.ChangePasswordPanel;
import com.raritan.rrc.ui.panes.ConnectionInfoPanel;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.DialbackMessagePanel;
import com.raritan.rrc.ui.panes.G2PropertiesPanel;
import com.raritan.rrc.ui.panes.G2VideoSettingsPanel;
import com.raritan.rrc.ui.panes.KeyboardMacroPanel;
import com.raritan.rrc.ui.panes.KvmView;
import com.raritan.rrc.ui.panes.LoadDeviceConfigurationPanel;
import com.raritan.rrc.ui.panes.LoginPanel;
import com.raritan.rrc.ui.panes.MacroExportSelectionPanel;
import com.raritan.rrc.ui.panes.MacroImportSelectionPanel;
import com.raritan.rrc.ui.panes.MacroTextInterpreterPanel;
import com.raritan.rrc.ui.panes.ModifyConnectionPanel;
import com.raritan.rrc.ui.panes.ModifyKeyboardMacroPanel;
import com.raritan.rrc.ui.panes.OptionsPanel;
import com.raritan.rrc.ui.panes.PowerPortView;
import com.raritan.rrc.ui.panes.ProgressPanel;
import com.raritan.rrc.ui.panes.PropertiesPanel;
import com.raritan.rrc.ui.panes.RSCView;
import com.raritan.rrc.ui.panes.SaveActivityLogPanel;
import com.raritan.rrc.ui.panes.SaveDeviceConfigurationPanel;
import com.raritan.rrc.ui.panes.SaveDiagnosticLogPanel;
import com.raritan.rrc.ui.panes.SaveTotalConfigurationPanel;
import com.raritan.rrc.ui.panes.SaveUserConfigurationPanel;
import com.raritan.rrc.ui.panes.SendTextToTargetPanel;
import com.raritan.rrc.ui.panes.SerialParametersPanel;
import com.raritan.rrc.ui.panes.SerialSettingsPanel;
import com.raritan.rrc.ui.panes.SerialView;
import com.raritan.rrc.ui.panes.SingleCursorInstructionsPanel;
import com.raritan.rrc.ui.panes.SmartCardAutoMountPanel;
import com.raritan.rrc.ui.panes.SmartCardPanel;
import com.raritan.rrc.ui.panes.StartLoggingPanel;
import com.raritan.rrc.ui.panes.UpdateDevicePanel;
import com.raritan.rrc.ui.panes.UpdateLDAPCertificatePanel;
import com.raritan.rrc.ui.panes.UpdateLDAPKeyPanel;
import com.raritan.rrc.ui.panes.VideoSettingsPanel;
import com.raritan.rrc.ui.panes.VirtualMediaDisconnectImagePanel;
import com.raritan.rrc.ui.panes.VirtualMediaDisconnectLocalPanel;
import com.raritan.rrc.ui.panes.VirtualMediaImagePanel;
import com.raritan.rrc.ui.panes.VirtualMediaLocalPanel;
import com.raritan.rrc.ui.rfbbridge.RFBProfile;
import com.raritan.rrc.ui.rfbbridge.RFBView;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.ui.panes.LogPanel;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.AbstractDisplayStrategy;
import com.raritan.tools.ui.panes.displays.Shell;
import com.raritan.tools.ui.panes.displays.ShellFocusObserver;
import com.raritan.tools.ui.panes.mediator.PanelMediator;
import java.awt.Component;
import java.awt.Container;
import java.awt.Frame;
import java.awt.KeyboardFocusManager;
import java.awt.Window;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import nn.pp.core.Platform;

public class RRCPanelMediator extends PanelMediator {
   private KeyboardMacroPanel mainKeyboardMacroPanel = null;
   private List listOfDialogs = Collections.synchronizedList(new ArrayList());
   RaritanPropertyResourceBundle bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   public static final WindowAdapter postLinuxWindowAdapter = new WindowAdapter() {
      @Override
      public void windowDeactivated(WindowEvent var1) {
         Window var2 = var1.getWindow();
         if (var1.getOppositeWindow() == null) {
            RRCApplet.RaritanKeyboardFocusManager var3 = (RRCApplet.RaritanKeyboardFocusManager)KeyboardFocusManager.getCurrentKeyboardFocusManager();
            var3.setGlobalActiveWindow(var2);
            var3.setGlobalFocusedWindow(var2);
         }

         var2.removeWindowListener(this);
      }
   };
   private Map vmLocalMap;
   private Map vmImageMap;
   private boolean library_downloaded;

   public RRCPanelMediator(Container var1, ScreenContext var2) {
      super(var1, var2);
   }

   @Override
   protected void initDialogPanels() {
      this.panelClasses.put("showAboutCommand", new AbstractDisplayStrategy(AboutPanel.class, true, this.scrContext, true));
      this.panelClasses.put("showSaveTotalConfigurationCommand", new AbstractDisplayStrategy(SaveTotalConfigurationPanel.class, true, this.scrContext));
      this.panelClasses.put("showSaveDeviceConfigurationCommand", new AbstractDisplayStrategy(SaveDeviceConfigurationPanel.class, true, this.scrContext));
      this.panelClasses.put("showSaveUserConfigurationCommand", new AbstractDisplayStrategy(SaveUserConfigurationPanel.class, true, this.scrContext));
      this.panelClasses.put("showSaveActivityLogCommand", new AbstractDisplayStrategy(SaveActivityLogPanel.class, true, this.scrContext));
      this.panelClasses.put("showOptionsCommand", new AbstractDisplayStrategy(OptionsPanel.class, true, this.scrContext));
      this.panelClasses.put("showSaveDiagnosticLogCommand", new AbstractDisplayStrategy(SaveDiagnosticLogPanel.class, true, this.scrContext));
      this.panelClasses.put("showLoadDeviceConfigurationCommand", new AbstractDisplayStrategy(LoadDeviceConfigurationPanel.class, true, this.scrContext));
      this.panelClasses.put("showConnectCommand", new AbstractDisplayStrategy(LoginPanel.class, true, this.scrContext));
      this.panelClasses.put("showNewProfileCommand", new AbstractDisplayStrategy(AddConnectionPanel.class, true, this.scrContext));
      this.panelClasses.put("showModifyProfileCommand", new AbstractDisplayStrategy(ModifyConnectionPanel.class, true, this.scrContext));
      this.panelClasses.put("showAddProfileCommand", new AbstractDisplayStrategy(AddConnectionPanel.class, true, this.scrContext));
      this.panelClasses.put("showUpdateDeviceCommand", new AbstractDisplayStrategy(UpdateDevicePanel.class, true, this.scrContext));
      this.panelClasses.put("showUpdateLDAPCertificateCommand", new AbstractDisplayStrategy(UpdateLDAPCertificatePanel.class, true, this.scrContext));
      this.panelClasses.put("showUpdateLDAPKeyCommand", new AbstractDisplayStrategy(UpdateLDAPKeyPanel.class, true, this.scrContext));
      this.panelClasses.put("showSerialPortCommand", new AbstractDisplayStrategy(SerialView.class, false, this.scrContext, true));
      this.panelClasses.put("showKX2G2SerialPortCommand", new AbstractDisplayStrategy(RSCView.class, false, this.scrContext));
      this.panelClasses.put("showHtmlPortCommand", new AbstractDisplayStrategy(AppletView.class, false, this.scrContext));
      this.panelClasses.put("showURLPortCommand", new AbstractDisplayStrategy(AppletView.class, false, this.scrContext));
      this.panelClasses.put("showPowerPortCommand", new AbstractDisplayStrategy(PowerPortView.class, false, this.scrContext));
      this.panelClasses.put("showOutletPortCommand", new AbstractDisplayStrategy(PowerPortView.class, true, this.scrContext));
      this.panelClasses.put("showVideoSettingsCommandKX1", new AbstractDisplayStrategy(VideoSettingsPanel.class, true, this.scrContext));
      this.panelClasses.put("showVideoSettingsCommandKX2", new AbstractDisplayStrategy(G2VideoSettingsPanel.class, true, this.scrContext));
      this.panelClasses.put("showSerialParametersCommand", new AbstractDisplayStrategy(SerialParametersPanel.class, true, this.scrContext));
      this.panelClasses.put("showSerialSettingsCommand", new AbstractDisplayStrategy(SerialSettingsPanel.class, true, this.scrContext));
      this.panelClasses.put("showSingleCursorInstructionCommand", new AbstractDisplayStrategy(SingleCursorInstructionsPanel.class, true, this.scrContext));
      this.panelClasses.put("showKeyboardMacrosCommand", new AbstractDisplayStrategy(KeyboardMacroPanel.class, true, this.scrContext));
      this.panelClasses.put("showAddKeyboardMacroCommand", new AbstractDisplayStrategy(AddKeyboardMacroPanel.class, true, this.scrContext));
      this.panelClasses.put("showModifyKeyboardMacroCommand", new AbstractDisplayStrategy(ModifyKeyboardMacroPanel.class, true, this.scrContext));
      this.panelClasses.put("showConnectionInfoCommand", new AbstractDisplayStrategy(ConnectionInfoPanel.class, true, this.scrContext));
      this.panelClasses.put("doUpdateDeviceCommand", new AbstractDisplayStrategy(ProgressPanel.class, true, this.scrContext));
      this.panelClasses.put("showChangePasswordCommand", new AbstractDisplayStrategy(ChangePasswordPanel.class, true, this.scrContext));
      this.panelClasses.put("showUserPasswordCommand", new AbstractDisplayStrategy(ChangePasswordPanel.class, true, this.scrContext));
      this.panelClasses.put("showStartLoggingCommand", new AbstractDisplayStrategy(StartLoggingPanel.class, true, this.scrContext));
      this.panelClasses.put("ShowDialbackMessageCommand", new AbstractDisplayStrategy(DialbackMessagePanel.class, true, this.scrContext));
      this.panelClasses.put("showImportMacrosCommand", new AbstractDisplayStrategy(MacroImportSelectionPanel.class, true, this.scrContext));
      this.panelClasses.put("showExportMacrosCommand", new AbstractDisplayStrategy(MacroExportSelectionPanel.class, true, this.scrContext));
      this.panelClasses.put("showSendtextToTargetCommand", new AbstractDisplayStrategy(SendTextToTargetPanel.class, true, this.scrContext));
      this.panelClasses.put("showMacroTextInterpreterCommand", new AbstractDisplayStrategy(MacroTextInterpreterPanel.class, true, this.scrContext));
      this.panelClasses.put("SelectCardReaderCommand", new AbstractDisplayStrategy(SmartCardPanel.class, true, this.scrContext));
      this.panelClasses.put("SmartCardAutoMountCommand", new AbstractDisplayStrategy(SmartCardAutoMountPanel.class, true, this.scrContext, true));
      this.panelClasses.put("ConnectAudioCommand", new AbstractDisplayStrategy(AudioPanel.class, true, this.scrContext));
      this.panelClasses.put("AudioSettingsCommand", new AbstractDisplayStrategy(AudioSettingsPanel.class, true, this.scrContext));
      System.runFinalization();
      System.gc();
   }

   @Override
   protected void initContainerPanels() {
      this.panelClasses.put("logCommand", new AbstractDisplayStrategy(LogPanel.class, false, this.scrContext));
      this.panelClasses.put("statusCommand", new AbstractDisplayStrategy(RRCStatusBar.class, false, this.scrContext));
   }

   @Override
   public synchronized void showPanel(CommandContext var1) {
      if (var1 != null) {
         String var2 = var1.getCommandKey();
         Object var3 = null;
         DeviceView var4 = null;
         this.scrContext.getLogger().logTextDebug(" Invoked with command key " + var2);
         Device var5 = null;
         ArrayList var6 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
         if (var6 != null && var6.size() > 0) {
            var5 = (Device)var6.get(0);
         }

         if ("showSingleCursorInstructionCommand".equals(var2)) {
            boolean var7 = ((RRCScreenContext)this.scrContext).getAppSettings().isSingleMouseInstructions();
            if (var5 != null && var5 instanceof Port && var5.isConnected() && var5.getDeviceClass().equals("KVM")) {
               boolean var8 = ((KvmPort)var5).isSingleCursorMode();
               if (var8 || !var7) {
                  DoSingleMouseModeCommand var35 = new DoSingleMouseModeCommand(this.scrContext);
                  var35.execute();
                  return;
               }
            }
         }

         if (var2.equals("showPropertiesCommand") && var5 != null && var5 instanceof Port && var5.isConnected()) {
            if (var5.getDeviceConnector().isKX2Device()) {
               if (var6 != null && var6.size() != 0 && var6.get(0) instanceof Port) {
                  Port var19 = (Port)var6.get(0);
                  DeviceView var26 = var19.getView();
                  RFBView var9 = (RFBView)var26;
                  if (var9 != null) {
                     var3 = new G2PropertiesPanel(true, this.scrContext, var9, var19.getPortKey());
                  }
               }
            } else {
               var3 = new PropertiesPanel(true, this.scrContext);
            }
         }

         if (var2.equals("showVirtualMediaLocalPanelCommand")) {
            ArrayList var27 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
            if (var27 != null && var27.size() != 0 && var27.get(0) instanceof Port) {
               Port var31 = (Port)var27.get(0);
               String var20 = var31.getPortKey();
               this.vmLocalMap = this.scrContext.getVirtualMediaLocalMap();
               if (this.vmLocalMap == null) {
                  this.vmLocalMap = new HashMap();
               }

               DeviceView var10 = var31.getView();
               RFBProfile var11 = null;
               RFBView var12 = (RFBView)var10;
               if (var12 != null) {
                  var11 = var12.getProfile();
               }

               if (!this.vmLocalMap.containsKey(var20)) {
                  RRCLogger.log(300, 1, "Creating new bean for VM Panel for port " + var20);
                  VirtualMediaLocalBean var13 = new VirtualMediaLocalBean((VMInterfaceInfo)var1.getCommandParameter("VM_vminterfaceinfo"));
                  var13.setPortKey(var20);
                  var13.setPort(var31.getPortIndex());
                  if (var12 != null) {
                     var13.setRFBView(var12);
                  } else {
                     RRCLogger.log(300, 1, "Error Setting handler in VmBean for Port: " + var20);
                  }

                  try {
                     if (var11 != null) {
                        var13.setRFBProfile(var11);
                        var11 = var13.getRFBProfile();
                     } else {
                        RRCLogger.log(300, 1024, "Error! Profile is NULL " + var20);
                     }
                  } catch (Exception var18) {
                     RRCLogger.log(300, 1024, var18.getMessage());
                  }

                  this.vmLocalMap.put(var20, var13);
                  this.scrContext.setVitualMediaLocalMap(this.vmLocalMap);
               } else {
                  VirtualMediaLocalBean var43 = (VirtualMediaLocalBean)this.vmLocalMap.get(var20);
                  if (var43 == null) {
                     this.checkReturnToFullScreen(var1);
                     RRCLogger.log(300, 1024, "VM Bean is NULL while disconnecting" + var20);
                     return;
                  }

                  if (var43.isDriveConnected()) {
                     var3 = new VirtualMediaDisconnectLocalPanel(this.scrContext, var20, var43);
                  }
               }

               if (var3 == null) {
                  VirtualMediaLocalPanel var44 = new VirtualMediaLocalPanel(true, this.scrContext);
                  VirtualMediaLocalBean var14 = (VirtualMediaLocalBean)this.vmLocalMap.get(var20);
                  if (var44.populateVMPanel(var14)) {
                     var44.setShell(this.bundle.getString("vmpanel.LOCAL_PANEL_NAME") + " " + var31.getName());
                     var3 = var44;
                  } else {
                     CommonPopups.showInfoDialog(
                        this.bundle.getString("vmpanel.nodrives.title"), this.bundle.getString("vmpanel.nodrives.text"), var10, this.scrContext
                     );
                  }
               }
            }
         }

         if (var2.equals("showVirtualMediaPanelCommand")) {
            ArrayList var28 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
            if (var28 != null && var28.size() != 0 && var28.get(0) instanceof Port) {
               Port var32 = (Port)var28.get(0);
               String var21 = var32.getPortKey();
               this.vmImageMap = this.scrContext.getVirtualMediaImageMap();
               if (this.vmImageMap == null) {
                  this.vmImageMap = new HashMap();
               }

               DeviceView var36 = var32.getView();
               RFBProfile var39 = null;
               RFBView var42 = (RFBView)var36;
               if (var42 != null) {
                  var39 = var42.getProfile();
               }

               if (!this.vmImageMap.containsKey(var21)) {
                  RRCLogger.log(200, 1, "Creating new bean for VM Panel for port " + var21);
                  VirtualMediaBean var45 = new VirtualMediaBean((VMInterfaceInfo)var1.getCommandParameter("VM_vminterfaceinfo"));
                  var45.setPortKey(var21);
                  var45.setPort(var32.getPortIndex());
                  if (var42 != null) {
                     var45.setRFBView(var42);
                  } else {
                     RRCLogger.log(200, 1, "Error Setting handler in VmBean for Port: " + var21);
                  }

                  try {
                     if (var39 != null) {
                        var45.setRFBProfile(var39);
                        var39 = var45.getRFBProfile();
                     } else {
                        RRCLogger.log(200, 1024, "Error! Profile is NULL " + var21);
                     }
                  } catch (Exception var17) {
                     RRCLogger.log(200, 1024, var17.getMessage());
                  }

                  this.vmImageMap.put(var21, var45);
                  this.scrContext.setVitualMediaImageMap(this.vmImageMap);
               } else {
                  Map var46 = this.scrContext.getVirtualMediaImageMap();
                  if (var46 == null) {
                     this.checkReturnToFullScreen(var1);
                     RRCLogger.log(300, 1, "VMImage Map is null when Disconnecting." + var21);
                     return;
                  }

                  VirtualMediaBean var48 = (VirtualMediaBean)var46.get(var21);
                  if (var48 == null) {
                     this.checkReturnToFullScreen(var1);
                     RRCLogger.log(300, 1, "VMImage Bean is null when Disconnecting." + var21);
                     return;
                  }

                  if (var48.isDriveConnected()) {
                     var3 = new VirtualMediaDisconnectImagePanel(this.scrContext, var21, var48, var42);
                  }
               }

               if (var3 == null) {
                  VirtualMediaImagePanel var47 = new VirtualMediaImagePanel(true, this.scrContext);
                  VirtualMediaBean var49 = (VirtualMediaBean)this.vmImageMap.get(var21);
                  var49.setVmMountRequestResponseList(var42.getVMShareTable());
                  var47.populateVMPanel(var49);
                  var47.setShell(this.bundle.getString("vmpanel.IMAGE_PANEL_NAME") + " " + var32.getName());
                  var3 = var47;
               }
            }
         }

         if (!var2.equals("showKvmPortCommand")
            && !var2.equals("doSwitchCommand")
            && !var2.equals("showKX2KvmPortCommand")
            && !var2.equals("showHtmlPortCommand")
            && !var2.equals("showURLPortCommand")
            && !var2.equals("showKVMFromScanCommand")) {
            if ("showVideoSettingsCommand".equals(var2)) {
               DeviceView var23 = (DeviceView)var1.getCommandParameter("DEVICE_VIEW");
               if (var23 instanceof KvmView) {
                  var3 = this.getTarget(var2 + "KX1");
               } else {
                  var3 = this.getTarget(var2 + "KX2");
               }
            } else if (!var2.equals("showVirtualMediaLocalPanelCommand")
               && !var2.equals("showPropertiesCommand")
               && !var2.equals("showVirtualMediaPanelCommand")) {
               var3 = this.getTarget(var2);
            }
         } else if (var5 != null) {
            try {
               Device var22 = ((Port)var5).getDevice();
               var3 = var22.getHandler().initializeDeviceView(var1, var2, this);
            } catch (RRCGeneralException var16) {
               JOptionPane var29 = new JOptionPane(
                  this.bundle.getString("View.error.fail.create") + System.getProperty("line.separator") + var16.getMessage(),
                  0,
                  -1,
                  null,
                  new Object[]{this.bundle.getString("basescreen.command.ok.text")}
               );
               JDialog var33 = var29.createDialog(null, this.bundle.getString("optionpane.error.title"));
               var33.setModal(true);
               var33.setVisible(true);
               RRCLogger.logException(var16);
            }

            var4 = (DeviceView)var3;
         } else {
            RRCLogger.log(300, 16, "Device is null");
         }

         if (var3 != null) {
            ((AbstractDisplay)var3).setCommandContext(var1);
            ((AbstractDisplay)var3).fillComponents(var1);
            if (var4 != null && !var2.equals("showVirtualMediaLocalPanelCommand")) {
               var4.customizeTarget((AbstractDisplay)var3);
            }

            if (((AbstractDisplay)var3).isDialog()) {
               ((AbstractDisplay)var3).onActivateDisplay();
               Shell var24 = ((AbstractDisplay)var3).getShell();
               boolean var30 = KeyboardFocusManager.getCurrentKeyboardFocusManager() instanceof RRCApplet.RaritanKeyboardFocusManager;
               RRCApplet.LinuxWindowDeactivatedHandler var34 = new RRCApplet.LinuxWindowDeactivatedHandler();
               if (var30) {
                  var24.addWindowListener(var34);
               }

               Frame var37 = JOptionPane.getFrameForComponent(var24);
               var24.setLocationRelativeTo((Window)var24.getParent());
               var24.setVisible(true);
               if (var30) {
                  var24.removeWindowListener(var34);
                  var37.addWindowListener(postLinuxWindowAdapter);
               }

               if (Platform.isWindows()) {
                  Window var41 = (Window)var24.getParent();
                  if (var41 != null && "sun.plugin.viewer.frame.WNetscapeEmbeddedFrame".equals(var41.getClass().getName())) {
                     var41.transferFocus();
                  }
               }
            } else if (var5 instanceof Port) {
               if (this.scrContext.getApplicationProperty("connection") == null && !((Port)var5).getBaseDevice().isConnected()) {
                  RRCLogger.log(200, 4, "Device was disconnected before connecting/switching to the port");
                  var5.disconnect();
               } else {
                  RaritanDesktopPane var25 = (RaritanDesktopPane)this.parent;
                  var25.addAbstractDisplayComponent((AbstractDisplay)var3);
                  if (var4 != null) {
                     var4.startVideo();
                     if (this.scrContext.getApplicationProperty("connection") != null
                        && var25.getSelectedFrame() != null
                        && !var25.getSelectedFrame().isMaximum()) {
                        try {
                           var25.getSelectedFrame().setMaximum(true);
                        } catch (PropertyVetoException var15) {
                           RRCLogger.log(200, 512, "PropertyVetoException: system will not allow us to maximize the target window");
                        }
                     }
                  }
               }
            }
         }

         this.scrContext.getLogger().logTextDebug(" Finished");
      }
   }

   public KeyboardMacroPanel getMainKeyboardMacroPanel() {
      return this.mainKeyboardMacroPanel;
   }

   public void setMainKeyboardMacroPanel(KeyboardMacroPanel var1) {
      this.mainKeyboardMacroPanel = var1;
   }

   @Override
   public Object showDialogOnTop(JOptionPane var1, String var2, AbstractDisplay var3) {
      JDialog var4 = var1.createDialog((Component)(var3 == null ? this.getParent() : var3), var2);
      synchronized (this.listOfDialogs) {
         this.listOfDialogs.add(var4);
      }

      if (var3 != null) {
         var4.addWindowFocusListener(var3);
      }

      MPCUtil.jre17WorkaroundInheritAlwaysOnTop(var4);
      var4.setModal(true);
      ShellFocusObserver.addShellVisible(var4, this.scrContext);
      var4.setVisible(true);
      ShellFocusObserver.removeShellVisible(var4, this.scrContext);
      Object var10 = var1.getValue();
      synchronized (this.listOfDialogs) {
         this.listOfDialogs.remove(var4);
      }

      var4.dispose();
      return var10;
   }

   @Override
   public void hideAll() {
      super.hideAll();
      this.hideDialogs();
   }

   public void hideDialogs() {
      synchronized (this.listOfDialogs) {
         for (JDialog var3 : this.listOfDialogs) {
            var3.dispose();
         }

         this.listOfDialogs.clear();
      }
   }

   public void checkReturnToFullScreen(CommandContext var1) {
      Boolean var2 = (Boolean)var1.getCommandParameter("returnInFullscreenMode");
      boolean var3 = var2 != null ? var2 : false;
      if (var3) {
         ShowTargetScreenResolutionCommand var4 = new ShowTargetScreenResolutionCommand(this.scrContext);
         if (var4.isExecutable()) {
            var4.execute();
         }
      }
   }
}
