package com.raritan.rrc.ui.rfbbridge;

import java.awt.Dimension;
import java.io.IOException;
import java.util.List;
import javaclientlib.utils.RRCLogger;
import nn.pp.core.INotificationEvent;
import nn.pp.rccore.IKvmPort;
import nn.pp.rccore.IUsbProfileList;
import nn.pp.rccore.IVMConfigInfo;
import nn.pp.rccore.IVMMountRequestResponse;
import nn.pp.rccore.RCAdapter;
import nn.pp.rccore.RCCore;

public class MainScreenRCAdapter extends RCAdapter {
   RFBView owner;

   public MainScreenRCAdapter(RFBView var1) {
      this.owner = var1;
   }

   @Override
   public void disconnected(Exception var1) {
      if (this.owner != null) {
         this.owner.disconnect();
      }
   }

   @Override
   public void connected() {
      this.owner.setFullyConnected(true);
      if (this.owner.getVideoSettingsSupported()) {
         try {
            this.owner.getRCCore().requestVideoSettingsUpdates();
         } catch (IOException var2) {
         }
      }

      this.owner.rcConnected();
      this.owner.setFrameSize();
   }

   @Override
   public void resolutionChanged(Dimension var1) {
      this.owner.clearStatusMessage();
   }

   @Override
   public void hotkeyDetected(int var1) {
      this.owner.handleHotkeys(var1);
   }

   @Override
   public String portListChanged(List<? extends IKvmPort> var1) {
      String var2 = this.owner.getTargetPortId();
      if (var2 != null) {
         for (IKvmPort var4 : var1) {
            if (var4.equals(var2)) {
               this.owner.setKvmPort(var4);
               return var4.getUniquePortId();
            }
         }
      }

      return null;
   }

   @Override
   public void monitorModeChanged(boolean var1) {
      this.owner.setMonitorOnly(var1);
   }

   @Override
   public void serverSessionIdChanged(int var1) {
      this.owner.setRfbSessionId(var1);
   }

   @Override
   public void osdMessageReceived(String var1, boolean var2) {
      this.owner.osdStateChanged(var2, var1);
   }

   @Override
   public void remoteIsoListChanged(List<IVMMountRequestResponse> var1) {
      this.owner.setRemoteIsoList(var1);
   }

   @Override
   public void receivedNotification(INotificationEvent var1) {
      this.owner.notify(var1);
   }

   @Override
   public void remoteIsoMountFinished(IVMMountRequestResponse var1) {
      this.owner.processVMMountResponse(var1);
   }

   @Override
   public void supportedMouseModesChanged(List<RCCore.MouseMode> var1) {
      this.owner.enableMouseModes(var1);
   }

   @Override
   public void mouseModeChanged(RCCore.MouseMode var1) {
      this.owner.setMouseModeMenuItem(var1);
   }

   @Override
   public void sunKeyboardSupported(boolean var1) {
      this.owner.setSunTarget(var1);
   }

   @Override
   public void cimLanguageOptionsSupported(boolean var1) {
      this.owner.setCimLanguageOptionsSupported(var1);
   }

   @Override
   public void UsbProfileListChanged(IUsbProfileList var1) {
      this.owner.setUsbProfileList(var1);
   }

   @Override
   public void virtualMediaConfigChanged(IVMConfigInfo var1) {
      this.owner.setVirtualMediaConfig(var1.getVMConfig());
   }

   @Override
   public void connectedUsersChanged(int var1) {
      this.owner.setConcurrentUsers(var1);
   }

   @Override
   public void ctrlAltReleaseDetected(boolean var1) {
      if (var1) {
         this.owner.showFSExitTip();
      }
   }

   @Override
   public void keyboardLedStateChanged(List<RCCore.KeyboardLed> var1) {
      if (this.owner != null) {
         RRCLogger.log(300, "LED Status: " + var1);
         if (var1.contains(RCCore.KeyboardLed.LED_CAPSLOCK)) {
            this.owner.setCapsLockStatus(true);
         } else {
            this.owner.setCapsLockStatus(false);
         }

         if (var1.contains(RCCore.KeyboardLed.LED_NUMLOCK)) {
            this.owner.setNumLockStatus(true);
         } else {
            this.owner.setNumLockStatus(false);
         }

         if (var1.contains(RCCore.KeyboardLed.LED_SCROLLLOCK)) {
            this.owner.setScrollLockStatus(true);
         } else {
            this.owner.setScrollLockStatus(false);
         }
      } else {
         RRCLogger.log(300, "LED Status: RFBView is null");
      }
   }
}
