package com.raritan.rrc.ui.rfbbridge;

import com.raritan.rrc.data.BladeChassis;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.KvmPortPermissionHelper;
import com.raritan.rrc.data.MassStorageDevice;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.USBProfile;
import com.raritan.rrc.data.USBProfilesInfo;
import com.raritan.rrc.data.VMConfigInfo;
import com.raritan.rrc.data.VMInterfaceInfo;
import com.raritan.rrc.data.VirtualMediaBean;
import com.raritan.rrc.data.VirtualMediaLocalBean;
import com.raritan.rrc.ui.MonitorSettingsHandler;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.ConnectAudioCommand;
import com.raritan.rrc.ui.commands.DeSelectPortViewCommand;
import com.raritan.rrc.ui.commands.DoDisconnectCommand;
import com.raritan.rrc.ui.commands.DoEnterOnscreenMenuCommand;
import com.raritan.rrc.ui.commands.DoExitOnscreenMenuCommand;
import com.raritan.rrc.ui.commands.SelectPortViewCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaImagePanelCommand;
import com.raritan.rrc.ui.commands.ShowVirtualMediaLocalPanelCommand;
import com.raritan.rrc.ui.commands.SmartCardAutoMountCommand;
import com.raritan.rrc.ui.components.ContextPopupMenu;
import com.raritan.rrc.ui.components.FullScreenToolBar;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.panes.DeviceView;
import com.raritan.rrc.ui.panes.DeviceViewAdapter;
import com.raritan.rrc.ui.panes.ErrorHandlerImpl;
import com.raritan.rrc.ui.panes.G2CompressionPanel;
import com.raritan.rrc.ui.panes.ICommandHandler;
import com.raritan.rrc.ui.panes.OptionsPanel;
import com.raritan.rrc.ui.panes.PropertiesPanel;
import com.raritan.rrc.ui.panes.RFBViewCommandHandler;
import com.raritan.rrc.ui.panes.RRCShellInternalFrame;
import com.raritan.rrc.ui.panes.VirtualMediaImagePanel;
import com.raritan.rrc.ui.panes.VirtualMediaLocalPanel;
import com.raritan.rrc.ui.panes.mediator.MainScreenMediator;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.rrc.util.StringUtils;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.AbstractUIManager;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandCheckMenuItem;
import com.raritan.tools.ui.components.CommandMenu;
import com.raritan.tools.ui.components.CommandMenuItem;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.ShellInternalFrame;
import com.util.kbd.KeyboardUtil;
import java.awt.AWTEvent;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Point;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import java.awt.event.ComponentEvent;
import java.awt.event.ComponentListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyVetoException;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Vector;
import java.util.logging.Level;
import javaclientlib.utils.RRCGeneralException;
import javaclientlib.utils.RRCLogger;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;
import javax.swing.Timer;
import javax.swing.event.InternalFrameAdapter;
import javax.swing.event.InternalFrameEvent;
import nn.pp.audiocore.AudioEventListener;
import nn.pp.common.ApplicationContext;
import nn.pp.common.ContextEvent;
import nn.pp.common.ContextListener;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.common.VMFeatures;
import nn.pp.common.audio.AudioErrorsAndMessageHandler;
import nn.pp.common.audio.AudioIndexHelper;
import nn.pp.common.smartcard.SmartCardBean;
import nn.pp.common.smartcard.SmartCardErrorsAndMessagesHandler;
import nn.pp.common.smartcard.SmartCardIndexHelper;
import nn.pp.common.ui.helpers.IKVMTargetViewer;
import nn.pp.core.INotificationEvent;
import nn.pp.core.NotificationEvent;
import nn.pp.core.T;
import nn.pp.ext.ExtensionFactory;
import nn.pp.ext.devPref.DevicePrefs;
import nn.pp.ext.macro.IMacro;
import nn.pp.ext.macro.IMacroHelper;
import nn.pp.ext.macro.MacroException;
import nn.pp.ext.macro.MacroFactory;
import nn.pp.ext.pref.IApplicationPreferences;
import nn.pp.rccore.IAudioStatusExSupport;
import nn.pp.rccore.IKvmPort;
import nn.pp.rccore.ILicenseSupport;
import nn.pp.rccore.IMultiMonitorTargetSupport;
import nn.pp.rccore.IUsbProfile;
import nn.pp.rccore.IUsbProfileList;
import nn.pp.rccore.IVMMountRequestResponse;
import nn.pp.rccore.IVideoSettings;
import nn.pp.rccore.KeyboardMacro;
import nn.pp.rccore.RCAdapter;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.RCCoreFactory;
import nn.pp.rccore.RCException;
import nn.pp.rccore.UsbProfile;
import nn.pp.rccore.VMMountRequestResponse;
import nn.pp.rccore.impl.KeyValuePair;
import nn.pp.rccore.impl.rfb.RfbNotificationEvent;

public class RFBView extends DeviceViewAdapter implements IKVMTargetViewer, FocusListener {
   private static String defkbd;
   private JComponent console = null;
   private RFBProfile profile = null;
   private KvmPort kvmPort;
   private int userCount;
   public static final int MOUSE_MODE_ABSOLUTE = 0;
   public static final int MOUSE_MODE_INTELLI = 1;
   public static final int MOUSE_MODE_STANDARD = 2;
   private int mouseMode;
   private RFBViewCommandHandler rFBViewCommandHandler = new RFBViewCommandHandler();
   private JScrollPane jsp;
   private VMMountRequestResponse vmMountsResponse = null;
   private VMMountRequestResponse[] vmShareTable = null;
   private JLabel northLabel;
   private JLabel southLabel;
   private JLabel westLabel;
   private JLabel eastLabel;
   private JLabel northWestLabel;
   private JLabel southEastLabel;
   private Timer timer = null;
   private boolean adjustingVertical = false;
   private int adjustmentValue = 0;
   private JScrollBar hScrollBar = new JScrollBar(0);
   private JScrollBar vScrollBar = new JScrollBar(1);
   private RFBView.AllListener allListener = new RFBView.AllListener();
   private static final Dimension VIEW_BORER_DIM = new Dimension(10, 10);
   private boolean scrollBothDirections = false;
   private boolean showScrollBorder = false;
   private boolean isFullScreenMode = false;
   private boolean scaleVideoFlag = false;
   private int rfbSessionId = -1;
   private ContextPopupMenu contextMenuKvm = null;
   private boolean isSambaConnectSuccessful = false;
   private boolean isSambaDisconnectSuccessful = false;
   private int mspConnectionSuccess = 0;
   private VirtualMediaImagePanel vmImagePanel = null;
   private VirtualMediaLocalPanel vmLocalPanel = null;
   private String ccVMPermissions = "";
   private static final int UNIT_INCREMENT = 10;
   private int dataIn = 0;
   private int dataOut = 0;
   private int fps = 0;
   private LinkedList<KvmPort> switchPortQueue = new LinkedList<>();
   private HashMap capabilityMap;
   private RemoteConsoleParameters rcparams;
   private RCCore rccore;
   private ILicenseSupport license;
   private IAudioStatusExSupport audioEx;
   private RCAdapter rcAdapter;
   private VideoSettingsRCAdapter vsAdapter;
   private boolean connected;
   private boolean fullyConnected = false;
   private boolean videoSettingsSupported = false;
   private boolean viewFinalized = false;
   private List<INotificationEvent> collectedNotifications = new Vector<>();
   public static final String NO_VIDEO_FROM_TARGET_SERVER = "No video from target server";
   private boolean monitorOnly;
   private boolean exclusiveMode;
   private boolean singleCursorMode;
   private List<IVMMountRequestResponse> remoteIsoList;
   private IVideoSettings vidSettings = null;
   private Hashtable<Integer, KeyStroke> hotkeyMap;
   private Hashtable<Integer, KeyValuePair<Integer, String>> categoryMap;
   private IMacroHelper macroHelper;
   private RCCore.Compression currentCompression;
   private RCCore.ColorDepth currentColorDepth;
   private RCCore.Smoothing currentSmoothing;
   private boolean isAutoSelected = false;
   private boolean isInitialEndoingAuto = false;
   private boolean isSunTarget;
   private boolean colorCalibSupported = false;
   private boolean cimLangOptsSupported = true;
   private boolean isQuitEvent = false;
   private ApplicationContext ctx;
   private ContextListener ctxListener;
   private final RFBView.SmartCardErrorsAndMessagesHandlerImpl smartCardErrorsAndMessagesHandlerImpl = new RFBView.SmartCardErrorsAndMessagesHandlerImpl();
   private int keyboardType = 0;
   private boolean capsLockOn = false;
   private boolean numLockOn = false;
   private boolean scrollLockOn = false;
   private AudioEventListener.DeviceState playbackState = AudioEventListener.DeviceState.DISCONNECTED;
   private AudioEventListener.DeviceState captureState = AudioEventListener.DeviceState.DISCONNECTED;
   IApplicationPreferences appPrefs;
   private ILicenseSupport.IListener licenseListener = new ILicenseSupport.IListener() {
      @Override
      public void licenseFeatureSupportChanged(String var1, boolean var2) {
         RFBView.this.kvmPort.updateLicenses();
      }
   };
   private RFBView.AudioErrorsAndMessageHandlerImpl audioErrorsAndMessageHandlerImpl = new RFBView.AudioErrorsAndMessageHandlerImpl();

   public RFBView(ScreenContext var1, RFBProfile var2) {
      super((RRCScreenContext)var1);
      this.profile = var2;
      RRCLogger.log(200, "Connecting to target Id " + this.profile.targetId);
      this.contextMenuKvm = new ContextPopupMenu(this.scrContext, this);
      this.contextMenuKvm.setOpaque(false);
      this.contextMenuKvm.setVisible(false);
      this.rcparams = new RemoteConsoleParameters();
      this.rcparams.host = var2.getRemoteHost();
      this.rcparams.ssl = var2.sslRequired;
      this.rcparams.sessionId = -1;
      this.rcparams.username = var2.username;
      this.rcparams.password = var2.password;
      this.rcparams.ericKey = var2.connectId;
      this.rcparams.rdmSession = var2.rdmSession;
      this.rcparams.rdmSessionMultiPortTag = var2.getRdmSessionMultiPortTag();
      this.rcparams.tcpPort = var2.primaryPort;
      this.rcparams.proxyConnectionIdVM = var2.proxyModeConnectionID;
      this.rcparams.proxyUseSSL = var2.proxyUseSSL;
      this.appPrefs = ((RRCScreenContext)this.scrContext).getAppSettings();
      if (MPCUtil.isCCLaunched((RRCScreenContext)var1)) {
         this.rcparams.targetPortId = var2.portIdRDM;
      } else {
         this.rcparams.targetPortId = var2.targetId;
      }
   }

   @Override
   protected void paintComponent(Graphics var1) {
      var1.setColor(Color.YELLOW);
      super.paintComponent(var1);
   }

   public void init() {
      RRCLogger.log(300, "init Started");
      this.setLayout(new BorderLayout());
      this.rcAdapter = new MainScreenRCAdapter(this);
      this.vsAdapter = new VideoSettingsRCAdapter(this);
      this.ctx = ApplicationContext.getInstance();
      this.ctxListener = new ContextListener() {
         @Override
         public void contextChanged(ContextEvent var1) {
            String var2 = var1.getKey();
            if (var2.equals("HOTKEYMAP")) {
               RFBView.this.populateHotkeyMaps();
            } else if (var2.equals("SCROLLBORDERS")) {
               RFBView.this.showScrollBars();
            }
         }

         @Override
         public void contextDestroyed(ContextEvent var1) {
         }

         @Override
         public void contextInitialized(ContextEvent var1) {
         }
      };
      this.ctx.registerListener(this.ctxListener);
      this.macroHelper = MacroFactory.getInstance().getMacroHelper();
      this.rccore = RCCoreFactory.loadGraphicalRCCore(RRCLogger.getLogger());
      this.rccore.addVideoEventListener(this.rcAdapter, 48);
      this.rccore.addVideoEventListener(this.vsAdapter, 24);
      this.rccore.addKeyboardListener(this.rcAdapter);
      this.rccore.addConnectionEventListener(this.rcAdapter, 223);
      this.rccore.addNotificationListener(this.rcAdapter);
      this.rccore.addVirtualMediaInfoListener(this.rcAdapter, 7);
      this.rccore.addMouseModeListener(this.rcAdapter, 7);
      this.license = this.rccore.getCapablity(ILicenseSupport.class);
      if (this.license != null) {
         this.license.addListener(this.licenseListener);
      }

      this.kvmPort.setLicenseSupport(this.license);
      this.audioEx = this.rccore.getCapablity(IAudioStatusExSupport.class);
      this.kvmPort.setAudioEx(this.audioEx);
      this.hotkeyMap = new Hashtable<>();
      this.categoryMap = new Hashtable<>();
      this.populateHotkeyMaps();
      IApplicationPreferences var1 = ExtensionFactory.getInstance().getApplicationPreferences();
      var1.importPreferences();
      this.keyboardTypeChanged(var1.getKeyboardType());
      this.rccore.addKeyboardInfoListener(this.rcAdapter, 24);
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      int var3 = var2.getAppSettings().getKeyboardType();
      Locale var4 = KeyboardUtil.getLocale(var3);
      RRCLogger.log(300, "Keyboard Number and locale is  " + var3 + " : " + var4);
      if (MPCUtil.isCCLaunched(var2)) {
         if (this.kvmPort != null) {
            HashMap var5 = this.kvmPort.getDeviceConnector().getConnectionMap();
            if (this.scrContext != null) {
               try {
                  String var6 = ((RRCScreenContext)this.scrContext).getParamValue(var5, "VirtualMedia", true);
                  this.setCCVMPermissions(var6);
                  RRCLogger.log(300, "Setting VM Permissions when launched from CC:" + var6);
               } catch (RRCGeneralException var7) {
                  RRCLogger.log(300, "Unable to set VM Permissions when launched from CC");
               }
            }

            String var8 = (String)var5.get("Access");
            if ("Control".equals(var8)) {
               this.kvmPort.getPortPermissionHelper().setKvmPermission(new KvmPortPermissionHelper.KvmPermission(IKvmPort.KvmPermission.CONTROL, true));
            }
         }

         if (this.ccVMPermissions != null && !this.ccVMPermissions.equals("")) {
            if (this.ccVMPermissions.toLowerCase().equals("n")) {
               RRCLogger.log(300, "NO VM Permissions when launched from CC. Disabling VM Menu:" + this.ccVMPermissions);
               this.disableVMMenu();
               this.kvmPort.getPortPermissionHelper().setVmPermission(new KvmPortPermissionHelper.VmPermission(IKvmPort.VmPermission.DENY, true));
            } else if (this.ccVMPermissions.toLowerCase().equals("w")) {
               this.kvmPort.getPortPermissionHelper().setVmPermission(new KvmPortPermissionHelper.VmPermission(IKvmPort.VmPermission.READWRITE, true));
            } else {
               this.kvmPort.getPortPermissionHelper().setVmPermission(new KvmPortPermissionHelper.VmPermission(IKvmPort.VmPermission.READONLY, true));
            }
         }
      }

      RRCLogger.log(300, "init Finished");
   }

   private void populateHotkeyMaps() {
      this.hotkeyMap.clear();
      this.categoryMap.clear();
      int var1 = 0;
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      String var3 = var2.getAppSettings().getkeyboardMenuHotkey();
      this.hotkeyMap.put(var1, KeyStroke.getKeyStroke("ctrl alt " + var3.charAt(var3.length() - 1)));
      this.categoryMap.put(var1, new KeyValuePair<>(3, "EXIT_FULLSCREEN_VALUE"));
      var1++;
      Object var4 = new Vector(0);

      try {
         var4 = MacroFactory.getInstance().getMacroParser().getKeyboardMacros();
      } catch (MacroException var7) {
         RRCLogger.log(150, "MacroException getting current keyboard macros, so Keyboard Macro functionality will be disabled", var7);
      }

      for (IMacro var6 : var4) {
         if (var6.getHotKey() > -1) {
            this.hotkeyMap.put(var1, KeyStroke.getKeyStroke("ctrl alt " + var6.getHotKey()));
            this.categoryMap.put(var1, new KeyValuePair<>(1, var6.getSequence()));
            var1++;
         }
      }

      this.rccore.setHotkeys(this.hotkeyMap);
   }

   private JPanel getConsolePanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new BorderLayout());
      this.showScrollBorder = ((RRCScreenContext)this.scrContext).getAppSettings().isShowScrollBorders();
      this.northLabel = new JLabel();
      this.southLabel = new JLabel();
      this.westLabel = new JLabel();
      this.eastLabel = new JLabel();
      this.northWestLabel = new JLabel();
      this.southEastLabel = new JLabel();
      this.northLabel.setPreferredSize(VIEW_BORER_DIM);
      this.southLabel.setPreferredSize(VIEW_BORER_DIM);
      this.eastLabel.setPreferredSize(VIEW_BORER_DIM);
      this.westLabel.setPreferredSize(VIEW_BORER_DIM);
      this.northLabel.setMinimumSize(VIEW_BORER_DIM);
      this.southLabel.setMinimumSize(VIEW_BORER_DIM);
      this.eastLabel.setMinimumSize(VIEW_BORER_DIM);
      this.westLabel.setMinimumSize(VIEW_BORER_DIM);
      this.northWestLabel.setPreferredSize(VIEW_BORER_DIM);
      this.southEastLabel.setPreferredSize(VIEW_BORER_DIM);
      boolean var2 = this.showScrollBorder && !this.isScaleVideoFlag();
      this.northLabel.setVisible(var2);
      this.southLabel.setVisible(var2);
      this.eastLabel.setVisible(var2);
      this.westLabel.setVisible(var2);
      this.northWestLabel.setVisible(var2);
      this.southEastLabel.setVisible(var2);
      this.northLabel.addMouseListener(this.allListener);
      this.southLabel.addMouseListener(this.allListener);
      this.westLabel.addMouseListener(this.allListener);
      this.eastLabel.addMouseListener(this.allListener);
      this.northWestLabel.addMouseListener(this.allListener);
      this.southEastLabel.addMouseListener(this.allListener);
      JPanel var3 = new JPanel();
      var3.setLayout(new BorderLayout());
      var3.add(this.southEastLabel, "East");
      var3.add(this.southLabel, "Center");
      JPanel var4 = new JPanel();
      var4.setLayout(new BorderLayout());
      var4.add(this.northWestLabel, "West");
      var4.add(this.northLabel, "Center");
      var1.add(var4, "North");
      var1.add(var3, "South");
      var1.add(this.westLabel, "West");
      var1.add(this.eastLabel, "East");
      JPanel var5 = new JPanel(new GridBagLayout());
      GridBagConstraints var6 = new GridBagConstraints();
      var6.anchor = 10;
      var6.fill = 0;
      var6.gridx = 0;
      var6.gridy = 0;
      var6.weightx = 0.0;
      var6.weighty = 0.0;
      var5.add(this.console, var6);
      this.jsp = new JScrollPane();
      this.jsp.setViewportView(var5);
      this.jsp.setHorizontalScrollBarPolicy(31);
      this.jsp.setVerticalScrollBarPolicy(21);
      this.jsp.addComponentListener(this.allListener);
      var1.add(this.jsp, "Center");
      return var1;
   }

   public void handleHotkeys(int var1) {
      RRCLogger.log(300, "Hotkey " + var1 + " detected");
      switch (this.categoryMap.get(var1).getKey()) {
         case 1:
            this.sendKeyboardMacro(this.categoryMap.get(var1).getValue());
            break;
         case 3:
            if (!this.isContextMenuKVMVisible()) {
               this.setContextMenuKVMVisible(true);
            }
            break;
         default:
            this.showFSExitTip();
      }
   }

   @Override
   public void startVideo() {
      RRCLogger.log(300, "startVideo Started");
      if (this.kvmPort != null) {
         G2CompressionPanel.resetPanel(this.kvmPort.getPortKey());
         this.start();
         MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, this.kvmPort);
      } else {
         RRCLogger.log(150, "KvmPort is null, unable to set view");
      }

      RRCLogger.log(300, "startVideo Finished");
   }

   private void setPortState() {
      this.kvmPort.setConnected(true);
      this.kvmPort.setState("CONNECTED");
      this.kvmPort.firePropertyChange("DEVICE_PORT_VIEW_ADD", null, this);
      this.doAutoSettings();
      if (this.kvmPort.isBladePort()) {
         BladeChassis var1 = this.kvmPort.getParentBladeChassis();
         if (var1 != null) {
            var1.setConnected(true);
            var1.setState("CONNECTED");
         }
      }
   }

   private void doAutoSettings() {
      RRCLogger.log(300, "doAutoSetting start");
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      RRCLogger.log(300, "Auto sync mouse: " + var1.getAppSettings().isAutoSyncMouse());
      if (var1.getAppSettings().isAutoSyncMouse()) {
         this.doMouseSyncSoft();
      }

      RRCLogger.log(300, "doAutoSetting end");
   }

   @Override
   public void fillComponents(CommandContext var1) {
      this.kvmPort = (KvmPort)var1.getCommandParameter("ports");
      if (this.kvmPort != null) {
         this.kvmPort.setView(this);
         this.init();
         this.kvmPort.setConnected(true);
         if (this.scrContext.getApplicationProperty("connection") != null) {
            this.shellInternalFrame.addInternalFrameListener(new InternalFrameAdapter() {
               @Override
               public void internalFrameActivated(InternalFrameEvent var1) {
                  MPCUtil.notifyObservers((RRCScreenContext)RFBView.this.scrContext, RFBView.this.kvmPort);
               }
            });
         }
      } else {
         RRCLogger.log(150, "KvmPort is null, unable to set view");
      }
   }

   private boolean isConnected() {
      return this.fullyConnected;
   }

   public void start() {
      this.connectRemoteConsole();
      this.console = this.rccore.getRCJComponent();
      this.console.addComponentListener(this.allListener);
      this.hScrollBar.addAdjustmentListener(this.allListener);
      this.hScrollBar.setUnitIncrement(10);
      this.vScrollBar.addAdjustmentListener(this.allListener);
      this.vScrollBar.setUnitIncrement(10);
      this.add(this.getConsolePanel(), "Center");
      this.add(this.hScrollBar, "South");
      this.add(this.vScrollBar, "East");
      this.focusGained(new FocusEvent(this, 1004));
   }

   public void connectRemoteConsole() {
      this.setVisible(true);
      LinkedHashMap var1 = (LinkedHashMap)this.kvmPort.getBaseDevice().getAppletParameters();
      String[] var2 = var1.keySet().toArray(new String[0]);
      DevicePreferences var3 = this.getPort().getDevice().getDevPrefs();
      if (var3 != null && (var3.getG2ColorDepth() != null || var3.getG2ConnectionSpeed() != null || var3.getG2Smoothing() != null)) {
         boolean var4 = false;
         if (var3.getG2ConnectionSpeed() == null && var3.getG2ColorDepth() != null && var3.getG2Smoothing() != null) {
            var4 = true;
         }

         this.rccore.setConnectionProperties(var4, var3.getG2ConnectionSpeed(), var3.getG2ColorDepth(), var3.getG2Smoothing());
         this.setCurrentCompression(var3.getG2ConnectionSpeed());
         this.setCurrentColorDepth(var3.getG2ColorDepth());
         this.setCurrentSmoothing(var3.getG2Smoothing());
         this.setAutoSelected(var4);
      } else if (this.getPort().getDevice().isModemProfiled()) {
         this.rccore.setLowBandwidth(true);
         this.setCurrentCompression(RCCore.Compression.LEVEL_8);
      }

      this.rccore.setAppletParameterMap(var1);
      if (this.port.isMultiMonitorPort() || MPCUtil.isCCMultiMonitorLaunch() || !MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext)) {
         IMultiMonitorTargetSupport var8 = this.rccore.getCapablity(IMultiMonitorTargetSupport.class);
         if (var8 != null) {
            HashMap var5 = new HashMap();
            var5.put(
               IMultiMonitorTargetSupport.ClientSessionInitProperties.MULTI_MONITOR_ASSOCIATION_ID,
               StringUtils.notNullOrEmpty(this.rcparams.rdmSessionMultiPortTag)
                  ? this.rcparams.rdmSessionMultiPortTag
                  : this.scrContext.getApplication().getAppId()
            );
            var8.setClientSessionInitProperties(var5);
         }
      }

      try {
         try {
            if (this.rcparams.username != null && this.rcparams.password != null) {
               this.rccore
                  .connectRCWithUserLogin(
                     this.rcparams.host, this.rcparams.tcpPort, this.rcparams.ssl, this.rcparams.targetPortId, this.rcparams.username, this.rcparams.password
                  );
            } else if (this.rcparams.ericKey != null && this.rcparams.ericKey.length() > 0) {
               this.rccore
                  .connectRCWithEricKey(this.rcparams.host, this.rcparams.tcpPort, this.rcparams.ssl, this.rcparams.targetPortId, this.rcparams.ericKey);
            } else {
               if (this.rcparams.rdmSession == null || this.rcparams.rdmSession.length() <= 0) {
                  throw new RCException(T._("Authentication parameters missing!"));
               }

               this.rccore
                  .connectRCWithRdmSession(
                     this.rcparams.host,
                     this.rcparams.tcpPort,
                     this.rcparams.ssl,
                     this.rcparams.targetPortId,
                     this.rcparams.rdmSession,
                     this.rcparams.proxyConnectionIdVM,
                     this.rcparams.proxyUseSSL
                  );
            }

            this.connected = true;
         } catch (IOException var6) {
            RRCLogger.log(100, "I/O Error connecting to remote device", var6);
            throw new RCException(T._("I/O Error connecting to remote device"));
         }
      } catch (RCException var7) {
         RRCLogger.log(200, "RCException connecting to remote device", var7);
         this.setStatusMessage(T._("Error connecting to remote device"));
      }
   }

   public Dimension getBlankSize() {
      return this.getSize();
   }

   public void canvasSizeChanged(Dimension var1) {
      RRCLogger.log(200, "Canvas size changed to " + var1);
      this.showScrollBars();
      if (this.vScrollBar != null && this.vScrollBar.isVisible()) {
         this.vScrollBar.setValue(0);
      }

      if (this.hScrollBar != null && this.hScrollBar.isVisible()) {
         this.hScrollBar.setValue(0);
      }

      this.validate();
      this.console.requestFocusInWindow();
   }

   public void changeWindowMode() {
   }

   public void rcConnected() {
      synchronized (this) {
         this.setPortState();
         if (!this.switchPortQueue.isEmpty()) {
            Thread var2 = new Thread(new Runnable() {
               @Override
               public void run() {
                  synchronized (RFBView.this) {
                     KvmPort var2x = RFBView.this.switchPortQueue.removeLast();
                     RFBView.this.switchPortQueue.clear();
                     RFBView.this.switchKvmPort(RFBView.this.kvmPort, var2x);
                  }
               }
            });
            var2.start();
         }

         RRCLogger.log(300, "Connected for view " + this.getPortName() + "_" + this.getPortIndex());
         if (this.isAllPortsConnected()) {
            RFBView var5 = this.getPrimaryPortView();
            if (var5 != null) {
               var5.allPortsConnected();
            }
         }
      }
   }

   private boolean isAllPortsConnected() {
      if (this.port.isSecondaryPort()) {
         return this.getPrimaryPortView().isAllPortsConnected();
      } else {
         Vector var1 = new Vector();
         var1.add(this);
         var1.addAll(this.getSecondaryPortViews());

         for (RFBView var3 : var1) {
            if (!var3.isConnected()) {
               return false;
            }
         }

         return true;
      }
   }

   private void allPortsConnected() {
      ((KvmPort)this.port).reevaluatePermissions();

      for (Port var2 : this.port.getAssociatedPorts()) {
         ((KvmPort)var2).reevaluatePermissions();
      }

      final Runnable var3 = new Runnable() {
         @Override
         public void run() {
            if (RFBView.this.port.isPrimaryPort()) {
               RFBView.this.adjustMultiMonitorPortWindows();

               try {
                  RFBView.this.shellInternalFrame.setSelected(true);
               } catch (PropertyVetoException var4) {
               }
            }

            IApplicationPreferences var1 = ExtensionFactory.getInstance().getApplicationPreferences();
            if (var1.isAlwaysOpenInFS()) {
               RFBView.this.setTargetScreenResolution(true);
            }

            for (RFBView var3x : RFBView.this.getSecondaryPortViews()) {
               var3x.finalizeView();
            }

            RFBView.this.finalizeView();
            if (RFBView.this.port.isPrimaryPort()) {
               (new Thread() {
                  @Override
                  public void run() {
                     try {
                        Thread.sleep(1000L);
                     } catch (Exception var2) {
                     }

                     SwingUtilities.invokeLater(new Runnable() {
                        @Override
                        public void run() {
                           try {
                              RFBView.this.shellInternalFrame.setSelected(true);
                              MPCUtil.notifyObservers((RRCScreenContext)RFBView.this.scrContext, RFBView.this.port);
                           } catch (Exception var2) {
                           }
                        }
                     });
                  }
               }).start();
            }
         }
      };
      (new Thread() {
         @Override
         public void run() {
            try {
               Thread.sleep(1000L);
            } catch (Exception var2) {
            }

            SwingUtilities.invokeLater(var3);
         }
      }).start();
   }

   private void finalizeView() {
      if (!this.viewFinalized) {
         this.viewFinalized = true;

         for (INotificationEvent var2 : this.collectedNotifications) {
            if (var2.isError()) {
               ErrorHandlerImpl.getInstance().handleError(var2.getErrorCode(), this.scrContext.getApplication().getContentPaneForPort(this.port), this);
            } else if (var2.isWarning()) {
               ErrorHandlerImpl.getInstance().handleWarning(var2.getErrorCode(), this.scrContext.getApplication().getContentPaneForPort(this.port), this);
            } else if (var2.isInfo()) {
               ErrorHandlerImpl.getInstance().handleInfo(var2.getErrorCode(), this.scrContext.getApplication().getContentPaneForPort(this.port), this);
            }
         }
      }
   }

   private void disconnectAssociatedPorts() {
      for (Port var2 : this.port.getAssociatedPorts()) {
         ((KvmPort)var2).disconnect(false);
      }
   }

   public void networkError() {
      try {
         if (!this.shellInternalFrame.isClosed() && this.kvmPort.isConnected()) {
            this.close();
            this.kvmPort.setConnected(false);
            this.kvmPort.setState("AVAILABLE");
            this.kvmPort.firePropertyChange("DEVICE_PORT_VIEW_REMOVE", this, null);
            this.closeSelf();
         }
      } catch (PropertyVetoException var2) {
         RRCLogger.log(100, "", var2);
      }
   }

   public void setWLANQuality(int var1) {
   }

   public void setTitle(String var1) {
   }

   public void setFrameTitle(String var1) {
   }

   public void setSunTarget(boolean var1) {
      this.isSunTarget = var1;
   }

   @Override
   public boolean isSunTarget() {
      return this.isSunTarget;
   }

   public void setCimLanguageOptionsSupported(boolean var1) {
      this.cimLangOptsSupported = var1;
   }

   public boolean isCimLanguageOptionsSupported() {
      return this.cimLangOptsSupported;
   }

   public static void main(String[] var0) {
   }

   public RFBProfile getProfile() {
      return this.profile;
   }

   public void setProfile(RFBProfile var1) {
      this.profile = var1;
   }

   public synchronized void close() {
      this.removeListeners();
   }

   @Override
   public synchronized boolean disconnect() {
      if (this.kvmPort != null) {
         RRCLogger.log(300, "Disconnecting port " + this.kvmPort.getPortIndex());
      }

      this.removeListeners();
      if (MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext) && !this.isQuitEvent()) {
         this.scrContext.getApplication().disconnect();
      }

      return true;
   }

   @Override
   public synchronized void removeListeners() {
      if ((RRCScreenContext)this.scrContext != null) {
         this.closeOpenVMConnections(false);
      }

      this.disconnectSmartCard(this.kvmPort);
      this.disconnectAudio(this.kvmPort);
      if (this.rccore != null) {
         if (this.connected) {
            this.rccore.disconnect();
            this.connected = false;
         }

         this.rccore.removeVideoEventListener(this.vsAdapter);
         this.rccore.removeVideoEventListener(this.rcAdapter);
         this.rccore.removeKeyboardListener(this.rcAdapter);
         this.rccore.removeConnectionEventListener(this.rcAdapter);
         this.rccore.removeNotificationListener(this.rcAdapter);
         this.rccore.removeVirtualMediaInfoListener(this.rcAdapter);
         this.rccore.removeMouseModeListener(this.rcAdapter);
         this.rccore.removeKeyboardInfoListener(this.rcAdapter);
         this.rccore = null;
      }

      if (this.license != null) {
         this.license.removeListener(this.licenseListener);
         this.license = null;
      }

      this.audioEx = null;
      if (this.contextMenuKvm != null) {
         this.contextMenuKvm.cleanup();
         this.contextMenuKvm = null;
      }

      if (this.ctx != null && this.ctxListener != null) {
         this.ctx.removeListener(this.ctxListener);
      }

      this.jsp = null;
      this.rcAdapter = null;
      this.vsAdapter = null;
      this.profile = null;
      this.rcparams = null;
      this.console = null;
      this.profile = null;
      this.kvmPort = null;
      this.vmMountsResponse = null;
      this.vmShareTable = null;
      this.northLabel = null;
      this.southLabel = null;
      this.eastLabel = null;
      this.westLabel = null;
      this.northWestLabel = null;
      this.southEastLabel = null;
      this.hScrollBar = null;
      this.vScrollBar = null;
      this.allListener = null;
      this.vmImagePanel = null;
      this.vmLocalPanel = null;
      this.ccVMPermissions = null;
      if (this.switchPortQueue != null) {
         this.switchPortQueue.clear();
         this.switchPortQueue = null;
      }

      if (this.capabilityMap != null) {
         this.capabilityMap.clear();
         this.capabilityMap = null;
      }

      if (this.remoteIsoList != null) {
         this.remoteIsoList.clear();
         this.remoteIsoList = null;
      }

      this.vidSettings = null;
      if (this.hotkeyMap != null) {
         this.hotkeyMap.clear();
         this.hotkeyMap = null;
      }

      if (this.categoryMap != null) {
         this.categoryMap.clear();
         this.categoryMap = null;
      }

      this.macroHelper = null;
      this.currentColorDepth = null;
      this.currentCompression = null;
      this.currentSmoothing = null;
      this.ctxListener = null;
      this.ctx = null;
      System.runFinalization();
      System.gc();
   }

   @Override
   public void keyboardTypeChanged(int var1) {
      Object var2 = null;
      RRCLogger.log(300, "New keyboard type is: " + var1);
      this.keyboardType = var1;
      var2 = KeyboardUtil.getLocale(var1);
      if (var2 == null) {
         RRCLogger.log(150, "Unknown keyboard type " + var1);
      } else {
         RRCLogger.log(300, "Setting locale to " + var2);

         try {
            this.rccore.setLocalKeyboardMapping((Locale)var2);
         } catch (IOException var4) {
            RRCLogger.log(150, "IOException trying to set local keyboard mapping", var4);
         }
      }
   }

   @Override
   public void sendCtrlAltDelete() {
      RRCLogger.log(300, "Sending CAD");
      this.sendKeyboardMacro("p 0&&p 2&&p 16&&r 16&&r 2&&r 0");
   }

   @Override
   public void sendAltTab() {
      RRCLogger.log(300, "Sending LeftAlt+Tab");
      this.sendKeyboardMacro("p 2&&p 19&&r 19&&r 2");
   }

   @Override
   public void sendCtrlNumlock() {
      RRCLogger.log(300, "Sending CTRL-NUMLOCK");
      this.sendKeyboardMacro("p 0&&p 8&&r 8&&r 0");
   }

   private void setTargetScreenResolution(boolean var1, AbstractUIManager.FullScreenTarget var2) {
      this.setFullScreenMode(var1);
      AbstractUIManager var3 = ((RRCScreenContext)this.scrContext).getApplication();
      var3.changeScreen(var1, this.getShellInternalFrame(), this.port, var2);
      if (this.isScaleVideoFlag()) {
         this.rccore.setScaleToFit(true, true, this.getShellInternalFrame().getSize());
      }

      if (var1) {
         this.setViewFocus();
      }
   }

   @Override
   public void setTargetScreenResolution(boolean var1) {
      if (this.port.isPrimaryPort()) {
         this.setTargetScreenResolution(var1, AbstractUIManager.FullScreenTarget.PRIMARY);

         for (RFBView var3 : this.getSecondaryPortViews()) {
            var3.setTargetScreenResolution(var1, AbstractUIManager.FullScreenTarget.SECONDARY);
         }
      } else if (this.port.isSecondaryPort() && MonitorSettingsHandler.getInstance().getMonitorCount() > 1) {
         RFBView var4 = this.getPrimaryPortView();
         var4.setTargetScreenResolution(var1);
      } else {
         this.setTargetScreenResolution(var1, AbstractUIManager.FullScreenTarget.SINGLE);
      }
   }

   @Override
   public void toggleTargetScreenResolution() {
      this.setTargetScreenResolution(!this.isFullScreenMode());
   }

   private void adjustMultiMonitorPortWindows() {
      Vector var1 = new Vector();
      var1.add(this);
      var1.addAll(this.getSecondaryPortViews());
      if (var1.size() != 1) {
         int var2 = 0;
         int var3 = 0;

         for (RFBView var5 : var1) {
            Point var6 = var5.getPort().getMonitorLocation();
            if (var6.x > var2) {
               var2 = var6.x;
            }

            if (var6.y > var3) {
               var3 = var6.y;
            }
         }

         Dimension var11 = this.getShellInternalFrame().getSize();
         var11.width /= var2 + 1;
         var11.height /= var3 + 1;

         for (RFBView var13 : var1) {
            ShellInternalFrame var7 = var13.getShellInternalFrame();
            Point var8 = var13.getPort().getMonitorLocation();

            try {
               var7.setMaximum(false);
               var7.setSize(var11);
               var7.setLocation(var8.x * var11.width, var8.y * var11.height);
            } catch (PropertyVetoException var10) {
            }
         }
      }
   }

   @Override
   public void synchronizeMouse(boolean var1) {
      if (this.isConnected()) {
         try {
            this.rccore.syncMouse(RCCore.MouseSyncType.HARD);
         } catch (IOException var3) {
            RRCLogger.log(150, "I/O Error performing hard mouse sync.", var3);
         }
      }
   }

   public void doMouseSyncSoft() {
      if (this.isConnected()) {
         try {
            this.rccore.syncMouse(RCCore.MouseSyncType.NORM);
         } catch (IOException var2) {
            RRCLogger.log(150, "I/O Error performing soft mouse sync.", var2);
         }
      }
   }

   @Override
   public boolean isCommandOperable(AbstractCommand var1) {
      boolean var2 = super.isCommandOperable(var1);
      if (var1 != null) {
         Class var3 = var1.getClass();
         if (DoEnterOnscreenMenuCommand.class.equals(var3) || DoExitOnscreenMenuCommand.class.equals(var3)) {
            var2 = false;
         }
      } else {
         RRCLogger.log(300, "isCommandOperable: Command is null");
      }

      return var2;
   }

   @Override
   public void setViewFocus() {
      try {
         if (this.getShellInternalFrame().isSelected()) {
            RRCLogger.log(300, "Grabbing focus");
            this.console.requestFocus();
            this.console.requestFocusInWindow();
         }
      } catch (Exception var2) {
         RRCLogger.log(100, "Exception in RFBView.setViewFocus: ", var2);
      }
   }

   @Override
   public void customizeTarget(AbstractDisplay var1) {
      if (var1 != null) {
         if (var1.isDialog()) {
            if (OptionsPanel.class.equals(var1.getClass())) {
               OptionsPanel var2 = (OptionsPanel)var1;
               var2.setEnabledKvmSwitchOSUIHotKey(false);
            } else if (PropertiesPanel.class.equals(var1.getClass())) {
               PropertiesPanel var3 = (PropertiesPanel)var1;
               var3.setEnabledProgressiveUpdateChkBox(false);
               var3.setEnabledSmoothingSlider(false);
               var3.setEnabledInternetFlowControlChkBox(false);
            }
         }
      } else {
         RRCLogger.log(300, "customizeTarget: aDisplay is null");
      }
   }

   @Override
   public boolean macroMenuActionPerformed(String var1) {
      RRCLogger.log(300, "Macro sequence: " + var1);
      return this.sendKeyboardMacro(var1);
   }

   @Override
   public void sendKeyboardMacroDirect(KeyboardMacro var1) {
      this.sendKeyboardMacro(var1);
   }

   @Override
   public boolean sendKeyboardMacro(String var1) {
      if (var1.length() < 3) {
         return false;
      } else {
         String[] var2 = var1.split("&&");
         Vector var3 = new Vector();
         KeyboardMacro var6 = new KeyboardMacro("", "", null, false);

         for (int var7 = 0; var7 < var2.length; var7++) {
            char var5 = var2[var7].charAt(0);
            int var4 = Integer.parseInt(var2[var7].substring(2));
            switch (var5) {
               case 'p':
               case 'r':
                  int var9 = this.macroHelper.getKeyMappings().getItem(var4).getKeyLocation();
                  Locale var10 = Locale.US;
                  int var11 = ((RRCScreenContext)this.scrContext).getAppSettings().getKeyboardType();
                  if (var11 == 5 || var11 == 1) {
                     var10 = KeyboardUtil.getLocale(var11);
                  }

                  var4 = this.macroHelper.getVKCode((short)var4, var10);
                  if (this.isSunTarget && var4 == 3) {
                     var4 = 456;
                  }

                  char var12 = this.macroHelper.getKeyChar((short)var4, var10);
                  var4 = this.rccore.getKeyCode(var4, var12, var9);
                  var3.add(var6.new KeyCode(var4, var5 == 'p'));
               case 'q':
               default:
                  break;
               case 's':
                  int var8 = this.macroHelper.getKeyMappings().getItem(var4).getKeyCode();
                  var3.add(var6.new KeyCode(true, var8));
            }
         }

         var6 = new KeyboardMacro("", "", var3.toArray(new KeyboardMacro.KeyCode[0]), false);
         return this.sendKeyboardMacro(var6);
      }
   }

   public boolean sendKeyboardMacro(KeyboardMacro var1) {
      if (var1.getConfirm()
         && JOptionPane.showOptionDialog(
               this, MessageFormat.format(T._("Do you really want to send {0}?"), var1.getNameOrCode()), T._("Confirmation"), 0, 3, null, null, null
            )
            == 1) {
         return false;
      } else {
         this.rccore.sendKeyboardMacro(var1, true);
         return true;
      }
   }

   public void setMouseMode(RCCore.MouseMode var1) {
      try {
         this.rccore.setMouseMode(var1);
      } catch (IOException var3) {
         RRCLogger.log(150, "IO Exception attempting to set mouse mode", var3);
      }
   }

   public void setMouseModeMenuItem(RCCore.MouseMode var1) {
      if (this.rccore.getMouseMode() != var1) {
         this.setMouseMode(var1);
      }

      if (var1 == RCCore.MouseMode.ABSOLUTE) {
         ((RRCScreenContext)this.scrContext).getMainScreenMediator().selectAbsoluteMouseModeView(true);
         this.mouseMode = 0;
      } else if (var1 == RCCore.MouseMode.AUTOMATIC) {
         ((RRCScreenContext)this.scrContext).getMainScreenMediator().selectIntelligentMouseModeView(true);
         this.mouseMode = 1;
      } else {
         ((RRCScreenContext)this.scrContext).getMainScreenMediator().selectStandardMouseModeView(true);
         this.mouseMode = 2;
      }

      MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, this.kvmPort);
   }

   public void setMouseAbsolute() {
      this.setMouseMode(RCCore.MouseMode.ABSOLUTE);
      this.mouseMode = 0;
   }

   public void setMouseIntelligent() {
      this.setMouseMode(RCCore.MouseMode.AUTOMATIC);
      this.mouseMode = 1;
   }

   public void setMouseStandard() {
      this.setMouseMode(RCCore.MouseMode.STANDARD);
      this.mouseMode = 2;
   }

   @Override
   public void setSingleCursor(boolean var1) {
      this.setFrameSize();
      this.setSingleCursorMode(var1);
      this.rccore.setSingleCursorMode(var1);
      this.rccore.setCaptureRightAway(var1);
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      FullScreenToolBar var3 = var2.getApplication().getFSToolBar(this.getShellInternalFrame());
      if (var3 != null) {
         var3.setLabelText();
         var3.setToolBarVisible(true);
      }

      if (var1) {
         String var4 = this.bundle.getString("SingleMouseModeInstructions3.text") + RRCScreenContext.getKvmPopupKey();
         this.setStatusMessage(var4 + ", " + this.bundle.getString("FullScreen.exitSMM"));
         this.shellInternalFrame
            .setTitle(
               MessageFormat.format(
                  this.bundle.getString("SingleMouseModeInstructions6.text"),
                  this.kvmPort.getViewName(),
                  var4 + this.bundle.getString("SingleMouseModeInstructions5.text")
               )
            );
      } else {
         this.setStatusMessage(this.bundle.getString("Status.rrcLoaded"));
         this.shellInternalFrame.setTitle(this.kvmPort.getViewName());

         for (Port var5 : this.getPort().getAssociatedPorts()) {
            if (((KvmPort)var5).isSingleCursorMode()) {
               ((KvmPort)var5).toggleSingleMouseCursor();
            }
         }
      }
   }

   public int getMouseMode() {
      RCCore.MouseMode var1 = RCCore.MouseMode.STANDARD;
      if (this.rccore != null) {
         var1 = this.rccore.getMouseMode();
      }

      if (var1 == RCCore.MouseMode.ABSOLUTE) {
         return 0;
      } else {
         return var1 == RCCore.MouseMode.AUTOMATIC ? 1 : 2;
      }
   }

   @Override
   public ICommandHandler getCommandHandler() {
      return this.rFBViewCommandHandler;
   }

   public void switchKvmPort(KvmPort var1, KvmPort var2) {
      synchronized (this) {
         try {
            if (this.fullyConnected && this.switchPortQueue.isEmpty()) {
               RRCLogger.log(300, "switchKvmPort Started");
               RRCScreenContext var4 = (RRCScreenContext)this.scrContext;
               this.closeOpenVMConnections(true);
               this.disconnectSmartCard(this.kvmPort);
               this.disconnectAudio(this.kvmPort);
               this.disconnectAssociatedPorts();
               KvmPort var5 = this.kvmPort;
               var5.setState("AVAILABLE");
               var5.setConnected(false);
               var5.setActive(false);
               var5.setLicenseSupport(null);
               var5.setAudioEx(null);
               if (var5.isBladePort()) {
                  BladeChassis var6 = var5.getParentBladeChassis();
                  if (var6 != null) {
                     var6.setState("AVAILABLE");
                  }
               }

               var4.removePortInObservable(var5);
               if (var5.equals(((IPReach)var5.getBaseDevice()).getActiveKvmPort())) {
                  ((IPReach)var5.getBaseDevice()).setActiveKvmPort(null);
               }

               this.kvmPort = var2;
               this.port = var2;
               RRCLogger.log(300, "Switching to " + var2.getPortIndex());
               this.rccore.switchKvmPort(this.port.getPortIndex(), this.port.getUniquePortId());
               this.kvmPort.setView(this);
               this.kvmPort.setDevView(this);
               this.kvmPort.setLicenseSupport(this.license);
               this.kvmPort.setAudioEx(this.audioEx);
               this.kvmPort.setActive(true);
               this.kvmPort.setContext(this.scrContext);
               ((IPReach)this.kvmPort.getBaseDevice()).setActiveKvmPort(this.kvmPort);
               this.setPortState();
               var4.addPortInObservable(this.kvmPort);
               this.shellInternalFrame.setTitle(this.kvmPort.getViewName());
               DoDisconnectCommand var15 = new DoDisconnectCommand(this.scrContext);
               SelectPortViewCommand var7 = new SelectPortViewCommand(this.scrContext);
               DeSelectPortViewCommand var8 = new DeSelectPortViewCommand(this.scrContext);
               var7.getContext().setCommandParameter("selectedPortDevice", this.kvmPort);
               var15.getContext().setCommandParameter("selectedPortDevice", this.kvmPort);
               ((RRCShellInternalFrame)this.shellInternalFrame).setFrameClosedCommand(var15);
               ((RRCShellInternalFrame)this.shellInternalFrame).setFrameActivatedCommand(var7);
               ((RRCShellInternalFrame)this.shellInternalFrame).setFrameDeActivatedCommand(var8);
               ((RRCShellInternalFrame)this.shellInternalFrame).setDeviceView(this);
               G2CompressionPanel.resetPanel(this.kvmPort.getPortKey());
               RRCLogger.log(300, "switchKvmPort Finished");

               try {
                  this.shellInternalFrame.setMaximum(true);
               } catch (PropertyVetoException var11) {
               }
            } else {
               this.switchPortQueue.addLast(var2);
            }
         } catch (RCException var12) {
            RRCLogger.getLogger().log(Level.WARNING, "Could not switch to KvmPort: " + var2.getPortIndex(), (Throwable)var12);
         } catch (IOException var13) {
            RRCLogger.getLogger().log(Level.WARNING, "Could not switch to KvmPort: " + var2.getPortIndex(), (Throwable)var13);
         }
      }
   }

   @Override
   public void refreshScreen() {
      try {
         this.rccore.requestVideoRefresh();
      } catch (IOException var2) {
         RRCLogger.log(100, "I/O Error requesting Video refresh.", var2);
      }
   }

   @Override
   public void calibrateColor() {
      try {
         this.rccore.requestVideoColorCalibration();
      } catch (IOException var2) {
         RRCLogger.log(100, "I/O Error requesting Color Calibration.", var2);
      }
   }

   @Override
   public void autoSenseVideo() {
      try {
         this.rccore.requestVideoAutoSense();
      } catch (IOException var2) {
         RRCLogger.log(100, "I/O Error requesting Auto Sense.", var2);
      }
   }

   public long getInData() {
      return this.rccore.getIncomingTrafficSpeed();
   }

   public long getOutData() {
      return this.rccore.getOutgoingTrafficSpeed();
   }

   public int getFpsCount() {
      return this.rccore.getFramesPerSecond();
   }

   public Dimension getScreenSize() {
      return this.console.getSize();
   }

   public void writeVideoSettings(IVideoSettings var1) {
      try {
         this.rccore.setVideoSettings(var1);
      } catch (IOException var3) {
      }
   }

   public void saveVideoSettings() {
      try {
         this.rccore.saveVideoSettings();
      } catch (IOException var2) {
         RRCLogger.log(150, "IO Exception trying to save Video Settings", var2);
      }
   }

   public void resetCurrentVideoSettings() {
      try {
         this.rccore.cancelVideoSettings();
         this.rccore.stopVideoSettingsUpdates();
      } catch (IOException var2) {
         RRCLogger.log(150, "IO Exception trying to remove Video Settings Updates during GUI disposal.", var2);
      }
   }

   public void requestVideoSettings() {
      try {
         this.rccore.requestVideoSettingsUpdates();
      } catch (IOException var2) {
         RRCLogger.log(150, "Unable to request Video Settings Updates");
      }
   }

   public IVideoSettings getVideoSettings() {
      return this.vidSettings;
   }

   @Override
   public void processComponentEvent(ComponentEvent var1) {
      if (this.console != null) {
      }
   }

   private void adjustScrollBars() {
      if (this.scrollBothDirections) {
         this.scrollVertical();
         this.scrollHorizontal();
      } else if (this.adjustingVertical) {
         this.scrollVertical();
      } else {
         this.scrollHorizontal();
      }
   }

   private void scrollVertical() {
      int var1 = this.vScrollBar.getValue();
      var1 += this.adjustmentValue * 10;
      if (var1 < 0) {
         var1 = 0;
      }

      if (var1 < this.vScrollBar.getMaximum()) {
         this.vScrollBar.setValue(var1);
      } else {
         this.vScrollBar.setValue(this.vScrollBar.getMaximum());
      }
   }

   private void scrollHorizontal() {
      int var1 = this.hScrollBar.getValue();
      var1 += this.adjustmentValue * 10;
      if (var1 < 0) {
         var1 = 0;
      }

      if (var1 < this.hScrollBar.getMaximum()) {
         this.hScrollBar.setValue(var1);
      } else {
         this.hScrollBar.setValue(this.hScrollBar.getMaximum());
      }
   }

   public void showScrollBars() {
      JScrollPane var1 = this.jsp;
      JComponent var2 = this.console;
      if (var1 != null && var2 != null) {
         boolean var3 = var1.getSize().width < var2.getSize().width;
         if (this.isTargetScreenResolution()) {
            var3 = var1.getViewport().getSize().width + this.vScrollBar.getSize().width < var2.getSize().width;
         }

         var3 = var3 && !this.isScaleVideoFlag();
         this.showScrollBorder = ((RRCScreenContext)this.scrContext).getAppSettings().isShowScrollBorders();
         this.showScrollBorder = this.showScrollBorder && !this.isTargetScreenResolution();
         this.hScrollBar.setVisible(var3);
         this.eastLabel.setVisible(var3 && this.showScrollBorder);
         this.westLabel.setVisible(var3 && this.showScrollBorder);
         var3 = var1.getSize().height < var2.getSize().height;
         if (this.isTargetScreenResolution()) {
            var3 = var1.getViewport().getSize().height + this.hScrollBar.getSize().height < var2.getSize().height;
         }

         var3 = var3 && !this.isScaleVideoFlag();
         this.vScrollBar.setVisible(var3);
         this.northLabel.setVisible(var3 && this.showScrollBorder);
         this.northWestLabel.setVisible(var3 && this.showScrollBorder);
         this.southLabel.setVisible(var3 && this.showScrollBorder);
         this.southEastLabel.setVisible(var3 && this.showScrollBorder);
         if (this.hScrollBar.isVisible()) {
            this.hScrollBar.setMaximum(var2.getSize().width - var1.getViewport().getSize().width + VIEW_BORER_DIM.width);
         }

         if (this.vScrollBar.isVisible()) {
            this.vScrollBar.setMaximum(var2.getSize().height - var1.getViewport().getSize().height + VIEW_BORER_DIM.height);
         }
      }
   }

   public void setCapsLockStatus(boolean var1) {
      this.setCapsLockOn(var1);
      ((RRCStatusBar)((RRCScreenContext)this.kvmPort.getContext()).getPanelMediator().getStatusPanel()).setCapsLockStatus(var1);
   }

   public void setNumLockStatus(boolean var1) {
      this.setNumLockOn(var1);
      ((RRCStatusBar)((RRCScreenContext)this.kvmPort.getContext()).getPanelMediator().getStatusPanel()).setNumLockStatus(var1);
   }

   public void setScrollLockStatus(boolean var1) {
      this.setScrollLockOn(var1);
      ((RRCStatusBar)((RRCScreenContext)this.kvmPort.getContext()).getPanelMediator().getStatusPanel()).setScrollsLockStatus(var1);
   }

   public void setConcurrentUsers(int var1) {
      this.kvmPort.setConcurrUsers(var1);
      ((RRCStatusBar)((RRCScreenContext)this.kvmPort.getContext()).getPanelMediator().getStatusPanel()).setConcurrentUsers(var1);
   }

   public void setKvmPort(IKvmPort var1) {
      this.kvmPort.getPortPermissionHelper().setKvmPermission(new KvmPortPermissionHelper.KvmPermission(var1.getKvmPermission(), false));
      this.kvmPort.getPortPermissionHelper().setVmPermission(new KvmPortPermissionHelper.VmPermission(var1.getVmPermission(), false));
   }

   public Dimension getViewportSize() {
      JScrollPane var1 = this.jsp;
      return var1 != null ? var1.getViewport().getSize() : new Dimension();
   }

   public String getCurrentMouseMode() {
      return null;
   }

   public void setCurrentMouseMode(String var1) {
   }

   @Override
   public void setIsAbsoluteMouseSupported(boolean var1) {
      this.isAbsoluteMouseSupported = var1;
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      MPCUtil.notifyObservers(var2, this.kvmPort);
      var2.getMainScreenMediator().enableAbsoluteMouseModeView(this.isAbsoluteMouseSupported);
      RRCLogger.log(300, "Absolute Mouse Supported: " + var1);
   }

   @Override
   public void setIsIntelligentMouseSupported(boolean var1) {
      this.isIntelligentMouseSupported = var1;
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      MPCUtil.notifyObservers(var2, this.kvmPort);
      var2.getMainScreenMediator().enableIntelligentMouseModeView(this.isIntelligentMouseSupported);
      RRCLogger.log(300, "Intelligent Mouse Supported: " + var1);
   }

   @Override
   public void setIsStandardMouseSupported(boolean var1) {
      this.isStandardMouseSupported = var1;
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      MPCUtil.notifyObservers(var2, this.kvmPort);
      var2.getMainScreenMediator().enableStandardMouseModeView(this.isStandardMouseSupported);
      RRCLogger.log(300, "Standard Mouse Supported: " + var1);
   }

   public void setMouseMode(int var1) {
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      MPCUtil.notifyObservers(var2, this.kvmPort);
      this.refreshMouseMenu();
      switch (var1) {
         case 0:
            var2.getMainScreenMediator().selectAbsoluteMouseModeView(this.isAbsoluteMouseSupported);
            RRCLogger.log(300, "Setting mouse mode to MOUSE_MODE_ABSOLUTE: " + var1);
            break;
         case 1:
            var2.getMainScreenMediator().selectIntelligentMouseModeView(this.isIntelligentMouseSupported);
            RRCLogger.log(300, "Setting mouse mode to MOUSE_MODE_INTELLI: " + var1);
            break;
         case 2:
            var2.getMainScreenMediator().selectStandardMouseModeView(this.isStandardMouseSupported);
            RRCLogger.log(300, "Setting mouse mode to MOUSE_MODE_STANDARD: " + var1);
            break;
         default:
            RRCLogger.log(300, "Unknown mouse mode: " + var1);
      }
   }

   public void refreshMouseMenu() {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      var1.getMainScreenMediator().enableAbsoluteMouseModeView(this.isAbsoluteMouseSupported);
      var1.getMainScreenMediator().enableIntelligentMouseModeView(this.isIntelligentMouseSupported);
      var1.getMainScreenMediator().enableStandardMouseModeView(this.isStandardMouseSupported);
   }

   public void handleFocus(Component var1) {
      var1.requestFocusInWindow();
   }

   @Override
   protected void processEvent(AWTEvent var1) {
      super.processEvent(var1);
   }

   @Override
   public boolean isTargetScreenResolution() {
      return this.isFullScreenMode();
   }

   public boolean isContextMenuKVMVisible() {
      return this.contextMenuKvm.isVisible();
   }

   @Override
   public void setContextMenuKVMVisible(boolean var1) {
      if (!var1) {
         this.getContextPopupMenu().setVisible(var1);
      } else {
         String var2 = "";
         var2 = this.port.getViewName() + this.port.getPortIndex();
         Map var3 = this.scrContext.getVirtualMediaLocalMap();
         Map var4 = this.scrContext.getVirtualMediaImageMap();
         if (var3 != null && var3.size() > 0) {
            VirtualMediaLocalBean var5 = (VirtualMediaLocalBean)var3.get(var2);
            if (var5 != null && var5.isDriveConnected()) {
               this.getContextPopupMenu().getVirtualMediaLocalMenu().setText(this.bundle.getString("VirtualMediaDisconnect") + " " + var5.getConnectedDrive());
            } else {
               this.getContextPopupMenu().getVirtualMediaLocalMenu().setText(this.bundle.getString("VirtualMediaLocalConnect.name"));
            }
         } else {
            this.getContextPopupMenu().getVirtualMediaLocalMenu().setText(this.bundle.getString("VirtualMediaLocalConnect.name"));
         }

         this.getContextPopupMenu()
            .getVirtualMediaLocalMenu()
            .setToolTipText(((ShowVirtualMediaLocalPanelCommand)this.getContextPopupMenu().getVirtualMediaLocalMenu().getCommand()).getToolTip());
         if (var4 != null && var4.size() > 0) {
            VirtualMediaBean var8 = (VirtualMediaBean)var4.get(var2);
            if (var8 != null && var8.isDriveConnected()) {
               this.getContextPopupMenu().getVirtualMediaImageMenu().setText(this.bundle.getString("VirtualMediaDisconnect") + " " + var8.getConnectedDrive());
            } else {
               this.getContextPopupMenu().getVirtualMediaImageMenu().setText(this.bundle.getString("VirtualMediaImageConnect.name"));
            }
         } else {
            this.getContextPopupMenu().getVirtualMediaImageMenu().setText(this.bundle.getString("VirtualMediaImageConnect.name"));
         }

         this.getContextPopupMenu()
            .getVirtualMediaImageMenu()
            .setToolTipText(((ShowVirtualMediaImagePanelCommand)this.getContextPopupMenu().getVirtualMediaImageMenu().getCommand()).getToolTip());
         ConnectAudioCommand var9 = (ConnectAudioCommand)this.getContextPopupMenu().getConnectAudioMenu().getCommand();
         if (var9.isExecutable()) {
            this.getContextPopupMenu()
               .getConnectAudioMenu()
               .setToolTipText(var9.isConnected() ? this.bundle.getString("Audio.disconnectAudio") : this.bundle.getString("Audio.connectAudio"));
         } else {
            this.getContextPopupMenu().getConnectAudioMenu().setToolTipText(var9.getToolTip());
         }

         this.getContextPopupMenu()
            .getConnectAudioMenu()
            .setText(var9.isConnected() ? this.bundle.getString("Audio.disconnectAudio") : this.bundle.getString("Audio.connectAudio"));
         CommandMenuItem var6 = this.getContextPopupMenu().getVirtualMediaLocalMenu();
         var6.setEnabled(var6.getCommand().isExecutable());
         var6 = this.getContextPopupMenu().getVirtualMediaImageMenu();
         var6.setEnabled(var6.getCommand().isExecutable());
         this.getContextPopupMenu().show(this, 10, 10);
      }
   }

   @Override
   public ContextPopupMenu getContextPopupMenu() {
      return this.contextMenuKvm;
   }

   @Override
   public boolean isScaleVideoFlag() {
      return this.scaleVideoFlag;
   }

   @Override
   public boolean isSingleCursor() {
      return this.singleCursorMode;
   }

   @Override
   public void setScaleVideoFlag(boolean var1) {
      this.scaleVideoFlag = var1;
      if (this.vScrollBar.isVisible()) {
         this.vScrollBar.setValue(0);
      }

      if (this.hScrollBar.isVisible()) {
         this.hScrollBar.setValue(0);
      }

      this.rccore.setScaleToFit(var1, true, this.getShellInternalFrame().getSize());
      this.rccore.setInterpolation(var1 ? RCCore.Interpolation.FAST : RCCore.Interpolation.NONE);
      if (this.scaleVideoFlag) {
         this.removeAll();
         this.add(this.console, "Center");
         this.validate();
      } else {
         this.remove(this.console);
         this.add(this.getConsolePanel(), "Center");
         this.add(this.hScrollBar, "South");
         this.add(this.vScrollBar, "East");
         this.validate();
      }

      this.showScrollBars();
   }

   public void setSmoothing(int var1) {
   }

   public int getFullScreenExitKeycode() {
      return -1;
   }

   public void setVMMountsResponse(VMMountRequestResponse var1) {
      this.vmMountsResponse = var1;
      this.processVMMountResponse(this.vmMountsResponse);
   }

   public VMMountRequestResponse getVMMountsResponse() {
      return this.vmMountsResponse;
   }

   public void setVMShareTable(VMMountRequestResponse[] var1) {
      this.vmShareTable = var1;
   }

   public VMMountRequestResponse[] getVMShareTable() {
      return this.vmShareTable;
   }

   public void processVMMountResponse(IVMMountRequestResponse var1) {
      try {
         RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
         int var3 = var1.getRetCode();
         RfbNotificationEvent var4 = new RfbNotificationEvent(0, var3);
         if (var4.isInfo() || var4.isWarning()) {
            if (var1.getOption() == 1) {
               byte var5 = 1;
               if (var4.isWarning()) {
                  var5 = 2;
               }

               this.setSambaConnectSuccessful(true);
               if (this.vmImagePanel != null) {
                  this.vmImagePanel.hideDialogAfterSambaResponse(var5);
                  RRCLogger.log(200, "Pre-configured Image Mount Connect Successful for Port: " + this.port);
               } else {
                  RRCLogger.log(300, "VMImagePanel is NULL. Cannot Hide Dialog.");
               }
            } else if (var1.getOption() == 0) {
               this.setSambaDisconnectSuccessful(true);
               if (this.vmImagePanel != null) {
                  this.vmImagePanel.hideDialogAfterSambaResponse(0);
                  RRCLogger.log(200, "Pre-configured Image Mount Disconnect Successful for Port: " + this.port);
               } else {
                  RRCLogger.log(300, "VMImagePanel is NULL. Cannot Hide Dialog.");
               }
            } else {
               RRCLogger.log(150, "Unknown Option from Server for Remote ISO Mount.");
            }
         }

         if (var4.isError()) {
            if (this.vmImagePanel instanceof VirtualMediaImagePanel) {
               this.vmImagePanel.sambaMountError();
            }

            RRCLogger.log(
               150, "Error Occured during Remote ISO Image Mount. Error Code:" + var4.getMessageGroupErrorCode() + " for Port:" + this.getPortIndex()
            );
            ErrorHandlerImpl.getInstance().handleError(var3, this.vmImagePanel, this);
         }
      } catch (Exception var6) {
         RRCLogger.log(150, "Exception during VM Mount: ", var6);
      }
   }

   private void showSingleMouseAfterConnected() {
      IApplicationPreferences var1 = ((RRCScreenContext)this.scrContext).getAppSettings();
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      if (var1.isAlwaysOpenSMM()) {
         Port var3 = var2.getSelectedPort();
         if (var3 != null && var3.isConnected() && var3 instanceof KvmPort && !this.port.isMultiMonitorPort()) {
            ((KvmPort)var3).toggleSingleMouseCursor();
            var2.getMainScreenMediator().selectSingleMouseCursorMode();
            FullScreenToolBar var4 = var2.getApplication().getFSToolBar(this.getShellInternalFrame());
            if (var4 != null) {
               var4.setLabelText();
               var4.setToolBarVisible(true);
            }
         }
      }

      if (var1.isAlwaysOpenScaled()) {
         this.setScaleVideoFlag(true);

         for (CommandCheckMenuItem var6 : var2.getMainScreenMediator().getCheckScaleVideoMenuItems()) {
            var6.setSelected(true);
         }

         var2.getMainScreenMediator().getToolBarScaleVideoButton().setSelected(true);
      }
   }

   public void notify(final INotificationEvent var1) {
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;
      if (var1.getErrorCode() == 302120971) {
         this.kvmPort.setRfbSwitchCompleted(true);
         this.showSingleMouseAfterConnected();
         RemoteConsoleParameters var3 = this.rcparams;
         if (var3 != null) {
            DevicePrefs var4 = DevicePrefs.getNode(var3.host);
            if (var4 != null) {
               String var5 = var4.getCardReaderName();
               if (var5 != null) {
                  this.startAutoMountingCardReader(var5);
               }
            }
         }
      } else if (var1.isQuit()) {
         this.setQuitEvent(true);
         if (var1.isInfo()) {
            ErrorHandlerImpl.getInstance().handleInfo(var1.getErrorCode(), var2.getApplication().getContentPane(), this);
         } else {
            ErrorHandlerImpl.getInstance().handleError(var1.getErrorCode(), var2.getApplication().getContentPane(), this);
         }

         this.close();

         try {
            this.closeSelf();
         } catch (PropertyVetoException var6) {
         }
      } else if (var1.isError()) {
         if (!this.viewFinalized) {
            this.collectedNotifications.add(var1);
         } else {
            ErrorHandlerImpl.getInstance().handleError(var1.getErrorCode(), var2.getApplication().getContentPane(), this);
         }
      } else if (var1.isWarning()) {
         if (!this.viewFinalized) {
            this.collectedNotifications.add(var1);
         } else {
            SwingUtilities.invokeLater(new Runnable() {
               RRCScreenContext rrcScreenContext = (RRCScreenContext)RFBView.this.scrContext;

               @Override
               public void run() {
                  ErrorHandlerImpl.getInstance().handleWarning(var1.getErrorCode(), this.rrcScreenContext.getApplication().getContentPane(), RFBView.this);
               }
            });
         }
      } else if (var1.isInfo() && var1.isRFB()) {
         switch (var1.getErrorCode()) {
            case 302055433:
            case 302055434:
            case 302055435:
            case 302055436:
               this.vmImagePanel.disconnected(true);
         }
      }

      RRCLogger.log(200, var1.toString());
   }

   public String[] getTokens(int[] var1) {
      KvmPort var2 = this.kvmPort;
      if (var2 != null) {
         assert var1.length > 0;

         if (var1[0] == 285671426) {
            USBProfilesInfo var3 = var2.getUsbProfilesInfo();
            USBProfile var4 = var3.getActiveUSBProfile();
            USBProfile var5 = var3.getPreferredUSBProfile();
            return new String[]{var4.getProfileName(), var5.getProfileName()};
         } else {
            return new String[]{this.kvmPort.getName()};
         }
      } else {
         return null;
      }
   }

   private void handleResizing() {
      if (this.isScaleVideoFlag()) {
         this.rccore.setScaleToFit(true, true, this.getSize());
      }
   }

   private void startAutoMountingCardReader(String var1) {
      assert SwingUtilities.isEventDispatchThread();

      KvmPort var2 = this.kvmPort;
      if (var2 != null) {
         if (var2.getSelectCardReaderAction().isEnabled()) {
            SmartCardBean var3 = var2.getSelectCardReaderAction().getConfiguredSmartCardBean();
            this.scrContext.getPanelMediator().showPanel(new SmartCardAutoMountCommand(this.scrContext, var3, var1, T._("SmartCard")).getContext());
         } else {
            RRCLogger.log(300, "Not performing AUTO_MOUNT of SmartCard. Reason is - " + var2.getSmartCardAction().getValue("ShortDescription"));
         }
      }
   }

   public boolean isSambaConnectSuccessful() {
      return this.isSambaConnectSuccessful;
   }

   public void setSambaConnectSuccessful(boolean var1) {
      this.isSambaConnectSuccessful = var1;
   }

   public boolean isSambaDisconnectSuccessful() {
      return this.isSambaDisconnectSuccessful;
   }

   public void setSambaDisconnectSuccessful(boolean var1) {
      this.isSambaDisconnectSuccessful = var1;
   }

   public void toggleTraffic() {
   }

   public void sessionTerminated() {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      ErrorHandlerImpl.getInstance().handleError("RFB_PROTO_ERR.SESSION.TERMINATED", var1.getApplication().getContentPane());
   }

   public void setCapabilityMap(HashMap var1) {
      this.capabilityMap = var1;
   }

   public HashMap getCapabilityMap() {
      return this.capabilityMap;
   }

   public String getDeviceName() {
      return null;
   }

   public void setDeviceName(String var1) {
   }

   public boolean hasUserClosedTheWindow() {
      return this.shellInternalFrame.isWindowClosing();
   }

   public void setFrameSize() {
      if (this.rccore != null) {
         this.rccore.setClientFrameSizeChanged(this.getSize());
      }
   }

   @Override
   protected void finalize() throws Throwable {
      RRCLogger.log(300, "Finalizing " + this.getPortIndex());
      super.finalize();
   }

   public String getPortIndex() {
      return this.kvmPort == null ? "" : Integer.toString(this.kvmPort.getPortIndex());
   }

   public String getPortName() {
      return this.kvmPort != null && this.kvmPort.getDescription() != null ? this.kvmPort.getDescription() : "";
   }

   public String getPortUniqueId() {
      return this.kvmPort != null && this.kvmPort.getStripTargetDeviceId() != null ? this.kvmPort.getStripTargetDeviceId() : "";
   }

   public void setVMImagePanel(VirtualMediaImagePanel var1) {
      this.vmImagePanel = var1;
   }

   public VirtualMediaImagePanel getVMImagePanel() {
      return this.vmImagePanel;
   }

   public void setVMLocalPanel(VirtualMediaLocalPanel var1) {
      this.vmLocalPanel = var1;
   }

   public VirtualMediaLocalPanel getVMLocalPanel() {
      return this.vmLocalPanel;
   }

   public void setCCVMPermissions(String var1) {
      this.ccVMPermissions = var1;
   }

   public String getCCVMPermissions() {
      return this.ccVMPermissions;
   }

   public void disableVMMenu() {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      if (var1 != null) {
         for (CommandMenu var3 : var1.getMainScreenMediator().getVirtualMediaMenus()) {
            var3.removeObservable(var1.getSelectedDevicesObservable());
         }
      }

      if (this.contextMenuKvm != null) {
         this.getContextPopupMenu().getVirtualMediaLocalMenu().removeObservable(var1.getSelectedDevicesObservable());
         this.getContextPopupMenu().getVirtualMediaImageMenu().removeObservable(var1.getSelectedDevicesObservable());
      }
   }

   public void setTrafficData(int var1, int var2, int var3) {
      this.dataIn = var1;
      this.dataOut = var2;
      this.fps = var3;
   }

   public synchronized boolean isVMLocalConnectionActive() {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      KvmPort var2 = this.kvmPort;
      if (var1 != null && var2 != null) {
         String var3 = var2.getViewName() + var2.getPortIndex();
         Map var4 = var1.getVirtualMediaLocalMap();
         if (var4 != null) {
            VirtualMediaLocalBean var5 = (VirtualMediaLocalBean)var4.get(var3);
            if (var5 != null && var5.isDriveConnected()) {
               return true;
            }
         }
      }

      return false;
   }

   public synchronized boolean isVMImageConnectionActive() {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      KvmPort var2 = this.kvmPort;
      if (var1 != null && var2 != null) {
         String var3 = var2.getViewName() + var2.getPortIndex();
         Map var4 = var1.getVirtualMediaImageMap();
         if (var4 != null) {
            VirtualMediaBean var5 = (VirtualMediaBean)var4.get(var3);
            if (var5 != null && var5.isDriveConnected()) {
               return true;
            }
         }
      }

      return false;
   }

   public synchronized boolean isVMConnectionActive() {
      return this.isVMLocalConnectionActive() || this.isVMImageConnectionActive();
   }

   public void disconnectSmartCard(final KvmPort var1) {
      if (SwingUtilities.isEventDispatchThread()) {
         this.disconnectSmartCardonEDT(var1);
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               RFBView.this.disconnectSmartCardonEDT(var1);
            }
         });
      }
   }

   private void disconnectSmartCardonEDT(KvmPort var1) {
      if (var1 != null) {
         var1.setRfbSwitchCompleted(false);
         var1.getSmartCardAction().setEnabled(false);
         var1.getSelectCardReaderAction().setEnabled(false);
         SmartCardBean var2 = var1.getSelectCardReaderAction().getSmartCardBean();
         if (var2 != null) {
            var2.quitSession();
            var1.getSelectCardReaderAction().resetSmartCardBean();
         }
      }
   }

   public void disconnectAudio(final KvmPort var1) {
      if (SwingUtilities.isEventDispatchThread()) {
         if (var1 != null) {
            var1.getConnectAudioAction().disconnectAudio();
         }
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               if (var1 != null) {
                  var1.getConnectAudioAction().disconnectAudio();
               }
            }
         });
      }
   }

   public synchronized void closeOpenVMConnections(boolean var1) {
      try {
         String var2 = "";
         if ((RRCScreenContext)this.scrContext != null) {
            if (this.kvmPort != null) {
               var2 = this.kvmPort.getViewName() + this.kvmPort.getPortIndex();
               Map var3 = this.scrContext.getVirtualMediaLocalMap();
               Map var4 = this.scrContext.getVirtualMediaImageMap();
               if (var3 != null && var3.size() > 0) {
                  VirtualMediaLocalBean var5 = (VirtualMediaLocalBean)var3.get(var2);
                  if (var5 != null) {
                     if (var1) {
                        var5.setSwitchedFlag(true);
                     }

                     if (var5.isDriveConnected()) {
                        RRCLogger.log(300, "Disconnecting Drive 1 Virtual Media Connection for port:" + this.port.getPortIndex());
                        var5.getVmCore().disconnect(true);
                        var5.setDriveConnected(false);
                        String var6 = var5.getConnectedDrive();
                        if (this.scrContext.getSelectedDrives().contains(var6)) {
                           this.scrContext.removeSelectedDrive(var6);
                           RRCLogger.log(300, -1, "Removing drive from ArrayList:" + var6);
                        }

                        RRCLogger.log(300, "Disconnected handlers for Drive 1 Virtual Media Connection for port:" + this.port.getPortIndex());
                     }
                  } else {
                     RRCLogger.log(300, "Not disconnecting Drive 1 VM connection. No VMBean for " + var2);
                  }

                  var3.remove(var2);
               } else {
                  RRCLogger.log(300, "VMLocalMap is empty. Not disconnecting Drive 1 VM connection for " + var2);
               }

               if (var4 != null && var4.size() > 0) {
                  VirtualMediaBean var11 = (VirtualMediaBean)var4.get(var2);
                  if (var11 != null) {
                     if (var1) {
                        var11.setSwitchedFlag(true);
                     }

                     if (var11.isDriveConnected()) {
                        RRCLogger.log(300, "Disconnecting Drive 2 Virtual Media Connection for port:" + this.port.getPortIndex());
                        if (var11.getConnectionType() == 3) {
                           VMMountRequestResponse var12 = var11.getSambaRequestDrive1();
                           if (var12 != null) {
                              var12.setOption(0);

                              try {
                                 this.rccore.mountOrUnmountRemoteIso(var12);
                                 RRCLogger.log(300, "Sending Remote ISO mount Disconnect request :" + var12.toString());
                              } catch (IOException var8) {
                                 RRCLogger.log(150, "Error Disconnecting Samba Mount for port " + var2, var8);
                              }

                              if (this.isSambaDisconnectSuccessful()) {
                                 var11.setDriveConnected(false);
                                 this.setSambaDisconnectSuccessful(false);
                                 var11.setConnectionType(0);
                              }
                           }
                        } else {
                           var11.getVmCore().disconnect(true);
                        }

                        var11.setDriveConnected(false);
                        if (var11.getConnectionType() == 1) {
                           String var13 = var11.getConnectedDrive();
                           if (this.scrContext.getSelectedDrives().contains(var13)) {
                              this.scrContext.removeSelectedDrive(var13);
                              RRCLogger.log(300, -1, "Removing drive from ArrayList:" + var13);
                           }
                        }

                        var11.setConnectionType(0);
                        RRCLogger.log(300, "Disconnected handlers for Drive 2 Virtual Media Connection for port:" + this.port.getPortIndex());
                        var4.remove(var2);
                     }
                  } else {
                     RRCLogger.log(300, "Not disconnecting Drive 2 VM connection. No VMBean for " + var2);
                  }

                  var4.remove(var2);
               } else {
                  RRCLogger.log(300, "VMImageMap is empty. Not disconnecting Drive 2 VM connection for " + var2);
               }

               ((RRCScreenContext)this.scrContext).toggleMenuBar(var2);
            } else {
               RRCLogger.log(300, "KvmPort is NULL. Cannot close VM Connections.");
            }
         } else {
            RRCLogger.log(300, "RRCScreenContext is NULL. Cannot close VM Connections.");
         }
      } catch (Exception var9) {
         RRCLogger.log(300, "Exception occured! Cannot close Drive Redirections.");
         RRCLogger.log(150, "", var9);
      }
   }

   @Override
   public void sendKVMPopupKey() {
      RRCScreenContext var1 = (RRCScreenContext)this.scrContext;
      byte var2 = -1;
      String var3 = var1.getAppSettings().getkeyboardMenuHotkey();
      if (var3 != null && !"".equals(var3.trim())) {
         if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionA"))) {
            var2 = 65;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionB"))) {
            var2 = 66;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionC"))) {
            var2 = 67;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionD"))) {
            var2 = 68;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionE"))) {
            var2 = 69;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionF"))) {
            var2 = 70;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionG"))) {
            var2 = 71;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionH"))) {
            var2 = 72;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionI"))) {
            var2 = 73;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionJ"))) {
            var2 = 74;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionK"))) {
            var2 = 75;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionL"))) {
            var2 = 76;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionM"))) {
            var2 = 77;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionN"))) {
            var2 = 78;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionO"))) {
            var2 = 79;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionP"))) {
            var2 = 80;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionQ"))) {
            var2 = 81;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionR"))) {
            var2 = 82;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionS"))) {
            var2 = 83;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionT"))) {
            var2 = 84;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionU"))) {
            var2 = 85;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionV"))) {
            var2 = 86;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionW"))) {
            var2 = 87;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionX"))) {
            var2 = 88;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionY"))) {
            var2 = 89;
         } else if (var3.equals(this.bundle.getString("KeyboardMenuHotkey.OptionZ"))) {
            var2 = 90;
         }

         char var4 = KeyEvent.getKeyText(var2).charAt(0);
      } else {
         RRCLogger.log(300, "Unable to send KVM popup because getkeyboardMenuHotkey() returned null or empth String");
      }
   }

   public Object getAssociatedPort() {
      return this.kvmPort;
   }

   public void osdStateChanged(boolean var1, String var2) {
      if (var1 && "No video from target server".equalsIgnoreCase(var2)) {
         this.scrContext.getLogger().logStatus(this.bundle.getString("Status.nosignal"));
         this.setStatusMessage(this.bundle.getString("Status.nosignal"));
      } else {
         this.scrContext.getLogger().logStatus(this.bundle.getString("Status.rrcLoaded"));
         this.setStatusMessage(this.bundle.getString("Status.rrcLoaded"));
      }
   }

   @Override
   public boolean isFullScreenMode() {
      return this.isFullScreenMode;
   }

   @Override
   public void setFullScreenMode(boolean var1) {
      this.isFullScreenMode = var1;
   }

   @Override
   public void addCustomMouseMotionListener(MouseMotionListener var1) {
      if (this.console != null) {
         for (MouseMotionListener var5 : this.console.getMouseMotionListeners()) {
            if (var5 == var1) {
               return;
            }
         }

         this.console.addMouseMotionListener(var1);
      }
   }

   @Override
   public void addCustomMouseListener(MouseListener var1) {
      if (this.console != null) {
         for (MouseListener var5 : this.console.getMouseListeners()) {
            if (var5 == var1) {
               return;
            }
         }

         this.console.addMouseListener(var1);
      }
   }

   @Override
   public void removeCustomMouseMotionListener(MouseMotionListener var1) {
      if (this.console != null) {
         this.console.removeMouseMotionListener(var1);
      }
   }

   @Override
   public void removeCustomMouseListener(MouseListener var1) {
      if (this.console != null) {
         this.console.removeMouseListener(var1);
      }
   }

   @Override
   public boolean getAbsoluteMouseSupported() {
      ((RRCScreenContext)this.scrContext).getMainScreenMediator().selectAbsoluteMouseModeView(this.getMouseMode() == 0);
      return this.isAbsoluteMouseSupported;
   }

   @Override
   public boolean getIntelligentMouseSupported() {
      ((RRCScreenContext)this.scrContext).getMainScreenMediator().selectIntelligentMouseModeView(this.getMouseMode() == 1);
      return this.isIntelligentMouseSupported;
   }

   @Override
   public boolean getStandardMouseSupported() {
      ((RRCScreenContext)this.scrContext).getMainScreenMediator().selectStandardMouseModeView(this.getMouseMode() == 2);
      return this.isStandardMouseSupported;
   }

   public boolean isColorCalibrationSupported() {
      return this.colorCalibSupported;
   }

   public void setUsbProfileList(IUsbProfileList var1) {
      final USBProfilesInfo var2 = createUSBProfileInfo(var1);

      assert this.kvmPort != null;

      SwingUtilities.invokeLater(new Runnable() {
         @Override
         public void run() {
            RFBView.this.kvmPort.setUsbProfilesInfo(var2);
            MPCUtil.notifyObservers((RRCScreenContext)RFBView.this.scrContext, RFBView.this.kvmPort);
         }
      });
   }

   static USBProfilesInfo createUSBProfileInfo(IUsbProfileList var0) {
      assert var0 != null;

      List var1 = var0.getProfiles();

      assert var1 != null;

      int var2 = var1.size();
      RRCLogger.log(300, "UsbProfileListEntrys " + var2);
      if (var2 <= 0) {
         return null;
      } else {
         RRCLogger.log(300, "USBProfiles " + getPrintableString(var1.toArray(new UsbProfile[var2])));
         ArrayList var3 = new ArrayList();

         for (int var4 = 0; var4 < var2; var4++) {
            UsbProfile var5 = (UsbProfile)var1.get(var4);
            var3.add(new USBProfile(var5.getId(), var5.getName(), var5.isSelected()));
         }

         IUsbProfile var6 = var0.getActive();

         assert var6 != null;

         RRCLogger.log(300, "ActiveUSBProfile ID : " + var6.getId() + " ActiveUSBProfile Name : " + var6.getName());
         IUsbProfile var7 = var0.getPreferred();

         assert var7 != null;

         RRCLogger.log(300, "PreferredUSBProfile ID : " + var7.getId() + " PreferredUSBProfile Name : " + var7.getName());
         return new USBProfilesInfo(var3, new USBProfile(var6.getId(), var6.getName()), new USBProfile(var7.getId(), var7.getName()));
      }
   }

   public void setVirtualMediaConfig(int[] var1) {
      VMConfigInfo var2 = getVMConfigInfo(var1);

      assert this.kvmPort != null;

      ArrayList var3 = null;
      ArrayList var4 = null;

      for (int var5 = 0; var5 < var1.length; var5++) {
         if ((var1[var5] & 8) != 0) {
            if (var3 == null) {
               var3 = new ArrayList(10);
            }

            var3.add(new VMFeatures(var5, var1[var5]));
         }

         if ((var1[var5] & 16) != 0) {
            if (var4 == null) {
               var4 = new ArrayList(10);
            }

            var4.add(new VMFeatures(var5, var1[var5]));
         }
      }

      this.kvmPort.setSmartCardIndexHelper(new SmartCardIndexHelper(var3));
      this.kvmPort.setAudioIndexHelper(new AudioIndexHelper(var4));
      if (this.isGreaterThanRfb128()) {
         boolean var8 = true;

         for (int var6 = 0; var6 < var1.length && var8; var6++) {
            var8 &= var1[var6] == 0;
         }

         boolean var10 = !var8;
         this.kvmPort.getVmConfigInfo().setCimActive(var10);
         if (var10) {
            VMConfigInfo var7 = this.kvmPort.getVmConfigInfo();
            var7.copyStateTo(var2);
            this.kvmPort.setVmConfigInfo(var2);
         }

         MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, this.kvmPort);
      } else if (!this.isVMConnectionActive()) {
         this.kvmPort.setVmConfigInfo(var2);
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               MPCUtil.notifyObservers((RRCScreenContext)RFBView.this.scrContext, RFBView.this.kvmPort);
            }
         });
      } else {
         boolean var9 = true;

         for (int var11 = 0; var11 < var1.length && var9; var11++) {
            var9 &= var1[var11] == 0;
         }

         boolean var12 = !var9;
         this.kvmPort.getVmConfigInfo().setCimActive(var12);
      }
   }

   static VMConfigInfo getVMConfigInfo(int[] var0) {
      assert var0 != null;

      assert checkIfStartingZeroes(var0);

      RRCLogger.log(300, "VMCFG" + getPrintableString(var0));
      ArrayList var1 = new ArrayList();

      for (int var2 = 0; var2 < var0.length; var2++) {
         ArrayList var3 = new ArrayList();
         if ((var0[var2] & 1) != 0) {
            var3.add(new MassStorageDevice(1));
         }

         assert (var0[var2] & 2) == 0;

         if ((var0[var2] & 4) != 0) {
            var3.add(new MassStorageDevice(4));
         }

         if (var3.size() > 0) {
            var1.add(new VMInterfaceInfo(var2, var3));
         }
      }

      return new VMConfigInfo(var1);
   }

   private static boolean checkIfStartingZeroes(int[] var0) {
      if (var0.length > 1 && var0[0] == 0) {
         for (int var1 = 1; var1 < var0.length; var1++) {
            if (var0[var1] != 0) {
               return false;
            }
         }
      }

      return true;
   }

   private static String getPrintableString(int[] var0) {
      String var1 = "[";

      for (int var2 = 0; var2 < var0.length; var2++) {
         var1 = var1 + var0[var2] + ",";
      }

      return var1 + "]";
   }

   private static String getPrintableString(UsbProfile[] var0) {
      String var1 = "[";

      for (int var2 = 0; var2 < var0.length; var2++) {
         var1 = var1 + var0[var2].getId() + "|" + var0[var2].getName() + ",";
      }

      return var1 + "]";
   }

   public void changeActiveUSBProfile(USBProfile var1) {
      RRCScreenContext var2 = (RRCScreenContext)this.scrContext;

      try {
         if (this.isConnected()) {
            this.rccore.requestUsbProfileChange(var1.getProfileID());
         } else {
            RRCLogger.log(300, "Not connected, unable to change Active USBProfile");
            ErrorHandlerImpl.getInstance().handleError("RFB_VIEW_ERR_NOT_CONNECTED", var2.getApplication().getContentPane());
         }
      } catch (IOException var4) {
         RRCLogger.logException(var4);
         RRCLogger.log(300, "Error changing Active USBProfile");
         ErrorHandlerImpl.getInstance().handleError("RFB_VIEW_ERR_ACTIVE_USB_PROFILE_CHANGE", var2.getApplication().getContentPane());
      }
   }

   public void setVideoSettings(IVideoSettings var1) {
      this.vidSettings = var1;
   }

   public void setFullyConnected(boolean var1) {
      this.fullyConnected = var1;
   }

   public void setMonitorOnly(boolean var1) {
      this.monitorOnly = var1;
   }

   public void setColorCalibrationSupported(boolean var1) {
      this.colorCalibSupported = var1;
   }

   public RCCore.Compression getCurrrentCompression() {
      return this.currentCompression;
   }

   public void setCurrentCompression(RCCore.Compression var1) {
      this.currentCompression = var1;
   }

   public RCCore.ColorDepth getCurrentColorDepth() {
      return this.currentColorDepth;
   }

   public void setCurrentColorDepth(RCCore.ColorDepth var1) {
      this.currentColorDepth = var1;
   }

   public RCCore.Smoothing getCurrentSmoothing() {
      return this.currentSmoothing;
   }

   public void setCurrentSmoothing(RCCore.Smoothing var1) {
      this.currentSmoothing = var1;
   }

   public boolean isAutoSelected() {
      return this.isAutoSelected;
   }

   public void setAutoSelected(boolean var1) {
      this.isAutoSelected = var1;
   }

   public boolean getIsInitialEndcoingAuto() {
      return this.isInitialEndoingAuto;
   }

   public void setInitialEndcoingAuto(boolean var1) {
      this.isInitialEndoingAuto = var1;
   }

   public RCCore getRCCore() {
      return this.rccore;
   }

   public List<IVMMountRequestResponse> getRemoteIsoList() {
      return this.remoteIsoList;
   }

   public void setRemoteIsoList(List<IVMMountRequestResponse> var1) {
      this.remoteIsoList = var1;
   }

   public void setSessionId(int var1) {
      this.rcparams.sessionId = var1;
   }

   public void setRfbSessionId(int var1) {
      this.rfbSessionId = var1;
   }

   @Override
   public int getRfbSessionId() {
      return this.rfbSessionId;
   }

   public void setSingleCursorMode(boolean var1) {
      this.singleCursorMode = var1;
   }

   public void setStatusMessage(String var1) {
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel(var1);
   }

   public void clearStatusMessage() {
      ((RRCStatusBar)this.scrContext.getPanelMediator().getStatusPanel()).setTextLabel(this.bundle.getString("Status.rrcLoaded"));
   }

   public String getTargetPortId() {
      return MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext) ? this.rcparams.targetPortId : this.kvmPort.getUniquePortId();
   }

   public String getUniqueRdmPortId() {
      return this.rcparams.targetPortId;
   }

   public boolean getVideoSettingsSupported() {
      return this.videoSettingsSupported;
   }

   public void setVideoSettingsSupported(boolean var1) {
      this.videoSettingsSupported = var1;
   }

   public void enableMouseModes(List<RCCore.MouseMode> var1) {
      MainScreenMediator var2 = ((RRCScreenContext)this.scrContext).getMainScreenMediator();
      StringBuffer var3 = new StringBuffer();
      var2.enableAbsoluteMouseModeView(var1.contains(RCCore.MouseMode.ABSOLUTE));
      var2.enableIntelligentMouseModeView(var1.contains(RCCore.MouseMode.AUTOMATIC));
      var2.enableStandardMouseModeView(var1.contains(RCCore.MouseMode.STANDARD));
      this.isAbsoluteMouseSupported = var1.contains(RCCore.MouseMode.ABSOLUTE);
      this.isIntelligentMouseSupported = var1.contains(RCCore.MouseMode.AUTOMATIC);
      this.isStandardMouseSupported = var1.contains(RCCore.MouseMode.STANDARD);

      for (RCCore.MouseMode var5 : var1) {
         var3.append((var3.length() < 1 ? "" : ", ") + var5);
      }

      RRCLogger.log(200, "Supported Mouse Modes: " + var3.toString());
   }

   public RemoteConsoleParameters getRCParameters() {
      return this.rcparams;
   }

   protected void showFSExitTip() {
      IApplicationPreferences var1 = ((RRCScreenContext)this.scrContext).getAppSettings();
      String var2 = "";
      if (var1 != null) {
         var2 = var1.getkeyboardMenuHotkey().toUpperCase();
      }

      if (var2 != "" && var2.contains("ALT")) {
         var2 = var2.replace("ALT", "LeftALT");
      }

      this.rccore.setOSD(this.bundle.getString("Optiondialog.KeyboardShortcutMenuHotkey") + ": " + var2, 4000, false);
   }

   public KvmPort getPort() {
      return this.kvmPort;
   }

   @Override
   public SmartCardErrorsAndMessagesHandler getSmartCardErrorsAndMessagesHandler() {
      return this.smartCardErrorsAndMessagesHandlerImpl;
   }

   @Override
   public DeviceView.SmartCardStatusListeners getSmartCardStatusListener() {
      return this.smartCardErrorsAndMessagesHandlerImpl;
   }

   @Override
   public AudioErrorsAndMessageHandler getAudioErrorsAndMessagesHandler() {
      return this.audioErrorsAndMessageHandlerImpl;
   }

   @Override
   public RemoteConsoleParameters getRemoteConsoleParameters() {
      return this.getRCParameters();
   }

   @Override
   public int getEricKeyCode(int var1, char var2, int var3) {
      return this.rccore.getKeyCode(var1, var2, var3);
   }

   private boolean isGreaterThanRfb128() {
      RCCore var1 = this.rccore;
      if (var1 != null) {
         String var2 = var1.getProtocolVersion();
         if (var2.length() == 5) {
            int var3 = Integer.parseInt(var2.substring(0, 2));
            int var4 = Integer.parseInt(var2.substring(3, 5));
            if (var3 >= 1 && var4 >= 28) {
               return true;
            }
         }
      }

      return false;
   }

   @Override
   public IMacroHelper getMacroHelper() {
      return this.macroHelper;
   }

   @Override
   public int getKeyboardType() {
      return this.keyboardType;
   }

   public boolean isCapsLockOn() {
      return this.capsLockOn;
   }

   public void setCapsLockOn(boolean var1) {
      this.capsLockOn = var1;
   }

   public boolean isNumLockOn() {
      return this.numLockOn;
   }

   public void setNumLockOn(boolean var1) {
      this.numLockOn = var1;
   }

   public boolean isScrollLockOn() {
      return this.scrollLockOn;
   }

   public void setScrollLockOn(boolean var1) {
      this.scrollLockOn = var1;
   }

   public AudioEventListener.DeviceState getPlaybackState() {
      return this.playbackState;
   }

   @Override
   public void setPlaybackState(AudioEventListener.DeviceState var1) {
      this.playbackState = var1;
      MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, this.kvmPort);
   }

   public AudioEventListener.DeviceState getCaptureState() {
      return this.captureState;
   }

   @Override
   public void setCaptureState(AudioEventListener.DeviceState var1) {
      this.captureState = var1;
      MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, this.kvmPort);
   }

   public boolean isQuitEvent() {
      return this.isQuitEvent;
   }

   public void setQuitEvent(boolean var1) {
      this.isQuitEvent = var1;
   }

   private RFBView getPrimaryPortView() {
      if (this.port.isPrimaryOrSinglePort()) {
         return this;
      } else {
         Port var1 = this.port.getPrimaryPort();
         return var1 != null ? (RFBView)var1.getView() : null;
      }
   }

   private List<RFBView> getSecondaryPortViews() {
      Vector var1 = new Vector();

      for (Port var3 : this.port.getSecondaryPorts()) {
         RFBView var4 = (RFBView)var3.getView();
         if (var4 != null) {
            var1.add(var4);
         }
      }

      return var1;
   }

   class AllListener extends MouseAdapter implements AdjustmentListener, ComponentListener {
      @Override
      public void mouseEntered(MouseEvent var1) {
         Object var2 = var1.getSource();
         RFBView.this.scrollBothDirections = false;
         if (var2 == RFBView.this.northLabel) {
            RFBView.this.adjustingVertical = true;
            RFBView.this.adjustmentValue = -1;
         }

         if (var2 == RFBView.this.southLabel) {
            RFBView.this.adjustingVertical = true;
            RFBView.this.adjustmentValue = 1;
         }

         if (var2 == RFBView.this.westLabel) {
            RFBView.this.adjustingVertical = false;
            RFBView.this.adjustmentValue = -1;
         }

         if (var2 == RFBView.this.eastLabel) {
            RFBView.this.adjustingVertical = false;
            RFBView.this.adjustmentValue = 1;
         }

         if (var2 == RFBView.this.northWestLabel) {
            RFBView.this.scrollBothDirections = true;
            RFBView.this.adjustmentValue = -1;
         }

         if (var2 == RFBView.this.southEastLabel) {
            RFBView.this.scrollBothDirections = true;
            RFBView.this.adjustmentValue = 1;
         }

         RFBView.this.timer = new Timer(50, new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent var1) {
               RFBView.this.adjustScrollBars();
            }
         });
         RFBView.this.timer.start();
      }

      @Override
      public void mouseExited(MouseEvent var1) {
         if (RFBView.this.timer != null) {
            RFBView.this.timer.stop();
            RFBView.this.timer = null;
         }
      }

      @Override
      public void adjustmentValueChanged(AdjustmentEvent var1) {
         if (var1.getSource() == RFBView.this.hScrollBar) {
            RFBView.this.jsp.getHorizontalScrollBar().setValue(RFBView.this.hScrollBar.getValue());
         } else if (var1.getSource() == RFBView.this.vScrollBar) {
            RFBView.this.jsp.getVerticalScrollBar().setValue(RFBView.this.vScrollBar.getValue());
         }
      }

      @Override
      public void componentHidden(ComponentEvent var1) {
      }

      @Override
      public void componentMoved(ComponentEvent var1) {
      }

      @Override
      public void componentResized(ComponentEvent var1) {
         if (RFBView.this.isScaleVideoFlag()) {
            RFBView.this.handleResizing();
         } else {
            RFBView.this.showScrollBars();
         }
      }

      @Override
      public void componentShown(ComponentEvent var1) {
      }
   }

   private class AudioErrorsAndMessageHandlerImpl implements AudioErrorsAndMessageHandler {
      private AudioErrorsAndMessageHandlerImpl() {
      }

      @Override
      public void errorMessage(Window var1, String var2, String var3) {
         CommonPopups.showErrorMessage(var2, var1, RFBView.this.scrContext, var3);
      }

      @Override
      public void notificationReceived(Window var1, INotificationEvent var2, String var3) {
         ErrorHandlerImpl.getInstance().handleError(var2.getErrorCode(), var1, RFBView.this, var3);
      }
   }

   private class SmartCardErrorsAndMessagesHandlerImpl extends DeviceView.SmartCardStatusListeners implements SmartCardErrorsAndMessagesHandler {
      private SmartCardErrorsAndMessagesHandlerImpl() {
      }

      @Override
      public void errorOrMessage(SmartCardErrorsAndMessagesHandler.ErrorCodes var1, Object var2, Window var3, String var4) {
         if (var2 instanceof Throwable) {
            RRCLogger.log(300, -1, (Throwable)var2, var1 + "");
         } else {
            RRCLogger.log(300, var1 + "" + (var2 == null ? "" : var2));
         }

         switch (var1) {
            case INCOMPATIBLE_VERSION_OF_DEVICE_PROTOCOL:
               String var10 = T._("The client application and this device have incompatible SmartCard feature protocol versions.");
               String var12 = T._("Please update your client, or contact your System Administrator, if you require this feature.");
               String var14 = "<html>" + var10 + "<br>" + var12 + "</html>";
               CommonPopups.showErrorMessage(var14, var3, RFBView.this.scrContext, var4);
               break;
            case NO_SUPPORTED_PROTOCOL:
               String var9 = T._("Error accessing the smart card. Please make sure the card is inserted correctly and makes proper contact.");
               String var11 = T._("If the problem persists, contact your System Administrator.");
               String var13 = "<html>" + var9 + "<br>" + var11 + "</html>";
               CommonPopups.showErrorMessage(var13, var3, RFBView.this.scrContext, var4);
               break;
            case COMMUNICATION_ERROR_OCCURED:
               CommonPopups.showErrorMessage(T._("Unexpected communication error. Please try again later."), var3, RFBView.this.scrContext, var4);
               break;
            case UNKNOWN_ERROR:
               CommonPopups.showErrorMessage(T._("Unknown error. Contact your System Administrator"), var3, RFBView.this.scrContext, var4);
               break;
            case CARD_READER_DOES_NOT_EXIST:
               String var6 = T._("Selected Smart Card Reader no longer detected, ");
               String var7 = T._("please refresh list, select another and try again...");
               String var8 = "<html>" + var6 + "<br>" + var7 + "</html>";
               CommonPopups.showErrorMessage(var8, var3, RFBView.this.scrContext, var4);
         }
      }

      @Override
      public void notificationReceived(NotificationEvent var1, Window var2, String var3) {
         ErrorHandlerImpl.getInstance().handleError(var1.getErrorCode(), var2, RFBView.this, var3);
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("DISCONNECTED")) {
            Object var2 = var1.getNewValue();
            if (var2 != null) {
               if (var2 instanceof IOException) {
                  this.errorOrMessage(
                     SmartCardErrorsAndMessagesHandler.ErrorCodes.COMMUNICATION_ERROR_OCCURED,
                     var2,
                     JOptionPane.getFrameForComponent(RFBView.this.scrContext.getApplication().getContentPane()),
                     T._("SmartCard")
                  );
               } else {
                  this.errorOrMessage(
                     SmartCardErrorsAndMessagesHandler.ErrorCodes.UNKNOWN_ERROR,
                     var2,
                     JOptionPane.getFrameForComponent(RFBView.this.scrContext.getApplication().getContentPane()),
                     T._("SmartCard")
                  );
               }
            }

            this.connected = false;
         } else if (var1.getPropertyName().equals("QUIT_NOTIFICATION")) {
            ErrorHandlerImpl.getInstance()
               .handleError(
                  ((NotificationEvent)var1.getNewValue()).getErrorCode(),
                  JOptionPane.getFrameForComponent(RFBView.this.scrContext.getApplication().getContentPane()),
                  RFBView.this,
                  T._("SmartCard")
               );
            this.connected = false;
         } else if (!var1.getPropertyName().equals("NOTIFICATION_FROM_SERVER")) {
            if (var1.getPropertyName().equals("NO_PROTO_SPPORTED")) {
               this.errorOrMessage(
                  SmartCardErrorsAndMessagesHandler.ErrorCodes.NO_SUPPORTED_PROTOCOL,
                  null,
                  JOptionPane.getFrameForComponent(RFBView.this.scrContext.getApplication().getContentPane()),
                  T._("SmartCard")
               );
               this.connected = false;
            } else if (var1.getPropertyName().equals("CARD_READER_MOUNTED")) {
               this.connected = true;
            } else if (var1.getPropertyName().equals("CANCEL_ISSUED") || var1.getPropertyName().equals("QUIT_ISSUED")) {
               this.connected = false;
            }
         }

         RFBView.this.getPort().getAudioAction().evaluateEnabled();
      }
   }
}
