package com.raritan.rrc.ui.screens;

import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.ConnectedServersToolBar;
import com.raritan.rrc.ui.components.RRCMenuBar;
import com.raritan.rrc.ui.components.RRCStatusBar;
import com.raritan.rrc.ui.components.RRCToolBar;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.ui.panes.mediator.MainScreenMediator;
import com.raritan.rrc.ui.panes.mediator.RRCPanelMediator;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.ui.panes.BaseTreePanel;
import com.raritan.tools.ui.panes.RaritanStatusBarPanel;
import com.raritan.tools.ui.screens.BaseScreen;
import java.awt.BorderLayout;
import java.awt.Graphics;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nn.pp.ext.pref.IApplicationPreferences;

public class MainScreen extends BaseScreen {
   private static final long serialVersionUID = -6873084021082688228L;
   private JSplitPane splLeftVertical;
   private JSplitPane splHorizontal;
   private RRCMenuBar menuBar;
   private RRCToolBar toolBar;
   private RaritanStatusBarPanel statusBar;
   private JTabbedPane left;
   private RaritanDesktopPane right;
   private JPanel northern;
   private JPanel bottomLeft;
   private double vertical = 0.8;
   private double horisontal = 0.3;
   private MainScreenMediator mainScreenMediator;
   private boolean firstTimePainting = true;
   private RaritanPropertyResourceBundle bundle;
   private ConnectedServersToolBar csToolBar;
   private JPanel menubarPanel;

   public MainScreen(ScreenContext var1, RRCScreenManager var2) {
      super(var1, var2);
   }

   public void addMenuBar() {
      this.northern.add(this.menuBar, new GridBagConstraints(0, 0, 2, 1, 1.0, 1.0, 17, 1, new Insets(0, 0, 0, 0), 0, 0));
   }

   @Override
   protected void initComponents() {
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.setLayout(new BorderLayout());
      this.mainScreenMediator = new MainScreenMediator((RRCScreenContext)this.scrContext);
      ((RRCScreenContext)this.scrContext).setMainScreenMediator(this.mainScreenMediator);
      this.right = new RaritanDesktopPane((RRCScreenContext)this.scrContext);
      this.right.addObservable(((RRCScreenContext)this.scrContext).getSelectedDevicesObservable());
      RRCPanelMediator var1 = new RRCPanelMediator(this.right, this.scrContext);
      this.scrContext.setPanelMediator(var1);
      final BaseTreePanel var2 = new BaseTreePanel((RRCScreenContext)this.scrContext);
      this.mainScreenMediator.setDeviceByIPTree(var2);
      this.initBars();
      this.northern = new JPanel(new GridBagLayout());
      this.northern.add(this.menuBar, new GridBagConstraints(0, 0, 2, 1, 1.0, 1.0, 17, 1, new Insets(0, 0, 0, 0), 0, 0));
      this.northern.add(this.toolBar, new GridBagConstraints(0, 1, 1, 1, 0.5, 1.0, 17, 1, new Insets(0, 0, 0, 0), 10, 0));
      this.northern.add(this.csToolBar, new GridBagConstraints(1, 1, 1, 1, 0.5, 1.0, 13, 1, new Insets(0, 0, 0, 0), 0, 0));
      this.add(this.northern, "North");
      if (this.menuBar != null) {
         ((RRCScreenContext)this.scrContext).setMenuBar(this.menuBar);
      }

      boolean var3 = this.scrContext.getApplicationProperty("connection") != null;
      if (var3) {
         this.add(this.right, "Center");
      } else {
         this.left = new JTabbedPane(3);
         final JPanel var4 = new JPanel(new BorderLayout());
         final JPanel var5 = new JPanel(new BorderLayout());
         final JPanel var6 = new JPanel(new BorderLayout());
         final JPanel var7 = new JPanel(new BorderLayout());
         var4.add(var2, "Center");
         this.left.addTab(this.bundle.getString("Tab.viewByName"), var4);
         this.left.addTab(this.bundle.getString("Tab.viewByIP"), var5);
         this.left.addTab(this.bundle.getString("Tab.viewByHostName"), var6);
         this.left.addTab(this.bundle.getString("Tab.viewByScan"), var7);
         this.left.addChangeListener(new ChangeListener() {
            @Override
            public void stateChanged(ChangeEvent var1) {
               switch (MainScreen.this.left.getSelectedIndex()) {
                  case 0:
                     ((RRCScreenContext)MainScreen.this.scrContext).setDeviceViewBy(0);
                     break;
                  case 1:
                     ((RRCScreenContext)MainScreen.this.scrContext).setDeviceViewBy(1);
                     break;
                  case 2:
                     ((RRCScreenContext)MainScreen.this.scrContext).setDeviceViewBy(2);
                     break;
                  case 3:
                     ((RRCScreenContext)MainScreen.this.scrContext).setDeviceViewBy(3);
               }

               var2.tabChanged(MainScreen.this.left, var4, var5, var6, var7);
            }
         });
         this.left.setBorder(BorderFactory.createLoweredBevelBorder());
         this.mainScreenMediator.setTabDevice(this.left);
         this.mainScreenMediator.selectNavigatorView(true);
         this.bottomLeft = this.scrContext.getPanelMediator().getLogPanel();
         this.bottomLeft.setBorder(BorderFactory.createLoweredBevelBorder());
         this.mainScreenMediator.setMessagePane(this.bottomLeft);
         this.mainScreenMediator.selectMessageView(false);
         this.splLeftVertical = new JSplitPane(0, this.left, this.bottomLeft);
         this.splLeftVertical.setDividerSize(5);
         this.mainScreenMediator.setLeftVerticalPane(this.splLeftVertical);
         this.splHorizontal = new JSplitPane(1, this.splLeftVertical, this.right);
         this.splHorizontal.setBorder(BorderFactory.createBevelBorder(1));
         this.splHorizontal.setDividerSize(5);
         this.mainScreenMediator.setSplHorizontal(this.splHorizontal);
         this.add(this.splHorizontal, "Center");
         DeviceTreeController.getInstance((RRCScreenContext)this.scrContext);
         this.scrContext.getLogger().logStatus(this.bundle.getString("Status.rrcLoaded"));
      }

      this.add(this.statusBar, "South");
      this.addComponentListener(new MainScreen.MainScreenResizer());
      if (this.scrContext instanceof RRCScreenContext) {
         IApplicationPreferences var8 = ((RRCScreenContext)this.scrContext).getAppSettings();
         var8.importPreferences();
         this.mainScreenMediator.selectMessageView(var8.getViewMessage());
         this.mainScreenMediator.selectBrowseAllDevicesView(var8.getShowAll());
         this.mainScreenMediator.selectShowWithoutTargetsView(var8.getShowUnassigned());
         this.mainScreenMediator.selectShowToolsView(var8.getShowTools());
         this.mainScreenMediator.selectCSToolBarView(var8.isShowCSTools());
         this.mainScreenMediator.selectShowWithoutGroupsView(var8.isShowGroups());
         this.mainScreenMediator.selectSortByChannelNumberView(false);
         this.mainScreenMediator.selectSortByChannelNameView(false);
         this.mainScreenMediator.selectSortByChannelStatusView(false);
         DeviceTreeController.getInstance((RRCScreenContext)this.scrContext).setSortType(var8.getChannelSortMethod());
         switch (var8.getChannelSortMethod()) {
            case 1:
               this.mainScreenMediator.selectSortByChannelNameView(true);
               break;
            case 2:
               this.mainScreenMediator.selectSortByChannelStatusView(true);
               break;
            default:
               this.mainScreenMediator.selectSortByChannelNumberView(true);
         }

         Command var9 = this.mainScreenMediator.getCheckShowWithoutTargetsMenuItems().get(0).getCommand();
         var9.getContext(true).setCommandParameter("showWithoutTargetsMode", new Boolean(var8.getShowUnassigned()));
         var9.execute();
         this.scrContext.getPanelMediator().showPanel(var9.getContext());
         var9 = this.mainScreenMediator.getCheckShowToolsMenuItems().get(0).getCommand();
         var9.getContext(true).setCommandParameter("showToolsMode", new Boolean(var8.getShowTools()));
         var9.execute();
         this.scrContext.getPanelMediator().showPanel(var9.getContext());
         var9 = this.mainScreenMediator.getCheckCSToolBarMenuItems().get(0).getCommand();
         var9.getContext(true).setCommandParameter("showCSToolbarMode", new Boolean(var8.isShowCSTools()));
         var9.execute();
         this.scrContext.getPanelMediator().showPanel(var9.getContext());
         this.scrContext.resetDefaultFocus();
      }
   }

   @Override
   protected void handleCommandResult(CommandResult var1) {
   }

   private void initBars() {
      this.menuBar = new RRCMenuBar((RRCScreenContext)this.scrContext, false);
      this.toolBar = new RRCToolBar((RRCScreenContext)this.scrContext);
      this.csToolBar = new ConnectedServersToolBar((RRCScreenContext)this.scrContext);
      this.statusBar = (RaritanStatusBarPanel)this.scrContext.getPanelMediator().getStatusPanel();
      ((RRCStatusBar)this.statusBar).addObservable(((RRCScreenContext)this.scrContext).getSelectedDevicesObservable());
      this.mainScreenMediator.selectBrowseAllDevicesView(true);
      this.mainScreenMediator.selectShowWithoutTargetsView(true);
      this.mainScreenMediator.selectShowPowerstripsView(true);
      this.mainScreenMediator.selectShowToolsView(true);
      this.mainScreenMediator.selectShowWithoutGroupsView(true);
      this.mainScreenMediator.selectSortByChannelNumberView(true);
      this.mainScreenMediator.setToolBar(this.toolBar);
      this.mainScreenMediator.selectToolBarView(true);
      this.mainScreenMediator.setStatusBar(this.statusBar);
      this.mainScreenMediator.selectStatusBarView(true);
      this.mainScreenMediator.selectStandardMouseModeView(true);
      this.mainScreenMediator.setCsToolBar(this.csToolBar);
   }

   @Override
   public void paint(Graphics var1) {
      super.paint(var1);
      boolean var2 = this.scrContext.getApplicationProperty("connection") != null;
      if (!var2 && this.firstTimePainting) {
         this.splHorizontal.setDividerLocation(this.getHorisontal());
         this.splLeftVertical.setDividerLocation(this.getVertical());
         this.firstTimePainting = false;
      }
   }

   public void setFirstTimePainting(boolean var1) {
      this.firstTimePainting = var1;
   }

   public double getVertical() {
      return this.vertical;
   }

   public void setVertical(double var1) {
      this.vertical = var1;
   }

   public double getHorisontal() {
      return this.horisontal;
   }

   public void setHorisontal(double var1) {
      this.horisontal = var1;
   }

   private class MainScreenResizer extends ComponentAdapter {
      private MainScreenResizer() {
      }

      @Override
      public void componentResized(ComponentEvent var1) {
         if (var1.getID() == 101 && MainScreen.this.right.getWidth() == 0) {
            MainScreen.this.setFirstTimePainting(true);
         }
      }
   }
}
