package com.raritan.rrc.ui.screens;

import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.DevicePreferences;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.MultiMonitorPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.ShowKX2KvmPortCommand;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.AbstractCommand;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.State;
import com.raritan.tools.ui.components.CommonPopups;
import com.raritan.tools.ui.screens.ScreenManager;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import javaclientlib.utils.RRCLogger;
import nn.pp.core.JVMVersionInfo;
import nn.pp.core.Platform;

public class RRCScreenManager extends ScreenManager {
   public static final int FS_USE_GD = 0;
   public static final int FS_USE_UNDECORATED = 1;
   public static final int FS_USE_INSETS = 2;
   public static final int FS_USE_EXTENDED_STATE = 3;
   int fullScreenImplementation = 0;
   private MainScreen mainScreen;

   public void setFullScreenStrategy() {
      this.fullScreenImplementation = 1;
      if (Platform.isMac()) {
         this.fullScreenImplementation = MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext) ? 2 : 1;
      } else if (Platform.isLinux() && JVMVersionInfo.getJVMVersionInfo().isJava17()) {
         this.fullScreenImplementation = 3;
      }
   }

   public int getFullScreenStrategy() {
      return this.fullScreenImplementation;
   }

   public MainScreen getMainScreen() {
      return this.mainScreen;
   }

   protected RRCScreenManager(ScreenContext var1) {
      super(var1);
      this.mainScreen = new MainScreen(var1, this);
      this.screens.put(State.INIT.toString(), this.mainScreen);
   }

   public static RRCScreenManager getNewInstance(ScreenContext var0) {
      return new RRCScreenManager(var0);
   }

   public static void addLanguageSpecificMacros(int var0, RRCScreenContext var1) {
      if (var1 != null) {
         switch (var0) {
            case 0:
            case 2:
            case 11:
               break;
            case 1:
               var1.addPredefinedMacro("Japan Ro", -1, "p 116&&r 116");
               var1.addPredefinedMacro("Japan Kana", -1, "p 104&&r 104");
               var1.addPredefinedMacro("Japan RightAlt + Kana", -1, "p 3&&p 104&&r 104&&r 3");
               break;
            case 3:
            case 4:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            default:
               if (Platform.isLinux()) {
                  var1.addPredefinedMacro("Less-than (European KBs)", -1, "p 134&&r 134");
               }
               break;
            case 5:
               var1.addPredefinedMacro("Hangul", -1, "p 115&&r 115");
         }
      }
   }

   @Override
   public boolean show() {
      super.show();
      if (this.scrContext != null) {
         addLanguageSpecificMacros(((RRCScreenContext)this.scrContext).getAppSettings().getKeyboardType(), (RRCScreenContext)this.scrContext);
      }

      boolean var1 = MPCUtil.isCCLaunched((RRCScreenContext)this.scrContext);
      if (var1) {
         DeviceConnector var2 = new DeviceConnector(null, null, this.scrContext);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 512, "RRCScreenManager.show() Connect to port " + this.scrContext.getApplicationProperty("connection"));
         }

         Port var3 = (Port)var2.connect(this.scrContext.getApplicationProperty("connection"), 0);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 512, "RRCScreenManager.show() Connected to port ? " + (var3 != null ? var3.toString() + var3.getId() : "no"));
         }

         if (var3 == null) {
            return false;
         }

         var3.getDevice().setContext(this.scrContext);
         MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, var3);
         Object var4 = null;
         if (var2.isKX2Device()) {
            var4 = DevicePreferences.getNode(var2.getDevice().getIP());
         } else {
            var4 = var2.getCCDevPrefs();
         }

         if (var4 == null) {
            var4 = new DevicePreferences();
         }

         var3.getDevice().setDevPrefs((DevicePreferences)var4);
         var3.setPortStatus(1);
         var3 = this.createMultiMonitorInfo(var3, var2);
         String var5 = var3.getClass().getName();
         int var6 = var5.lastIndexOf(46);
         var5 = var5.substring(var6 + 1);
         String var7 = "com.raritan.rrc.ui.commands.Show";
         if (var2.isKX2Device()) {
            var7 = var7 + "KX2";
         }

         var7 = var7 + var5 + "Command";

         try {
            Class var8 = Class.forName(var7);
            Constructor var9 = var8.getConstructor(ScreenContext.class);
            AbstractCommand var10 = (AbstractCommand)var9.newInstance(this.scrContext);
            var10.getContext().setCommandParameter("selectedPortDevice", var3.getDevice());
            if (var10.isExecutable()) {
               CommandResult var11 = var10.execute();
               if (!var11.isSuccess() && var11.hasErrorDescription()) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 512, "RRCScreenManager.show cmd " + var7 + ", error: " + var11.getErrorDescription());
                  }

                  this.handleCommandResultErrorDescription(var11);
                  var2.disConnect();
                  return false;
               }

               var3.getDevice().getHandler().doPostLogin(var1);
               this.handleCommandResult(var11);
               this.scrContext.getPanelMediator().showPanel(var10.getContext());
               if (var10 instanceof ShowKX2KvmPortCommand && var3.isPrimaryPort()) {
                  ArrayList var12 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
                  if (var12 != null && var12.size() > 0) {
                     for (MultiMonitorPort.PortConfig var15 : var3.getSecondaryPortConfigs()) {
                        Map var16 = var3.getDevice().getChildren();
                        if (var16 != null) {
                           for (Object var18 : var16.values()) {
                              Port var19;
                              if (var18 instanceof Port && (var19 = (Port)var18).getTargetDeviceId().equals(var15.getPortId())) {
                                 var12.set(0, var19);
                                 ShowKX2KvmPortCommand var20 = new ShowKX2KvmPortCommand(this.scrContext);
                                 var20.setAllowSecondary(true);
                                 if (var20.isExecutable()) {
                                    var20.getContext().setCommandParameter("selectedPortDevice", var3.getDevice());
                                    var11 = var20.execute();
                                    if (!var11.isSuccess() && var11.hasErrorDescription()) {
                                       this.handleCommandResultErrorDescription(var11);
                                    } else if (var11.isSuccess()) {
                                       this.handleCommandResult(var11);
                                       this.scrContext.getPanelMediator().showPanel(var20.getContext());
                                    }
                                 }
                                 break;
                              }
                           }
                        }
                     }
                  }

                  var3.getBaseDevice().setActiveKvmPort((KvmPort)var3);
               }
            }
         } catch (ClassNotFoundException var21) {
            this.scrContext.getLogger().logTextInfo("Class " + var7 + " not found");
         } catch (NoSuchMethodException var22) {
            this.scrContext.getLogger().logTextInfo("Required constructor not found");
         } catch (InvocationTargetException var23) {
            this.scrContext.getLogger().logTextInfo("Exception occurred while constructing command");
         } catch (IllegalAccessException var24) {
            this.scrContext.getLogger().logTextInfo("Cannot access the command's constructor");
         } catch (InstantiationException var25) {
            this.scrContext.getLogger().logTextInfo("Cannot instantiate the command");
         } catch (Exception var26) {
            this.scrContext.getLogger().logTextInfo("Exception occured in RRCScreenManager in show():" + var26.getMessage());
         }
      }

      return true;
   }

   private void addMultiMonitorPort(MultiMonitorPort var1, HashMap var2, int var3) {
      try {
         String var4 = var3 == 0 ? "" : "." + var3;
         var1.addPort(
            "//*[@id=" + (String)var2.get("ID" + var4) + "]",
            Integer.parseInt((String)var2.get("MonitorIndex" + var4)),
            Integer.parseInt((String)var2.get("MonitorHPosition" + var4)),
            Integer.parseInt((String)var2.get("MonitorVPosition" + var4))
         );
      } catch (Exception var5) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(150, "Could not parse Multi Monitor information", var5);
         }
      }
   }

   private Port createMultiMonitorInfo(Port var1, DeviceConnector var2) {
      if (var2.isKX2Device() && var2.getConnectionMap().containsKey("ID.1")) {
         MultiMonitorPort var3 = new MultiMonitorPort(var1.getDevice());
         this.addMultiMonitorPort(var3, var2.getConnectionMap(), 0);

         for (int var4 = 1; var2.getConnectionMap().containsKey("ID." + var4); var4++) {
            DeviceConnector var5 = new DeviceConnector(null, null, this.scrContext);
            Port var6 = (Port)var5.connect(this.scrContext.getApplicationProperty("connection"), var4);
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 512, "RRCScreenManager.show() Connected to secondary port " + var6);
            }

            if (var6 != null) {
               var6.getDevice().remove(var6);
               var1.getDevice().add(var6, var6.getName() + var6.getId());
               var6.setDevice(var1.getDevice());
               var6.setParent(var1.getDevice());
               var6.setPortStatus(1);
               this.addMultiMonitorPort(var3, var2.getConnectionMap(), var4);
            } else {
               var5.disConnect();
            }

            var1.getDevice().setMultiMonitorPorts(var3);
            if (var1.isSecondaryPort() && var1.getPrimaryPort() != null) {
               return var1.getPrimaryPort();
            }
         }
      }

      return var1;
   }

   protected void handleCommandResult(CommandResult var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   protected void handleCommandResultErrorDescription(CommandResult var1) {
      if (var1 != null) {
         StringBuffer var2 = new StringBuffer("");
         if (var1.getErrorDescription() != null && var1.getErrorDescription().length > 0) {
            for (int var3 = 0; var3 < var1.getErrorDescription().length; var3++) {
               var2.append(var1.getErrorDescription()[var3]);
               var2.append("\n");
            }
         } else if (var1.getStatusMessage() != null) {
            var2.append(var1.getStatusMessage());
         } else {
            var2.append("No command result info.");
         }

         CommonPopups.showCommandResultErrorMessage(var2.toString(), null, this.scrContext);
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   public RRCScreenContext getScreenContext() {
      return (RRCScreenContext)this.scrContext;
   }
}
