package com.raritan.rrc.util;

public class CircBuffer {
   public static final int HISTORY_BUFFER_SIZE = 16384;
   private StringBuffer buffer;

   public CircBuffer() {
      this.buffer = new StringBuffer();
   }

   public CircBuffer(int var1) {
      if (var1 > 0) {
         this.buffer = new StringBuffer(var1);
      }
   }

   public CircBuffer(CircBuffer var1) {
      if (var1 != null) {
         if (var1.getSize() != 0) {
            this.buffer = new StringBuffer(var1.getSize());
         }
      }
   }

   public final int getSize() {
      return this.buffer != null ? this.buffer.capacity() : 0;
   }

   public final int getCount() {
      return this.buffer != null ? this.buffer.length() : 0;
   }

   public int getMaxBytesToRead() {
      int var1 = this.getCount();
      if (var1 > 16384) {
         var1 = 16384;
      }

      return var1;
   }

   public final boolean isEmpty() {
      return this.buffer.length() == 0;
   }

   public final boolean canHold() {
      return this.buffer.capacity() - this.getSize() > 0;
   }

   public void empty() {
      if (this.buffer != null) {
         this.buffer.delete(0, this.buffer.length());
      }
   }

   private char[] getBuffer() {
      return this.buffer.toString().toCharArray();
   }

   public void readBulk(char[] var1, int var2) {
      if (var1 != null && var2 != 0 && !this.isEmpty()) {
         if (var2 <= this.getCount()) {
            System.arraycopy(this.buffer.toString().toCharArray(), 0, var1, 0, var2);
         }
      }
   }

   public void readHistory(byte[] var1) {
      if (var1 != null) {
         byte[] var2 = this.buffer.substring(0, this.getMaxBytesToRead()).getBytes();
         System.arraycopy(var2, 0, var1, 0, var2.length);
      }
   }

   public void writeBulk(char[] var1, int var2) {
      if (var1 != null && var2 != 0) {
         if (var1.length <= var2) {
            this.buffer.append(var1);
         }
      }
   }

   @Override
   public void finalize() {
      this.empty();
      this.buffer = null;

      try {
         super.finalize();
      } catch (Throwable var2) {
      }
   }
}
