package com.raritan.rrc.util.modem;

import com.raritan.rrc.util.OS;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.util.Locale;
import javaclientlib.utils.RRCLogger;

public class PPPDConnector extends ModemConnector {
   private static final int STATUS_DIALING_WAIT_FOR_CALLBACK = 17;
   private static final String DIAL_LAUNCH_SCRIPT_NAME = "launch-dial.sh";
   private static final String CHECKPERMS_SCRIPT_NAME = "checkperms.sh";
   private static final String DIAL_SCRIPT_NAME = "dial-up.sh";
   private static final String DIAL_CALLBACK_SCRIPT_NAME = "dial-up-callback.sh";
   private static final String UPDATE_PPPD_SCRIPT_NAME = "update-pppd.sh";
   private static final String MODEM_DETECT_SCRIPT_NAME = "find-modem.sh";
   private static final String MODEM_HANGUP_SCRIPT_NAME = "hangup.sh";
   private static final String CHAT_COMMAND_NAME = "chat";
   private static final int BUFFER_SIZE = 1024;
   private String serverIPAddress = null;
   private String launchDialScriptName = null;
   private String checkPermsScriptName = null;
   private String dialScriptFilename = null;
   private String updatePPPDScriptFilename = null;
   private String chatCommandFilename = null;
   private String hangupScriptFilename = null;
   private String dialCallbackScriptFilename = null;
   private static final int EXIT_CODE_PPPD_SUCCESS = 0;
   private static final int EXIT_CODE_PPPD_FATAL_ERROR = 1;
   private static final int EXIT_CODE_PPPD_OPTIONS_ERROR = 2;
   private static final int EXIT_CODE_PPPD_PERMISSIONS_ERROR = 3;
   private static final int EXIT_CODE_PPPD_NOT_SUPPORTED = 4;
   private static final int EXIT_CODE_PPPD_SIGNALED = 5;
   private static final int EXIT_CODE_PPPD_PORT_NOT_LOCKABLE = 6;
   private static final int EXIT_CODE_PPPD_PORT_NOT_OPENABLE = 7;
   private static final int EXIT_CODE_PPPD_CONNECT_SCRIPT_FAILED = 8;
   private static final int EXIT_CODE_PPPD_PTY_ERROR = 9;
   private static final int EXIT_CODE_PPPD_NEGO_FAILED = 10;
   private static final int EXIT_CODE_PPPD_SERVER_AUTH_FAILED = 11;
   private static final int EXIT_CODE_PPPD_DISCONNECTED_ON_IDLE = 12;
   private static final int EXIT_CODE_PPPD_DISCONNECTED_ON_CONNECT_TIME = 13;
   private static final int EXIT_CODE_PPPD_CALLBACK = 14;
   private static final int EXIT_CODE_PPPD_DISCONNECTED_ON_FAILED_ECHO = 15;
   private static final int EXIT_CODE_PPPD_MODEM_HUNGUP = 16;
   private static final int EXIT_CODE_PPPD_SERIAL_LOOPBACK = 17;
   private static final int EXIT_CODE_PPPD_INIT_SCRIPT_FAILED = 18;
   private static final int EXIT_CODE_PPPD_AUTH_FAILED = 19;
   private static final int EXIT_CODE_ALREADY_CONNECTED = 201;
   private static final int EXIT_CODE_NOT_ENOUNG_ARGUMENTS = 202;
   private static final int EXIT_CODE_OS_NOT_SUPPORTED = 203;
   private static final int EXIT_CODE_CHAT_NOT_FOUND = 204;
   private static final int EXIT_CODE_OPTIONSFILE_MISSING = 100;
   private static final int EXIT_CODE_INSUFFICIENT_PERMISSIONS = 101;
   private static final int EXIT_CODE_PPPD_NOT_IN_PATH = 102;
   public static final int ERROR_CHECK_CALLBACK_NUMBER = 1001;
   public static final int ERROR_CHECK_PPPDVER = 1002;
   public static final int ERROR_CHECK_PPPD_SETUID = 1003;
   public static final int ERROR_CHECK_OPTIONS_FILE = 1004;
   public static final int ERROR_CHECK_PERMISSIONS = 1005;
   public static final int ERROR_CHECK_PPPD_PATH = 1006;
   private static PPPDConnector sConnectionOwner = null;
   private Process process;
   private Object HANGUP_SERIALIZER = new Object();
   private RaritanPropertyResourceBundle bundle;

   private static synchronized void setCurrentOwner(PPPDConnector var0) {
      sConnectionOwner = var0;
   }

   private static synchronized boolean isCurrentOwner(PPPDConnector var0) {
      return sConnectionOwner == null ? false : sConnectionOwner == var0;
   }

   private static synchronized boolean isOwned() {
      return sConnectionOwner != null;
   }

   private synchronized void setProcess(Process var1) {
      this.process = var1;
   }

   private synchronized Process getProcess() {
      return this.process;
   }

   public static String getDefaultModem() {
      OS var0 = OS.getCurrent();
      if (var0 == OS.LINUX) {
         return "/dev/ttyS0";
      } else if (var0 == OS.MAC) {
         return "/dev/cu.modem";
      } else {
         return var0 == OS.SOLARIS ? "/dev/ttya" : "";
      }
   }

   public PPPDConnector(Locale var1) {
      if (var1 != null) {
         this.bundle = RaritanResourceBundle.getResourceBundle(var1);
      }
   }

   private static Process exec(String var0) throws IOException {
      return Runtime.getRuntime().exec(var0);
   }

   private static Process execAndWait(String var0) throws IOException {
      Process var1 = exec(var0);

      try {
         var1.waitFor();
      } catch (InterruptedException var3) {
      }

      return var1;
   }

   private static void deleteFile(String var0) {
      if (var0 != null) {
         File var1 = new File(var0);
         if (var1.exists()) {
            var1.delete();
         }
      }
   }

   private String copyScript(String var1, boolean var2) {
      InputStream var3 = this.getClass().getResourceAsStream("/" + var1);
      if (var3 == null) {
         RRCLogger.log(300, -1, "Unable to locate " + var1 + " in jar file");
         return null;
      } else {
         BufferedReader var4 = new BufferedReader(new InputStreamReader(var3));
         FileOutputStream var5 = null;
         BufferedWriter var6 = null;

         Object var8;
         try {
            File var7 = File.createTempFile("javarrc_", "_" + var1);
            if (var2) {
               var5 = new FileOutputStream(var7);
               byte[] var29 = new byte[1024];

               for (int var9 = var3.read(var29); var9 > 0; var9 = var3.read(var29)) {
                  var5.write(var29, 0, var9);
               }
            } else {
               var6 = new BufferedWriter(new FileWriter(var7));

               for (String var28 = var4.readLine(); var28 != null; var28 = var4.readLine()) {
                  var6.write(var28);
                  var6.newLine();
               }
            }

            execAndWait("chmod 755 " + var7.getAbsolutePath());
            return var7.getAbsolutePath();
         } catch (IOException var26) {
            RRCLogger.log(300, -1, var26, "Exception on copying file " + var1);
            var8 = null;
         } finally {
            if (var5 != null) {
               try {
                  var5.close();
               } catch (IOException var25) {
                  var25.printStackTrace();
               }
            }

            if (var6 != null) {
               try {
                  var6.close();
               } catch (IOException var24) {
                  var24.printStackTrace();
               }
            }

            if (var4 != null) {
               try {
                  var4.close();
               } catch (IOException var23) {
                  var23.printStackTrace();
               }
            }
         }

         return (String)var8;
      }
   }

   @Override
   public long rasConnect(String var1, String var2) throws Exception {
      return this.rasConnectWithIdentity(var1, var2, "PPP", "PPPpw", false);
   }

   @Override
   public long rasConnectWithIdentity(String var1, String var2, String var3, String var4) throws Exception {
      if (null == var3 || "".equals(var3)) {
         RRCLogger.log(300, 4, "Username invalid");
         throw new IllegalArgumentException("Username invalid");
      } else if (null != var4 && !"".equals(var4)) {
         return this.rasConnectWithIdentity(var1, var2, var3, var4, true);
      } else {
         RRCLogger.log(300, 4, "Null or empty password not valid");
         throw new IllegalArgumentException("Null or empty password not valid");
      }
   }

   private long rasConnectWithIdentity(String var1, String var2, String var3, String var4, boolean var5) throws Exception {
      if (isOwned()) {
         RRCLogger.log(300, -1, "Already in use by an existing connection");
         return 633L;
      } else if (!this.prepareScripts()) {
         RRCLogger.log(300, -1, "Error on preparing scripts for dialing");
         return 1L;
      } else {
         int var6 = this.checkPermissions();
         if (var6 != 0) {
            return var6;
         } else {
            boolean var7 = OS.getCurrent() == OS.MAC;
            if (var7) {
               this.chatCommandFilename = "/usr/sbin/chat";
            }

            String var8 = " -p " + var1 + " -m " + var2 + " -upd " + this.updatePPPDScriptFilename + (var7 ? " -chat " + this.chatCommandFilename : "");
            String var9 = this.launchDialScriptName + " " + this.dialScriptFilename + var8 + (var5 ? " -callback 0" : "");
            String var10 = this.launchDialScriptName + " " + this.dialScriptFilename + var8;
            String var11 = this.launchDialScriptName + " " + this.dialCallbackScriptFilename + var8;
            var6 = -1;

            long var43;
            try {
               label440: {
                  String var12;
                  if (var5 && !var7 && OS.getCurrent() != OS.SOLARIS) {
                     var6 = this.launchPPPD(var9, var3, var4);
                     RRCLogger.log(300, -1, "command : " + var9 + " Exit code : " + var6);
                     switch (var6) {
                        case 0:
                           this.readServerIP();
                           var6 = 0;
                           return var6;
                        case 1:
                        case 4:
                        case 5:
                        case 9:
                        case 11:
                        case 12:
                        case 13:
                        case 15:
                        case 17:
                        case 18:
                        case 202:
                        case 203:
                        default:
                           break label440;
                        case 2:
                           RRCLogger.log(300, -1, "Probably callback option not supported");
                           this.destroyShellProcess();
                           var12 = var10;
                           break;
                        case 3:
                           return 1003L;
                        case 6:
                           return 633L;
                        case 7:
                           return 633L;
                        case 8:
                           return 651L;
                        case 10:
                        case 16:
                           return 1001L;
                        case 14:
                           RRCLogger.log(300, -1, "Callback negotiated");
                           String var25 = "dial.windialstatus.17";
                           if (this.bundle != null) {
                              var25 = this.bundle.getString(var25);
                           }

                           this.fireDialStatusMsg(var25);
                           this.destroyShellProcess();
                           var12 = var11;
                           break;
                        case 19:
                           return 691L;
                        case 201:
                           return 633L;
                        case 204:
                           RRCLogger.log(300, -1, "chat script used to talk to modem not found");
                           break label440;
                     }
                  } else {
                     var12 = var10;
                  }

                  var6 = this.launchPPPD(var12, var3, var4);
                  RRCLogger.log(300, -1, "command : " + var12 + " Exit code : " + var6);
                  switch (var6) {
                     case 0:
                        this.readServerIP();
                        var6 = 0;
                        return var6;
                     case 3:
                        return 1003L;
                     case 6:
                        return 633L;
                     case 7:
                        return 633L;
                     case 8:
                        return 651L;
                     case 10:
                     case 16:
                        if (var5) {
                           return 1002L;
                        }

                        return 1L;
                     case 19:
                        return 691L;
                     case 201:
                        return 633L;
                     case 204:
                        RRCLogger.log(300, -1, "chat script used to talk to modem not found");
                     case 1:
                     case 2:
                     case 4:
                     case 5:
                     case 9:
                     case 11:
                     case 12:
                     case 13:
                     case 14:
                     case 15:
                     case 17:
                     case 18:
                     case 202:
                     case 203:
                     default:
                        return 1L;
                  }
               }

               var43 = 1L;
            } catch (IOException var20) {
               RRCLogger.log(300, -1, var20, "Exception on modem connect");
               return 1L;
            } catch (InterruptedException var21) {
               RRCLogger.log(300, -1, var21, "Exception on modem connect");
               return 1L;
            } finally {
               if (var6 == 0) {
                  setCurrentOwner(this);
                  this.destroyShellProcess();
                  this.cleanUpScripts();
               } else {
                  this.rasHangUp();
               }
            }

            return var43;
         }
      }
   }

   private void destroyShellProcess() {
      Process var1 = this.getProcess();
      if (var1 != null) {
         var1.destroy();
         this.setProcess(null);
      }
   }

   private void readServerIP() throws IOException {
      Process var1 = this.getProcess();
      BufferedReader var2 = new BufferedReader(new InputStreamReader(var1.getInputStream()));

      try {
         this.serverIPAddress = var2.readLine();
      } finally {
         var2.close();
      }
   }

   private int launchPPPD(String var1, String var2, String var3) throws IOException, InterruptedException {
      Process var4;
      try {
         var4 = exec(var1);
      } catch (IOException var17) {
         RRCLogger.log(300, -1, var17, "Exception on launching pppd process");
         throw var17;
      }

      this.setProcess(var4);
      BufferedWriter var5 = new BufferedWriter(new OutputStreamWriter(var4.getOutputStream()));

      try {
         var5.write(var2);
         var5.newLine();
         var5.write(var3);
         var5.newLine();
         var5.flush();
      } catch (IOException var15) {
         RRCLogger.log(300, -1, var15, "Exception on passing username and password to pppd process");
         throw var15;
      } finally {
         try {
            var5.close();
         } catch (IOException var14) {
            var14.printStackTrace();
         }
      }

      return var4.waitFor();
   }

   private boolean prepareScripts() {
      this.launchDialScriptName = this.copyScript("launch-dial.sh", false);
      this.checkPermsScriptName = this.copyScript("checkperms.sh", false);
      this.dialScriptFilename = this.copyScript("dial-up.sh", false);
      this.dialCallbackScriptFilename = this.copyScript("dial-up-callback.sh", false);
      this.updatePPPDScriptFilename = this.copyScript("update-pppd.sh", false);
      this.hangupScriptFilename = this.copyScript("hangup.sh", false);
      return this.dialScriptFilename != null
         && this.checkPermsScriptName != null
         && this.launchDialScriptName != null
         && this.dialCallbackScriptFilename != null
         && this.updatePPPDScriptFilename != null
         && this.hangupScriptFilename != null;
   }

   private int checkPermissions() throws IOException {
      Process var1 = null;

      try {
         var1 = exec(this.checkPermsScriptName);
      } catch (IOException var4) {
         RRCLogger.log(300, -1, var4, "Exception on launching check permissions script");
         throw var4;
      }

      try {
         int var2 = var1.waitFor();
         RRCLogger.log(300, -1, "Return value of check permissions script : " + var2);
         switch (var2) {
            case 100:
               return 1004;
            case 101:
               return 1005;
            case 102:
               return 1006;
            default:
               return var2;
         }
      } catch (InterruptedException var3) {
         RRCLogger.log(300, -1, var3, "Exception on executing check permissions script");
         return 1;
      }
   }

   @Override
   public long rasEnumConnections() {
      throw new UnsupportedOperationException();
   }

   @Override
   public long rasEnumDevices() {
      return 1L;
   }

   @Override
   public long rasEnumEntries() {
      throw new UnsupportedOperationException();
   }

   @Override
   public String rasGetDeviceName(long var1) {
      throw new UnsupportedOperationException();
   }

   @Override
   public String rasGetDeviceType(long var1) {
      return "modem";
   }

   @Override
   public String rasGetEntryName(long var1) {
      throw new UnsupportedOperationException();
   }

   @Override
   public String rasGetServerIP() {
      return this.serverIPAddress;
   }

   @Override
   public void rasHangUp() {
      synchronized (this.HANGUP_SERIALIZER) {
         if (!isOwned()) {
            this.hangUp();
         } else if (isCurrentOwner(this)) {
            this.hangUp();
            setCurrentOwner(null);
         }
      }
   }

   private void hangUp() {
      try {
         this.hangupScriptFilename = this.copyScript("hangup.sh", false);
         if (this.hangupScriptFilename != null) {
            exec(this.hangupScriptFilename);

            try {
               Thread.sleep(1000L);
            } catch (InterruptedException var6) {
            }
         }

         this.destroyShellProcess();
      } catch (IOException var7) {
         RRCLogger.logException(var7);
      } finally {
         if (this.hangupScriptFilename != null) {
            deleteFile(this.hangupScriptFilename);
            this.hangupScriptFilename = null;
         }
      }

      this.cleanUpScripts();
   }

   private void cleanUpScripts() {
      deleteFile(this.dialScriptFilename);
      this.dialScriptFilename = null;
      deleteFile(this.checkPermsScriptName);
      this.checkPermsScriptName = null;
      deleteFile(this.updatePPPDScriptFilename);
      this.updatePPPDScriptFilename = null;
      deleteFile(this.launchDialScriptName);
      deleteFile(this.dialCallbackScriptFilename);
      if (OS.getCurrent() == OS.MAC) {
         this.chatCommandFilename = null;
      }
   }
}
