package com.raritan.rrc.util.modem;

import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import java.util.Locale;
import javaclientlib.utils.RRCLogger;

public class RRC_RAS extends ModemConnector {
   private Object LOCK = new Object();
   private Object HANGUP_SERIALIZER = new Object();
   private static RRC_RAS _sConnectionOwner = null;
   private WinDialingStatus _dialState;
   private RaritanPropertyResourceBundle _bundle;

   public RRC_RAS(Locale var1) {
      String var2 = getDLLName();
      RRCLogger.log(300, -1, "Loading modem DLL with name " + var2);
      System.loadLibrary(var2);
      if (var1 != null) {
         this._bundle = RaritanResourceBundle.getResourceBundle(var1);
      }
   }

   private static String getDLLName() {
      return "amd64".equals(System.getProperty("os.arch")) ? "RAS_x64" : "RAS";
   }

   private native long connect(String var1, long var2);

   private native long connectWithIdentity(String var1, long var2, String var4, String var5);

   private native long enumConnections();

   private native long enumDevices();

   private native long enumEntries();

   private native String getDeviceName(long var1);

   private native String getDeviceType(long var1);

   private native String getEntryName(long var1);

   private native void hangUp();

   private native String GetIPServer();

   private static synchronized void _setCurrentOwner(RRC_RAS var0) {
      _sConnectionOwner = var0;
   }

   private static synchronized boolean _isCurrentOwner(RRC_RAS var0) {
      return _sConnectionOwner == null ? false : _sConnectionOwner == var0;
   }

   private static synchronized boolean _isOwned() {
      return _sConnectionOwner != null;
   }

   @Override
   public long rasConnect(String var1, String var2) throws InterruptedException {
      return this.rasConnectWithIdentity(var1, var2, "PPP", "PPPpw");
   }

   @Override
   public long rasConnectWithIdentity(String var1, String var2, String var3, String var4) throws InterruptedException {
      if (_isOwned()) {
         return 633L;
      } else {
         long var5 = this.rasEnumDevices();
         long var7 = 0L;

         for (int var9 = 0; var9 < var5; var9++) {
            if (this.rasGetDeviceName(var9).equals(var2)) {
               var7 = var9;
               break;
            }
         }

         long var16;
         synchronized (this.LOCK) {
            this._dialState = null;
            var16 = this.connectWithIdentity(var1, var7, var3, var4);
            if (var16 == 0L) {
               while (this._dialState == null) {
                  try {
                     this.LOCK.wait();
                  } catch (InterruptedException var14) {
                     RRCLogger.log(200, 4, var14, "rasConnectWithIdentity thread Interrupted");
                     throw var14;
                  }
               }

               var16 = this._dialState.getErrorCode();
            }
         }

         if (var16 == 0L) {
            _setCurrentOwner(this);
         } else {
            this.hangUp();
         }

         return var16;
      }
   }

   @Override
   public long rasEnumConnections() {
      return this.enumConnections();
   }

   @Override
   public long rasEnumDevices() {
      return this.enumDevices();
   }

   @Override
   public long rasEnumEntries() {
      return this.enumEntries();
   }

   @Override
   public String rasGetDeviceName(long var1) {
      return this.getDeviceName(var1);
   }

   @Override
   public String rasGetDeviceType(long var1) {
      return this.getDeviceType(var1);
   }

   @Override
   public String rasGetEntryName(long var1) {
      return this.getEntryName(var1);
   }

   @Override
   public void rasHangUp() {
      synchronized (this.HANGUP_SERIALIZER) {
         if (!_isOwned()) {
            this.hangUp();
         } else if (_isCurrentOwner(this)) {
            this.hangUp();
            _setCurrentOwner(null);
         }
      }
   }

   @Override
   public String rasGetServerIP() {
      return this.GetIPServer();
   }

   public void dialingStatus(WinDialingStatus var1) {
      RRCLogger.log(300, 4, var1.toString());
      if (var1.isError() || var1.isConnected()) {
         synchronized (this.LOCK) {
            this._dialState = var1;
            this.LOCK.notify();
         }
      } else if (var1.isWaitingForCallback()) {
         String var2 = "dial.windialstatus." + var1.getState();
         if (this._bundle != null) {
            var2 = this._bundle.getString(var2);
         }

         this.fireDialStatusMsg(var2);
      }
   }
}
