package com.raritan.smartcard.impl;

import com.raritan.smartcard.CardAccessErrorsListener;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import javax.smartcardio.CardTerminal;
import nn.pp.core.WorkstationUnlockDetector;

public class CardAccessManager {
   private final SmartCardClientModule clientModule;
   private final CardLockProvider lockProvider;
   private final TransportProtoProvider transProtoProvider;
   private final Map<String, Set<CardAccessManager.Handle>> mountedCardReaders = new HashMap<>();

   public CardAccessManager(SmartCardClientModule var1, CardLockProvider var2, TransportProtoProvider var3) {
      this.clientModule = var1;
      this.lockProvider = var2;
      this.transProtoProvider = var3;
   }

   public CardAccessManager.Handle mountSmartCardReader(
      String var1,
      String var2,
      ServerCardEventsListener var3,
      SmartCardReaderListener16 var4,
      CardAccessErrorsListener var5,
      EventsListenerManager var6,
      WorkstationUnlockDetector var7
   ) {
      CardAccessHandler var8 = new CardAccessHandler(this.lockProvider, this.transProtoProvider, var3, var5, var7, var2);
      CardEventsProcessor var9 = new CardEventsProcessor(var2, var8, var3, var8, var6);
      var3.setCardTransmitHandler(var9);
      CardAccessManager.Handle var10 = new CardAccessManager.Handle(var1, var9, var9, var4, var5);
      synchronized (this) {
         Object var12 = this.mountedCardReaders.get(var1);
         if (var12 == null) {
            var12 = new HashSet();
            this.mountedCardReaders.put(var1, (Set<CardAccessManager.Handle>)var12);
         }

         var12.add(var10);
      }

      var9.cardReaderInserted(var1);
      this.clientModule.monitorSmartCardReader(var1, var4);
      this.clientModule.monitorSmartCardReader(var1, var10.getSmartCardModuleListener());
      this.clientModule.monitorSmartCardReader(var1, var10.getCleanupListener());
      return var10;
   }

   public void unmountSmartCardReader(CardAccessManager.Handle var1) {
      boolean var2 = false;
      synchronized (this) {
         if (this.mountedCardReaders.containsKey(var1.getCardReaderName())) {
            Set var4 = this.mountedCardReaders.get(var1.getCardReaderName());
            var2 = var4.remove(var1);
            if (var2 && var4.isEmpty()) {
               this.mountedCardReaders.remove(var1.getCardReaderName());
            }
         }
      }

      if (var2) {
         SmartCardModuleListener var3 = var1.getSmartCardModuleListener();
         this.clientModule.unmonitorSmartCardReader(var1.getCardReaderName(), var3);
         var3.cardReaderRemoved(var1.getCardReaderName());
         this.clientModule.unmonitorSmartCardReader(var1.getCardReaderName(), var1.getCleanupListener());
         this.clientModule.unmonitorSmartCardReader(var1.getCardReaderName(), var1.getCallerCardStateListener());
      }
   }

   public void simulateRemoveAndReinsert(CardAccessManager.Handle var1) {
      boolean var2 = false;
      synchronized (this) {
         if (this.mountedCardReaders.containsKey(var1.getCardReaderName())) {
            Set var4 = this.mountedCardReaders.get(var1.getCardReaderName());
            var2 = var4.contains(var1);
         }
      }

      if (var2) {
         CardTerminal var3 = SmartCardClientModule.getCardTerminal(var1.getCardReaderName());
         if (var3 != null) {
            var1.getAtomicEventListener().removeAndReinsert(var3);
         }
      }
   }

   public class Handle {
      private final String cardReaderName;
      private final SmartCardModuleListener smartCardModuleListener;
      private final SmartCardReaderAtomicEventsListener atomicEventListener;
      private final SmartCardReaderListener16 callerCardStateListener;
      private final CardAccessErrorsListener cardAccessErrorsListener;
      private final SmartCardReaderListener16 cleanupListener;

      public Handle(
         String var2, SmartCardModuleListener var3, SmartCardReaderAtomicEventsListener var4, SmartCardReaderListener16 var5, CardAccessErrorsListener var6
      ) {
         this.cardReaderName = var2;
         this.smartCardModuleListener = var3;
         this.atomicEventListener = var4;
         this.callerCardStateListener = var5;
         this.cardAccessErrorsListener = var6;
         this.cleanupListener = new CardAccessManager.Handle.Scrl();
      }

      public String getCardReaderName() {
         return this.cardReaderName;
      }

      public SmartCardModuleListener getSmartCardModuleListener() {
         return this.smartCardModuleListener;
      }

      public SmartCardReaderAtomicEventsListener getAtomicEventListener() {
         return this.atomicEventListener;
      }

      public SmartCardReaderListener16 getCallerCardStateListener() {
         return this.callerCardStateListener;
      }

      public CardAccessErrorsListener getCardAccessErrorsListener() {
         return this.cardAccessErrorsListener;
      }

      public SmartCardReaderListener16 getCleanupListener() {
         return this.cleanupListener;
      }

      private class Scrl implements SmartCardReaderListener16 {
         private Scrl() {
         }

         @Override
         public void cardInserted(CardTerminal var1) {
         }

         @Override
         public void cardRemoved(CardTerminal var1) {
         }

         @Override
         public void cardReaderRemoved(String var1) {
            CardAccessManager.this.unmountSmartCardReader(Handle.this);
         }
      }
   }
}
