package com.raritan.smartcard.impl;

import java.util.HashMap;
import java.util.Map;
import java.util.WeakHashMap;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;
import javax.smartcardio.Card;

public class CardLockProviderImpl implements CardLockProvider {
   private final Map<Card, Map> lockMap;
   private static final String LOCK = "lock";
   private static final String CARD_VALID = "card_valid";

   public CardLockProviderImpl(WeakHashMap<Card, Map> var1) {
      this.lockMap = var1;
   }

   @Override
   public Lock getCardLock(Card var1) {
      synchronized (this.lockMap) {
         ReentrantLock var2;
         if (!this.lockMap.containsKey(var1)) {
            HashMap var4 = new HashMap();
            var4.put("lock", var2 = new ReentrantLock());
            var4.put("card_valid", true);
            this.lockMap.put(var1, var4);
         } else {
            Map var7 = this.lockMap.get(var1);
            var2 = (ReentrantLock)var7.get("lock");
         }

         return var2;
      }
   }

   @Override
   public void invalidateCard(Card var1) {
      assert ((ReentrantLock)this.getCardLock(var1)).isHeldByCurrentThread();

      synchronized (this.lockMap) {
         Map var3 = this.lockMap.get(var1);

         assert var3 != null;

         var3.put("card_valid", false);
      }
   }

   @Override
   public boolean isCardValid(Card var1) {
      assert ((ReentrantLock)this.getCardLock(var1)).isHeldByCurrentThread();

      synchronized (this.lockMap) {
         Map var3 = this.lockMap.get(var1);

         assert var3 != null;

         return (Boolean)var3.get("card_valid");
      }
   }
}
