package com.raritan.smartcard.impl;

import com.raritan.smartcard.impl.crp.SmartCardNotificationEvent;
import java.util.concurrent.Callable;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.NotificationListener;

public class ExceptionPrintingCallable<C, D extends Callable<C>> implements Callable<C> {
   private final D delegate;
   private final EventsListenerManager eventsManager;
   private static final Logger LOGGER = Logger.getLogger(ExceptionPrintingCallable.class.getName());

   public ExceptionPrintingCallable(D var1, EventsListenerManager var2) {
      this.delegate = (D)var1;
      this.eventsManager = var2;
   }

   @Override
   public C call() throws Exception {
      try {
         return this.delegate.call();
      } catch (Exception var2) {
         LOGGER.log(Level.INFO, "Unhandled Exception occured", (Throwable)var2);
         this.notifyError();
         throw var2;
      } catch (Throwable var3) {
         LOGGER.log(Level.INFO, "Unhandled Exception occured", var3);
         if (var3 instanceof Error) {
            this.notifyError();
            throw (Error)var3;
         } else {
            throw new RuntimeException("Should not happen. Satisfying compiler");
         }
      }
   }

   private void notifyError() {
      if (this.eventsManager != null) {
         for (NotificationListener var2 : this.eventsManager.getListeners(NotificationListener.class)) {
            var2.receivedNotification(new SmartCardNotificationEvent(1, 10001, true, "Unhandled Exception"));
         }
      }
   }
}
