package com.raritan.smartcard.impl;

import com.raritan.smartcard.SmartCardInitException;
import com.raritan.smartcard.SmartCardReaderStatus;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.smartcardio.CardException;
import javax.smartcardio.CardTerminal;
import javax.smartcardio.TerminalFactory;

public class SmartCardClientModule {
   private final SmartCardReaderMonitor monitor;
   private static final Logger LOGGER = Logger.getLogger(SmartCardClientModule.class.getName());
   private final HashMap<String, SmartCardClientModule.SmartCardReaderListenersInfo> readersInfoMap = new HashMap<>();
   private final Object readersInfoMapLock = new Object();

   public SmartCardClientModule() throws SmartCardInitException {
      TerminalFactory var1 = TerminalFactory.getDefault();
      LOGGER.log(Level.INFO, "factory " + var1);
      LOGGER.log(Level.INFO, "factory provider" + var1.getProvider());
      if ("None".equals(var1.getType())) {
         throw new SmartCardInitException(SmartCardInitException.ExceptionCause.NO_SUPPORTED_SMARTCARD_IMPL);
      } else {
         this.monitor = new SmartCardReaderMonitor(var1, new SmartCardClientModule.MonitorListener());
      }
   }

   public List<String> getSmartCardReaders(boolean var1) {
      ArrayList var2 = new ArrayList();
      Object var3 = null;
      TerminalFactory var4 = TerminalFactory.getDefault();

      try {
         var3 = var4.terminals().list();
      } catch (CardException var7) {
         LOGGER.log(Level.INFO, "Exception on getting list of terminals", (Throwable)var7);
         return var2;
      }

      for (CardTerminal var6 : var3) {
         var2.add(var6.getName());
      }

      return var2;
   }

   public synchronized SmartCardReaderStatus monitorSmartCardReader(String var1, SmartCardReaderListener16 var2) {
      boolean var3 = false;
      SmartCardReaderStatus var5;
      synchronized (this.readersInfoMapLock) {
         SmartCardClientModule.SmartCardReaderListenersInfo var4 = this.readersInfoMap.get(var1);
         if (null == var4) {
            var3 = true;
            var4 = new SmartCardClientModule.SmartCardReaderListenersInfo(var1);
            this.readersInfoMap.put(var1, var4);
         }

         var4.getListeners().add(var2);
         var5 = var4.getStatus();
         CardTerminal var7 = getCardTerminal(var1);
         if (var7 != null) {
            if (SmartCardReaderStatus.PRESENT.equals(var5)) {
               var2.cardInserted(var7);
            } else if (SmartCardReaderStatus.ABSENT.equals(var5)) {
               var2.cardRemoved(var7);
            }
         }
      }

      if (var3) {
         this.monitor.monitor(var1);
      }

      return var5;
   }

   public synchronized void unmonitorSmartCardReader(String var1, SmartCardReaderListener16 var2) {
      boolean var3 = false;
      synchronized (this.readersInfoMapLock) {
         SmartCardClientModule.SmartCardReaderListenersInfo var5 = this.readersInfoMap.get(var1);
         if (null != var5) {
            List var6 = var5.getListeners();
            boolean var7 = var6.remove(var2);

            assert var7 : "Incorrect listener supplied..";

            if (var6.isEmpty()) {
               this.readersInfoMap.remove(var1);
               var3 = true;
            }
         }
      }

      if (var3) {
         this.monitor.unmonitor(var1);
      }
   }

   public synchronized void dispose() {
      this.monitor.dispose();
      synchronized (this.readersInfoMapLock) {
         this.readersInfoMap.clear();
      }
   }

   public static CardTerminal getCardTerminal(String var0) {
      return TerminalFactory.getDefault().terminals().getTerminal(var0);
   }

   private class MonitorListener implements SmartCardReaderListener16 {
      private MonitorListener() {
      }

      @Override
      public void cardInserted(CardTerminal var1) {
         Iterator var2 = this.getIterator(var1, true);
         if (null != var2) {
            while (var2.hasNext()) {
               ((SmartCardReaderListener16)var2.next()).cardInserted(var1);
            }
         }
      }

      @Override
      public void cardRemoved(CardTerminal var1) {
         Iterator var2 = this.getIterator(var1, false);
         if (null != var2) {
            while (var2.hasNext()) {
               ((SmartCardReaderListener16)var2.next()).cardRemoved(var1);
            }
         }
      }

      @Override
      public void cardReaderRemoved(String var1) {
         SmartCardClientModule.SmartCardReaderListenersInfo var2;
         synchronized (SmartCardClientModule.this.readersInfoMapLock) {
            var2 = SmartCardClientModule.this.readersInfoMap.remove(var1);
         }

         if (null != var2) {
            Iterator var3 = var2.listeners.iterator();

            while (var3.hasNext()) {
               ((SmartCardReaderListener16)var3.next()).cardReaderRemoved(var1);
            }
         }
      }

      private Iterator<SmartCardReaderListener16> getIterator(CardTerminal var1, boolean var2) {
         String var3 = var1.getName();
         Iterator var4 = null;
         synchronized (SmartCardClientModule.this.readersInfoMapLock) {
            SmartCardClientModule.SmartCardReaderListenersInfo var6 = SmartCardClientModule.this.readersInfoMap.get(var3);
            if (null != var6) {
               var6.setStatus(var2 ? SmartCardReaderStatus.PRESENT : SmartCardReaderStatus.ABSENT);
               var4 = var6.getListeners().iterator();
            }

            return var4;
         }
      }
   }

   static class SmartCardReaderListenersInfo {
      private final String cardReaderName;
      private SmartCardReaderStatus status = SmartCardReaderStatus.UNKNOWN;
      private final List<SmartCardReaderListener16> listeners = new CopyOnWriteArrayList<>();

      public SmartCardReaderListenersInfo(String var1) {
         this.cardReaderName = var1;
      }

      List<SmartCardReaderListener16> getListeners() {
         return this.listeners;
      }

      public synchronized SmartCardReaderStatus getStatus() {
         return this.status;
      }

      public synchronized void setStatus(SmartCardReaderStatus var1) {
         this.status = var1;
      }
   }
}
