package com.raritan.smartcard.impl.crp;

import com.raritan.smartcard.SmartCardException;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import nn.pp.core.impl.MonitoringDataInputStream;

public class CRPVersionMessage implements MessageToCommandProducer<Object> {
   private final int versionMajor;
   private final int versionMinor;

   public CRPVersionMessage() {
      this(-1, -1);
   }

   private CRPVersionMessage(int var1, int var2) {
      this.versionMajor = var1;
      this.versionMinor = var2;
   }

   public CRPVersionMessage readMessage(MonitoringDataInputStream var1) throws IOException, SmartCardException {
      byte[] var2 = new byte[16];
      var1.readFully(var2);

      String var3;
      try {
         var3 = new String(var2, "ISO-8859-1");
      } catch (UnsupportedEncodingException var6) {
         throw new SmartCardException(var6);
      }

      if (var3.substring(0, 10).equals("e-RIC CRP xx.xx\n".substring(0, 10))
         && var2[10] >= 48
         && var2[10] <= 57
         && var2[11] >= 48
         && var2[11] <= 57
         && var2[12] == 46
         && var2[13] >= 48
         && var2[13] <= 57
         && var2[14] >= 48
         && var2[14] <= 57
         && var2[15] == 10) {
         int var4 = (var2[10] - 48) * 10 + (var2[11] - 48);
         int var5 = (var2[13] - 48) * 10 + (var2[14] - 48);
         return new CRPVersionMessage(var4, var5);
      } else {
         throw new SmartCardException("Incorrect protocol version format");
      }
   }

   @Override
   public void visit(Object var1) {
   }

   public int getVersionMajor() {
      return this.versionMajor;
   }

   public int getVersionMinor() {
      return this.versionMinor;
   }

   public String getVersionAsString() {
      return "V" + getFormatted(this.getVersionMajor()) + "_" + getFormatted(this.getVersionMinor());
   }

   private static String getFormatted(int var0) {
      return var0 < 10 ? "0" + var0 : "" + var0;
   }
}
