package com.raritan.smartcard.impl.crp;

import com.raritan.smartcard.impl.CardTransmitHandler;
import com.raritan.smartcard.impl.EventsListenerManager;
import com.raritan.smartcard.impl.ServerCardEventsListener;
import com.raritan.smartcard.impl.commands.CardInsertedMessage;
import com.raritan.smartcard.impl.commands.CardRemovedMessage;
import com.raritan.smartcard.impl.commands.ClientCommandsExecutor;
import com.raritan.smartcard.impl.commands.MountCardReaderRequest;
import com.raritan.smartcard.impl.commands.QuitMessageFromClient;
import com.raritan.smartcard.impl.commands.ResponseAPDU;

public class ServerCardEventsListenerImpl implements ServerCardEventsListener {
   private final ClientCommandsExecutor handler;
   private final EventsListenerManager eventsListenerManager;
   private final int rfbSessionID;
   private final int msindex;

   public ServerCardEventsListenerImpl(ClientCommandsExecutor var1, int var2, int var3, EventsListenerManager var4) {
      this.handler = var1;
      this.rfbSessionID = var2;
      this.msindex = var3;
      this.eventsListenerManager = var4;
   }

   @Override
   public void cardInserted(String var1, byte[] var2) {
      this.handler.executeClientCommands(new CardInsertedMessage(var1, var2));
   }

   @Override
   public void cardReaderInserted() {
      this.handler.executeClientCommands(new MountCardReaderRequest(this.rfbSessionID, this.msindex));
   }

   @Override
   public void cardReaderRemoved() {
      this.handler.executeClientCommands(new QuitMessageFromClient());
   }

   @Override
   public void cardRemoved() {
      this.handler.executeClientCommands(new CardRemovedMessage());
   }

   @Override
   public void setCardTransmitHandler(CardTransmitHandler var1) {
      this.eventsListenerManager.addListener(CardTransmitHandler.class, var1);
   }

   @Override
   public void transmit(byte[] var1) {
      this.handler.executeClientCommands(new ResponseAPDU(var1));
   }
}
