package com.raritan.smartcard.impl.crp.V01_00;

import com.raritan.smartcard.SmartCardException;
import com.raritan.smartcard.SmartCardSessionEventsListener;
import com.raritan.smartcard.impl.CardTransmitHandler;
import com.raritan.smartcard.impl.EventsListenerManager;
import com.raritan.smartcard.impl.commands.AuthHttpIDChallResponse;
import com.raritan.smartcard.impl.commands.AuthHttpIDGetChallenge;
import com.raritan.smartcard.impl.commands.AuthRDMRequest;
import com.raritan.smartcard.impl.commands.CardInsertedMessage;
import com.raritan.smartcard.impl.commands.CardRemovedMessage;
import com.raritan.smartcard.impl.commands.ClientCommandsExecutor;
import com.raritan.smartcard.impl.commands.CommandVisitorV01_00;
import com.raritan.smartcard.impl.commands.MountCardReaderRequest;
import com.raritan.smartcard.impl.commands.PongResponse;
import com.raritan.smartcard.impl.commands.QuitMessageFromClient;
import com.raritan.smartcard.impl.commands.ResponseAPDU;
import com.raritan.smartcard.impl.commands.SupportsVisitor;
import com.raritan.smartcard.impl.crp.SmartCardNotificationEvent;
import java.io.IOException;
import nn.pp.core.NotificationListener;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.core.impl.MonitoringDataOutputStream;

public class CRPMessageHandlerV01_00Impl implements CRPMessageHandlerV01_00, CommandVisitorV01_00 {
   private volatile ClientCommandsExecutor clientCommandsExecutor;
   private volatile EventsListenerManager eventsListenerManager;
   private volatile MonitoringDataOutputStream os;
   private volatile MonitoringDataInputStream is;
   private final CommandToMessageWriterVisitor messageWriter = new CommandToMessageWriterVisitor();
   private int capduSeqNum;
   private final ProtoStateMachine stateMachine = new ProtoStateMachine();

   @Override
   public void handleAuthResponse(AuthResponse var1) {
      if (this.handleMessageReading(ProtoMessages.AUTH_RESPONSE, var1.getAck() != 0) && var1.getAck() == 0) {
         this.setQuitState();

         for (NotificationListener var3 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var3.receivedNotification(new SmartCardNotificationEvent(var1.getReason()));
         }
      }
   }

   @Override
   public void handleMountCardReaderResponse(MountCardReaderResponse var1) {
      if (this.handleMessageReading(ProtoMessages.MOUNT_CARD_READER_RESPONSE, var1.getAck() != 0)) {
         if (var1.getAck() == 0) {
            this.setQuitState();

            for (NotificationListener var3 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
               var3.receivedNotification(new SmartCardNotificationEvent(var1.getReason()));
            }
         } else {
            for (SmartCardSessionEventsListener var5 : this.eventsListenerManager.getListeners(SmartCardSessionEventsListener.class)) {
               var5.cardReaderMounted("");
            }
         }
      }
   }

   @Override
   public void handlePingRequest(PingRequest var1) {
      if (this.handleMessageReading(ProtoMessages.PING, true)) {
         this.clientCommandsExecutor.executeClientCommands(new PongResponse());
      }
   }

   @Override
   public void handleQuitRequestFromServer(QuitRequestFromServer var1) {
      if (this.handleMessageReading(ProtoMessages.QUIT_RESP, true)) {
         for (NotificationListener var3 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var3.receivedNotification(new SmartCardNotificationEvent(1, var1.getReason()));
         }
      }
   }

   @Override
   public void handleCommandAPDU(CommandAPDURequest var1) {
      if (this.handleMessageReading(ProtoMessages.CAPDU, true)) {
         this.setCapduSeqNum(var1.getSequenceNum());

         for (CardTransmitHandler var3 : this.eventsListenerManager.getListeners(CardTransmitHandler.class)) {
            var3.transmit(var1.getCapdu());
         }
      }
   }

   void setClientCommandsExecutor(ClientCommandsExecutor var1) {
      this.clientCommandsExecutor = var1;
   }

   void setOs(MonitoringDataOutputStream var1) {
      this.os = var1;
   }

   void setIs(MonitoringDataInputStream var1) {
      this.is = var1;
   }

   @Override
   public void handleAuthRDMRequest(AuthRDMRequest var1) throws IOException, SmartCardException {
      this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST);
   }

   @Override
   public void handleCardInsertedMessage(CardInsertedMessage var1) throws IOException, SmartCardException {
      this.handleWritingWithWait(var1, ProtoMessages.CARD_INSERTED, ProtoStates.AUTHENTICATED, ProtoStates.CARD_READER_MOUNTED);
   }

   @Override
   public void handleCardRemovedMessage(CardRemovedMessage var1) throws IOException, SmartCardException {
      this.handleMessageWriting(var1, ProtoMessages.CARD_REMOVED);
   }

   @Override
   public void handleHttpIDChallengeResponse(AuthHttpIDChallResponse var1) throws IOException, SmartCardException {
      this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST);
   }

   @Override
   public void handleHttpIDGetChallenge(AuthHttpIDGetChallenge var1) throws IOException, SmartCardException {
      if (this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST)) {
         AuthHttpIDChallenge var2 = new AuthHttpIDChallenge().readMessage(this.is);
         byte[] var3 = var2.getChallenge();
         this.clientCommandsExecutor.executeClientCommands(new AuthHttpIDChallResponse(var3, var1.getHttpSessionID()));
      }
   }

   @Override
   public void handleMountCardReaderRequest(MountCardReaderRequest var1) throws IOException, SmartCardException {
      this.handleWritingWithWait(var1, ProtoMessages.MOUNT_CARD_READER_REQUEST, ProtoStates.UNKNOWN, ProtoStates.AUTHENTICATED);
   }

   @Override
   public void handlePongResponse(PongResponse var1) throws IOException, SmartCardException {
      this.handleMessageWriting(var1, ProtoMessages.PONG);
   }

   @Override
   public void handleQuitMessageFromClient(QuitMessageFromClient var1) throws IOException, SmartCardException {
      if (this.handleMessageWriting(var1, ProtoMessages.QUIT_REQ)) {
         for (SmartCardSessionEventsListener var3 : this.eventsListenerManager.getListeners(SmartCardSessionEventsListener.class)) {
            var3.disconnected(null);
         }
      }
   }

   @Override
   public void handleRAPDU(ResponseAPDU var1) throws IOException, SmartCardException {
      var1.setSequenceNum(this.getCapduSeqNum());
      this.handleMessageWriting(var1, ProtoMessages.RAPDU);
   }

   private synchronized int getCapduSeqNum() {
      return this.capduSeqNum;
   }

   private synchronized void setCapduSeqNum(int var1) {
      this.capduSeqNum = var1;
   }

   void setEventsListenerManager(EventsListenerManager var1) {
      this.eventsListenerManager = var1;
   }

   private void setQuitState() {
      synchronized (this.stateMachine) {
         this.stateMachine.transitionOnMessage(ProtoMessages.QUIT_RESP);
      }
   }

   private boolean handleMessageReading(ProtoMessages var1, boolean var2) {
      boolean var3 = false;
      ProtoStates var4;
      synchronized (this.stateMachine) {
         var4 = this.stateMachine.getState();
         if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
            return false;
         }

         if (this.stateMachine.isValidMessage(var1)) {
            if (var2) {
               this.stateMachine.transitionOnMessage(var1);
            }

            return true;
         }

         if (var1 == ProtoMessages.CAPDU && var4 == ProtoStates.CARD_REMOVED) {
            return false;
         }

         this.setQuitState();
         var3 = true;
      }

      if (var3) {
         for (NotificationListener var6 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var6.receivedNotification(new SmartCardNotificationEvent(1, 10001, true, "Current State was " + var4));
         }
      }

      return false;
   }

   private boolean handleMessageWriting(SupportsVisitor<CommandVisitorV01_00> var1, ProtoMessages var2) throws IOException, SmartCardException {
      boolean var3 = false;
      ProtoStates var4;
      synchronized (this.stateMachine) {
         var4 = this.stateMachine.getState();
         if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
            return false;
         }

         if (this.stateMachine.isValidMessage(var2)) {
            this.messageWriter.setOs(this.os);

            try {
               var1.accept(this.messageWriter);
            } catch (IOException var8) {
               this.setQuitState();
               throw var8;
            } catch (SmartCardException var9) {
               this.setQuitState();
               throw var9;
            }

            this.stateMachine.transitionOnMessage(var2);
            return true;
         }

         this.setQuitState();
         var3 = true;
      }

      if (var3) {
         for (NotificationListener var6 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var6.receivedNotification(new SmartCardNotificationEvent(1, 10001, true, "Current State was " + var4));
         }
      }

      return false;
   }

   private void handleWritingWithWait(SupportsVisitor<CommandVisitorV01_00> var1, ProtoMessages var2, ProtoStates var3, ProtoStates var4) throws IOException, SmartCardException {
      boolean var5 = false;
      ProtoStates var6;
      synchronized (this.stateMachine) {
         var6 = this.stateMachine.getState();
         if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
            return;
         }

         boolean var8;
         while (true) {
            try {
               var8 = this.waitForRequiredState(var2, var3, var4);
               break;
            } catch (InterruptedException var13) {
            }
         }

         if (var8) {
            if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
               return;
            }

            this.messageWriter.setOs(this.os);

            try {
               var1.accept(this.messageWriter);
            } catch (IOException var11) {
               this.setQuitState();
               throw var11;
            } catch (SmartCardException var12) {
               this.setQuitState();
               throw var12;
            }

            this.stateMachine.transitionOnMessage(var2);
         } else {
            this.setQuitState();
            var5 = true;
         }
      }

      if (var5) {
         for (NotificationListener var16 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var16.receivedNotification(new SmartCardNotificationEvent(1, 10001, true, "Current State was " + var6));
         }
      }
   }

   private boolean waitForRequiredState(ProtoMessages var1, ProtoStates var2, ProtoStates var3) throws InterruptedException {
      if (!this.stateMachine.isValidMessage(var1)) {
         if (this.stateMachine.getState() != var2) {
            return false;
         }

         this.stateMachine.waitOnState(var3);
      }

      return true;
   }

   public void handleDisconnection() {
      synchronized (this.stateMachine) {
         this.stateMachine.transitionOnMessage(ProtoMessages.QUIT_RESP);
      }
   }
}
