package com.raritan.smartcard.impl.crp.V01_00;

import com.raritan.smartcard.SmartCardException;
import com.raritan.smartcard.impl.commands.AuthHttpIDChallResponse;
import com.raritan.smartcard.impl.commands.AuthHttpIDGetChallenge;
import com.raritan.smartcard.impl.commands.AuthRDMRequest;
import com.raritan.smartcard.impl.commands.CardInsertedMessage;
import com.raritan.smartcard.impl.commands.CardRemovedMessage;
import com.raritan.smartcard.impl.commands.CommandVisitorV01_00;
import com.raritan.smartcard.impl.commands.MountCardReaderRequest;
import com.raritan.smartcard.impl.commands.PongResponse;
import com.raritan.smartcard.impl.commands.QuitMessageFromClient;
import com.raritan.smartcard.impl.commands.ResponseAPDU;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.NoSuchAlgorithmException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.Util;
import nn.pp.core.impl.MonitoringDataOutputStream;

public class CommandToMessageWriterVisitor implements CommandVisitorV01_00 {
   private MonitoringDataOutputStream mos;
   private static final Logger LOGGER = Logger.getLogger(CommandToMessageWriterVisitor.class.getName());

   @Override
   public void handleAuthRDMRequest(AuthRDMRequest var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(7);
      String var3 = var1.getRdmID() + '\u0000';

      byte[] var4;
      try {
         var4 = var3.getBytes("ISO-8859-1");
      } catch (UnsupportedEncodingException var6) {
         throw new SmartCardException(var6);
      }

      var2.write((byte)var4.length);
      var2.write(var4);
      var2.flush();
      Object var7 = null;
   }

   @Override
   public void handleCardInsertedMessage(CardInsertedMessage var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(2);
      byte[] var3 = var1.getProto().getBytes("ISO-8859-1");
      var2.write(var3.length);
      byte[] var4 = var1.getAtrBytes();
      var2.write(var4.length);
      var2.write(var3);
      var2.write(var4);
      var2.flush();
      Object var5 = null;
   }

   @Override
   public void handleCardRemovedMessage(CardRemovedMessage var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(9);
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handleHttpIDChallengeResponse(AuthHttpIDChallResponse var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();

      byte[] var3;
      try {
         var3 = Util.getHash(var1.getChallenge(), var1.getHttpSessionID().getBytes("ISO-8859-1"));
      } catch (NoSuchAlgorithmException var6) {
         throw new SmartCardException(var6);
      }

      byte[] var4 = Util.binToHex(var3).getBytes("ISO-8859-1");
      if (var4.length != 64 && var4.length != 32) {
         throw new SmartCardException("Response has invalid length");
      } else {
         byte[] var5 = new byte[var4.length + 9];
         System.arraycopy("CRP RESP=".getBytes("ISO-8859-1"), 0, var5, 0, 9);
         System.arraycopy(var4, 0, var5, 9, var4.length);
         var2.write(var5);
         var2.flush();
         Object var7 = null;
      }
   }

   @Override
   public void handleHttpIDGetChallenge(AuthHttpIDGetChallenge var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(6);
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handleMountCardReaderRequest(MountCardReaderRequest var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(1);
      var2.write(var1.getMsindex());
      var2.writeShort(0);
      var2.writeInt(var1.getRfbSessionID());
      var2.writeInt(0);
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handlePongResponse(PongResponse var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(5);
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handleQuitMessageFromClient(QuitMessageFromClient var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(3);
      var2.write(0);
      var2.writeShort(0);
      var2.writeInt(var1.getReason());
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handleRAPDU(ResponseAPDU var1) throws IOException, SmartCardException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(8);
      var2.write(0);
      var2.writeShort(0);
      var2.writeInt(var1.getSequenceNum());
      byte[] var3 = var1.getData();
      var2.writeInt(var3.length);
      var2.write(var3);
      var2.flush();
      Object var4 = null;
   }

   synchronized void setOs(MonitoringDataOutputStream var1) {
      this.mos = var1;
   }

   private synchronized MonitoringDataOutputStream getMos() {
      return this.mos;
   }
}
