package com.raritan.tools.ui;

import com.raritan.protocol.browser.DeviceNameAddressProvider;
import com.raritan.tools.ui.blocking.BlockingHelper;
import com.raritan.tools.ui.panes.mediator.PanelMediator;
import com.raritan.tools.util.ImageHolder;
import com.raritan.tools.util.Logger;
import com.raritan.tools.util.ObservableContainer;
import java.applet.AppletContext;
import java.awt.Component;
import java.awt.Font;
import java.awt.Image;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Observable;
import java.util.Properties;
import javax.swing.ImageIcon;
import javax.swing.UIManager;

public abstract class ScreenContext extends Observable {
   public static final String PROPERTY_LOCALE = "default.locale";
   public static final String PROPERTY_APPLICATION_LOG_LEVEL = "application.log.level";
   public static final String PROPERTY_APPLICATION_LOG_OUTPUT = "application.log.output";
   public static final String PROPERTY_LOG_HISTORY = "log.panel.history";
   public static final String PROPERTY_LOG_TIMESTAMP_FORMAT = "log.timestamp.format";
   public static final String PROPERTY_LOG_ADD_TIMESTAMP = "log.timestamp";
   private Locale locale;
   protected Properties applicationProperties;
   private ImageHolder imageHolder;
   private AbstractUIManager application;
   private State currentState;
   private PanelMediator panelMediator;
   protected HashMap notifiers = new HashMap();
   protected Logger logger;
   protected HashMap observableContainers;
   private BlockingHelper blockingHelper;
   private AppletContext appletContext = null;
   private URL codeBase;
   private Map vmLocalMap;
   private Map vmImagelMap;
   private ArrayList selectedDrives = new ArrayList();
   public static String BUILD = null;

   protected ScreenContext(State var1) {
      this.currentState = var1;
      this.imageHolder = new ImageHolder(this);
      this.applicationProperties = null;
      if (Locale.getDefault().getLanguage().equalsIgnoreCase(Locale.ENGLISH.getLanguage())) {
         this.setFonts();
      }

      this.observableContainers = new HashMap();
   }

   public static ScreenContext getNewInstance(Map var0) {
      return null;
   }

   public Properties getProperties() {
      return this.applicationProperties;
   }

   public synchronized void setState(State var1) {
      if (this.getState() == State.LOGGEDIN && var1 == State.LOGGEDOUT) {
         this.getPanelMediator().hideAll();
      }

      if (var1 == State.LOGGEDIN) {
         this.createNotificationHandlers();
      } else {
         this.destroyNotificationHandlers();
      }

      this.currentState = var1;
      this.setChanged();
      this.notifyObservers();
   }

   public State getState() {
      return this.currentState;
   }

   public synchronized void setPanelMediator(PanelMediator var1) {
      this.panelMediator = var1;
   }

   public PanelMediator getPanelMediator() {
      return this.panelMediator;
   }

   public Locale getLocale() {
      return this.locale;
   }

   public void setLocale(Locale var1) {
      this.locale = var1;
   }

   public String getApplicationProperty(String var1) {
      return this.applicationProperties.getProperty(var1);
   }

   public void setApplication(AbstractUIManager var1) {
      this.application = var1;
   }

   public AbstractUIManager getApplication() {
      return this.application;
   }

   public Component getOptionComponent() {
      return this.application.getOptionComponent();
   }

   public URL getIconBase() {
      return this.application.getIconBase();
   }

   public ImageIcon getImageIcon(String var1) {
      Image var2 = this.imageHolder.getImage(var1);
      if (var2 == null) {
         return null;
      } else {
         ImageIcon var3 = new ImageIcon(var2);
         var3.setDescription(var1);
         return var3;
      }
   }

   private void setFonts() {
      Font var1 = new Font("Verdana", 0, 10);
      Font var2 = var1.deriveFont(0);
      Font var3 = var1.deriveFont(10.0F);
      UIManager.put("Button.font", var2);
      UIManager.put("CheckBox.font", var2);
      UIManager.put("CheckBoxMenuItem.font", var2);
      UIManager.put("CheckBoxMenuItem.acceleratorFont", var3);
      UIManager.put("ColorChooser.font", var1);
      UIManager.put("ComboBox.font", var2);
      UIManager.put("DesctopIcon.font", var2);
      UIManager.put("EditorPane.font", var1);
      UIManager.put("FormattedTextField.font", var1);
      UIManager.put("InternalFrame.titleFont", var2);
      UIManager.put("Label.font", var2);
      UIManager.put("List.font", var2);
      UIManager.put("Menu.font", var2);
      UIManager.put("Menu.acceleratorFont", var3);
      UIManager.put("MenuBar.font", var2);
      UIManager.put("MenuItem.font", var2);
      UIManager.put("MenuItem.acceleratorFont", var3);
      UIManager.put("OptionPane.font", var1);
      UIManager.put("Panel.font", var1);
      UIManager.put("PasswordField.font", var1);
      UIManager.put("PopupMenu.font", var2);
      UIManager.put("ProgressBar.font", var2);
      UIManager.put("RadioButton.font", var2);
      UIManager.put("RadioButtonMenuItem.font", var2);
      UIManager.put("RadioButtonMenuItem.acceleratorFont", var3);
      UIManager.put("ScrollPane.font", var1);
      UIManager.put("Spinner.font", var2);
      UIManager.put("TabbedPane.font", var2);
      UIManager.put("Table.font", var1);
      UIManager.put("TableHeader.font", var1);
      UIManager.put("TextArea.font", var1);
      UIManager.put("TextField.font", var1);
      UIManager.put("TextPane.font", var1);
      UIManager.put("TitledBorder.font", var2);
      UIManager.put("ToggleButton.font", var2);
      UIManager.put("ToolBar.font", var2);
      UIManager.put("ToolTip.font", var1);
      UIManager.put("Tree.font", var1);
      UIManager.put("Viewport.font", var1);
   }

   public abstract void createNotificationHandlers();

   public abstract void destroyNotificationHandlers();

   public void addObservable(ObservableContainer var1) {
      this.observableContainers.put(var1.getContainerName(), var1);
   }

   public ObservableContainer getObservable(String var1) {
      Object var2 = this.observableContainers.get(var1);
      return (ObservableContainer)var2;
   }

   public void clearObservableContainers() {
      this.observableContainers.clear();
   }

   public Logger getLogger() {
      if (this.logger == null) {
         this.logger = new Logger(this);
      }

      return this.logger;
   }

   public void destroy() {
      this.destroyNotificationHandlers();
      this.panelMediator.destroy();
      this.panelMediator = null;
      this.application = null;
   }

   public Properties getApplicationProperties() {
      return this.applicationProperties;
   }

   public void setApplicationProperties(Properties var1) {
      this.applicationProperties = var1;
   }

   public void setAppletContext(AppletContext var1) {
      this.appletContext = var1;
   }

   public AppletContext getAppletContext() {
      return this.appletContext;
   }

   public void setAppletCodeBase(URL var1) {
      this.codeBase = var1;
   }

   public URL getAppletCodeBase() {
      return this.codeBase;
   }

   public BlockingHelper getBlockingHelper() {
      if (this.blockingHelper == null) {
         this.blockingHelper = new BlockingHelper(this);
      }

      return this.blockingHelper;
   }

   public void resetDefaultFocus() {
   }

   public void setVitualMediaLocalMap(Map var1) {
      this.vmLocalMap = var1;
   }

   public Map getVirtualMediaLocalMap() {
      return this.vmLocalMap;
   }

   public synchronized void setVitualMediaImageMap(Map var1) {
      this.vmImagelMap = var1;
   }

   public synchronized Map getVirtualMediaImageMap() {
      return this.vmImagelMap;
   }

   public ArrayList getSelectedDrives() {
      return this.selectedDrives;
   }

   public void setSelectedDrives(ArrayList var1) {
      this.selectedDrives = var1;
   }

   public void addSelectedDrive(String var1) {
      this.selectedDrives.add(var1);
   }

   public void removeSelectedDrive(String var1) {
      this.selectedDrives.remove(var1);
   }

   public abstract DeviceNameAddressProvider getDeviceNameAddressProvider();
}
