package com.raritan.tools.ui.components;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.ui.ScreenContext;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JButton;

public class CommandButton extends JButton implements CommandHolder, MultyObserverComponentInterface, ConfirmableCommandInterface {
   private static final long serialVersionUID = 5135506049969896633L;
   private Command command;
   private boolean confirmation = false;
   private final HashMap observables = new HashMap();
   protected ScreenContext scrContext;

   public CommandButton(ScreenContext var1) {
      this.scrContext = var1;
      this.init();
   }

   public CommandButton(String var1, ScreenContext var2) {
      super(var1);
      this.scrContext = var2;
      this.init();
   }

   public CommandButton(String var1, Icon var2, ScreenContext var3) {
      super(var1, var2);
      this.scrContext = var3;
      this.init();
   }

   public CommandButton(Action var1, ScreenContext var2) {
      super(var1);
      this.scrContext = var2;
      this.init();
   }

   public CommandButton(Icon var1, ScreenContext var2) {
      super(var1);
      this.scrContext = var2;
      this.init();
   }

   @Override
   public Command getCommand() {
      return this.command;
   }

   @Override
   public void setCommand(Command var1) {
      this.command = var1;
      this.setEnabled(var1 != null ? var1.isExecutable() : false);
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (this.getCommand() != null) {
         this.setEnabled(this.getCommand().isExecutable());
      } else {
         this.setEnabled(false);
      }
   }

   protected void init() {
      this.command = new DummyCommand(this.scrContext);
      this.setEnabled(this.command.isExecutable());
      this.enableInputMethods(false);
      CommandButton.EnterKeyListener var1 = new CommandButton.EnterKeyListener();
      this.addKeyListener(var1);
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void setConfirmation(boolean var1) {
      this.confirmation = var1;
   }

   @Override
   public boolean getConfirmation() {
      return this.confirmation;
   }

   public class EnterKeyListener extends KeyAdapter {
      @Override
      public void keyPressed(KeyEvent var1) {
         if (var1.getKeyCode() == 10) {
            CommandButton.this.doClick();
         }
      }
   }
}
