package com.raritan.tools.ui.components;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.ui.ScreenContext;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileSystemView;

public class CommandFileChooser extends JFileChooser implements CommandHolder, MultyObserverComponentInterface {
   private static final long serialVersionUID = 5589895539602793441L;
   private Command command;
   private final HashMap observables = new HashMap();
   protected ScreenContext scrContext;

   public CommandFileChooser(ScreenContext var1) {
      this.init(var1);
   }

   public CommandFileChooser(File var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   public CommandFileChooser(String var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   public CommandFileChooser(FileSystemView var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   public CommandFileChooser(File var1, FileSystemView var2, ScreenContext var3) {
      super(var1, var2);
      this.init(var3);
   }

   public CommandFileChooser(String var1, FileSystemView var2, ScreenContext var3) {
      super(var1, var2);
      this.init(var3);
   }

   protected void init(ScreenContext var1) {
      this.scrContext = var1;
      this.command = new DummyCommand(this.scrContext);
      this.setEnabled(this.command.isExecutable());
   }

   @Override
   public Command getCommand() {
      return this.command;
   }

   @Override
   public void setCommand(Command var1) {
      this.command = var1;
      this.setEnabled(var1 != null ? var1.isExecutable() : false);
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (this.getCommand() != null) {
         this.setEnabled(this.getCommand().isExecutable());
      } else {
         this.setEnabled(false);
      }
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }
}
