package com.raritan.tools.ui.components;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.ui.ScreenContext;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javax.swing.Action;
import javax.swing.JMenu;

public class CommandMenu extends JMenu implements CommandHolder, MultyObserverComponentInterface, ConfirmableCommandInterface {
   private static final long serialVersionUID = 3457522766771073833L;
   protected Command command;
   protected ScreenContext scrContext;
   private boolean confirmation = false;
   private final HashMap observables = new HashMap();

   @Override
   public void setPopupMenuVisible(boolean var1) {
      super.setPopupMenuVisible(var1);
      this.getPopupMenu().repaint();
   }

   public CommandMenu(ScreenContext var1) {
      this.init(var1);
   }

   public CommandMenu(String var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
      this.command = new DummyCommand(this.scrContext);
   }

   public CommandMenu(String var1, boolean var2, ScreenContext var3) {
      super(var1, var2);
      this.init(var3);
   }

   public CommandMenu(Action var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   @Override
   public void setCommand(Command var1) {
      this.command = var1;
      if (var1 != null) {
         this.setEnabled(var1.isExecutable());
      }
   }

   @Override
   public Command getCommand() {
      return this.command;
   }

   protected void init(ScreenContext var1) {
      this.scrContext = var1;
      this.command = new DummyCommand(this.scrContext);
   }

   @Override
   public void setConfirmation(boolean var1) {
      this.confirmation = var1;
   }

   @Override
   public boolean getConfirmation() {
      return this.confirmation;
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (this.getCommand() != null) {
         this.setEnabled(this.getCommand().isExecutable());
      } else {
         this.setEnabled(false);
      }
   }
}
