package com.raritan.tools.ui.components;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.ui.ScreenContext;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JMenuItem;

public class CommandMenuItem extends JMenuItem implements CommandHolder, MultyObserverComponentInterface, ConfirmableCommandInterface {
   private static final long serialVersionUID = 2477924176805756783L;
   private Command command;
   private int itemID = 0;
   private boolean confirmation = false;
   private final HashMap observables = new HashMap();
   protected ScreenContext scrContext;

   public CommandMenuItem(ScreenContext var1) {
      this.init(var1);
   }

   public CommandMenuItem(Icon var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   public CommandMenuItem(String var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   public CommandMenuItem(Action var1, ScreenContext var2) {
      super(var1);
      this.init(var2);
   }

   public CommandMenuItem(String var1, Icon var2, ScreenContext var3) {
      super(var1, var2);
      this.init(var3);
   }

   public CommandMenuItem(String var1, int var2, ScreenContext var3) {
      super(var1, var2);
      this.init(var3);
   }

   @Override
   public void setCommand(Command var1) {
      this.command = var1;
      if (var1 != null) {
         this.setEnabled(var1.isExecutable());
      }
   }

   @Override
   public Command getCommand() {
      return this.command;
   }

   public void setItemID(int var1) {
      this.itemID = var1;
   }

   public int getItemID() {
      return this.itemID;
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (this.getCommand() != null) {
         this.setEnabled(this.getCommand().isExecutable());
      } else {
         this.setEnabled(false);
      }
   }

   protected void init(ScreenContext var1) {
      this.scrContext = var1;
      this.command = new DummyCommand(this.scrContext);
      this.setEnabled(this.command.isExecutable());
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void setConfirmation(boolean var1) {
      this.confirmation = var1;
   }

   @Override
   public boolean getConfirmation() {
      return this.confirmation;
   }
}
