package com.raritan.tools.ui.components;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.ui.ScreenContext;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.List;
import java.util.Observable;
import java.util.Vector;
import javax.swing.JTree;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreeNode;

public class CommandTree extends JTree implements CommandHolder, MultyObserverComponentInterface {
   private static final long serialVersionUID = 5943057532803696258L;
   private Command cmd;
   private final HashMap observables = new HashMap();
   protected ScreenContext scrContext;

   public CommandTree(ScreenContext var1) {
      this.initCommandTree(var1);
   }

   public CommandTree(Object[] var1, ScreenContext var2) {
      super(var1);
      this.initCommandTree(var2);
   }

   public CommandTree(Hashtable var1, ScreenContext var2) {
      super(var1);
      this.initCommandTree(var2);
   }

   public CommandTree(Vector var1, ScreenContext var2) {
      super(var1);
      this.initCommandTree(var2);
   }

   public CommandTree(TreeModel var1, ScreenContext var2) {
      super(var1);
      this.initCommandTree(var2);
   }

   public CommandTree(TreeNode var1, ScreenContext var2) {
      super(var1);
      this.initCommandTree(var2);
   }

   public CommandTree(TreeNode var1, boolean var2, ScreenContext var3) {
      super(var1, var2);
      this.initCommandTree(var3);
   }

   @Override
   public Command getCommand() {
      return this.cmd;
   }

   @Override
   public void setCommand(Command var1) {
      this.cmd = var1;
   }

   private void initCommandTree(ScreenContext var1) {
      this.scrContext = var1;
      this.cmd = new DummyCommand(this.scrContext);
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void update(Observable var1, Object var2) {
      if (this.getCommand() != null) {
         this.setEnabled(this.getCommand().isExecutable());
      } else {
         this.setEnabled(false);
      }
   }
}
