package com.raritan.tools.ui.components;

import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.ShellFocusObserver;
import com.raritan.tools.util.Util;
import java.awt.Component;
import java.awt.Container;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JOptionPane;

public class CommonPopups {
   public static final int POPUP_RESULT_UNKNOWN = 0;
   public static final int POPUP_RESULT_CANCEL = 1;
   public static final int POPUP_RESULT_OK = 2;

   public static void showCommandResultErrorMessage(Object[] var0, AbstractDisplay var1, ScreenContext var2) {
      StringBuffer var3 = new StringBuffer("");

      for (int var4 = 0; var4 < var0.length; var4++) {
         var3.append(var0[var4]);
         var3.append("\n");
      }

      showCommandResultErrorMessage(var3.toString(), var1, var2);
   }

   public static void showCommandResultErrorMessage(String var0, AbstractDisplay var1, ScreenContext var2) {
      RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(var2.getLocale());
      JOptionPane var4 = new JOptionPane(var0, 0, -1, null, new Object[]{var3.getString("basescreen.command.ok.text")});
      addKeyListener(new CommonPopups.EnterKeyListener(), var4.getComponents());
      var2.getPanelMediator().showDialogOnTop(var4, var3.getString("optionpane.error.title"), var1);
   }

   public static void showErrorMessage(String var0, Component var1, ScreenContext var2, String var3) {
      RaritanPropertyResourceBundle var4 = RaritanResourceBundle.getResourceBundle(var2.getLocale());
      JOptionPane var5 = new JOptionPane(var0, 0, -1, null, new Object[]{var4.getString("basescreen.command.ok.text")});
      addKeyListener(new CommonPopups.EnterKeyListener(), var5.getComponents());
      String var6 = var4.getString("optionpane.error.title") + " " + var3;
      if (var1 instanceof AbstractDisplay) {
         var2.getPanelMediator().showDialogOnTop(var5, var6, (AbstractDisplay)var1);
      } else {
         JDialog var7 = var5.createDialog(var1, var6);
         Util.jre17WorkaroundInheritAlwaysOnTop(var7);
         var7.setLocationRelativeTo(var1);
         var7.setModal(true);
         var7.setVisible(true);
         var7.dispose();
      }
   }

   public static int showExitConfirmationDialog(AbstractDisplay var0, ScreenContext var1) {
      RaritanPropertyResourceBundle var2 = RaritanResourceBundle.getResourceBundle(var1.getLocale());
      return showConfirmationDialog(
         var2.getString("confirmation.dialog.command.execution.title"), var2.getString("confirmation.dialog.command.execution.text"), var0, var1
      );
   }

   public static int showExitConfirmationDialog(Component var0, ScreenContext var1) {
      RaritanPropertyResourceBundle var2 = RaritanResourceBundle.getResourceBundle(var1.getLocale());
      JOptionPane var3 = new JOptionPane(
         var2.getString("confirmation.dialog.command.execution.text"),
         2,
         0,
         null,
         new Object[]{var2.getString("basescreen.command.yes.text"), var2.getString("basescreen.command.no.text")}
      );
      addKeyListener(new CommonPopups.EnterKeyListener(), var3.getComponents());
      Object var4 = var1.getPanelMediator().showDialogOnTop(var3, var2.getString("confirmation.dialog.command.execution.title"), var0);
      if (var4 != null) {
         return var4.equals(var2.getString("basescreen.command.yes.text")) ? 2 : 1;
      } else {
         return 1;
      }
   }

   public static int showConfirmationDialog(String var0, Object var1, AbstractDisplay var2, ScreenContext var3) {
      return showConfirmationDialog(var0, var1, var2, var3, null);
   }

   public static int showConfirmationDialog(String var0, Object var1, AbstractDisplay var2, ScreenContext var3, String[] var4) {
      RaritanPropertyResourceBundle var5 = RaritanResourceBundle.getResourceBundle(var3.getLocale());
      if (var4 != null && var4.length < 2) {
         throw new IllegalArgumentException("Buttons array should contain exactly 2 elements");
      } else {
         JOptionPane var6 = new JOptionPane(
            var1,
            2,
            0,
            null,
            var4 != null
               ? new Object[]{var5.getString(var4[0]), var5.getString(var4[1])}
               : new Object[]{var5.getString("basescreen.command.yes.text"), var5.getString("basescreen.command.no.text")}
         );
         addKeyListener(new CommonPopups.EnterKeyListener(), var6.getComponents());
         Object var7 = var3.getPanelMediator().showDialogOnTop(var6, var0, var2);
         if (var7 == null) {
            return 1;
         } else {
            return var7.equals(var4 != null && var4.length > 0 ? var5.getString(var4[0]) : var5.getString("basescreen.command.yes.text")) ? 2 : 1;
         }
      }
   }

   public static int showInfoDialog(String var0, Object var1, AbstractDisplay var2, ScreenContext var3) {
      RaritanPropertyResourceBundle var4 = RaritanResourceBundle.getResourceBundle(var3.getLocale());
      JOptionPane var5 = new JOptionPane(var1, 1, -1, null, new Object[]{var4.getString("basescreen.command.ok.text")});
      addKeyListener(new CommonPopups.EnterKeyListener(), var5.getComponents());
      Object var6 = var3.getPanelMediator().showDialogOnTop(var5, var0, var2);
      return 2;
   }

   public static int showFileOverwriteConfirmationDialog(AbstractDisplay var0, ScreenContext var1) {
      RaritanPropertyResourceBundle var2 = RaritanResourceBundle.getResourceBundle(var1.getLocale());
      return showConfirmationDialog(var2.getString("filebrowser.save.fileexists.title"), var2.getString("filebrowser.save.fileexists.message"), var0, var1);
   }

   public static void showWarningDialog(String var0, Object var1, Component var2, ScreenContext var3) {
      RaritanPropertyResourceBundle var4 = RaritanResourceBundle.getResourceBundle(var3.getLocale());
      JOptionPane var5 = new JOptionPane(var1, 2, -1, null, new Object[]{var4.getString("basescreen.command.ok.text")});
      JDialog var6 = var5.createDialog(var2, var0);
      Util.jre17WorkaroundInheritAlwaysOnTop(var6);
      if (var2 != null) {
         var6.setLocationRelativeTo(var2);
      }

      var6.setModal(true);
      ShellFocusObserver.addShellVisible(var6, var3);
      var6.setVisible(true);
      ShellFocusObserver.removeShellVisible(var6, var3);
      var6.dispose();
   }

   private static void addKeyListener(KeyListener var0, Component[] var1) {
      if (var1 != null) {
         for (int var2 = 0; var2 < var1.length; var2++) {
            if (var1[var2] instanceof JButton) {
               ((JButton)var1[var2]).enableInputMethods(false);
               ((JButton)var1[var2]).addKeyListener(var0);
            } else if (var1[var2] instanceof Container) {
               addKeyListener(var0, ((Container)var1[var2]).getComponents());
            }
         }
      }
   }

   private static class EnterKeyListener extends KeyAdapter {
      private EnterKeyListener() {
      }

      @Override
      public void keyPressed(KeyEvent var1) {
         if (var1.getKeyCode() == 10 && var1.getSource() instanceof JButton) {
            ((JButton)var1.getSource()).doClick();
         }
      }
   }
}
