package com.raritan.tools.ui.components;

import javax.swing.JFormattedTextField.AbstractFormatter;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.DocumentFilter;
import javax.swing.text.DocumentFilter.FilterBypass;

public class InputFilterFormatter extends AbstractFormatter {
   private static final long serialVersionUID = 5765856728391476118L;
   public static final String LETTER_CHARACTERS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
   public static final String NUMBER_CHARACTERS = "1234567890";
   public static final String SPACE_CHARACTER = " ";
   public static final String MISC_CHARACTERS = "_.:";
   public static String DEFAULT_VALID_CHARACTERS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890 _.:";
   public static final int UNLIMITED_LENGTH = -1;
   private String validCharacters;
   private InputFilterFormatter.InputDocumentFilter docFilter;
   private boolean shouldStartWithLetter;
   private int maximumTextLenght = -1;

   public InputFilterFormatter() {
      this(false);
   }

   public InputFilterFormatter(boolean var1) {
      this.validCharacters = DEFAULT_VALID_CHARACTERS;
      this.shouldStartWithLetter = var1;
   }

   public void setMaximumTextLength(int var1) {
      if (var1 < 0 && var1 != -1) {
         throw new IllegalArgumentException("Illegal lenght, please enter non-negative or UNLIMITED_LENGTH");
      } else {
         this.maximumTextLenght = var1;
         if (this.docFilter != null) {
            this.docFilter.setMaximumTextLength(var1);
         }
      }
   }

   public void formatFilterForDeviceName() {
      String var1 = DEFAULT_VALID_CHARACTERS;
      var1 = removeValidChar(var1, ' ');
      this.setValidCharacters(var1 + "-");
      this.setShouldStartWithLetter(true);
      this.setMaximumTextLength(15);
   }

   public void formatFilterForPortName() {
      this.setShouldStartWithLetter(false);
      this.setMaximumTextLength(-1);
   }

   @Override
   public Object stringToValue(String var1) {
      return var1;
   }

   @Override
   public String valueToString(Object var1) {
      String var2 = var1 == null ? "" : var1.toString();
      return filterInvalid(var2, this.validCharacters);
   }

   @Override
   protected DocumentFilter getDocumentFilter() {
      if (this.docFilter == null) {
         this.docFilter = new InputFilterFormatter.InputDocumentFilter(this.validCharacters, this.shouldStartWithLetter);
         this.docFilter.setMaximumTextLength(this.maximumTextLenght);
      }

      return this.docFilter;
   }

   public static String generateValidCharacters(boolean var0, boolean var1, boolean var2, boolean var3) {
      StringBuffer var4 = new StringBuffer();
      if (var0) {
         var4.append("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ");
      }

      if (var1) {
         var4.append("1234567890");
      }

      if (var2) {
         var4.append(" ");
      }

      if (var3) {
         var4.append("_.:");
      }

      return var4.toString();
   }

   public static String filterInvalid(String var0, String var1) {
      if (var0 != null && !var0.equals("")) {
         StringBuffer var2 = new StringBuffer(var0);

         for (int var4 = var0.length() - 1; var4 >= 0; var4--) {
            char var3 = var2.charAt(var4);
            if (var1.indexOf(var3) == -1) {
               var2.deleteCharAt(var4);
            }
         }

         return var2.toString();
      } else {
         return var0;
      }
   }

   public boolean isShouldStartWithLetter() {
      return this.shouldStartWithLetter;
   }

   public String getValidCharacters() {
      return this.validCharacters;
   }

   public void setShouldStartWithLetter(boolean var1) {
      this.shouldStartWithLetter = var1;
      if (this.docFilter != null) {
         this.docFilter.setShouldStartWithLetter(var1);
      }
   }

   public void setValidCharacters(String var1) {
      this.validCharacters = var1;
      if (this.docFilter != null) {
         this.docFilter.setValidCharacters(var1);
      }
   }

   public static String removeValidChar(String var0, char var1) {
      int var2 = var0.indexOf(var1);
      if (var2 < 0) {
         return var0;
      } else {
         StringBuffer var3 = new StringBuffer(var0);
         var3.deleteCharAt(var2);
         return var3.toString();
      }
   }

   public static class InputDocumentFilter extends DocumentFilter {
      private String validCharacters;
      private boolean shouldStartWithLetter;
      private int maximumTextLenght = -1;

      public InputDocumentFilter(String var1, boolean var2) {
         this.validCharacters = var1;
         this.shouldStartWithLetter = var2;
      }

      public void setMaximumTextLength(int var1) {
         this.maximumTextLenght = var1;
      }

      @Override
      public void insertString(FilterBypass var1, int var2, String var3, AttributeSet var4) throws BadLocationException {
         if (var3 != null) {
            String var5 = InputFilterFormatter.filterInvalid(var3, this.validCharacters);
            if (var2 != 0
               || !this.shouldStartWithLetter
               || "".equals(var5)
               || "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".indexOf(var5.charAt(0)) != -1) {
               Document var6 = var1.getDocument();
               if (this.maximumTextLenght < 0 || var6.getLength() + var5.length() <= this.maximumTextLenght) {
                  super.insertString(var1, var2, var5, var4);
               }
            }
         }
      }

      @Override
      public void replace(FilterBypass var1, int var2, int var3, String var4, AttributeSet var5) throws BadLocationException {
         if (var4 != null) {
            String var6 = InputFilterFormatter.filterInvalid(var4, this.validCharacters);
            if (var2 != 0
               || !this.shouldStartWithLetter
               || "".equals(var6)
               || "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".indexOf(var6.charAt(0)) != -1) {
               Document var7 = var1.getDocument();
               if (this.maximumTextLenght <= 0 || var7.getLength() + var6.length() - var3 <= this.maximumTextLenght) {
                  super.replace(var1, var2, var3, var6, var5);
               }
            }
         }
      }

      @Override
      public void remove(FilterBypass var1, int var2, int var3) throws BadLocationException {
         if (var2 == 0 && var3 > 0) {
            String var4 = var1.getDocument().getText(var2 + var3, var1.getDocument().getLength() - 1);
            if (this.shouldStartWithLetter && "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".indexOf(var4.charAt(0)) == -1) {
               return;
            }
         }

         super.remove(var1, var2, var3);
      }

      public boolean isShouldStartWithLetter() {
         return this.shouldStartWithLetter;
      }

      public String getValidCharacters() {
         return this.validCharacters;
      }

      public void setShouldStartWithLetter(boolean var1) {
         this.shouldStartWithLetter = var1;
      }

      public void setValidCharacters(String var1) {
         this.validCharacters = var1;
      }
   }
}
