package com.raritan.tools.ui.components;

import com.raritan.rrc.data.MultiMonitorPort;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.commands.ShowKX2KvmPortCommand;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.ArrayList;
import java.util.Map;

public class MenuActionListenerImplementation implements ActionListener, ItemListener {
   protected ScreenContext scrContext;
   private RaritanPropertyResourceBundle bundle;
   private boolean actionJustPerformed = false;

   public MenuActionListenerImplementation(ScreenContext var1) {
      this.scrContext = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      Object var2 = var1.getSource();
      boolean var3 = false;
      if (var2 instanceof ConfirmableCommandInterface) {
         var3 = ((ConfirmableCommandInterface)var1.getSource()).getConfirmation();
      }

      if (var2 instanceof CommandHolder) {
         if (var3) {
            var3 = CommonPopups.showConfirmationDialog(
                  this.bundle.getString("confirmation.dialog.command.execution.title"),
                  this.bundle.getString("confirmation.dialog.command.execution.text"),
                  null,
                  this.scrContext
               )
               != 2;
         }

         if (!var3) {
            CommandHolder var4 = (CommandHolder)var2;
            Command var5 = var4.getCommand();
            if (var5 != null) {
               CommandResult var6 = var4.getCommand().execute();
               if (!var6.isSuccess()) {
                  if (var6.hasErrorDescription()) {
                     this.handleCommandResultErrorDescription(var6);
                  }
               } else if (!var6.hasErrorDescription()) {
                  this.handleCommandResult(var6);
                  this.scrContext.getPanelMediator().showPanel(var5.getContext());
                  Object var7 = var5.getContext().getCommandParameter("ports");
                  Port var8;
                  if (var5 instanceof ShowKX2KvmPortCommand && var7 != null && var7 instanceof Port && (var8 = (Port)var7).isPrimaryPort()) {
                     ArrayList var9 = (ArrayList)((RRCScreenContext)this.scrContext).getSelectedDevicesObservable().getComponent();
                     if (var9 != null && var9.size() > 0) {
                        for (MultiMonitorPort.PortConfig var12 : var8.getSecondaryPortConfigs()) {
                           Map var13 = var8.getDevice().getChildren();
                           if (var13 != null) {
                              for (Object var15 : var13.values()) {
                                 Port var16;
                                 if (var15 instanceof Port && (var16 = (Port)var15).getTargetDeviceId().equals(var12.getPortId())) {
                                    var9.set(0, var16);
                                    ShowKX2KvmPortCommand var17 = new ShowKX2KvmPortCommand(this.scrContext);
                                    var17.setAllowSecondary(true);
                                    if (var17.isExecutable()) {
                                       var17.getContext().setCommandParameter("selectedPortDevice", var16.getDevice());
                                       var6 = var17.execute();
                                       if (!var6.isSuccess() && var6.hasErrorDescription()) {
                                          this.handleCommandResultErrorDescription(var6);
                                       } else if (var6.isSuccess()) {
                                          this.handleCommandResult(var6);
                                          this.scrContext.getPanelMediator().showPanel(var17.getContext());
                                       }
                                    }
                                    break;
                                 }
                              }
                           }
                        }
                     }
                  }
               }

               this.scrContext.resetDefaultFocus();
            }
         }
      }

      this.actionJustPerformed = true;
   }

   protected void handleCommandResult(CommandResult var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   protected void handleCommandResultErrorDescription(CommandResult var1) {
      if (var1 != null) {
         StringBuffer var2 = new StringBuffer("");
         if (var1.getErrorDescription() != null && var1.getErrorDescription().length > 0) {
            for (int var3 = 0; var3 < var1.getErrorDescription().length; var3++) {
               var2.append(var1.getErrorDescription()[var3]);
               var2.append("\n");
            }
         } else if (var1.getStatusMessage() != null) {
            var2.append(var1.getStatusMessage());
         } else {
            var2.append("No command result info.");
         }

         CommonPopups.showCommandResultErrorMessage(var2.toString(), null, this.scrContext);
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   @Override
   public void itemStateChanged(ItemEvent var1) {
   }

   public boolean isActionJustPerformed() {
      boolean var1 = this.actionJustPerformed;
      this.actionJustPerformed = false;
      return var1;
   }
}
