package com.raritan.tools.ui.components;

import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.ShellInternalFrame;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.beans.PropertyVetoException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Observable;
import javaclientlib.utils.RRCLogger;
import javax.swing.BorderFactory;
import javax.swing.JDesktopPane;
import javax.swing.JInternalFrame;
import javax.swing.JLayeredPane;
import javax.swing.JPanel;

public class RaritanDesktopPane extends JDesktopPane implements MultyObserverComponentInterface {
   private static final long serialVersionUID = -4676488084431544444L;
   static final Integer COMMON_PANEL_LAYER = DEFAULT_LAYER;
   static final Integer INTERNAL_FRAME_LAYER = new Integer(20);
   private JLayeredPane commonPane;
   private JPanel emptyPanel;
   private final HashMap observables = new HashMap();
   private RRCScreenContext scrContext;

   public RaritanDesktopPane(RRCScreenContext var1) {
      this.addComponentListener(new RaritanDesktopPane.DesktopComponentAdapter());
      this.createEmptyPanel();
      this.setBackground(this.emptyPanel.getBackground());
      this.setBorder(BorderFactory.createLoweredBevelBorder());
      this.setCommonPanelLayer();
      this.scrContext = var1;
   }

   public void addAbstractDisplayComponent(AbstractDisplay var1) {
      this.resizeComponents();
      if (var1.isInternalFrame()) {
         ShellInternalFrame var2 = var1.getShellInternalFrame();
         if (var2.getDesktopPane() == null) {
            this.setLayer(var2, INTERNAL_FRAME_LAYER);
            this.add(var2, INTERNAL_FRAME_LAYER);
            this.setInternalFrameVisible(var2, true);
         }
      } else {
         int var5 = this.commonPane.getComponentCountInLayer(COMMON_PANEL_LAYER);
         if (var5 > 0) {
            Component[] var3 = this.commonPane.getComponentsInLayer(COMMON_PANEL_LAYER);

            for (int var4 = 0; var4 < var5; var4++) {
               this.commonPane.remove(var3[var4]);
            }
         }

         this.commonPane.setLayer(var1, COMMON_PANEL_LAYER);
         this.commonPane.add(var1, COMMON_PANEL_LAYER);
      }

      this.revalidate();
   }

   public void setInternalFrameVisible(ShellInternalFrame var1, boolean var2) {
      var1.setVisible(var2);
   }

   private void createEmptyPanel() {
      this.emptyPanel = new JPanel(new BorderLayout());
   }

   private void setCommonPanelLayer() {
      this.commonPane = new JLayeredPane();
      this.commonPane.setLayout(new GridLayout());
      this.setLayer(this.commonPane, DEFAULT_LAYER);
      this.add(this.commonPane, DEFAULT_LAYER);
   }

   protected void resizeComponents() {
      Dimension var1 = this.getSize();
      this.commonPane.setSize(var1);
   }

   @Override
   public void update(Observable var1, Object var2) {
      try {
         Object var3 = null;
         if (this.scrContext != null
            && this.scrContext.getSelectedDevicesObservable() != null
            && this.scrContext.getSelectedDevicesObservable().getComponent() != null) {
            ArrayList var4 = (ArrayList)this.scrContext.getSelectedDevicesObservable().getComponent();
            if (var4.get(0) != null) {
               var3 = (Device)var4.get(0);
               if (var3 instanceof Port) {
                  Port var5 = (Port)var3;
                  if (var5.isConnected()) {
                     if (var5.getView() != null) {
                        ShellInternalFrame var6 = var5.getView().getShellInternalFrame();
                        if (var6 != null) {
                           if (var6.isIcon()) {
                              var6.setIcon(false);
                           }

                           var6.setSelected(true);
                           this.scrContext.resetDefaultFocus();
                        }
                     } else if (this.getSelectedFrame() != null) {
                        this.getSelectedFrame().setSelected(false);
                     }
                  } else if (this.getSelectedFrame() != null) {
                     this.getSelectedFrame().setSelected(false);
                  }
               } else if (this.getSelectedFrame() != null) {
                  this.getSelectedFrame().setSelected(false);
               }
            }
         }
      } catch (PropertyVetoException var7) {
         RRCLogger.logException(var7);
      }
   }

   @Override
   public void addObservable(Observable var1) {
      this.observables.put(this.hashCode() + "", this);
      var1.addObserver(this);
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public JInternalFrame getSelectedFrame() {
      JInternalFrame[] var1 = this.getAllFrames();

      for (int var2 = 0; var2 < var1.length; var2++) {
         if (var1[var2].isSelected()) {
            return var1[var2];
         }
      }

      return super.getSelectedFrame();
   }

   class DesktopComponentAdapter extends ComponentAdapter {
      public DesktopComponentAdapter() {
      }

      @Override
      public void componentResized(ComponentEvent var1) {
         super.componentResized(var1);
         RaritanDesktopPane.this.resizeComponents();
         RaritanDesktopPane.this.commonPane.revalidate();
      }
   }
}
