package com.raritan.tools.ui.panes;

import com.raritan.rrc.data.BladeChassis;
import com.raritan.rrc.data.Device;
import com.raritan.rrc.data.DeviceConnector;
import com.raritan.rrc.data.IPReach;
import com.raritan.rrc.data.KvmPort;
import com.raritan.rrc.data.Paragon;
import com.raritan.rrc.data.Port;
import com.raritan.rrc.data.VirtualBladeChassis;
import com.raritan.rrc.ui.RRCScreenContext;
import com.raritan.rrc.ui.components.NavigatorRenderer;
import com.raritan.rrc.ui.controller.DeviceTreeController;
import com.raritan.rrc.ui.models.DeviceDisplayLabelExtractor;
import com.raritan.rrc.ui.models.DeviceMouseListener;
import com.raritan.rrc.ui.models.FilteredTreeTableModel;
import com.raritan.rrc.ui.models.IPViewComparator;
import com.raritan.rrc.ui.models.NameViewComparator;
import com.raritan.rrc.util.MPCUtil;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandTree;
import com.raritan.tools.ui.components.MultyObserverComponentInterface;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.util.StringTreeNode;
import java.awt.GridLayout;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Observable;
import java.util.SortedMap;
import java.util.TreeMap;
import javaclientlib.utils.RRCLogger;
import javax.swing.ImageIcon;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTree;
import javax.swing.SwingUtilities;
import javax.swing.ToolTipManager;
import javax.swing.UIManager;
import javax.swing.event.TreeModelEvent;
import javax.swing.event.TreeModelListener;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.MutableTreeNode;
import javax.swing.tree.TreePath;

public class BaseTreePanel extends AbstractDisplay implements TreeSelectionListener, MultyObserverComponentInterface {
   private DefaultMutableTreeNode rootNode;
   private TreePath rootPath;
   private DefaultTreeModel treeModel;
   private CommandTree tree;
   private JScrollPane scrollPane;
   private final HashMap observables = new HashMap();
   private TreeMap itemsMap = new TreeMap();
   private HashMap hashMap = new HashMap();
   private ArrayList connectedDevicesList = new ArrayList();
   private Device device;
   private NavigatorRenderer deviceTreeRenderer;
   private boolean treeRelaoding;
   private String unknown;
   private String devLabel;
   private String ipLabel;
   private String hostLabel;
   private String scanLabel;
   private int selectedTab = 0;

   public BaseTreePanel(ScreenContext var1) {
      super(var1);
      super.setLayout(new GridLayout(1, 0));
      this.setTreeProperties();
      this.initTree();
      this.scrollPane = new JScrollPane(this.tree);
      this.add(this.scrollPane);
   }

   @Override
   public void valueChanged(TreeSelectionEvent var1) {
      if (var1 != null && !this.treeRelaoding) {
         TreePath[] var2 = var1.getPaths();
         if (var2 != null && var2.length > 0) {
            TreePath var3 = null;
            DefaultMutableTreeNode var4 = null;

            for (int var5 = 0; var5 < var2.length; var5++) {
               var3 = var2[var5];
               if (var1.isAddedPath(var5)) {
                  var4 = (DefaultMutableTreeNode)var3.getLastPathComponent();
                  if (var4 != null) {
                     if (this.selectedTab != 3) {
                        if (var4.getUserObject() instanceof Device) {
                           Device var19 = (Device)var4.getUserObject();
                           if (this.scrContext != null && ((RRCScreenContext)this.scrContext).getSelectedDevicesObservable() != null) {
                              MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, var19);
                              break;
                           }
                        }
                     } else {
                        try {
                           TreePath[] var6 = this.tree.getSelectionPaths();
                           if (var6 != null && var6.length > 1) {
                              for (int var7 = 0; var7 < var6.length; var7++) {
                                 TreePath var8 = var6[var7];
                                 DefaultMutableTreeNode var9 = (DefaultMutableTreeNode)var8.getLastPathComponent();
                                 Object var10 = var9.getUserObject();
                                 KvmPort var11 = null;
                                 if (var10 instanceof KvmPort) {
                                    var11 = (KvmPort)var10;
                                 } else {
                                    this.tree.removeSelectionPath(var6[var7]);
                                 }

                                 if (var11 != null && var11.isSecondaryPort()) {
                                    this.tree.removeSelectionPath(var6[var7]);
                                 }

                                 DefaultMutableTreeNode var12 = (DefaultMutableTreeNode)var4.getParent();
                                 if (var12 != null) {
                                    Device var13 = (Device)var12.getUserObject();
                                    if (var13 != null) {
                                       if (var13 instanceof IPReach) {
                                          if (var11 != null && var11.getDevice() != null && !var11.getDevice().getId().equals(var13.getId())) {
                                             for (int var20 = 0; var20 < var6.length - 1; var20++) {
                                                this.tree.removeSelectionPath(var6[var20]);
                                             }

                                             this.tree.setSelectionPath(var3);
                                          }
                                       } else if (var13 instanceof BladeChassis && var13 != null && var13 instanceof BladeChassis) {
                                          BladeChassis var14 = (BladeChassis)var13;
                                          if (var11 != null && var11.getDevice() != null && !var11.getDevice().getId().equals(var14.getBaseDevice().getId())) {
                                             for (int var15 = 0; var15 < var6.length - 1; var15++) {
                                                this.tree.removeSelectionPath(var6[var15]);
                                             }

                                             this.tree.setSelectionPath(var3);
                                          }
                                       }
                                    }
                                 }
                              }
                           }
                        } catch (Exception var16) {
                           RRCLogger.logException(var16);
                        }
                     }
                  }
               }
            }
         }
      }
   }

   public void clear() {
      this.rootNode.removeAllChildren();
      this.treeModel.reload();
   }

   public void removeCurrentNode() {
      TreePath var1 = this.tree.getSelectionPath();
      if (var1 != null) {
         DefaultMutableTreeNode var2 = (DefaultMutableTreeNode)var1.getLastPathComponent();
         var var3 = (MutableTreeNode & MutableTreeNode)var2.getParent();
         if (var3 != null) {
            this.treeModel.removeNodeFromParent(var2);
            return;
         }
      }
   }

   public DefaultMutableTreeNode addObject(Object var1) {
      Object var2 = null;
      TreePath var3 = this.tree.getSelectionPath();
      if (var3 == null) {
         var2 = this.rootNode;
      } else {
         var2 = (DefaultMutableTreeNode)var3.getLastPathComponent();
      }

      return this.addObject((DefaultMutableTreeNode)var2, var1, true);
   }

   public DefaultMutableTreeNode addObject(DefaultMutableTreeNode var1, Object var2) {
      return this.addObject(var1, var2, false);
   }

   public DefaultMutableTreeNode addObject(DefaultMutableTreeNode var1, Object var2, boolean var3) {
      DefaultMutableTreeNode var4 = new DefaultMutableTreeNode(var2);
      if (var1 == null) {
         var1 = this.rootNode;
      }

      this.treeModel.insertNodeInto(var4, var1, var1.getChildCount());
      if (var3) {
         this.tree.scrollPathToVisible(new TreePath(var4.getPath()));
      }

      return var4;
   }

   public boolean deleteDeviceIfAvailable(String var1) {
      assert SwingUtilities.isEventDispatchThread();

      if (this.hashMap.containsKey(var1)) {
         this.deleteDevice(var1);
         return true;
      } else {
         return false;
      }
   }

   public void deleteDevice(String var1) {
      assert SwingUtilities.isEventDispatchThread();

      SortedMap var2 = this.itemsMap.headMap(var1);
      int var3 = var2.size();
      Object var4 = this.itemsMap.remove(var1);

      assert var4 != null;

      var4 = this.hashMap.remove(var1);

      assert var4 != null;

      MutableTreeNode var5 = (MutableTreeNode)this.treeModel.getChild(this.rootNode, var3);

      assert var5 != null;

      if (var5 != null) {
         this.treeModel.removeNodeFromParent(var5);
      }
   }

   public void addDevice(String var1, Device var2) {
      assert SwingUtilities.isEventDispatchThread();

      Object var3 = this.hashMap.put(var1, var2);

      assert var3 == null;

      var3 = this.itemsMap.put(var1, var2);

      assert var3 == null;

      SortedMap var4 = this.itemsMap.headMap(var1);
      int var5 = var4.size();
      if (((RRCScreenContext)this.scrContext).getCreateProfileBy() != 3) {
         this.treeModel.insertNodeInto(new DefaultMutableTreeNode(var2), this.rootNode, var5);
      }
   }

   public void addConnectedDevice(Device var1) {
      assert SwingUtilities.isEventDispatchThread();

      if (var1.isConnected()) {
         Boolean var2 = this.connectedDevicesList.add(var1);
      }

      this.treeModel.insertNodeInto(new DefaultMutableTreeNode(var1), this.rootNode, 1);
   }

   public void doSort(int var1) {
      assert SwingUtilities.isEventDispatchThread();

      if (this.hashMap.size() > 0) {
         Iterator var2 = this.hashMap.values().iterator();
         IPReach var3 = null;

         while (var2.hasNext()) {
            var3 = (IPReach)var2.next();
            if (var3.isConnected() && var3.hasChildren()) {
               var3.sort(var1);
            }
         }

         this.populateTree();
      }
   }

   public void doGroup(boolean var1) {
      assert SwingUtilities.isEventDispatchThread();

      if (this.hashMap.size() > 0) {
         Iterator var2 = this.hashMap.values().iterator();
         IPReach var3 = null;

         while (var2.hasNext()) {
            var3 = (IPReach)var2.next();
            if (var3.isConnected() && var3.hasChildren()) {
               var3.showGroupView(var1);
            }
         }

         this.populateTree();
      }
   }

   public void doGroup(Device var1, boolean var2) {
      assert SwingUtilities.isEventDispatchThread();

      if (var1.isConnected() && var1.hasChildren()) {
         System.out.println("Processing group view for device:" + this.device.getIP());
         var1.showGroupView(var2);
      }

      this.populateTree();
   }

   protected void populateTree() {
      TreePath var1 = this.tree.getSelectionPath();
      this.rootNode.removeAllChildren();
      this.treeModel.reload(this.rootNode);

      try {
         Iterator var2 = this.itemsMap.keySet().iterator();

         while (var2.hasNext()) {
            this.device = (IPReach)this.itemsMap.get(var2.next());
            this.addObject(this.rootNode, this.device);
            if (this.device.isConnected()) {
               this.populatePorts(this.device);
            }
         }

         this.tree.expandRow(0);
      } catch (Exception var7) {
         this.scrContext.getLogger().logTextError(var7.getMessage());
      }

      if (var1 != null && ((DefaultMutableTreeNode)var1.getLastPathComponent()).getUserObject() instanceof Device) {
         try {
            this.treeRelaoding = true;
            this.setSelectedTreePath(var1);
         } finally {
            this.treeRelaoding = false;
         }
      }
   }

   protected void initTree() {
      this.rootNode = new DefaultMutableTreeNode(new StringTreeNode(this.bundle.getString("NavigatorRoot.name"), new ImageIcon(new byte[0])));
      this.rootPath = new TreePath(this.rootNode);
      this.unknown = this.bundle.getString("TreeDisplay.Unknown");
      this.devLabel = this.bundle.getString("Tree.Device.ToolTip.DeviceName");
      this.ipLabel = this.bundle.getString("Tree.Device.ToolTip.IPAddrs");
      this.hostLabel = this.bundle.getString("Tree.Device.ToolTip.HostName");
      this.scanLabel = this.bundle.getString("Tree.Device.ToolTip.Scan");
      this.treeModel = new FilteredTreeTableModel(this.rootNode);
      this.treeModel.addTreeModelListener(new TreeModelListener() {
         @Override
         public void treeNodesChanged(TreeModelEvent var1) {
         }

         @Override
         public void treeNodesInserted(TreeModelEvent var1) {
            this.expandRoot(var1);
         }

         @Override
         public void treeNodesRemoved(TreeModelEvent var1) {
         }

         @Override
         public void treeStructureChanged(TreeModelEvent var1) {
            this.expandRoot(var1);
         }

         private void expandRoot(TreeModelEvent var1) {
            if (BaseTreePanel.this.rootNode.getChildCount() > 0 && !BaseTreePanel.this.tree.isExpanded(BaseTreePanel.this.rootPath)) {
               Object[] var2 = var1.getPath();
               DefaultMutableTreeNode var3 = (DefaultMutableTreeNode)var2[0];
               if (var3.isRoot()) {
                  BaseTreePanel.this.tree.expandPath(BaseTreePanel.this.rootPath);
               }
            }
         }
      });
      this.tree = new CommandTree(this.treeModel, this.scrContext);
      this.tree.getSelectionModel().setSelectionMode(1);
      this.tree.setEditable(false);
      this.tree.setExpandsSelectedPaths(true);
      this.tree.setShowsRootHandles(true);
      this.tree.addTreeSelectionListener(this);
      this.deviceTreeRenderer = new NavigatorRenderer(this.scrContext, false);
      this.tree.setToggleClickCount(1);
      this.setupView(0);
      ToolTipManager.sharedInstance().registerComponent(this.tree);
      this.tree.setCellRenderer(this.deviceTreeRenderer);
      this.tree.addMouseListener(new DeviceMouseListener(this.scrContext));
   }

   private void setTreeProperties() {
      UIManager.put("Tree.expandedIcon", this.scrContext.getImageIcon(this.bundle.getString("Tree.Minus.image")));
      UIManager.put("Tree.collapsedIcon", this.scrContext.getImageIcon(this.bundle.getString("Tree.Plus.image")));
   }

   @Override
   public List getObservables() {
      return new ArrayList(this.observables.values());
   }

   @Override
   public void clearObservables() {
      if (this.observables != null && this.observables.size() > 0) {
         for (Observable var2 : this.observables.values()) {
            var2.deleteObserver(this);
         }

         this.observables.clear();
      }
   }

   @Override
   public void addObservable(Observable var1) {
      if (var1 != null) {
         this.observables.put(this.hashCode() + "", this);
         var1.addObserver(this);
      }
   }

   @Override
   public void removeObservable(Observable var1) {
      this.observables.remove(this.hashCode() + "");
      var1.deleteObserver(this);
   }

   @Override
   public void update(Observable var1, Object var2) {
      this.invokePopulateTree();
   }

   public void invokePopulateTree() {
      if (SwingUtilities.isEventDispatchThread()) {
         this.populateTree();
         this.refreshTree();
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               BaseTreePanel.this.populateTree();
               BaseTreePanel.this.refreshTree();
            }
         });
      }
   }

   public synchronized void refreshTree() {
      try {
         if (this.tree != null && this.tree.isDisplayable()) {
            this.tree.updateUI();
         }
      } catch (Exception var2) {
         RRCLogger.logException(var2);
      }
   }

   public synchronized TreePath getSelectedTreePath() {
      return this.tree.getSelectionPath();
   }

   public synchronized void setSelectedTreePath(TreePath var1) {
      this.tree.setSelectionPath(var1);
      if (var1 != null) {
         DefaultMutableTreeNode var2 = (DefaultMutableTreeNode)var1.getLastPathComponent();
         ((FilteredTreeTableModel)this.tree.getModel()).nodeChanged(var2);
      }
   }

   public void setShowWithoutTargets(boolean var1) {
      ((FilteredTreeTableModel)this.tree.getModel()).setShowWithoutTargets(var1);
      this.refreshTree();
   }

   public void setShowPowerstrips(boolean var1) {
      ((FilteredTreeTableModel)this.tree.getModel()).setShowPowerStrips(var1);
      this.refreshTree();
   }

   public void setShowTools(boolean var1) {
      ((FilteredTreeTableModel)this.tree.getModel()).setShowTools(var1);
      this.refreshTree();
   }

   public synchronized void setDeviceNodeChanged(final Device var1) {
      if (SwingUtilities.isEventDispatchThread()) {
         this._setDeviceNodeChanged(var1);
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               BaseTreePanel.this._setDeviceNodeChanged(var1);
            }
         });
      }
   }

   private synchronized void _setDeviceNodeChanged(Device var1) {
      DefaultMutableTreeNode var2 = null;
      DefaultMutableTreeNode var3 = null;
      Object var4 = null;
      int var5 = 0;

      while (var5 < this.rootNode.getChildCount()) {
         var3 = (DefaultMutableTreeNode)this.rootNode.getChildAt(var5);
         var4 = (Device)var3.getUserObject();
         if (var4.equals(var1)) {
            var2 = var3;
            break;
         }

         int var6 = 0;

         while (true) {
            label70: {
               if (var6 < var3.getChildCount()) {
                  var4 = (Device)((DefaultMutableTreeNode)var3.getChildAt(var6)).getUserObject();
                  if (!(var4 instanceof BladeChassis) && !(var4 instanceof VirtualBladeChassis)) {
                     if (!var4.equals(var1)) {
                        break label70;
                     }

                     var2 = (DefaultMutableTreeNode)var3.getChildAt(var6);
                  } else {
                     if (!var4.equals(var1)) {
                        DefaultMutableTreeNode var7 = (DefaultMutableTreeNode)var3.getChildAt(var6);
                        int var8 = 0;

                        while (true) {
                           if (var8 >= var7.getChildCount()) {
                              break label70;
                           }

                           var4 = (Device)((DefaultMutableTreeNode)var7.getChildAt(var8)).getUserObject();
                           if (var4.equals(var1)) {
                              var2 = (DefaultMutableTreeNode)var7.getChildAt(var8);
                              break label70;
                           }

                           var8++;
                        }
                     }

                     var2 = (DefaultMutableTreeNode)var3.getChildAt(var6);
                  }
               }

               var5++;
               break;
            }

            var6++;
         }
      }

      if (var2 != null) {
         try {
            ((FilteredTreeTableModel)this.tree.getModel()).nodeChanged(var2);
         } catch (Exception var9) {
         }
      }
   }

   public synchronized void selNodeChanged() {
      if (this.tree != null) {
         TreePath var1 = this.tree.getSelectionPath();
         if (var1 != null) {
            DefaultMutableTreeNode var2 = (DefaultMutableTreeNode)var1.getLastPathComponent();
            ((FilteredTreeTableModel)this.tree.getModel()).nodeChanged(var2);
         }
      }
   }

   protected synchronized void populatePorts(Device var1) {
      DefaultMutableTreeNode var2 = this.findNodeContaining(null, var1);
      if (var2 != null) {
         TreePath var3 = this.getSelectedTreePath();
         this.populatePorts(var2, var1, true);
         this.setSelectedTreePath(var3);
      }
   }

   protected void populatePorts(DefaultMutableTreeNode var1, Device var2, boolean var3) {
      try {
         if (var1 != null) {
            if (var2.hasChildren()) {
               var1.removeAllChildren();
               this.treeModel.reload(var1);
            }

            Map var4 = var2.getChildren();
            Device[] var5 = new Device[var4.size()];
            Iterator var6 = var4.keySet().iterator();

            for (int var7 = 0; var6.hasNext(); var7++) {
               var5[var7] = (Device)var4.get(var6.next());
            }

            for (int var11 = 0; var11 < var5.length; var11++) {
               Device var12 = var5[var11];
               var12.addPropertyChangeListener(DeviceTreeController.getInstance((RRCScreenContext)this.scrContext));
               if (!(var12 instanceof Port) || !((Port)var12).getPortType().equals("MultiMonitorPort")) {
                  DefaultMutableTreeNode var8 = this.addObject(var1, var12);
                  if (var12 instanceof IPReach) {
                     IPReach var9 = (IPReach)var12;
                     if (var9.isConnected()) {
                        this.populatePorts(var8, var9, true);
                     }
                  } else if (var12 instanceof BladeChassis || var12 instanceof VirtualBladeChassis) {
                     this.populatePorts(var8, var12, false);
                  }
               }
            }

            if (var3) {
               this.tree.expandPath(new TreePath(var1.getPath()));
            }
         }
      } catch (Exception var10) {
      }
   }

   protected synchronized DefaultMutableTreeNode findNodeContaining(DefaultMutableTreeNode var1, Object var2) {
      if (var1 == null) {
         var1 = this.rootNode;
      }

      if (var1 != null) {
         Object var3 = var1.getUserObject();
         if (var3 == var2) {
            return var1;
         }

         int var4 = var1.getChildCount();

         for (int var5 = 0; var5 < var4; var5++) {
            DefaultMutableTreeNode var6 = (DefaultMutableTreeNode)var1.getChildAt(var5);
            var6 = this.findNodeContaining(var6, var2);
            if (var6 != null) {
               return var6;
            }
         }
      }

      return null;
   }

   public void tabChanged(JTabbedPane var1, JPanel var2, JPanel var3, JPanel var4, JPanel var5) {
      int var6 = var1.getSelectedIndex();
      this.selectedTab = var6;
      if (var6 == 0) {
         this.setupView(var6);
         this.populateTree();
         this.tree.getSelectionModel().setSelectionMode(1);
         var3.removeAll();
         var4.removeAll();
         var5.removeAll();
         var2.add(this, "Center");
         var2.revalidate();
      } else if (var6 == 1) {
         this.setupView(var6);
         this.populateTree();
         this.tree.getSelectionModel().setSelectionMode(1);
         var2.removeAll();
         var4.removeAll();
         var5.removeAll();
         var3.add(this, "Center");
         var3.revalidate();
      } else if (var6 == 2) {
         this.setupView(var6);
         this.populateTree();
         this.tree.getSelectionModel().setSelectionMode(1);
         var2.removeAll();
         var3.removeAll();
         var5.removeAll();
         var4.add(this, "Center");
         var4.revalidate();
      } else {
         DeviceTreeController.getInstance((RRCScreenContext)this.scrContext).stopBroadcastAndUpdateDevices();
         this.setupView(var6);
         this.populateTree();
         this.tree.getSelectionModel().setSelectionMode(4);
         var2.removeAll();
         var3.removeAll();
         var4.removeAll();
         var5.add(this, "Center");
         var5.revalidate();
      }

      if (((RRCScreenContext)this.scrContext).getSelectView() != null) {
         ((RRCScreenContext)this.scrContext).getSelectView().setViewFocus();
      }
   }

   public synchronized void deselectTree() {
      this.tree.clearSelection();
      MPCUtil.notifyObservers((RRCScreenContext)this.scrContext, null);
   }

   public void invokePopulatePorts(final Device var1) {
      if (SwingUtilities.isEventDispatchThread()) {
         this.populatePorts(var1);
         this.refreshTree();
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               BaseTreePanel.this.populatePorts(var1);
               BaseTreePanel.this.refreshTree();
            }
         });
      }
   }

   public synchronized void removePorts(Device var1) {
      DefaultMutableTreeNode var2 = null;
      if (!(var1 instanceof Paragon)) {
         Object var3 = null;

         for (int var4 = 0; var4 < this.rootNode.getChildCount(); var4++) {
            var3 = (DefaultMutableTreeNode)this.rootNode.getChildAt(var4);
            if (var3.getUserObject().equals(var1)) {
               var2 = (DefaultMutableTreeNode)var3;
            }
         }
      } else {
         TreePath var7 = this.tree.getSelectionPath();
         if (var7 != null) {
            var2 = (DefaultMutableTreeNode)var7.getLastPathComponent();
         }
      }

      if (var2 != null) {
         DefaultMutableTreeNode var8 = null;
         Paragon var10 = null;

         for (int var5 = 0; var5 < var2.getChildCount(); var5++) {
            var8 = (DefaultMutableTreeNode)var2.getChildAt(var5);
            if (var8.getUserObject() instanceof Paragon) {
               var10 = (Paragon)var8.getUserObject();
               var10.disconnect();
            }
         }

         var2.removeAllChildren();
         this.treeModel.reload(var2);
         this.tree.collapseRow(this.tree.getRowForPath(this.tree.getSelectionPath()));
      }
   }

   public synchronized void setSelectedDevice(Device var1) {
      DefaultMutableTreeNode var2 = null;
      DefaultMutableTreeNode var3 = null;
      Object var4 = null;

      for (int var5 = 0; var5 < this.rootNode.getChildCount(); var5++) {
         var3 = (DefaultMutableTreeNode)this.rootNode.getChildAt(var5);
         var4 = (Device)var3.getUserObject();
         if (var4.equals(var1)) {
            var2 = var3;
            break;
         }

         for (int var6 = 0; var6 < var3.getChildCount(); var6++) {
            var4 = (Device)((DefaultMutableTreeNode)var3.getChildAt(var6)).getUserObject();
            if (var4 instanceof BladeChassis || var4 instanceof VirtualBladeChassis) {
               DefaultMutableTreeNode var7 = (DefaultMutableTreeNode)var3.getChildAt(var6);

               for (int var8 = 0; var8 < var7.getChildCount(); var8++) {
                  var4 = (Device)((DefaultMutableTreeNode)var7.getChildAt(var8)).getUserObject();
                  if (var4.equals(var1)) {
                     var2 = (DefaultMutableTreeNode)var7.getChildAt(var8);
                     if (var2 != null) {
                        TreePath var9 = new TreePath(var2.getPath());
                        this.setSelectedTreePath(var9);
                     }

                     return;
                  }
               }
            }

            if (var4.equals(var1)) {
               var2 = (DefaultMutableTreeNode)var3.getChildAt(var6);
               break;
            }
         }
      }

      if (var2 != null) {
         TreePath var14 = new TreePath(var2.getPath());
         this.setSelectedTreePath(var14);
      }
   }

   private void setupView(int var1) {
      switch (var1) {
         case 0:
            DeviceDisplayLabelExtractor var9 = new DeviceDisplayLabelExtractor(0, this.unknown, this.devLabel, this.ipLabel, this.hostLabel, this.scanLabel);
            this.deviceTreeRenderer.setDeviceDisplayLabelExtractor(var9);
            NameViewComparator var12 = new NameViewComparator(this.hashMap, var9);
            this.itemsMap = new TreeMap(var12);
            this.itemsMap.putAll(this.hashMap);

            assert this.itemsMap.size() == this.hashMap.size();
            break;
         case 1:
            DeviceDisplayLabelExtractor var8 = new DeviceDisplayLabelExtractor(1, this.unknown, this.devLabel, this.ipLabel, this.hostLabel, this.scanLabel);
            this.deviceTreeRenderer.setDeviceDisplayLabelExtractor(var8);
            IPViewComparator var11 = new IPViewComparator(this.hashMap, var8);
            this.itemsMap = new TreeMap(var11);
            this.itemsMap.putAll(this.hashMap);

            assert this.itemsMap.size() == this.hashMap.size();
            break;
         case 2:
            DeviceDisplayLabelExtractor var7 = new DeviceDisplayLabelExtractor(2, this.unknown, this.devLabel, this.ipLabel, this.hostLabel, this.scanLabel);
            this.deviceTreeRenderer.setDeviceDisplayLabelExtractor(var7);
            NameViewComparator var10 = new NameViewComparator(this.hashMap, var7);
            this.itemsMap = new TreeMap(var10);
            this.itemsMap.putAll(this.hashMap);

            assert this.itemsMap.size() == this.hashMap.size();
            break;
         case 3:
            DeviceDisplayLabelExtractor var2 = new DeviceDisplayLabelExtractor(3, this.unknown, this.devLabel, this.ipLabel, this.hostLabel, this.scanLabel);
            this.deviceTreeRenderer.setDeviceDisplayLabelExtractor(var2);
            HashMap var3 = new HashMap();
            var3.putAll(this.hashMap);
            Iterator var4 = var3.values().iterator();

            while (var4.hasNext()) {
               Device var5 = (Device)var4.next();
               DeviceConnector var6 = var5.getDeviceConnector();
               if (var6 == null) {
                  var4.remove();
               } else if (!var5.isScanSupported()) {
                  var4.remove();
               }
            }

            NameViewComparator var13 = new NameViewComparator(var3, var2);
            this.itemsMap = new TreeMap(var13);
            this.itemsMap.putAll(var3);
      }
   }

   @Override
   protected void feedCommandContext(CommandContext var1) {
   }

   @Override
   public void fillComponents(CommandContext var1) {
   }

   @Override
   public void makeLayout() {
   }

   public static Enumeration saveExpansionState(JTree var0) {
      return var0.getExpandedDescendants(new TreePath(var0.getModel().getRoot()));
   }

   public static void loadExpansionState(JTree var0, Enumeration var1) {
      if (var1 != null) {
         while (var1.hasMoreElements()) {
            TreePath var2 = (TreePath)var1.nextElement();
            var0.expandPath(var2);
         }
      }
   }
}
