package com.raritan.tools.ui.panes.displays;

import com.raritan.tools.commands.CancelButtonCommand;
import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.CommonPopups;
import java.awt.Component;
import java.awt.Container;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowFocusListener;
import javax.swing.AbstractAction;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.KeyStroke;
import javax.swing.text.JTextComponent;

public abstract class AbstractDisplay extends JPanel implements ActionListener, WindowFocusListener, FocusListener {
   protected static final String CMD_HELP = "CMD_HELP";
   private Shell shell;
   protected ShellInternalFrame shellInternalFrame;
   private CommandContext ctx;
   protected Component parentComponent = null;
   protected boolean resizable = false;
   protected boolean isDialog = false;
   protected boolean isNewPanel = false;
   protected boolean isInternalFrame = false;
   protected boolean isParentLimited = false;
   protected ScreenContext scrContext;
   protected RaritanPropertyResourceBundle bundle;
   protected CommandButton ok;
   protected CommandButton cancel;
   protected CommandButton apply;
   protected String helpURL = this.getClass().getName();
   protected Component helpNode = null;

   public AbstractDisplay(ScreenContext var1) {
      this.scrContext = var1;
      this.bundle = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.resizable = false;
      this.shell = new Shell(this.scrContext);
      this.getInputMap(2).put(KeyStroke.getKeyStroke(10, 0), "OK");
      this.getInputMap(2).put(KeyStroke.getKeyStroke(27, 0), "Cancel");
      this.getActionMap().put("OK", new AbstractAction() {
         private static final long serialVersionUID = 7832166575272756880L;

         @Override
         public void actionPerformed(ActionEvent var1) {
            if (AbstractDisplay.this.ok != null) {
               AbstractDisplay.this.ok.doClick();
            }
         }
      });
      this.getActionMap().put("Cancel", new AbstractAction() {
         private static final long serialVersionUID = -5020860591759224987L;

         @Override
         public void actionPerformed(ActionEvent var1) {
            if (AbstractDisplay.this.cancel != null) {
               AbstractDisplay.this.cancel.doClick();
            }
         }
      });
   }

   public void clearMaps() {
      try {
         this.getActionMap().remove("OK");
         System.out.println("OK action map cleared");
      } catch (Exception var5) {
         System.out.println("OK action map exception " + var5.getMessage());
      }

      try {
         this.getActionMap().remove("Cancel");
         System.out.println("Cancel action map cleared");
      } catch (Exception var4) {
         System.out.println("Cancel action map exception " + var4.getMessage());
      }

      try {
         this.getInputMap(2).remove(KeyStroke.getKeyStroke(10, 0));
         System.out.println("Enter key map cleared");
      } catch (Exception var3) {
         System.out.println("Enter key map exception " + var3.getMessage());
      }

      try {
         this.getInputMap(2).remove(KeyStroke.getKeyStroke(27, 0));
         System.out.println("Escape key map cleared");
      } catch (Exception var2) {
         System.out.println("Escape key map exception " + var2.getMessage());
      }
   }

   public void setCommandContext(CommandContext var1) {
      this.ctx = var1;
   }

   public CommandContext getCommandContext() {
      return this.ctx;
   }

   public abstract void makeLayout();

   public boolean isDialog() {
      return this.isDialog;
   }

   public boolean isInternalFrame() {
      return this.isInternalFrame;
   }

   public boolean isParentLimited() {
      return this.isParentLimited;
   }

   public void setShell(String var1) {
      if (this.isParentLimited() && this.parentComponent != null) {
         this.shell = new Shell(this.parentComponent, this.scrContext);
      }

      this.shell.setTitle(var1);
      this.shell.setResizable(this.resizable);
      this.shell.getContentPane().add(this);
      this.shell.setModal(true);
      this.shell.pack();
      this.shell.setVisible(false);
      this.shell.setClosable(true);
   }

   public void setShellInternalFrame(String var1) {
      this.shellInternalFrame = new ShellInternalFrame();
      this.shellInternalFrame.setTitle(var1);
      this.shellInternalFrame.setResizable(this.resizable);
      this.shellInternalFrame.setClosable(true);
      this.shellInternalFrame.pack();
      this.shellInternalFrame.setVisible(false);
      this.shellInternalFrame.getContentPane().add(this);
   }

   public Shell getShell() {
      return this.shell;
   }

   public ShellInternalFrame getShellInternalFrame() {
      return this.shellInternalFrame;
   }

   public JPanel doButtonWidget() {
      this.ok = new CommandButton("OK", this.scrContext);
      this.ok.addActionListener(this);
      this.cancel = new CommandButton("Cancel", this.scrContext);
      this.cancel.setCommand(new CancelButtonCommand(this.scrContext));
      this.cancel.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(2));
      var1.add(this.ok);
      var1.add(this.cancel);
      return var1;
   }

   protected static String getClassName(Object var0) {
      String var1 = var0.getClass().getName();
      int var2 = var1.lastIndexOf(".");
      return var1.substring(var2 + 1);
   }

   @Override
   public void focusGained(FocusEvent var1) {
      Component var2 = var1.getOppositeComponent();
      if (var2 != null) {
         this.helpNode = var2;
      }
   }

   @Override
   public void focusLost(FocusEvent var1) {
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      this.scrContext.getLogger().logTextDebug("started");
      Object var2 = var1.getSource();
      if (var2 instanceof CommandHolder && this.checkPassedCommandConfirm(var2)) {
         Command var3 = ((CommandHolder)var2).getCommand();
         this.scrContext.getLogger().logTextDebug("command is " + var3.getKey());
         this.scrContext.getLogger().logTextDebug("cmd.isExecutable() " + var3.isExecutable());
         if (var3.isExecutable()) {
            this.executeCommand(var3);
            if (this.ok != null) {
               this.ok.setEnabled(true);
            }
         }
      }

      this.scrContext.getLogger().logTextDebug("finished");
   }

   protected void setVisibleAfterCommand(Command var1) {
      boolean var2 = this.getShell().isVisible();
      if (var1 != null && this.cancel != null && var1.equals(this.cancel.getCommand())) {
         var2 = false;
      } else if (var1 != null && this.ok != null && var1.equals(this.ok.getCommand())) {
         var2 = false;
      }

      if (this.getShell().isVisible() != var2) {
         this.getShell().setVisible(var2);
         if (!var2) {
            this.onPasivateDisplay();
         }
      }
   }

   protected boolean checkPassedCommandConfirm(Object var1) {
      boolean var2 = true;
      if (var1 instanceof ConfirmableCommandInterface) {
         var2 = !((ConfirmableCommandInterface)var1).getConfirmation();
      }

      if (!var2) {
         var2 = CommonPopups.showConfirmationDialog(
               this.bundle.getString("confirmation.dialog.command.execution.title"),
               this.bundle.getString("confirmation.dialog.command.execution.text"),
               null,
               this.scrContext
            )
            == 2;
      }

      return var2;
   }

   protected CommandResult executeCommand(Command var1) {
      var1.getContext(true);
      this.setCommandContext(var1.getContext());
      this.feedCommandContext(var1.getContext());
      CommandResult var2 = var1.execute();
      if (!var2.isSuccess() && !var2.getStatusMessage().equals("")) {
         this.handleCommandResultErrorDescription(var2);
      } else {
         this.handleCommandResult(var2);
         this.setVisibleAfterCommand(var1);
         this.scrContext.getPanelMediator().showPanel(var1.getContext());
      }

      return var2;
   }

   protected void handleCommandResult(CommandResult var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   protected void handleCommandResultErrorDescription(CommandResult var1) {
      if (var1 != null) {
         StringBuffer var2 = new StringBuffer("");
         if (var1.getErrorDescription() != null && var1.getErrorDescription().length > 0) {
            for (int var3 = 0; var3 < var1.getErrorDescription().length; var3++) {
               var2.append(var1.getErrorDescription()[var3]);
               var2.append("\n");
            }
         } else if (var1.getStatusMessage() != null) {
            var2.append(var1.getStatusMessage());
         } else {
            var2.append("No command result info.");
         }

         CommonPopups.showCommandResultErrorMessage(var2.toString(), this, this.scrContext);
         this.scrContext.getLogger().logStatus(var1.getStatusMessage());
         this.scrContext.getLogger().logTextInfo(var1.getStatusMessage());
      }
   }

   @Override
   public void windowLostFocus(WindowEvent var1) {
      ShellFocusObserver.setFocusOnLast(this.scrContext);
   }

   @Override
   public void windowGainedFocus(WindowEvent var1) {
   }

   public abstract void fillComponents(CommandContext var1);

   protected abstract void feedCommandContext(CommandContext var1);

   public void onPasivateDisplay() {
   }

   public void onActivateDisplay() {
   }

   public void reset() {
      resetControls(this);
   }

   public static void resetControls(Container var0) {
      int var1 = var0.getComponentCount();
      Object var2 = null;

      for (int var3 = 0; var3 < var1; var3++) {
         var2 = var0.getComponent(var3);
         resetControl((Component)var2);
         if (var2 instanceof Container) {
            resetControls((Container)var2);
         }
      }
   }

   public static void resetControl(Component var0) {
      if (var0 instanceof JTextComponent) {
         ((JTextComponent)var0).setText("");
      } else if (var0 instanceof JComboBox) {
         try {
            ((JComboBox)var0).setSelectedIndex(1);
         } catch (IllegalArgumentException var3) {
         }
      } else if (var0 instanceof JCheckBox) {
         try {
            ((JCheckBox)var0).setSelected(false);
         } catch (IllegalArgumentException var2) {
         }
      }
   }

   public boolean isNewPanel() {
      return this.isNewPanel;
   }

   public void setNewPanel(boolean var1) {
      this.isNewPanel = var1;
   }

   public boolean isBlockingDialog() {
      return false;
   }

   public void setDefaultFocussedComponent() {
   }
}
