package com.raritan.tools.ui.panes.displays;

import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.util.Util;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Point;
import java.awt.Toolkit;
import java.awt.event.WindowEvent;
import java.awt.event.WindowFocusListener;
import java.awt.event.WindowListener;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;

public class Shell extends JDialog implements WindowListener, WindowFocusListener {
   private static final long serialVersionUID = 941050393440965891L;
   private static final Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
   private static final Point screenCenter = new Point(screenSize.width / 2, screenSize.height / 2);
   private int defaultCloseOperation = 1;
   private ShellComponentAdapter sca;
   protected ScreenContext scrContext;
   private boolean alwaysOnTopFlag = false;
   private boolean blockingDialog = false;

   public Shell(ScreenContext var1) {
      super(JOptionPane.getFrameForComponent(var1.getApplication().getContentPane()), true);
      this.scrContext = var1;
      this.initShell();
      this.setAlwaysOnTop(true);
      this.setModal(true);
      this.setFocusable(true);
   }

   public Shell(Component var1, ScreenContext var2) {
      super(JOptionPane.getFrameForComponent(var2.getApplication().getContentPane()), true);
      this.scrContext = var2;
      this.initShell();
      this.sca = new ShellComponentAdapter();
      this.sca.setFloatingParent(var1);
      this.addComponentListener(this.sca);
   }

   private void initShell() {
      this.addWindowListener(this);
      this.setWindowFocusListener(true);
      this.setFocusableWindowState(true);
   }

   public ShellComponentAdapter getShellComponentAdapter() {
      return this.sca;
   }

   public void setCentered() {
      int var1 = this.getWidth() / 2;
      int var2 = this.getHeight() / 2;
      Point var3 = new Point(screenCenter.x - var1, screenCenter.y - var2);
      this.setLocation(var3);
   }

   public void setWindowFocusListener(boolean var1) {
      if (var1) {
         this.addWindowFocusListener(this);
      } else {
         this.removeWindowFocusListener(this);
      }
   }

   @Override
   public void setVisible(final boolean var1) {
      if (var1) {
         ShellFocusObserver.addShellVisible(this, this.scrContext);
      } else {
         ShellFocusObserver.removeShellVisible(this, this.scrContext);
      }

      Util.jre17WorkaroundInheritAlwaysOnTop(this);
      if (this.isBlockingDialog()) {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               Shell.super.setVisible(var1);
               if (var1) {
                  Shell.this.toFront();
               }
            }
         });
      } else {
         super.setVisible(var1);
      }

      if (!var1) {
         this.scrContext.getApplication().addDisposedShell(this);
      }
   }

   @Override
   public void windowGainedFocus(WindowEvent var1) {
   }

   @Override
   public void windowLostFocus(WindowEvent var1) {
      ShellFocusObserver.setFocusOnLast(this.scrContext);
   }

   public void setClosable(boolean var1) {
      if (var1) {
         this.defaultCloseOperation = 1;
      } else {
         this.defaultCloseOperation = 0;
      }

      this.setDefaultCloseOperation(this.defaultCloseOperation);
   }

   @Override
   protected void processWindowEvent(WindowEvent var1) {
      WindowListener[] var2 = this.getWindowListeners();
      if (var2.length > 0) {
         for (int var3 = 0; var3 < var2.length; var3++) {
            WindowListener var4 = var2[var3];
            switch (var1.getID()) {
               case 200:
                  this.windowOpened(var1);
                  break;
               case 201:
                  var4.windowClosing(var1);
                  break;
               case 202:
                  var4.windowClosed(var1);
                  break;
               case 203:
                  var4.windowIconified(var1);
                  break;
               case 204:
                  var4.windowDeiconified(var1);
                  break;
               case 205:
                  var4.windowActivated(var1);
                  break;
               case 206:
                  var4.windowDeactivated(var1);
            }
         }
      }
   }

   @Override
   public void windowOpened(WindowEvent var1) {
   }

   @Override
   public void windowClosing(WindowEvent var1) {
      switch (this.defaultCloseOperation) {
         case 0:
         default:
            break;
         case 1:
            this.setVisible(false);
            break;
         case 2:
            this.setVisible(false);
            this.dispose();
      }
   }

   @Override
   public void windowActivated(WindowEvent var1) {
   }

   @Override
   public void windowClosed(WindowEvent var1) {
   }

   @Override
   public void windowDeactivated(WindowEvent var1) {
      if (this.alwaysOnTopFlag) {
         this.toFront();
      }
   }

   @Override
   public void windowDeiconified(WindowEvent var1) {
   }

   @Override
   public void windowIconified(WindowEvent var1) {
   }

   public boolean isBlockingDialog() {
      return this.blockingDialog;
   }

   public void setBlockingDialog(boolean var1) {
      this.blockingDialog = var1;
   }
}
