package com.raritan.tools.ui.panes.mediator;

import com.raritan.tools.commands.CommandContext;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.RaritanDesktopPane;
import com.raritan.tools.ui.panes.LogPanel;
import com.raritan.tools.ui.panes.RaritanStatusBarPanel;
import com.raritan.tools.ui.panes.displays.AbstractDisplay;
import com.raritan.tools.ui.panes.displays.AbstractDisplayStrategy;
import com.raritan.tools.ui.panes.displays.Shell;
import com.raritan.tools.ui.panes.displays.ShellFocusObserver;
import com.raritan.tools.util.Util;
import java.awt.Component;
import java.awt.Container;
import java.awt.Frame;
import java.lang.reflect.InvocationTargetException;
import java.util.Calendar;
import java.util.Hashtable;
import javaclientlib.utils.RRCLogger;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;

public abstract class PanelMediator {
   protected static final boolean SHOW_IN_DIALOG = true;
   protected static final boolean SHOW_IN_CONTAINER = false;
   public static final String DEVICE_TABBED_PANEL = "DEVICE_TABBED_PANEL";
   public static final String USER_GROUP_TABBED_PANEL = "USER_GROUP_TABBED_PANEL";
   protected Container parent = null;
   private Hashtable panels = new Hashtable();
   protected Hashtable targetPanels = new Hashtable();
   protected Hashtable panelClasses = new Hashtable();
   protected ScreenContext scrContext;

   public PanelMediator(Container var1, ScreenContext var2) {
      this.scrContext = var2;
      this.parent = var1;
      this.initPanels();
   }

   public void showPanel(CommandContext var1) {
      if (var1 != null) {
         this.scrContext.getLogger().logTextDebug(" Invoked with command key " + var1.getCommandKey());
         AbstractDisplay var2 = this.getTarget(var1.getCommandKey());
         if (var2 != null) {
            var2.setCommandContext(var1);
            var2.fillComponents(var1);
            if (var2.isDialog()) {
               var2.onActivateDisplay();
               Shell var3 = var2.getShell();
               var3.setCentered();
               var3.setVisible(true);
            } else {
               RaritanDesktopPane var4 = (RaritanDesktopPane)this.parent;
               var4.addAbstractDisplayComponent(var2);
            }
         }

         this.scrContext.getLogger().logTextDebug(" Finished");
      }
   }

   public void hideAll() {
      for (Object var2 : this.panels.values()) {
         if (var2 instanceof AbstractDisplay && ((AbstractDisplay)var2).isDialog()) {
            ((AbstractDisplay)var2).getShell().setVisible(false);
         }
      }
   }

   public void showLogMessage(final CommandContext var1) {
      final AbstractDisplay var2 = this.getTarget(var1.getCommandKey());
      if (SwingUtilities.isEventDispatchThread()) {
         var2.setCommandContext(var1);
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               var2.setCommandContext(var1);
            }
         });
      }

      var2.fillComponents(var1);
      this.parent.repaint();
   }

   public Container getParent() {
      return this.parent;
   }

   public void setParent(Container var1) {
      this.parent = var1;
   }

   public AbstractDisplay getLogPanel() {
      return this.getTarget("logCommand");
   }

   public AbstractDisplay getStatusPanel() {
      return this.getTarget("statusCommand");
   }

   public void showStatusPanel(boolean var1) {
      AbstractDisplay var2 = this.getStatusPanel();
      if (var2 != null) {
         var2.setVisible(var1);
      }
   }

   protected void initPanels() {
      this.scrContext.getLogger().logTextInfo(" Invoked at " + Calendar.getInstance().getTime());
      this.initContainerPanels();
      this.initDialogPanels();
      this.scrContext.getLogger().logTextInfo(" Finished at " + Calendar.getInstance().getTime());
   }

   protected void initContainerPanels() {
      this.panelClasses.put("logCommand", new AbstractDisplayStrategy(LogPanel.class, false, this.scrContext));
      this.panelClasses.put("statusCommand", new AbstractDisplayStrategy(RaritanStatusBarPanel.class, false, this.scrContext));
   }

   protected abstract void initDialogPanels();

   public AbstractDisplay getTarget(String var1) {
      AbstractDisplay var2 = null;
      AbstractDisplayStrategy var3 = (AbstractDisplayStrategy)this.panelClasses.get(var1);
      if (var3 != null) {
         String var4 = var3.getAbstractDisplayClass().getName();
         Frame var5 = JOptionPane.getFrameForComponent(this.scrContext.getApplication().getContentPane());
         PanelMediator.PanelKey var6 = new PanelMediator.PanelKey(var4, var5);
         var2 = (AbstractDisplay)this.panels.get(var6);
         if (var2 == null) {
            var2 = (AbstractDisplay)this.panels.get(var4);
         }

         if (var2 == null) {
            try {
               var2 = var3.create();
               if (!var2.isNewPanel()) {
                  this.panels.put(var2.isDialog() ? var6 : var4, var2);
               }
            } catch (NoSuchMethodException var8) {
               RRCLogger.logException(var8);
            } catch (InstantiationException var9) {
               RRCLogger.logException(var9);
            } catch (IllegalAccessException var10) {
               RRCLogger.logException(var10);
            } catch (InvocationTargetException var11) {
               RRCLogger.logException(var11);
            }
         }
      }

      return var2;
   }

   public Object showDialogOnTop(JOptionPane var1, String var2, AbstractDisplay var3) {
      JDialog var4 = var1.createDialog((Component)(var3 == null ? this.getParent() : var3), var2);
      if (var3 != null) {
         var4.addWindowFocusListener(var3);
         var4.setLocationRelativeTo(var3);
      }

      Util.jre17WorkaroundInheritAlwaysOnTop(var4);
      var4.setModal(true);
      ShellFocusObserver.addShellVisible(var4, this.scrContext);
      var4.setVisible(true);
      ShellFocusObserver.removeShellVisible(var4, this.scrContext);
      var4.dispose();
      return var1.getValue();
   }

   public Object showDialogOnTop(JOptionPane var1, String var2, Component var3) {
      JDialog var4 = var1.createDialog((Component)(var3 == null ? this.getParent() : var3), var2);
      if (var3 != null) {
         var4.setLocationRelativeTo(var3);
      }

      Util.jre17WorkaroundInheritAlwaysOnTop(var4);
      var4.setModal(true);
      ShellFocusObserver.addShellVisible(var4, this.scrContext);
      var4.setVisible(true);
      ShellFocusObserver.removeShellVisible(var4, this.scrContext);
      var4.dispose();
      return var1.getValue();
   }

   public void destroy() {
      this.panelClasses.clear();
      this.panelClasses.clear();
      this.parent = null;
   }

   private class PanelKey {
      private String name;
      private Frame frame;

      public PanelKey(String var2, Frame var3) {
         this.name = var2;
         this.frame = var3;
      }

      @Override
      public boolean equals(Object var1) {
         if (!(var1 instanceof PanelMediator.PanelKey)) {
            return false;
         } else {
            PanelMediator.PanelKey var2 = (PanelMediator.PanelKey)var1;
            return this.name.equals(var2.name) && this.frame == var2.frame;
         }
      }

      @Override
      public int hashCode() {
         return this.name.hashCode() + this.frame.hashCode();
      }
   }
}
