package com.raritan.tools.ui.screens;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.CommandHolder;
import com.raritan.tools.commands.CommandResult;
import com.raritan.tools.commands.ConfirmableCommandInterface;
import com.raritan.tools.commands.DummyCommand;
import com.raritan.tools.resources.RaritanPropertyResourceBundle;
import com.raritan.tools.resources.RaritanResourceBundle;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.components.CommandButton;
import com.raritan.tools.ui.components.CommonPopups;
import java.awt.Cursor;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JPanel;

public abstract class BaseScreen extends JPanel implements ActionListener {
   public String CMD_OK;
   public String CMD_CANCEL;
   protected JPanel pnlButtons;
   protected CommandButton btnOk;
   protected CommandButton btnCancel;
   protected ScreenContext scrContext;
   protected ScreenManager scrManager;

   public BaseScreen(ScreenContext var1, ScreenManager var2) {
      this.scrContext = var1;
      this.scrManager = var2;
      RaritanPropertyResourceBundle var3 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
      this.CMD_OK = var3.getString("basescreen.command.ok.text");
      this.CMD_CANCEL = var3.getString("basescreen.command.cancel.text");
      this.initScreen();
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      boolean var2 = false;
      Object var3 = var1.getSource();
      if (var3 instanceof ConfirmableCommandInterface) {
         var2 = ((ConfirmableCommandInterface)var1.getSource()).getConfirmation();
      }

      if (var3 instanceof CommandHolder) {
         if (var2) {
            RaritanPropertyResourceBundle var4 = RaritanResourceBundle.getResourceBundle(this.scrContext.getLocale());
            var2 = CommonPopups.showConfirmationDialog(
                  var4.getString("confirmation.dialog.command.execution.title"),
                  var4.getString("confirmation.dialog.command.execution.text"),
                  null,
                  this.scrContext
               )
               != 2;
         }

         if (!var2) {
            this.setCursor(Cursor.getPredefinedCursor(3));
            CommandHolder var5 = (CommandHolder)var3;
            this.handleCommandResult(var5.getCommand().execute());
            this.scrManager.show();
            this.setCursor(Cursor.getDefaultCursor());
         }
      }
   }

   protected void initScreen() {
      this.setLayout(new GridBagLayout());
      this.initComponents();
   }

   protected void constructButtonsPane(JButton[] var1) {
      this.pnlButtons = new JPanel();
      this.pnlButtons.setLayout(new GridLayout(1, 0, 4, 4));
      if (var1 != null) {
         for (int var2 = 0; var2 < var1.length; var2++) {
            this.pnlButtons.add(var1[var2]);
         }
      }

      this.btnOk = new CommandButton(this.CMD_OK, this.scrContext);
      this.btnOk.setCommand(this.getOkCommand());
      this.btnOk.setConfirmation(this.getOkConfirmation());
      this.btnOk.setIcon(this.getOkIcon());
      this.btnOk.setEnabled(this.getOkCommand().isExecutable());
      this.btnOk.addActionListener(this);
      this.pnlButtons.add(this.btnOk);
      this.btnCancel = new CommandButton(this.CMD_CANCEL, this.scrContext);
      this.btnCancel.setCommand(this.getCancelCommand());
      this.btnCancel.setConfirmation(this.getCancelConfirmation());
      this.btnCancel.setIcon(this.getCancelIcon());
      this.btnCancel.setEnabled(this.getCancelCommand().isExecutable());
      this.btnCancel.addActionListener(this);
      this.pnlButtons.add(this.btnCancel);
   }

   protected Command getOkCommand() {
      return new DummyCommand(this.scrContext);
   }

   protected Command getCancelCommand() {
      return new DummyCommand(this.scrContext);
   }

   protected boolean getOkConfirmation() {
      return false;
   }

   protected boolean getCancelConfirmation() {
      return false;
   }

   protected Icon getOkIcon() {
      return null;
   }

   protected Icon getCancelIcon() {
      return null;
   }

   protected abstract void initComponents();

   protected abstract void handleCommandResult(CommandResult var1);
}
