package com.raritan.tools.util;

import com.raritan.tools.commands.Command;
import com.raritan.tools.commands.LogCommand;
import com.raritan.tools.commands.StatusCommand;
import com.raritan.tools.ui.ScreenContext;
import com.raritan.tools.ui.panes.mediator.PanelMediator;
import java.util.Date;

public class Logger {
   protected ScreenContext scrContext;
   private LogCommand logCommand;
   private StatusCommand statusCommand;
   private static final String LOG_DEBUG = "Debug";
   private static final String LOG_ERROR = "Error";
   private static final String LOG_INFO = "Info";
   private static final String LOG_WARRING = "Warn";
   private static final String LOG_STDOUT = "StdOut";
   private static final String LOG_LOGPANEL = "LogPanel";
   private final String currentLogLevels;
   private final String currentLogOutputs;
   private final Boolean addTimestamp;

   public Logger(ScreenContext var1) {
      this.scrContext = var1;
      this.logCommand = new LogCommand(this.scrContext);
      this.statusCommand = new StatusCommand(this.scrContext);
      this.currentLogLevels = this.scrContext.getApplicationProperty("application.log.level");
      this.currentLogOutputs = this.scrContext.getApplicationProperty("application.log.output");
      this.addTimestamp = new Boolean(this.scrContext.getApplicationProperty("log.timestamp"));
   }

   public void logTextDebug(String var1) {
      if (this.currentLogLevels.indexOf("Debug") != -1) {
         this.logCommand.getContext().setCommandParameter("logtype", "(Debug)");
         this.log(this.logCommand, var1);
      }
   }

   public void logTextError(String var1) {
      if (this.currentLogLevels.indexOf("Error") != -1) {
         this.logCommand.getContext().setCommandParameter("logtype", "(Error)");
         this.log(this.logCommand, var1);
      }
   }

   public void logTextInfo(String var1) {
      if (var1 != null && !var1.equals("")) {
         if (this.currentLogLevels.indexOf("Info") != -1) {
            this.logCommand.getContext().setCommandParameter("logtype", "(Info)");
            this.log(this.logCommand, var1);
         }
      }
   }

   public void logTextWarrning(String var1) {
      if (this.currentLogLevels.indexOf("Warn") != -1) {
         this.logCommand.getContext().setCommandParameter("logtype", "(Warn)");
         this.log(this.logCommand, var1);
      }
   }

   private void log(Command var1, String var2) {
      if (this.currentLogOutputs.indexOf("StdOut") != -1) {
         StringBuffer var3 = new StringBuffer(var1.getContext().getCommandParameter("logtype").toString());
         var3.append(" ");
         StackTraceElement[] var4 = new Throwable().getStackTrace();
         String var5 = var4[2].getClassName();
         String var6 = var4[2].getMethodName();
         var3.append("[");
         var3.append(var5);
         var3.append("]");
         var3.append("[");
         var3.append(var6);
         var3.append("]:");
         var3.append(var2);
      }

      if (this.currentLogOutputs.indexOf("LogPanel") != -1 && this.scrContext.getPanelMediator() != null) {
         if (this.addTimestamp) {
            var2 = " [" + this.getTimeStamp() + "] " + var2;
         }

         var1.getContext(true).setCommandParameter("logtext", var2);
         var1.execute();
         this.scrContext.getPanelMediator().showLogMessage(var1.getContext());
      }
   }

   public void logStatus(String var1) {
      this.statusCommand.getContext(true).setCommandParameter("logtext", var1);
      this.statusCommand.execute();
      PanelMediator var2 = this.scrContext.getPanelMediator();
      if (var2 != null) {
         var2.showLogMessage(this.statusCommand.getContext());
      }
   }

   private String getTimeStamp() {
      String var1 = null;
      Object var2 = null;
      if (var2 == null) {
         var1 = new Date(System.currentTimeMillis()).toString();
      } else {
         var1 = var2.format(new Date(System.currentTimeMillis()));
      }

      return var1;
   }
}
