package com.raritan.tools.util.io;

import com.raritan.tools.util.Util;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public abstract class AbstractFileMapper implements FileMapper {
   private static final int INT_BYTE_ARRAY_SIZE = 8;

   protected byte[] encodeInt(int var1) {
      byte[] var2 = new byte[8];

      for (int var4 = 7; var4 >= 0; var4--) {
         int var3 = var1 & 0xFF;
         if (var3 > 127) {
            var3 -= 256;
         }

         var2[var4] = (byte)var3;
         var1 >>= 8;
      }

      return var2;
   }

   protected int decodeInt(byte[] var1) {
      int var2 = 0;
      short var3 = 0;

      for (int var4 = 0; var4 < var1.length; var4++) {
         var3 = var1[var4];
         if (var4 > 0 & var3 < 0) {
            var3 += 256;
         }

         var2 *= 256;
         var2 += var3;
      }

      return var2;
   }

   protected byte[] encodeString(String var1) {
      return var1.getBytes();
   }

   protected String decodeString(byte[] var1) {
      return new String(var1);
   }

   protected byte[] encodeBoolean(boolean var1) {
      return this.encodeInt(Util.booleanToInt(var1));
   }

   protected boolean decodeBoolean(byte[] var1) {
      return Util.intToBoolean(this.decodeInt(var1));
   }

   protected String readString(InputStream var1) throws IOException {
      byte[] var2 = new byte[8];
      var1.read(var2);
      byte[] var3 = new byte[this.decodeInt(var2)];
      var1.read(var3);
      return this.decodeString(var3);
   }

   protected int readInt(InputStream var1) throws IOException {
      byte[] var2 = new byte[8];
      var1.read(var2);
      return this.decodeInt(var2);
   }

   protected boolean readBool(InputStream var1) throws IOException {
      byte[] var2 = new byte[8];
      var1.read(var2);
      return this.decodeBoolean(var2);
   }

   protected void writeString(OutputStream var1, String var2) throws IOException {
      String var3 = var2;
      if (var2 == null) {
         var3 = "";
      }

      var1.write(this.encodeInt(var3.length()));
      var1.write(this.encodeString(var3));
   }

   protected void writeInt(OutputStream var1, int var2) throws IOException {
      var1.write(this.encodeInt(var2));
   }

   protected void writeBool(OutputStream var1, boolean var2) throws IOException {
      var1.write(this.encodeBoolean(var2));
   }
}
