package javaclientlib.clientlib;

import java.io.DataInputStream;
import java.io.FilterOutputStream;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.InetAddress;
import java.net.Socket;
import javaclientlib.tr.Constants;
import javaclientlib.tr.TRRSP_ID_DATA;
import javaclientlib.utils.RC4Cipher;
import javaclientlib.utils.RRCLogger;
import javaclientlib.utils.RRCUtil;
import javaclientlib.utils.SecureSocket;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

public class CSCConnect {
   private int iConnected;
   private int iIsSSL;
   private int iAuthenticated;
   private Socket objCSCSocket;
   private boolean boolNeedSSL = false;
   private DataInputStream objDataInputStream;
   private FilterOutputStream objFilterOutputStream;
   private SecureSocket objSSLSocket;
   private static int MAX_CSC_INFO = 1024;
   private static byte[] CSC_Discover = new byte[]{0, 0, 0, 20, 60, 67, 83, 67, 95, 68, 105, 115, 99, 111, 118, 101, 114, 47, 62, 0};
   private static int CSC_Dis_Len = 20;
   private static byte[] byNull = new byte[]{0};

   public CSCConnect() {
      this.objCSCSocket = null;
      this.iConnected = 0;
      this.iIsSSL = 0;
      this.iAuthenticated = 0;
      this.objDataInputStream = null;
   }

   @Override
   protected void finalize() {
      this.disconnect();
   }

   public int connect(int var1, short var2, byte[] var3) {
      try {
         this.iConnected = 0;
         this.iIsSSL = 0;
         Object var4 = null;
         var4 = InetAddress.getByAddress(RRCUtil.getBytesForInt(var1));
         if (var2 == 0) {
            var2 = (short)Constants.TR_PORT_BASE;
         }

         this.objCSCSocket = new Socket((InetAddress)var4, var2);
         if (this.objCSCSocket == null) {
            return -2;
         } else {
            this.objCSCSocket.setTcpNoDelay(true);
            this.createStreams();
            this.iConnected = 1;
            return 0;
         }
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         return -2;
      }
   }

   public byte[] GetCSCInfo() {
      String var1 = new String("<CSC_Ack/>");
      byte[] var2 = new byte[200];
      byte[] var5 = new byte[4];
      boolean var7 = false;
      int var6 = this.read(var2, 0, 4);
      if (var6 < 0) {
         return null;
      } else {
         int var3 = this.getIntForBytes(var2, 0);
         if (var3 > 200) {
            return null;
         } else {
            var6 = this.read(var2, 0, var3);
            var3 = var1.length() + 4 + 1;
            var6 = this.write(RRCUtil.getBytesForInt(var3), 4);
            var6 = this.write(var1.getBytes(), var1.length());
            var6 = this.write(byNull, 1);
            if (var6 < 0) {
               return null;
            } else {
               var6 = this.read(var5, 0, 4);
               if (var6 < 0) {
                  return null;
               } else {
                  var3 = this.getIntForBytes(var5, 0);
                  var3 -= 4;
                  var5 = new byte[var3];
                  if (var5 == null) {
                     return null;
                  } else {
                     var6 = this.read(var5, 0, var3);
                     return var6 < 0 ? null : var5;
                  }
               }
            }
         }
      }
   }

   public int startNewCSCSession(String var1, String var2, String var3, String var4, String var5) {
      String var6 = new String("<CSC_Start_Session ProtocolID=\"" + var1 + "\"/>");
      byte[] var7 = new byte[200];
      int var8 = var6.length() + 1 + 4;
      int var10 = this.write(RRCUtil.getBytesForInt(var8), 4);
      var10 = this.write(var6.getBytes(), var6.length());
      var10 = this.write(byNull, 1);
      if (var10 < 0) {
         return var10;
      } else {
         if (var4.equals("SSL")) {
            var10 = this.startSSL();
            if (var10 != 0) {
               return var10;
            }

            this.createStreams();
         } else {
            this.boolNeedSSL = false;
         }

         if (var5.equals("CSC")) {
            var6 = new String("<CSC_Auth UserName=\"" + var2 + "\" Password=\"" + var3 + "\"/>");
            var8 = var6.length() + 1 + 4;
            var10 = this.write(RRCUtil.getBytesForInt(var8), 4);
            var10 = this.write(var6.getBytes(), var6.length());
            var10 = this.write(byNull, 1);
            if (var10 < 0) {
               return var10;
            } else {
               var10 = this.read(var7, 0, 4);
               var8 = this.getIntForBytes(var7, 0);
               var8 = var8 - 4 - 1;
               if (var8 < 200) {
                  var10 = this.read(var7, 0, var8);
               }

               String var12 = new String(var7, 0, var8);
               this.read(var7, 0, 1);
               if (var12.equals("<CSC_Pass/>")) {
                  this.iAuthenticated = 1;
                  return 0;
               } else {
                  this.disconnect();
                  return -1;
               }
            }
         } else {
            this.iAuthenticated = 1;
            return 0;
         }
      }
   }

   public int startReferralCSCSession(String var1, String var2, String var3, String var4) {
      String var5 = new String("<CSC_Start_Session ProtocolID=\"" + var1 + "\" SessionID=\"" + var2 + "\"/>");
      byte[] var6 = new byte[200];
      int var7 = var5.length() + 1 + 4;
      this.write(RRCUtil.getBytesForInt(var7), 4);
      this.write(var5.getBytes(), var7 - 5);
      this.write(byNull, 1);
      if (var4.equals("SSL")) {
         int var9 = this.startSSL();
         if (var9 != 0) {
            return var9;
         }

         this.createStreams();
      } else {
         this.boolNeedSSL = false;
      }

      return this.CSC_Test(var3.getBytes());
   }

   private int CSC_Test(byte[] var1) {
      try {
         Object var3 = null;
         Object var4 = null;
         Object var5 = null;
         Object var6 = null;
         Object var8 = null;
         Object var9 = null;
         String var10 = "1234567890";
         Object var11 = null;
         Object var12 = null;
         Object var13 = null;
         var8 = new BASE64Decoder().decodeBuffer(new String(var1));
         var11 = this.readMessage(0);
         if (var11 == null) {
            return -10;
         } else {
            var12 = this.getAttributeValue(new String((byte[])var11), "ClearText");
            var11 = null;
            if (var12 == null) {
               return -1;
            } else {
               var3 = new BASE64Decoder().decodeBuffer(new String((byte[])var12));
               int var14 = ((Object[])var3).length;
               RC4Cipher var15 = new RC4Cipher((byte[])var8);
               var15.encrypt((byte[])var3, 0, (byte[])var3, 0, var14);
               RC4Cipher var35 = null;
               var5 = new BASE64Encoder().encode((byte[])var3).getBytes();
               var14 = (int)System.currentTimeMillis();
               byte[] var16 = var10.getBytes();
               var4 = new byte[var16.length];

               for (int var17 = 0; var17 < var16.length; var17++) {
                  ((Object[])var4)[var17] = (byte)(var16[var17] ^ (char)var14);
                  var14 >>= 3;
                  var14 = (int)(var14 ^ System.currentTimeMillis());
               }

               var6 = new BASE64Encoder().encode((byte[])var4).getBytes();
               var14 = ((Object[])var6).length;
               String var7 = "<CSC_Test2 Encrypted=\"" + new String((byte[])var5) + "\" ClearText=\"" + new String((byte[])var6) + "\"/>";
               var14 = this.writeMessage(var7.getBytes());
               if (var14 < 0) {
                  return var14;
               } else {
                  var11 = this.readMessage(0);
                  if (var11 == null) {
                     return -10;
                  } else {
                     var13 = this.getAttributeValue(new String((byte[])var11), "Encrypted");
                     var11 = null;
                     if (var13 == null) {
                        return -1;
                     } else {
                        var3 = new BASE64Decoder().decodeBuffer(new String((byte[])var13));
                        var35 = new RC4Cipher((byte[])var8);
                        var35.decrypt((byte[])var3, 0, (byte[])var3, 0, ((Object[])var3).length);
                        if (((Object[])var3).length != var16.length) {
                           return -1;
                        } else {
                           for (int var37 = 0; var37 < var16.length; var37++) {
                              if (((Object[])var4)[var37] != ((Object[])var3)[var37]) {
                                 return -1;
                              }
                           }

                           return 0;
                        }
                     }
                  }
               }
            }
         }
      } catch (Exception var18) {
         RRCLogger.logException(var18);
         return -1;
      }
   }

   public void disconnect() {
      if (this.iConnected != 0) {
         this.objCSCSocket = null;
         this.iConnected = 0;
         this.iIsSSL = 0;
         this.iAuthenticated = 0;
      }
   }

   private int startSSL() {
      try {
         this.boolNeedSSL = true;
         String var1 = this.objCSCSocket.getInetAddress().getHostAddress();
         this.objSSLSocket = new SecureSocket(this.objCSCSocket, var1, Constants.TR_PORT_BASE, false);
         this.objSSLSocket.connect();
         return 0;
      } catch (Exception var2) {
         RRCLogger.logException(var2);
         return -4;
      }
   }

   public int writeMessage(byte[] var1) {
      int var3 = 0;
      int var4 = 4 + var1.length + 1;
      var3 = this.write(RRCUtil.getBytesForInt(var4), 4);
      if (var3 < 0) {
         return var3;
      } else {
         var3 = this.write(var1, var4 - 4 - 1);
         if (var3 < 0) {
            return var3;
         } else {
            var3 = this.write(byNull, 1);
            return var3 < 0 ? var3 : var3;
         }
      }
   }

   public byte[] readMessage(int var1) {
      byte[] var6 = new byte[4];
      int var4 = this.read(var6, 0, 4);
      if (var4 < 0) {
         return null;
      } else {
         int var3 = this.getIntForBytes(var6, 0);
         if (var1 > 0 && var3 > var1) {
            return null;
         } else if (var3 < 9) {
            return null;
         } else {
            byte[] var5 = new byte[var3 - 4];
            if (var5 == null) {
               return null;
            } else {
               var4 = this.read(var5, 0, var3 - 4);
               return var4 < 0 ? null : var5;
            }
         }
      }
   }

   public int write(byte[] var1, int var2) {
      byte var3 = 0;
      boolean var4 = true;
      if (this.iConnected != 0) {
         try {
            this.objFilterOutputStream.write(var1, 0, var2);
         } catch (Exception var6) {
            RRCLogger.logException(var6);
            var4 = false;
         }

         if (!var4) {
            this.iConnected = 0;
            var3 = -20;
         }
      } else {
         var3 = -8;
      }

      return var3;
   }

   public int read(byte[] var1, int var2, int var3) {
      boolean var4 = true;
      byte var5 = 0;
      int var6 = 0;
      if (this.iConnected != 0) {
         try {
            var6 = this.objDataInputStream.read(var1, var2, var3);
         } catch (Exception var8) {
            RRCLogger.logException(var8);
            var4 = false;
         }

         if (var6 < 0 || !var4) {
            this.iConnected = 0;
            var5 = -20;
         }
      } else {
         var4 = false;
         var5 = -10;
      }

      return var5;
   }

   private int getIntForBytes(byte[] var1, int var2) {
      return ((var1[var2 + 0] & 0xFF) << 24) + ((var1[var2 + 1] & 0xFF) << 16) + ((var1[var2 + 2] & 0xFF) << 8) + ((var1[var2 + 3] & 0xFF) << 0);
   }

   private void createStreams() {
      try {
         if (this.boolNeedSSL) {
            this.objDataInputStream = new DataInputStream(this.objSSLSocket.getSecureInputStream());
            this.objFilterOutputStream = new FilterOutputStream(this.objSSLSocket.getSecureOutputStream());
         } else {
            this.objDataInputStream = new DataInputStream(this.objCSCSocket.getInputStream());
            this.objFilterOutputStream = new FilterOutputStream(this.objCSCSocket.getOutputStream());
         }
      } catch (Exception var2) {
         this.objDataInputStream = null;
         this.objFilterOutputStream = null;
         RRCLogger.logException(var2);
      }
   }

   public byte[] Query_CSC_Info(int var1, short var2, int var3) {
      new TRRSP_ID_DATA();
      InetAddress var8 = null;

      try {
         if (var2 == 0) {
            var2 = (short)Constants.TR_PORT_BASE;
         }

         DatagramSocket var5 = new DatagramSocket();
         DatagramPacket var6 = new DatagramPacket(CSC_Discover, CSC_Dis_Len);
         var6.setPort(var2);
         if (var3 == 0) {
            var3 = 10;
         }

         var3 = var3 * 1000 + (int)System.currentTimeMillis();

         do {
            if (var8 == null) {
               byte[] var9 = RRCUtil.getBytesForInt(var1);
               var8 = InetAddress.getByAddress(var9);
               var6.setAddress(var8);
            }

            var5.send(var6);
            var5.setSoTimeout(1000);
            int var15 = var6.getLength();
            byte[] var10 = new byte[2048];
            DatagramPacket var7 = new DatagramPacket(var10, var10.length);
            var5.receive(var7);
            String var11 = new String(var10);
            if ((var15 >= 11 || var15 <= 2048 && var15 <= var7.getLength() && var11.equals("0x00")) && var11.indexOf("CSC_Info") != 0) {
               for (int var12 = 0; var12 < var15 - 4; var12++) {
                  var10[var12] = var10[var12 + 4];
               }

               var5.disconnect();
               return var10;
            }
         } while (var3 >= System.currentTimeMillis());
      } catch (Exception var13) {
         RRCLogger.logException(var13);
      }

      return null;
   }

   public String getNodeString(String var1, String var2) {
      if (var1 == null) {
         return null;
      } else {
         int var3 = var1.indexOf("<" + var2 + ">");
         int var4 = var1.indexOf("</" + var2 + ">");
         return var3 != -1 && var4 != -1 ? var1.substring(var3 + var2.length() + 2, var4) : null;
      }
   }

   public byte[] getAttributeValue(String var1, String var2) {
      String var3 = " " + var2 + "=\"";
      int var4 = -1;
      if (var1 == null) {
         return null;
      } else {
         var4 = var1.indexOf(var3);
         if (var4 == -1) {
            var3 = " " + var2 + "= \"";
            var4 = var1.indexOf(var3);
            if (var4 == -1) {
               var3 = " " + var2 + " =\"";
               var4 = var1.indexOf(var3);
               if (var4 == -1) {
                  var3 = " " + var2 + " = \"";
                  var4 = var1.indexOf(var3);
               }
            }
         }

         if (var4 == -1) {
            return null;
         } else {
            int var5 = var4 + var3.length();
            int var6 = var1.indexOf("\"", var5);
            int var7 = var4 + var3.length();
            if (var6 != -1) {
               String var8 = var1.substring(var5, var6);
               if (var8.charAt(var8.length() - 1) == '\n') {
                  var8 = var8.substring(0, var8.length() - 1);
               }

               if (var8 != null) {
                  return var8.getBytes();
               }
            }

            return null;
         }
      }
   }

   public static void main(String[] var0) {
      try {
         int var1 = -1;
         InetAddress var2 = InetAddress.getByName("172.16.35.103");
         Object var3 = null;
         CSCConnect var4 = new CSCConnect();
         var1 = var4.connect(var2.hashCode(), (short)5000, "Dummy".getBytes());
         if (var1 < 0) {
            System.exit(1);
         }

         var3 = var4.GetCSCInfo();
         var1 = var4.startNewCSCSession("RDM", "admin", Constants.DEFAULT_PASSWORD, "SSL", "CSC");
         if (var1 < 0) {
            System.exit(1);
         }

         String var5 = "<Session><GetSessionID/></Session>";
         var4.writeMessage(var5.getBytes());
         byte[] var6 = var4.readMessage(0);
         var5 = new String(var6);
         String var7 = var4.getNodeString(var5, "SessionID");
         String var8 = var4.getNodeString(var5, "SessionKey");
         var8 = var8.substring(0, var8.length() - 1);
         CSCConnect var9 = new CSCConnect();
         var1 = var9.connect(var2.hashCode(), (short)5000, "Dummy".getBytes());
         if (var1 < 0) {
            System.exit(1);
         }

         var3 = var9.GetCSCInfo();
         var1 = var9.startReferralCSCSession("RDMEvent", var7, var8, "SSL");
         if (var1 < 0) {
            System.exit(1);
         }
      } catch (Exception var10) {
         var10.printStackTrace();
      }
   }
}
