package javaclientlib.clientlib;

import javaclientlib.utils.RRCLogger;

public class HIDKeyboard implements Keyboard {
   private int iKBDataCount;
   private byte[] byKBBuffer;
   private TRVideoStream videoStream;
   protected boolean boolNumLock;
   protected boolean boolScrollLock;
   protected boolean boolCapsLock;
   protected byte[] keyState = new byte[256];

   public HIDKeyboard(TRVideoStream var1) {
      this.iKBDataCount = 0;
      this.byKBBuffer = new byte[16];
      this.videoStream = var1;
      this.clearKeyStatus();
   }

   @Override
   public boolean setKeyState(short var1, boolean var2, boolean var3) {
      byte[] var4 = new byte[2];
      boolean var5 = true;
      this.keyState[var1] = (byte)(var2 ? 1 : 0);
      var4[0] = (byte)(var2 ? 1 : 2);
      var4[1] = (byte)var1;
      var5 = this.outputKeyData(var4, 0, 2);
      if (var3) {
         var5 &= this.flushKeyData();
      }

      return var5;
   }

   @Override
   public boolean getKeyState(short var1) {
      return this.keyState[var1] != 0;
   }

   @Override
   public boolean releaseAllPressedKeys() {
      byte[] var2 = new byte[]{5};
      boolean var1 = this.outputKeyData(var2, 0, 1);
      return var1 & this.flushKeyData();
   }

   @Override
   public boolean releaseKeyIfPressed(short var1) {
      byte[] var2 = new byte[2];
      if (var1 > 255) {
         return false;
      } else {
         var2[0] = 3;
         var2[1] = (byte)var1;
         return this.outputKeyData(var2, 0, 2);
      }
   }

   @Override
   public boolean toogleKeyState(short var1) {
      byte[] var2 = new byte[2];
      boolean var3 = true;
      if (var1 > 255) {
         return false;
      } else {
         var2[0] = 4;
         var2[1] = (byte)var1;
         var3 = this.outputKeyData(var2, 0, 2);
         return var3 & this.flushKeyData();
      }
   }

   @Override
   public boolean outputKeyData(byte[] var1, int var2, int var3) {
      try {
         boolean var4 = true;
         if (var3 + this.iKBDataCount > 16) {
            var4 = this.flushKeyData();
         }

         System.arraycopy(var1, var2, this.byKBBuffer, this.iKBDataCount, var3);
         this.iKBDataCount += var3;
         return var4;
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         return false;
      }
   }

   @Override
   public boolean flushKeyData() {
      try {
         boolean var1 = true;
         if (this.iKBDataCount != 0) {
            var1 = this.sendKeyData(this.iKBDataCount, this.byKBBuffer);
            this.iKBDataCount = 0;
         }

         return var1;
      } catch (Exception var2) {
         RRCLogger.logException(var2);
         return false;
      }
   }

   public boolean sendKeyData(int var1, byte[] var2) {
      return this.videoStream.sendKeyData(var1, var2);
   }

   @Override
   public void setLEDState(boolean var1, boolean var2, boolean var3) {
      this.boolScrollLock = var1;
      this.boolNumLock = var2;
      this.boolCapsLock = var3;
   }

   @Override
   public boolean getScrollLockStatus() {
      return this.boolScrollLock;
   }

   @Override
   public boolean getNumLockStatus() {
      return this.boolNumLock;
   }

   @Override
   public boolean getCapsLockStatus() {
      return this.boolCapsLock;
   }

   @Override
   public void setScanCode3Data(byte[] var1, int var2) {
   }

   @Override
   public void setScanCodeSet(int var1) {
   }

   @Override
   public void setTargetType(boolean var1) {
   }

   protected void clearKeyStatus() {
      for (int var1 = 0; var1 < 256; var1++) {
         this.keyState[var1] = 0;
      }

      this.setLEDState(false, false, false);
   }

   @Override
   public synchronized boolean isTargetType() {
      return false;
   }
}
