package javaclientlib.clientlib;

import com.util.kbd.KeyHIDValue;
import javaclientlib.tr.HIDtoPS2;
import javaclientlib.tr.HIDtoSun;
import javaclientlib.utils.RRCLogger;

public class PS2Keyboard implements Keyboard {
   private boolean isLShiftDown = false;
   private boolean isRShiftDown = false;
   private boolean isLControlDown = false;
   private boolean isRControlDown = false;
   private boolean isLAltDown = false;
   private boolean isRAltDown = false;
   private boolean isAnyShiftDown = false;
   private boolean isAnyControlDown = false;
   private boolean isAnyAltDown = false;
   private final int US = 0;
   private final int JP = 1;
   private final int NUMBREAKKEYS = 6;
   private byte[] breakKeys = new byte[]{29, 42, 54, 56, -99, -72};
   protected int iCurrentScanCodeSet;
   protected boolean boolNeedSC3Settings;
   protected boolean boolNumLock;
   protected boolean boolScrollLock;
   protected boolean boolCapsLock;
   protected byte[] bySC3KeySettings = new byte[256];
   protected byte[] keyState = new byte[256];
   protected byte shiftStat;
   protected byte ctrlStat;
   protected byte altStat;
   protected byte scrollStat;
   protected boolean pauseStat;
   protected int[][] scanCodeTable;
   protected boolean targetType;
   protected int language;
   private int iKBDataCount;
   private byte[] byKBBuffer;
   private TRVideoStream videoStream;

   public PS2Keyboard(TRVideoStream var1) {
      this.setCurrentScanCodeSet(2);
      this.setDefaultSC3KeySettings();
      this.setNeedSC3Settings(false);
      this.clearKeyStatus();
      this.iKBDataCount = 0;
      this.byKBBuffer = new byte[16];
      this.videoStream = var1;
   }

   public int getScanCodeSet() {
      return this.iCurrentScanCodeSet;
   }

   @Override
   public boolean getScrollLockStatus() {
      return this.boolScrollLock;
   }

   @Override
   public boolean getNumLockStatus() {
      return this.boolNumLock;
   }

   @Override
   public boolean getCapsLockStatus() {
      return this.boolCapsLock;
   }

   public boolean sC3KeySettingsNeeded() {
      return this.boolNeedSC3Settings;
   }

   public byte getALTKeyState() {
      return this.altStat;
   }

   public byte getCTRLKeyState() {
      return this.ctrlStat;
   }

   public void setCurrentScanCodeSet(int var1) {
      this.iCurrentScanCodeSet = var1;
   }

   public int getCurrentScanCodeSet() {
      return this.iCurrentScanCodeSet;
   }

   public void setNeedSC3Settings(boolean var1) {
      this.boolNeedSC3Settings = var1;
   }

   public boolean getNeedSC3Settings() {
      return this.boolNeedSC3Settings;
   }

   private static byte[] concatenateArrays(byte[][] var0) {
      int var4 = 0;
      int var5 = 0;
      int var6 = var0.length;

      for (int var1 = 0; var1 < var6; var1++) {
         if (var0[var1] != null) {
            var5 += var0[var1].length;
         }
      }

      byte[] var7 = new byte[var5];

      for (int var8 = 0; var8 < var6; var8++) {
         if (var0[var8] != null) {
            int var3 = var0[var8].length;

            for (int var2 = 0; var2 < var3; var4++) {
               var7[var4] = var0[var8][var2];
               var2++;
            }
         }
      }

      return var7;
   }

   private void setShiftCtrlAltStatus(short var1, boolean var2) {
      switch (var1) {
         case 224:
            this.isLControlDown = var2;
            break;
         case 225:
            this.isLShiftDown = var2;
            break;
         case 226:
            this.isLAltDown = var2;
         case 227:
         default:
            break;
         case 228:
            this.isRControlDown = var2;
            break;
         case 229:
            this.isRShiftDown = var2;
            break;
         case 230:
            this.isRAltDown = var2;
      }

      this.isAnyShiftDown = this.isLShiftDown || this.isRShiftDown;
      this.isAnyControlDown = this.isLControlDown || this.isRControlDown;
      this.isAnyAltDown = this.isLAltDown || this.isRAltDown;
   }

   private int getCtrlAltEmulationKey(short var1) {
      switch (var1) {
         case 59:
         case 60:
         case 61:
         case 62:
         case 63:
         case 64:
         case 65:
         case 66:
         case 67:
         case 68:
         case 69:
            return var1 - 59;
         case 70:
         case 71:
         case 72:
         case 73:
         case 74:
         case 75:
         case 76:
         case 77:
         case 78:
         case 79:
         case 80:
         case 81:
         case 82:
         case 83:
         case 84:
         default:
            return -1;
         case 85:
         case 86:
         case 87:
            return var1 - 74;
      }
   }

   public boolean setSunKeyState(short var1, boolean var2, boolean var3) {
      Object var4 = null;
      boolean var5 = false;
      int var6 = var2 ? 0 : 1;
      this.keyState[var1] = (byte)(var2 ? 1 : 0);
      switch (var1) {
         case 224:
         case 225:
         case 226:
         case 228:
         case 229:
         case 230:
            this.setShiftCtrlAltStatus(var1, var2);
         case 227:
         default:
            var4 = HIDtoSun.sunCodes[var6][var1];
            if (var1 == 72 && var2) {
               this.pauseStat = true;
            }

            if (this.pauseStat && var1 != 72) {
               this.pauseStat = false;
               if (var1 == 4) {
                  var4 = HIDtoSun.sunStopASequence;
                  var3 = true;
               }
            } else if (this.isAnyControlDown && this.isAnyAltDown && this.getCtrlAltEmulationKey(var1) > -1) {
               int var7 = this.getCtrlAltEmulationKey(var1);
               var4 = concatenateArrays(
                  new byte[][]{
                     this.isLControlDown ? HIDtoSun.sunCodes[var6][224] : null,
                     this.isRControlDown ? HIDtoSun.sunCodes[var6][228] : null,
                     this.isLAltDown ? HIDtoSun.sunCodes[var6][226] : null,
                     this.isRAltDown ? HIDtoSun.sunCodes[var6][230] : null,
                     HIDtoSun.sunEmulationRemap[var7]
                  }
               );
            } else if (KeyHIDValue.keyboardLanguage != 2 && var1 == 230) {
               var4 = HIDtoSun.sunCodes[var6][226];
            }

            if (var4 != null && ((Object[])var4).length > 0 && ((Object[])var4)[0] != 0) {
               var5 = this.outputKeyData((byte[])var4, 0, ((Object[])var4).length);
            }

            return var3 ? var5 & this.flushKeyData() : var5;
      }
   }

   @Override
   public boolean setKeyState(short var1, boolean var2, boolean var3) {
      boolean var4 = false;
      if (var1 == 0) {
         if (var3) {
            var4 &= this.flushKeyData();
         }

         return var4;
      } else {
         if (this.iCurrentScanCodeSet == 3 && !this.getNumLockStatus()) {
            if (var1 == 89) {
               var1 = 77;
            } else if (var1 == 90) {
               var1 = 81;
            } else if (var1 == 91) {
               var1 = 78;
            } else if (var1 == 92) {
               var1 = 80;
            } else if (var1 == 94) {
               var1 = 79;
            } else if (var1 == 95) {
               var1 = 74;
            }

            if (var1 == 96) {
               var1 = 82;
            }

            if (var1 == 97) {
               var1 = 75;
            }

            if (var1 == 98) {
               var1 = 73;
            }

            if (var1 == 99) {
               var1 = 76;
            }
         }

         if (this.isTargetType()) {
            return this.setSunKeyState(var1, var2, var3);
         } else {
            synchronized (this) {
               byte[] var6;
               this.keyState[var1] = (byte)(var2 ? 1 : 0);
               var6 = HIDtoPS2.scanCodes[this.iCurrentScanCodeSet - 1][var2 ? 0 : 1][var1];
               label228:
               switch (this.iCurrentScanCodeSet) {
                  case 1:
                     switch (var1) {
                        case 70:
                           if (var2) {
                              var6 = HIDtoPS2.makePrScrSC1;
                           } else {
                              var6 = HIDtoPS2.breakPrScrSC1;
                           }
                           break;
                        case 72:
                           if (this.isAnyControlDown) {
                              var6 = HIDtoPS2.scanCodes[this.iCurrentScanCodeSet - 1][var2 ? 0 : 1][120];
                           }
                     }
                  case 2:
                     if (var1 > 223) {
                        this.setShiftCtrlAltStatus(var1, var2);
                     }

                     switch (var1) {
                        case 70:
                           if (var2) {
                              if (this.isAnyAltDown) {
                                 var6 = HIDtoPS2.makeAlt_AND_PrScrSC2;
                              } else if (!this.isAnyControlDown && !this.isAnyShiftDown) {
                                 var6 = HIDtoPS2.makePrScrSC2;
                              } else {
                                 var6 = HIDtoPS2.makeCtl_OR_Shift_AND_PrScrSC2;
                              }
                           } else if (this.isAnyAltDown) {
                              var6 = HIDtoPS2.breakAlt_AND_PrScrSC2;
                           } else if (!this.isAnyControlDown && !this.isAnyShiftDown) {
                              var6 = HIDtoPS2.breakPrScrSC2;
                           } else {
                              var6 = HIDtoPS2.breakCtl_OR_Shift_AND_PrScrSC2;
                           }
                        case 71:
                        case 83:
                        default:
                           break label228;
                        case 72:
                           if (this.isAnyControlDown) {
                              var6 = HIDtoPS2.scanCodes[this.iCurrentScanCodeSet - 1][var2 ? 0 : 1][120];
                           }
                           break label228;
                        case 73:
                        case 74:
                        case 75:
                        case 76:
                        case 77:
                        case 78:
                        case 79:
                        case 80:
                        case 81:
                        case 82:
                           if (this.isAnyShiftDown != this.boolNumLock) {
                              if (this.boolNumLock) {
                                 var6 = concatenateArrays(
                                    new byte[][]{
                                       HIDtoPS2.fakeLShift[this.iCurrentScanCodeSet - 1][0], var6, HIDtoPS2.fakeLShift[this.iCurrentScanCodeSet - 1][1]
                                    }
                                 );
                              } else {
                                 var6 = concatenateArrays(
                                    new byte[][]{
                                       this.isLShiftDown && var2 ? HIDtoPS2.fakeLShift[this.iCurrentScanCodeSet - 1][1] : null,
                                       this.isRShiftDown && var2 ? HIDtoPS2.fakeRShift[this.iCurrentScanCodeSet - 1][1] : null,
                                       var6,
                                       this.isRShiftDown && !var2 ? HIDtoPS2.fakeRShift[this.iCurrentScanCodeSet - 1][0] : null,
                                       this.isLShiftDown && !var2 ? HIDtoPS2.fakeLShift[this.iCurrentScanCodeSet - 1][0] : null
                                    }
                                 );
                              }
                           }
                           break label228;
                        case 84:
                           if (this.isAnyShiftDown) {
                              var6 = concatenateArrays(
                                 new byte[][]{
                                    this.isLShiftDown && var2 ? HIDtoPS2.fakeLShift[this.iCurrentScanCodeSet - 1][1] : null,
                                    this.isRShiftDown && var2 ? HIDtoPS2.fakeRShift[this.iCurrentScanCodeSet - 1][1] : null,
                                    var6,
                                    this.isRShiftDown && !var2 ? HIDtoPS2.fakeRShift[this.iCurrentScanCodeSet - 1][0] : null,
                                    this.isLShiftDown && !var2 ? HIDtoPS2.fakeLShift[this.iCurrentScanCodeSet - 1][0] : null
                                 }
                              );
                           }
                           break label228;
                     }
                  case 3:
                     if (!var2 && var6.length > 1) {
                        int var7 = var6[1] < 0 ? 256 + var6[1] : var6[1];
                        if (this.bySC3KeySettings[var7] == -7 || this.bySC3KeySettings[var7] == -9) {
                           var6 = null;
                        }
                     }
               }

               if (var6 != null) {
                  var4 = this.outputKeyData(var6, 0, var6.length);
               }

               if (var3) {
                  var4 &= this.flushKeyData();
               }

               return var4;
            }
         }
      }
   }

   @Override
   public boolean getKeyState(short var1) {
      return this.keyState[var1] != 0;
   }

   @Override
   public boolean releaseAllPressedKeys() {
      boolean var1 = true;
      synchronized (this) {
         for (short var2 = 0; var2 < 256; var2++) {
            if (this.keyState[var2] != 0) {
               var1 &= this.setKeyState(var2, false, false);
            }
         }

         return var1 & this.flushKeyData();
      }
   }

   @Override
   public boolean releaseKeyIfPressed(short var1) {
      boolean var2 = true;
      if (this.keyState[var1] != 0) {
         var2 = this.setKeyState(var1, false, false);
      }

      return var2;
   }

   @Override
   public boolean toogleKeyState(short var1) {
      boolean var2 = this.setKeyState(var1, true, false);
      return var2 & this.setKeyState(var1, false, false);
   }

   public boolean breakAll() throws Exception {
      boolean var2 = true;
      synchronized (this) {
         for (int var1 = 0; var1 < 6; var1++) {
            var2 &= this.setKeyState(this.breakKeys[var1], false, false);
         }

         return var2;
      }
   }

   @Override
   public void setScanCode3Data(byte[] var1, int var2) {
      synchronized (this) {
         if (var1[0] == -1) {
            for (int var5 = 0; var5 < 141; var5++) {
               this.bySC3KeySettings[var5] = var1[var5 + 1];
            }
         } else {
            for (int var11 = 0; var11 < var2; var11++) {
               byte var3 = var1[var11];
               byte var4 = var1[var11 + 1];
               switch (var3) {
                  case -52:
                  default:
                     break;
                  case -9:
                  case -8:
                  case -7:
                  case -6:
                     for (int var6 = 0; var6 < 256; var6++) {
                        this.bySC3KeySettings[var6] = var3;
                     }
                     break;
                  case -5:
                  case -4:
                  case -3:
                     this.bySC3KeySettings[var4] = (byte)(var3 - 4);
                     var11++;
               }
            }
         }

         this.boolNeedSC3Settings = false;
      }
   }

   @Override
   public void setScanCodeSet(int var1) {
      synchronized (this) {
         if (var1 != this.iCurrentScanCodeSet && var1 == 3) {
            this.boolNeedSC3Settings = true;
         }

         this.iCurrentScanCodeSet = var1;
      }
   }

   @Override
   public void setLEDState(boolean var1, boolean var2, boolean var3) {
      this.boolScrollLock = var1;
      this.boolNumLock = var2;
      this.boolCapsLock = var3;
   }

   protected void setDefaultSC3KeySettings() {
      this.setAllSC3KeySettings((byte)-9);
      this.bySC3KeySettings[17] = -8;
      this.bySC3KeySettings[18] = -8;
      this.bySC3KeySettings[20] = -8;
      this.bySC3KeySettings[25] = -8;
      this.bySC3KeySettings[57] = -7;
      this.bySC3KeySettings[88] = -7;
      this.bySC3KeySettings[89] = -8;
      this.bySC3KeySettings[136] = -8;
      this.bySC3KeySettings[140] = -8;
      this.bySC3KeySettings[141] = -8;
      this.bySC3KeySettings[103] = -7;
      this.bySC3KeySettings[110] = -7;
      this.bySC3KeySettings[101] = -7;
      this.bySC3KeySettings[111] = -7;
      this.bySC3KeySettings[109] = -7;
      this.bySC3KeySettings[118] = -7;
      this.bySC3KeySettings[108] = -7;
      this.bySC3KeySettings[107] = -7;
      this.bySC3KeySettings[105] = -7;
      this.bySC3KeySettings[119] = -7;
      this.bySC3KeySettings[117] = -7;
      this.bySC3KeySettings[115] = -7;
      this.bySC3KeySettings[114] = -7;
      this.bySC3KeySettings[112] = -7;
      this.bySC3KeySettings[126] = -7;
      this.bySC3KeySettings[125] = -7;
      this.bySC3KeySettings[116] = -7;
      this.bySC3KeySettings[122] = -7;
      this.bySC3KeySettings[113] = -7;
      this.bySC3KeySettings[132] = -7;
      this.bySC3KeySettings[121] = -7;
      this.bySC3KeySettings[8] = -7;
      this.bySC3KeySettings[7] = -7;
      this.bySC3KeySettings[15] = -7;
      this.bySC3KeySettings[23] = -7;
      this.bySC3KeySettings[31] = -7;
      this.bySC3KeySettings[39] = -7;
      this.bySC3KeySettings[47] = -7;
      this.bySC3KeySettings[55] = -7;
      this.bySC3KeySettings[63] = -7;
      this.bySC3KeySettings[71] = -7;
      this.bySC3KeySettings[79] = -7;
      this.bySC3KeySettings[86] = -7;
      this.bySC3KeySettings[94] = -7;
      this.bySC3KeySettings[87] = -7;
      this.bySC3KeySettings[95] = -7;
      this.bySC3KeySettings[100] = -7;
   }

   protected void setAllSC3KeySettings(byte var1) {
      for (int var2 = 0; var2 < 142; var2++) {
         this.bySC3KeySettings[var2] = var1;
      }
   }

   @Override
   public boolean outputKeyData(byte[] var1, int var2, int var3) {
      try {
         for (int var6 = 0; var6 < var1.length; var6++) {
            int var4 = var1[var6] & 127;
            boolean var5 = (var1[var6] & 128) != 0;
            if (var5) {
               var4 |= 128;
            }
         }

         boolean var9 = true;
         if (var3 + this.iKBDataCount > 16) {
            var9 = this.flushKeyData();
         }

         System.arraycopy(var1, var2, this.byKBBuffer, this.iKBDataCount, var3);
         this.iKBDataCount += var3;
         return var9;
      } catch (Exception var7) {
         RRCLogger.logException(var7);
         return false;
      }
   }

   @Override
   public boolean flushKeyData() {
      try {
         boolean var1 = true;
         if (this.iKBDataCount != 0) {
            var1 = this.sendKeyData(this.iKBDataCount, this.byKBBuffer);
            this.iKBDataCount = 0;
         }

         return var1;
      } catch (Exception var2) {
         RRCLogger.logException(var2);
         return false;
      }
   }

   public boolean sendKeyData(int var1, byte[] var2) {
      return this.videoStream.sendKeyData(var1, var2);
   }

   protected void clearKeyStatus() {
      for (int var1 = 0; var1 < 256; var1++) {
         this.keyState[var1] = 0;
      }

      this.shiftStat = this.ctrlStat = this.altStat = 0;
      this.setLEDState(false, false, false);
   }

   @Override
   public synchronized boolean isTargetType() {
      return this.targetType;
   }

   @Override
   public synchronized void setTargetType(boolean var1) {
      this.targetType = var1;
   }
}
