package javaclientlib.clientlib;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.RandomAccessFile;
import java.lang.reflect.Method;
import java.net.InetAddress;
import javaclientlib.common.RFPParser;
import javaclientlib.tr.Constants;
import javaclientlib.tr.RFP;
import javaclientlib.tr.TRCMD_RFP_MESSAGE_DATA;
import javaclientlib.tr.TRCOMMAND;
import javaclientlib.tr.TRLIB_COMM;
import javaclientlib.tr.TRLIB_REFERRAL_COMM;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.tr.TRRSP_RFP_MESSAGE_DATA;
import javaclientlib.tr.TRSRVR_SERIAL_PARAMS;
import javaclientlib.utils.Monitor;
import javaclientlib.utils.RRCLogger;

public class RFPClient extends RFPParser implements IProgress {
   public static final Object mutex = new Object();
   boolean isKX = false;
   private boolean boolCancel = false;
   private int iError;
   private FileOutputStream fileReceive;
   private int iReceived;
   private int iReceiveFileLength;
   private TRConnection objConnection;
   private Monitor objMonitor;
   private boolean autoReboot;
   private boolean done;
   private int iState = 2;
   public static final int RFP_CLIENT_STATE_NULL = 0;
   public static final int RFP_CLIENT_STATE_SEND = 1;
   public static final int RFP_CLIENT_STATE_WAIT_RESULT = 2;
   public static final int RFP_CLIENT_STATE_RECV_START = 3;
   public static final int RFP_CLIENT_STATE_RECV_DATA = 4;
   public static final int RFP_CLIENT_STATE_RECV_DONE = 5;
   public static final String TR_META_FILE_TOTAL_CONFIG = "All";
   public static final String TR_META_FILE_CONFIG = "DeviceAndPortConfigFile";
   public static final String TR_META_FILE_CONFIG_1 = "DeviceConfigFile";
   public static final String TR_META_FILE_CONFIG_2 = "MP432PortConfigFile";
   public static final String TR_META_FILE_USER_CONFIG = "UserConfigFile";
   public static final String TR_META_FILE_LOGEXPORT = "LogExportFile";
   public static final String TR_META_FILE_DEBUG = "DebugLogFile";
   public static final int TR_RFP_STRIP_HEADER = 1;
   public static final int TRLIB_ERROR_IO_CANCEL = 0;
   public static final int ERROR_WRITE_FAULT = 0;

   public RFPClient() {
      this.objMonitor = new Monitor();
      this.autoReboot = false;
      this.done = false;
   }

   public void resetValues() {
      this.boolCancel = false;
      this.iState = 2;
      this.objMonitor = new Monitor();
      this.autoReboot = false;
      this.done = false;
   }

   public void setTRConnection(TRConnection var1) throws Exception {
      Object var2 = null;
      Object var3 = null;
      Class[] var4 = new Class[]{Class.forName("javaclientlib.tr.TRCOMMAND"), Class.forName("java.lang.Object")};
      Class var5 = this.getClass();
      Method var6 = var5.getDeclaredMethod("TRRSP_RFP_Message_Glue", var4);
      Object var7 = null;
      Object var8 = null;
      if (this.objConnection != null) {
         this.objConnection.setExtRspHandler(35, (Method)var3, var8, var7, null, null, null);
      }

      this.objConnection = var1;
      this.objConnection.setExtRspHandler(35, var6, this, this, (Method)var3, var8, var7);
   }

   public TRConnection getTRConnection() {
      return this.objConnection;
   }

   public RFP getInfo(String var1) {
      try {
         RandomAccessFile var2 = new RandomAccessFile(var1, "r");
         int var3 = this.parseFile(var2);
         var2.close();
         return var3 != 0 ? null : this.getHeader();
      } catch (Exception var4) {
         return null;
      }
   }

   public boolean createRFPConnection() {
      return this.objConnection.createRFPSocketConnection();
   }

   public boolean closeRFPConnection() {
      return this.objConnection.closeRFPSocketConnection();
   }

   public boolean send(String var1, int var2, boolean var3) throws Exception {
      this.resetValues();
      this.isKX = var3;
      FileInputStream var4 = null;
      int var6 = 0;
      TRCMD_RFP_MESSAGE_DATA var7 = new TRCMD_RFP_MESSAGE_DATA();
      if (this.objConnection == null) {
         return false;
      } else {
         try {
            this.objConnection.setPingDevice(false);
            var4 = new FileInputStream(var1);
            this.boolCancel = false;
            this.iError = 0;
            int var12 = var4.available();
            int var5 = 4084;
            if (var5 > var12) {
               var5 = var12;
            }

            int var8 = 0;
            this.done = false;
            this.iState = 1;
            this.objMonitor.notifying();
            boolean var9 = this.sendRFPMessage(1, var12);
            if (this.objConnection.isKX2Device()) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(200, 64, "DoUpdateDevice thread notfiy all...");
               }

               synchronized (mutex) {
                  mutex.notifyAll();
               }
            }

            do {
               var6 = var4.read(var7.toByteArray(), 12, var5);
               if (var6 < 0) {
                  this.iState = 0;
                  var4.close();
                  break;
               }

               var8 += var6;
               if (var6 > 0) {
                  var7.setCommand((byte)53);
                  var7.setCmdLength((short)(12 + var6));
                  var7.setPktID((byte)0);
                  var7.setPhase(2);
                  var7.setFileData(var8);
                  var9 = this.objConnection.sendRFPTRCmd(var7);
                  if (!var9) {
                     this.iState = 0;
                     this.boolCancel = true;
                     var4.close();
                     break;
                  }

                  if (!this.objConnection.isKX2Device()) {
                     if (this.objConnection.getServerID().getProtocolVersion() >= 21) {
                        boolean var20;
                        do {
                           var20 = this.objMonitor.waiting(500);
                        } while (this.objConnection.isConnected() && !this.boolCancel && var20);

                        if (this.iError != 0 && !this.objConnection.isConnected()) {
                           this.iError = 536870913;
                           break;
                        }

                        if (this.iError != 0) {
                           this.iState = 0;
                           var4.close();
                        }
                     }
                  } else {
                     boolean var10;
                     do {
                        var10 = this.objMonitor.waiting(500);
                     } while (this.objConnection.isConnected() && !this.boolCancel && var10);

                     if (this.iError != 0 && !this.objConnection.isConnected()) {
                        this.iError = 536870913;
                        break;
                     }

                     if (this.iError != 0) {
                        this.iState = 0;
                        var4.close();
                     }
                  }
               }

               if (RRCLogger.logEnabled) {
                  RRCLogger.log(200, 64, "Update Device...Sent..." + var8);
               }

               this.progress(var12, var8);
            } while (var6 > 0 && !this.boolCancel);

            if (this.boolCancel) {
               TRConnection.setLastError(this.iError | 33562624);
               this.iState = 0;
               var4.close();
               return false;
            } else {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(200, 64, "Sending done and state is wait result");
               }

               this.iState = 2;
               var9 = this.sendRFPMessage(3, 0);
               if (!var9) {
                  this.iState = 0;
                  var4.close();
                  return false;
               } else {
                  do {
                     boolean var21 = this.objMonitor.waiting(500);
                  } while (this.objConnection.isConnected() && !this.boolCancel && !this.autoReboot && !this.done);

                  if (this.iError != 0) {
                     TRConnection.setLastError(this.iError | 33562624);
                     this.iState = 0;
                     var4.close();
                     return false;
                  } else {
                     var4.close();
                     this.iState = 0;
                     return true;
                  }
               }
            }
         } catch (Exception var16) {
            RRCLogger.logException(var16);
            if (var4 != null) {
               var4.close();
            }

            this.iState = 0;
            return false;
         }
      }
   }

   public boolean sendRFPMessage(int var1, int var2) throws Exception {
      TRCMD_RFP_MESSAGE_DATA var3 = new TRCMD_RFP_MESSAGE_DATA();
      var3.setCmdLength((short)12);
      var3.setCommand((byte)53);
      var3.setPhase(var1);
      var3.setFileData(var2);
      this.objConnection.sendRFPTRCmd(var3);
      return true;
   }

   public boolean getNeedAutoReboot() {
      return this.autoReboot;
   }

   @Override
   public void progress(int var1, int var2) {
   }

   public boolean receive(String var1, String var2, int var3) throws Exception {
      this.resetValues();
      StringBuffer var4 = new StringBuffer();
      boolean var5 = false;
      if (var1.equalsIgnoreCase("DeviceAndPortConfigFile")) {
         var4.append("<?xml version=\"1.0\"?><" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>");
         var4.append("<RFP_File>");
         var4.append("<MetaFileName>DeviceConfigFile</MetaFileName>");
         var4.append("</RFP_File>");
         var4.append("<RFP_File>");
         var4.append("<MetaFileName>MP432PortConfigFile</MetaFileName>");
         var4.append("</RFP_File>");
         var4.append("</" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>");
      } else if (!var1.equalsIgnoreCase("UserConfigFile") && !var1.equalsIgnoreCase("LogExportFile") && !var1.equalsIgnoreCase("DebugLogFile")) {
         String var6 = this.objConnection.isKX2Device() ? "MetaFileName" : "szfileName";
         var4.append("<?xml version=\"1.0\"?><" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>");
         var4.append("<RFP_File><" + var6 + ">" + var1);
         var4.append("</" + var6 + "></RFP_File></" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>");
      } else {
         var4.append("<?xml version=\"1.0\"?><" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>");
         var4.append("<RFP_File>");
         var4.append("<MetaFileName>" + var1 + "</MetaFileName>");
         var4.append("</RFP_File></" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>");
      }

      return this.receiveEx(var4.toString(), var2, var3);
   }

   public boolean sendRFPMessagePackage(String var1) {
      RFPClient.DoRcvRFPThread var2 = null;
      int var3 = var1.length() + 1;
      int var4 = 0;
      TRCMD_RFP_MESSAGE_DATA var6 = new TRCMD_RFP_MESSAGE_DATA();

      try {
         this.iError = 0;
         this.log("rfp request" + var1);
         if (this.objConnection == null) {
            TRConnection.setLastError(-1);
            return false;
         }

         this.boolCancel = false;
         this.objMonitor = new Monitor();
         this.iReceived = 0;
         this.iReceiveFileLength = 0;
         this.iState = 3;
         boolean var8 = this.sendRFPMessage(0, var3);
         if (this.objConnection.isKX2Device()) {
            var2 = new RFPClient.DoRcvRFPThread();
            var2.start();
            Thread.sleep(500L);
            if (RRCLogger.logEnabled) {
               RRCLogger.log(200, 64, "DoUpdateDevice thread notfiy all...");
            }

            synchronized (mutex) {
               mutex.notifyAll();
            }
         }

         if (!var8) {
            TRConnection.setLastError(-1);
            if (RRCLogger.logEnabled) {
               RRCLogger.log(400, 65, "Sending RFP Request_Start failed.");
            }

            return false;
         }

         short var7 = 4084;
         var4 = 0;
         var6.setRFPData(var1.getBytes());

         do {
            int var5;
            if (var3 > var7) {
               var5 = var7;
            } else {
               var5 = var3;
            }

            var6.setPhase(1);
            var6.setFileData(var3);
            var6.setCmdLength((short)(12 + var5));
            var6.setCommand((byte)53);
            var6.setPktID((byte)0);
            var8 = this.objConnection.sendRFPTRCmd(var6);
            if (!var8) {
               TRConnection.setLastError(-1);
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(400, 65, "Sending RFP Message failed.");
               }

               return false;
            }

            var4 += var5;
         } while (var4 < var3);

         var8 = this.sendRFPMessage(2, 0);
         if (!var8) {
            TRConnection.setLastError(-1);
            if (RRCLogger.logEnabled) {
               RRCLogger.log(400, 65, "Sending RFP Request_Done failed.");
            }

            return false;
         }
      } catch (Exception var14) {
         RRCLogger.logException(var14);
      }

      do {
         boolean var9 = this.objMonitor.waiting(500);
      } while (this.objConnection.isConnected() && !this.boolCancel && !this.autoReboot && !this.done);

      TRConnection.setLastError(this.iError | 33562624);
      if (this.iError != 0) {
         this.iState = 0;
         return false;
      } else {
         return true;
      }
   }

   public boolean receiveEx(String var1, String var2, int var3) throws Exception {
      RFPClient.DoRcvRFPThread var4 = null;
      int var5 = var1.length() + 1;
      int var6 = 0;
      TRCMD_RFP_MESSAGE_DATA var8 = new TRCMD_RFP_MESSAGE_DATA();

      try {
         this.log("rfp request" + var1);
         if (this.objConnection == null) {
            return false;
         }

         this.boolCancel = false;
         this.fileReceive = new FileOutputStream(var2);
         this.objMonitor = new Monitor();
         this.iReceived = 0;
         this.iReceiveFileLength = 0;
         this.iError = 0;
         this.iState = 3;
         boolean var10 = this.sendRFPMessage(0, var5);
         if (this.objConnection.isKX2Device()) {
            var4 = new RFPClient.DoRcvRFPThread();
            var4.start();
            Thread.sleep(500L);
            if (RRCLogger.logEnabled) {
               RRCLogger.log(200, 64, "DoUpdateDevice thread notfiy all...");
            }

            synchronized (mutex) {
               mutex.notifyAll();
            }
         }

         if (!var10) {
            this.fileReceive.close();
            return false;
         }

         short var9 = 4084;
         var6 = 0;
         this.iState = 3;
         var8.setRFPData(var1.getBytes());

         do {
            int var7;
            if (var5 > var9) {
               var7 = var9;
            } else {
               var7 = var5;
            }

            var8.setPhase(1);
            var8.setFileData(var5);
            var8.setCmdLength((short)(12 + var7));
            var8.setCommand((byte)53);
            var8.setPktID((byte)0);
            var10 = this.objConnection.sendRFPTRCmd(var8);
            if (!var10) {
               this.fileReceive.close();
               return false;
            }

            var6 += var7;
            var1 = var1 + var7;
         } while (var6 < var5);

         var10 = this.sendRFPMessage(2, 0);
         if (!var10) {
            this.fileReceive.close();
            return false;
         }

         boolean var11;
         do {
            var11 = this.objMonitor.waiting(500);
         } while (this.objConnection.isConnected() && !this.boolCancel && var11);

         if (var4 != null) {
            var4.interrupt();
         }

         if (this.iError != 0 && !this.objConnection.isConnected()) {
            this.iError = 536870913;
         }

         if (this.iError != 0) {
            TRConnection.setLastError(this.iError | 33562624);
            this.iState = 0;
            this.fileReceive.close();
            return false;
         }

         if ((var3 & 1) == 1) {
            return this.stripHeader(var2);
         }
      } catch (Exception var16) {
         RRCLogger.logException(var16);
      }

      this.fileReceive.close();
      return true;
   }

   public boolean stripHeader(String var1) {
      boolean var2 = true;
      RandomAccessFile var6 = null;
      FileOutputStream var7 = null;
      byte[] var8 = new byte[1024];

      try {
         var6 = new RandomAccessFile(var1, "r");
         int var5 = this.parseFile(var6);
         var6.seek(this.iDataOffset);
         var7 = new FileOutputStream("RFP_Tmp9.545");

         int var3;
         do {
            var3 = var6.read(var8, 0, 1024);
            if (var3 < 0) {
               if (var6 != null) {
                  var6.close();
               }

               if (var7 != null) {
                  var7.close();
               }
            }

            var7.write(var8, 0, var3);
            int var4 = var8.length;
            if (var4 != var3) {
               if (var6 != null) {
                  var6.close();
               }

               if (var7 != null) {
                  var7.close();
               }
            }
         } while (var3 == 1024);

         var6.close();
         var7.close();
         var6 = null;
         var7 = null;
         File var9 = new File("RFP_Tmp9.545");
         File var10 = new File(var1);
         var2 = var10.delete();
         var2 = var9.renameTo(var10);
      } catch (Exception var11) {
         RRCLogger.logException(var11);
      }

      return var2;
   }

   private String dumpState(TRRSP_RFP_MESSAGE_DATA var1) {
      String var2 = "UNKNOWN(" + this.iState + ")";
      String var3 = "UNKNOWN(" + var1.getPhase() + ")";
      String var4 = "UNKNOWN(" + var1.getRfpData() + ")";
      switch (this.iState) {
         case 0:
            var2 = "NULL";
            break;
         case 1:
            var2 = "SEND";
            break;
         case 2:
            var2 = "WAIT_RESULT";
            break;
         case 3:
            var2 = "RECV_START";
            break;
         case 4:
            var2 = "RECV_DATA";
            break;
         case 5:
            var2 = "DONE";
      }

      switch (var1.getPhase()) {
         case 1:
            var3 = "REQUEST_DATA";
            break;
         case 2:
            var3 = "DATA";
            break;
         case 3:
            var3 = "DONE";
            break;
         case 4:
            var3 = "CANCEL";
            break;
         case 5:
            var3 = "RESULT";
      }

      switch (var1.getRfpData()) {
         case 0:
            var4 = "UPDATE_SUCCESS";
            break;
         case 13:
            var4 = "INTERNAL";
            break;
         case 24:
            var4 = "PACKET_ACK";
            break;
         case 25:
            var4 = "AUTO_REBOOT";
      }

      return "State = " + var2 + " Phase = " + var3 + " Data = " + var4;
   }

   public boolean TRRSP_RFP_Message(TRCOMMAND var1) {
      TRRSP_RFP_MESSAGE_DATA var4 = new TRRSP_RFP_MESSAGE_DATA(var1.toByteArray());
      if (RRCLogger.logEnabled) {
         RRCLogger.log(200, 64, "RFP MESSAGE : " + this.dumpState(var4));
      }

      try {
         if (var4.getPhase() == 4) {
            if (this.iState != 0) {
               if (var4.getRfpData() != 0) {
                  this.iError = var4.getRfpData();
               } else {
                  this.iError = 0;
               }

               this.iState = 0;
               this.cancel();
            }

            return true;
         }

         label117:
         switch (this.iState) {
            case 0:
               this.iError = 0;
               if (var4.getRfpData() != 0) {
                  if (var4.getRfpData() == 25) {
                     this.autoReboot = true;
                     this.iError = 0;
                  } else if (var4.getRfpData() == 0) {
                     this.done = true;
                     this.iError = 0;
                  } else {
                     this.iError = var4.getRfpData();
                     if (this.objConnection.getServerID().getProtocolVersion() < 21) {
                        this.iError += 536875008;
                     } else {
                        this.iError += 33562624;
                     }
                  }
               } else {
                  this.iError = 0;
               }

               this.objMonitor.notifying();
               return true;
            case 1:
               if (this.objConnection.isKX2Device()) {
                  switch (var4.getPhase()) {
                     case 5:
                        if (var4.getRfpData() != 24) {
                           this.iError = 33562624 + var4.getRfpData();
                           this.boolCancel = true;
                        } else {
                           this.iError = 0;
                        }

                        this.objMonitor.notifying();
                        return true;
                     default:
                        System.err.println("Unexpected RFP Code:" + var4.getPhase());
                  }
               } else if (this.objConnection.getServerID().getProtocolVersion() >= 21) {
                  switch (var4.getPhase()) {
                     case 5:
                        if (var4.getRfpData() != 24) {
                           this.iError = 33562624 + var4.getRfpData();
                           this.boolCancel = true;
                        } else {
                           this.iError = 0;
                        }

                        this.objMonitor.notifying();
                        return true;
                     default:
                        System.err.println("Unexpected RFP Code:" + var4.getPhase());
                  }
               }
               break;
            case 2:
               switch (var4.getPhase()) {
                  case 3:
                     this.iError += 33562624;
                     this.objMonitor.notifying();
                     return true;
                  case 5:
                     if (var4.getRfpData() != 0) {
                        if (var4.getRfpData() == 25) {
                           this.autoReboot = true;
                           this.iError = 0;
                        } else {
                           this.iError = var4.getRfpData();
                           if (this.objConnection.getServerID().getProtocolVersion() < 21) {
                              this.iError += 536875008;
                           } else {
                              this.iError += 33562624;
                           }
                        }
                     } else {
                        this.iError = 0;
                        this.done = true;
                     }

                     this.objMonitor.notifying();
                     return true;
                  default:
                     break label117;
               }
            case 3:
               switch (var4.getPhase()) {
                  case 1:
                     this.iState = 4;
                     this.iReceiveFileLength = var4.getRfpData();
                     this.iReceived = 0;
                     this.progress(this.iReceiveFileLength, 0);
                     return true;
                  default:
                     break label117;
               }
            case 4:
               switch (var4.getPhase()) {
                  case 2:
                     int var2 = var4.getCmdLength() - 12;
                     this.fileReceive.write(var4.toByteArray(), 12, var2);
                     if (var2 + this.iReceived <= this.iReceiveFileLength) {
                        this.iReceived += var2;
                        this.progress(this.iReceiveFileLength, this.iReceived);
                        if (this.iReceived == this.iReceiveFileLength) {
                           this.iState = 5;
                        }

                        return true;
                     }
                  default:
                     break label117;
               }
            case 5:
               switch (var4.getPhase()) {
                  case 3:
                     this.iState = 0;
                     this.iError = 0;
                     this.objMonitor.notifying();
                     return true;
               }
         }

         System.out.println("before cancel RFP state " + this.dumpState(var4));
         this.cancel();
         this.iState = 0;
      } catch (Exception var6) {
         RRCLogger.logException(var6);
      }

      return true;
   }

   public void cancel() {
      if (this.iError == 0) {
         this.iError = 0;
      }

      this.boolCancel = true;
      this.objMonitor.notifying();
   }

   public boolean TRRSP_RFP_Message_Glue(TRCOMMAND var1, Object var2) {
      TRRSP_RFP_MESSAGE_DATA var3 = new TRRSP_RFP_MESSAGE_DATA(var1.toByteArray());
      RFPClient var4 = (RFPClient)var2;
      return var4.TRRSP_RFP_Message(var3);
   }

   private void log(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 64, "RFPCLient::" + var1);
      }
   }

   public static void main(String[] var0) {
      TRLIB_COMM var1 = new TRLIB_COMM();
      TRLIB_USERINFO var2 = new TRLIB_USERINFO();
      TRLIB_REFERRAL_COMM var3 = new TRLIB_REFERRAL_COMM();
      new TRSRVR_SERIAL_PARAMS();
      boolean var5 = false;
      Object var6 = null;

      try {
         var6 = InetAddress.getByName("172.16.35.103");
         var1.setIpAddress(var6.hashCode());
         var1.setConnType(2);
         var1.setServerName("IP Reach".getBytes());
         var1.setDnsName("IP Reach".getBytes());
         var1.setIpPort(5000);
         var1.setFindBy(0);
         var2.setName("admin".getBytes());
         var2.setPassword(Constants.DEFAULT_PASSWORD.getBytes());
         var3.setVersion(1);
         TRConnection var7 = new TRConnection();
         RFPClient var9 = new RFPClient();
         new RFP();
         Thread.sleep(10L);
         RFP var10 = var9.getInfo("c:/temp.RFP");
         if (var10 != null) {
            for (int var11 = 0; var11 < 64; var11++) {
               if (var10.getRfpFile(var11) != null) {
                  if (var10.getRfpFile(var11).getFileName() != null) {
                     System.out.println("fileName  " + new String(var10.getRfpFile(var11).getFileName()));
                  }

                  if (var10.getRfpFile(var11).getScript() != null) {
                     System.out.println("script    " + new String(var10.getRfpFile(var11).getScript()));
                  }

                  if (var10.getRfpFile(var11).getSignature() != null) {
                     System.out.println("signature " + new String(var10.getRfpFile(var11).getSignature()));
                  }

                  if (var10.getRfpFile(var11).getModel() != null) {
                     System.out.println("model     " + new String(var10.getRfpFile(var11).getModel()));
                  }

                  if (var10.getRfpFile(var11).getVersion() != null) {
                     System.out.println("version   " + new String(var10.getRfpFile(var11).getVersion()));
                  }

                  if (var10.getRfpFile(var11).getVersionMin() != null) {
                     System.out.println("versionMin" + new String(var10.getRfpFile(var11).getVersionMin()));
                  }

                  if (var10.getRfpFile(var11).getVersionMax() != null) {
                     System.out.println("versionMax" + new String(var10.getRfpFile(var11).getVersionMax()));
                  }
               }
            }
         }

         var9.stripHeader("c:/temp.RFP");
         System.out.print("Disconnect Connection");
         System.out.println("--------------------------------");
         var7.disConnect();
         System.out.println("**************+Disconnect Successful **********");
      } catch (Exception var12) {
         RRCLogger.logException(var12);
      }
   }

   private class DoRcvRFPThread extends Thread {
      protected DoRcvRFPThread() {
      }

      @Override
      public void run() {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 64, "DoRecieveRFP thread waiting...");
         }

         synchronized (RFPClient.mutex) {
            try {
               RFPClient.mutex.wait();
            } catch (InterruptedException var4) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.logException(var4);
               }

               return;
            }
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 64, "DoRecieveRFP thread awake...");
         }

         RFPClient.this.objConnection.readRFPResponseMessage();
      }
   }
}
