package javaclientlib.clientlib;

import java.io.BufferedInputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.FilterOutputStream;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.InetAddress;
import java.net.Socket;
import java.net.SocketException;
import java.net.SocketTimeoutException;
import java.util.Arrays;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Random;
import java.util.Vector;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javaclientlib.common.RadiusPacket;
import javaclientlib.tr.Constants;
import javaclientlib.tr.RADIUS_ATTRIB_HEADER;
import javaclientlib.tr.RADIUS_ATTRIB_STRING;
import javaclientlib.tr.RADIUS_PACKET;
import javaclientlib.tr.TRCMDWAIT;
import javaclientlib.tr.TRCMD_ACCESS_REQUEST_DATA;
import javaclientlib.tr.TRCMD_CHANGE_PASSWORD_DATA;
import javaclientlib.tr.TRCMD_CLIENT_CHALLENGE_DATA;
import javaclientlib.tr.TRCMD_CLIENT_RESPONSE_DATA;
import javaclientlib.tr.TRCMD_DATABASE_REQUEST_DATA;
import javaclientlib.tr.TRCMD_ENUM_VIDEO_DEVICES_DATA;
import javaclientlib.tr.TRCMD_HANDSHAKE_ACK_DATA;
import javaclientlib.tr.TRCMD_IDENTIFY_REMOTE_DATA;
import javaclientlib.tr.TRCMD_SET_DATA_ITEM_DATA;
import javaclientlib.tr.TRCOMMAND;
import javaclientlib.tr.TRLIB_COMM;
import javaclientlib.tr.TRLIB_REFERRAL_COMM;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.tr.TRRSP_ACCESS_RESPONSE_DATA;
import javaclientlib.tr.TRRSP_DATABASE_RESPONSE_DATA;
import javaclientlib.tr.TRRSP_KB_STATUS_DATA;
import javaclientlib.tr.TRRSP_NACK_DATA;
import javaclientlib.tr.TRRSP_RDM_EVENT_DATA;
import javaclientlib.tr.TRRSP_SERVER_CHALLENGE_DATA;
import javaclientlib.tr.TRRSP_SERVER_RESPONSE_DATA;
import javaclientlib.tr.TRRSP_TARGET_PARAMS_DATA;
import javaclientlib.tr.TRRSP_VIDEO_MARKER_DATA;
import javaclientlib.tr.TRSRVR_CHANNEL_DATA;
import javaclientlib.tr.TRSRVR_SERVER_ID;
import javaclientlib.tr.TRSRVR_TARGET_PARAMS;
import javaclientlib.utils.MD5;
import javaclientlib.utils.Monitor;
import javaclientlib.utils.RC4Cipher;
import javaclientlib.utils.RRCLogger;
import javaclientlib.utils.RRCUtil;
import javaclientlib.utils.SecureSocket;
import javaclientlib.utils.XMLParser;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.xml.sax.SAXException;
import sun.misc.BASE64Decoder;
import sun.misc.BASE64Encoder;

public class TRConnection extends Thread implements ITRConnection {
   protected boolean updateActive = false;
   private int cnt = 0;
   private static XMLParser xmlParser;
   public long lConnectTime;
   private final int DO_NOTHING = 0;
   private final int DONT_READ = 1;
   private final int READ_EXPECTED = 2;
   private final int READ_AVAILABLE = 3;
   private final int READ_UPTO = 4;
   private final int TRLIB_ANY_RESPONSE = 0;
   private final int TR_MAX_VIDEO_STREAM = 256;
   private final int TR_MAX_SERIAL_STREAM = 32;
   private int responseTotalSize = 0;
   private TRCOMMAND objTRBaseCommand;
   private Vector objVSList;
   private Vector objSSList;
   private TRSerialStream objSSAdmin;
   private Hashtable objCmdWaitHashtable;
   private Monitor objSyncMonitor;
   private TRRSP_ACCESS_RESPONSE_DATA accessResponse;
   private TRKeepAliveThread objKeepAliveThrd;
   private TRLIB_COMM objComm;
   public TRLIB_USERINFO objUserInfo;
   private TRLIB_REFERRAL_COMM objReferral;
   private TRSRVR_SERVER_ID objSvrID;
   private TRVideoStream[] objVSArray;
   private TRSerialStream[] objSSArray;
   private RSPDEF[] objRSPDEFList;
   private Object objCriticalSection;
   private Object objMutex;
   private Object objWriteCR;
   private Socket objReadSock;
   private Socket objWriteSock;
   private Socket objEventSock;
   private SecureSocket objEventSSLSocket;
   private DataInputStream objBufferedInputStream = null;
   private DataOutputStream objFilterOutputStream = null;
   private DataInputStream objBufferedInputEventStream = null;
   private FilterOutputStream objFilterOutputEventStream = null;
   private Socket objRFPSock;
   private SecureSocket objRFPSSLSocket;
   private DataInputStream objBufferedInputRFPStream = null;
   private FilterOutputStream objFilterOutputRFPStream = null;
   private SecureSocket objReadSSLSocket;
   private SecureSocket objWriteSSLSocket;
   private byte[] byRand1;
   private byte[] byRand2;
   private byte[] byRand3;
   private byte[] byRand4;
   private byte byChapID;
   private byte[] byChapData;
   private byte[] RC4Key;
   private byte byPktID;
   private boolean boolSingleTCPPortProtocol;
   private boolean boolHaveLoginData;
   private boolean boolCommResolved;
   private boolean boolConnected;
   private boolean boolSocketOK;
   private boolean boolAuthenticated;
   private boolean boolPassWordChangeInprocess;
   private boolean boolDisconnecting;
   private boolean boolNeedSSL;
   private boolean boolNeedRC4;
   private boolean boolOrderlyShutdown;
   private boolean boolObjectGood;
   private boolean boolIsAdministrator;
   private String sessionId;
   private String sessionKey;
   private long lTimeLastMsg;
   private long lLastSeed;
   private long lTimeLastMsgSent;
   private long lPermissions;
   private int iReadCount;
   protected int iDataIn;
   protected int iDataOut;
   private RC4Cipher readRC4;
   private RC4Cipher writeRC4;
   public static Vector objConnVectorList;
   private static int iLastError;
   private String productVersion;
   private String deviceType;
   private boolean isKx2Device = false;
   private boolean isKX101G2Device = false;
   private boolean isKX101G1Device = false;
   private static byte[] byNull = new byte[]{0};
   private int iConnected;
   private int rfpConnected;
   private static String EVENT = "Event";
   private static String RFP = "RFP";
   private static final String GET_DEVICE_ID = "<Database><Get><Select>/System/Device</Select><Nodes> Device </Nodes><SubNodes> Name SerialNo @id</SubNodes></Get></Database>";
   private boolean pingDevice = true;
   private boolean gdMode = false;
   private boolean useTLS = false;

   public static String long2IPString(long var0) {
      StringBuffer var2 = new StringBuffer();
      var2.append(var0 >> 24 & 255L);
      var2.append('.');
      var2.append(var0 >> 16 & 255L);
      var2.append('.');
      var2.append(var0 >> 8 & 255L);
      var2.append('.');
      var2.append(var0 & 255L);
      return var2.toString();
   }

   public static long bytes2LongIP(byte[] var0) {
      long var1 = var0[0] << 24;
      var1 += var0[1] << 16 & 0xFF0000;
      var1 += var0[2] << 8 & 0xFF00;
      return var1 + (var0[3] & 255);
   }

   public TRConnection() {
      this.boolObjectGood = false;
      this.objComm = new TRLIB_COMM();
      this.objReferral = new TRLIB_REFERRAL_COMM();
      this.boolSingleTCPPortProtocol = false;
      this.boolHaveLoginData = this.boolCommResolved = false;
      this.boolConnected = this.boolAuthenticated = false;
      this.boolPassWordChangeInprocess = false;
      this.boolDisconnecting = this.boolNeedSSL = false;
      this.boolNeedRC4 = false;
      this.boolOrderlyShutdown = false;
      this.boolIsAdministrator = false;
      this.sessionId = null;
      this.sessionKey = null;
      this.objReadSock = this.objWriteSock = null;
      this.objEventSock = null;
      this.objSvrID = null;
      this.objReadSSLSocket = null;
      this.objEventSSLSocket = null;
      this.objRFPSock = null;
      this.objRFPSSLSocket = null;
      this.objWriteSSLSocket = new SecureSocket();
      this.objVSArray = new TRVideoStream[256];
      this.objSSArray = new TRSerialStream[32];
      this.objVSList = new Vector();
      this.objSSList = new Vector();
      this.objSSAdmin = null;
      this.byPktID = 1;
      this.objCmdWaitHashtable = new Hashtable();
      this.objSyncMonitor = new Monitor();
      this.objCriticalSection = new Object();
      this.objWriteCR = new Object();
      this.lTimeLastMsg = System.currentTimeMillis();
      this.accessResponse = null;
      this.lPermissions = 0L;
      byte[] var1 = new byte[65535];
      this.objTRBaseCommand = new TRCOMMAND(var1);
      this.byRand1 = new byte[64];
      this.byRand2 = new byte[64];
      this.byRand3 = new byte[64];
      this.byRand4 = new byte[64];
      this.iReadCount = 0;
      this.iDataIn = 0;
      this.iDataOut = 0;
      this.populateRSPDEF();
      this.boolObjectGood = true;
      objConnVectorList = new Vector();
      objConnVectorList.addElement(this);
   }

   @Override
   protected void finalize() {
      if (this.boolObjectGood) {
         objConnVectorList.removeElement(this);
      }

      this.objVSArray = null;
      this.objSSArray = null;
      this.objCmdWaitHashtable = null;
      this.objSyncMonitor = null;
      this.objCriticalSection = null;
      this.objWriteCR = null;
      this.objComm = null;
      this.objReferral = null;
      this.objWriteSSLSocket = null;
      this.objVSList = null;
      this.objSSList = null;
      this.objSSAdmin = null;
      this.accessResponse = null;
      Object var1 = null;
      this.objTRBaseCommand = null;
      this.byRand1 = null;
      this.byRand2 = null;
      this.byRand3 = null;
      this.byRand4 = null;
      objConnVectorList = null;
   }

   private void populateRSPDEF() {
      this.objRSPDEFList = new RSPDEF[48];

      for (int var1 = 0; var1 < 48; var1++) {
         this.objRSPDEFList[var1] = new RSPDEF();
      }

      this.objRSPDEFList[0].populateRSDEF("nop", 2, 4, null, null);
      this.objRSPDEFList[1].populateRSDEF("nop", 0, 0, null, null);
      this.objRSPDEFList[2].populateRSDEF("response", 2, 4, null, null);
      this.objRSPDEFList[3].populateRSDEF("nack", 2, 8, null, null);
      this.objRSPDEFList[43].populateRSDEF("TRRSP_Notify", 3, 4100, null, null);
      this.objRSPDEFList[5].populateRSDEF("pong", 2, 4, null, null);
      this.objRSPDEFList[6].populateRSDEF("response", 2, 78, null, null);
      this.objRSPDEFList[7].populateRSDEF("TRRSP_Server_Challenge", 2, 136, null, null);
      this.objRSPDEFList[28].populateRSDEF("TRRSP_Server_Response", 2, 41, null, null);
      this.objRSPDEFList[9].populateRSDEF("TRRSP_Access_Response", 3, 4100, null, null);
      this.objRSPDEFList[29].populateRSDEF("response", 2, 89, null, null);
      this.objRSPDEFList[47].populateRSDEF("targetParamsChanged", 2, 145, null, null);
      this.objRSPDEFList[11].populateRSDEF("response", 2, 46, null, null);
      this.objRSPDEFList[39].populateRSDEF("TRRSP_New_Video_Mode", 2, 65, null, null);
      this.objRSPDEFList[40].populateRSDEF("TRRSP_Cache", 3, 265, null, null);
      this.objRSPDEFList[41].populateRSDEF("TRRSP_Compressed", 4, 15, null, null);
      this.objRSPDEFList[45].populateRSDEF("TRRSP_Cell_Data", 4, 8, null, null);
      this.objRSPDEFList[42].populateRSDEF("TRRSP_Bitplane", 4, 14, null, null);
      this.objRSPDEFList[16].populateRSDEF("TRRSP_Packed", 4, 4108, null, null);
      this.objRSPDEFList[31].populateRSDEF("TRRSP_Video_Marker", 2, 7, null, null);
      this.objRSPDEFList[32].populateRSDEF("TRRSP_KB_Status", 3, 521, null, null);
      this.objRSPDEFList[19].populateRSDEF("response", 2, 33, null, null);
      this.objRSPDEFList[20].populateRSDEF("TRRSP_Receive_Serial", 4, 7, null, null);
      this.objRSPDEFList[21].populateRSDEF("response", 2, 0, null, null);
      this.objRSPDEFList[23].populateRSDEF("response", 2, 32, null, null);
      this.objRSPDEFList[33].populateRSDEF("response", 2, 12, null, null);
      this.objRSPDEFList[26].populateRSDEF("response", 2, 121, null, null);
      this.objRSPDEFList[35].populateRSDEF("externalResponse", 3, 4108, null, null);
      this.objRSPDEFList[36].populateRSDEF("responseWithAvailableData", 4, 18, null, null);
      this.objRSPDEFList[37].populateRSDEF("response", 2, 5, null, null);
      this.objRSPDEFList[38].populateRSDEF("response", 2, 5, null, null);
      this.objRSPDEFList[46].populateRSDEF("TRRSP_RDM_Event", 3, 4100, null, null);
   }

   public boolean connect(TRLIB_COMM var1, TRLIB_USERINFO var2, byte[] var3, TRLIB_REFERRAL_COMM var4) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "objComm = " + var1);
      }

      try {
         if (var1 == null) {
            setLastError(536870914);
            return false;
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "objComm.getInetAddress() = " + var1.getInetAddress());
         }

         if (var1.getConnType() == 2 && var1.getFindBy() == 0 && var1.getInetAddress().isAnyLocalAddress()) {
            setLastError(536870914);
            return false;
         }

         if (var2 != null) {
            this.boolHaveLoginData = true;
            this.objUserInfo = var2;
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "objRefComm = " + var4);
         }

         if (var4 != null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "objRefComm.getVersion() = " + var4.getVersion());
            }

            if (var4.getVersion() != 1) {
               setLastError(536870914);
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(300, 4, "objRefComm.getVersion() != 1..returning false");
               }

               return false;
            }
         }

         if (var4 != null) {
            this.objReferral = var4;
         } else {
            this.objReferral.setVersion(0);
         }

         this.objComm = var1;
         if (this.isGDMode()) {
            this.rspProc();
         } else if (!this.isAlive()) {
            this.start();
         }
      } catch (Exception var6) {
         RRCLogger.logException(var6);
      }

      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "RConnection.connect returning true");
      }

      return true;
   }

   @Override
   public void run() {
      this.setName("RspProc Thread");
      boolean var1 = this.rspProc();
      this.log("run: RspProc returned " + var1);
   }

   public void dbNotify(int var1, int var2) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, " DBNOTIFY Notice " + var1 + " " + var2);
      }

      if (var1 != 1028) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, System.currentTimeMillis() + " Notice " + var1 + " " + var2);
         }

         this.notify(var1, var2);
      }
   }

   private boolean rasDial() {
      throw new RuntimeException("RAS not Supported in This Version");
   }

   private boolean serverHandshake() {
      boolean var1 = false;
      Object var2 = null;
      int var3 = 0;
      boolean var4 = false;

      try {
         TRCMD_HANDSHAKE_ACK_DATA var5 = new TRCMD_HANDSHAKE_ACK_DATA();
         TRCMD_IDENTIFY_REMOTE_DATA var6 = new TRCMD_IDENTIFY_REMOTE_DATA();
         TRSRVR_SERVER_ID var7 = new TRSRVR_SERVER_ID();
         InetAddress var8 = this.objComm.getInetAddress();
         byte[] var10000 = new byte[]{0, 0, 0, 0};
         this.boolSocketOK = true;
         this.objReadSock.setTcpNoDelay(true);
         this.objReadSock.setSoTimeout(174000);
         this.objWriteSock = this.objReadSock;
         this.objSvrID = new TRSRVR_SERVER_ID();
         var3 = this.negotiateCSC(this.objSvrID);
         if (this.boolDisconnecting) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(200, 4, "Serverhandshake:  negotiateCSC returned " + var3);
            }

            return false;
         } else if (var3 < 0) {
            this.dbNotify(1017, 122);
            return false;
         } else {
            if (var3 > 0) {
               var4 = true;
            }

            if (this.boolDisconnecting) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(200, 4, "Serverhandshake: DISCONNECTING 1 " + var3);
               }

               return false;
            } else {
               if (!this.isKx2Device) {
                  if (this.objSvrID.getProtocolVersion() <= 11) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "Serverhandshake: ProtocolVersion Not Supported :: Protocol Version = 11");
                     }

                     return false;
                  }

                  this.boolSingleTCPPortProtocol = true;
                  if (this.objSvrID.getProtocolVersion() < 11) {
                     this.dbNotify(1014, 15);
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "Serverhandshake: Server's Protocol Version < CSC Prot Version " + var3);
                     }

                     return false;
                  }

                  if (this.objSvrID.getOldestProtocolVersion() > 30) {
                     this.dbNotify(1013, 16);
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "Server's Protocol Version < CSC Prot Version " + var3);
                     }

                     return false;
                  }

                  switch (this.objSvrID.getSecurityFlags() & 3840) {
                     case 256:
                        this.boolNeedSSL = false;
                        break;
                     case 512:
                     case 1024:
                     case 2048:
                        this.boolNeedSSL = true;
                        break;
                     default:
                        this.dbNotify(1016, 16);
                        if (RRCLogger.logEnabled) {
                           RRCLogger.log(200, 4, "Serverhandshake: SecurityFlags Not Set ");
                        }

                        return false;
                  }

                  if (this.boolNeedSSL) {
                     var1 = this.initializeSSL(this.objComm.getInetAddress().getHostAddress(), true);
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 4, "Serverhandshake:  initializeSSL returned " + var1);
                     }

                     if (!var1) {
                        this.dbNotify(1015, 18);
                     }

                     this.createBufferInputStream();
                  }

                  if (this.boolDisconnecting) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "Serverhandshake: DISCONNECTING 2" + var3);
                     }

                     return false;
                  }

                  if (this.objReferral.getVersion() > 0) {
                     this.objWriteSock = this.objReadSock;
                     this.objWriteSSLSocket = this.objReadSSLSocket;
                     DataOutputStream var10 = this.objFilterOutputStream;
                     this.createFilterOutputStream();
                     var3 = this.CSC_Test(this.objReferral.getSessionKey());
                     this.objFilterOutputStream = var10;
                     this.objWriteSock = null;
                     this.objWriteSSLSocket = null;
                     this.createBufferInputStream();
                     if (var3 < 0) {
                        this.dbNotify(1017, 192);
                        return false;
                     }
                  }

                  var1 = this.read(var5.toByteArray(), 0, 34);
                  if (this.boolDisconnecting) {
                     return true;
                  }

                  if (!var1) {
                     this.dbNotify(1017, 20);
                     return false;
                  }

                  if (var5.getSignature() == 1547540642) {
                     if (var5.getCommand() != 43 || var5.getCmdLength() != 34) {
                        this.dbNotify(1016, 21);
                        return false;
                     }
                  } else if (var5.getSignature() != -1958523193 || var5.getCommand() != 43 || var5.getCmdLength() != 34) {
                     this.dbNotify(1016, 21);
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "Serverhandshake: CONNECTION- BAD DATA 3");
                     }

                     return false;
                  }

                  if (this.boolSingleTCPPortProtocol) {
                     var1 = this.svrHndshakeAftSocketCreation(var5, false);
                     if (this.boolDisconnecting) {
                        return false;
                     }

                     if (!var1) {
                        this.dbNotify(1017, 127);
                        return false;
                     }
                  }

                  synchronized (this.objCriticalSection) {
                     if (this.boolSingleTCPPortProtocol) {
                        if (this.objComm.getIpPort() == 0) {
                           this.objWriteSock = new Socket(var8, Constants.TR_PORT_BASE);
                        } else {
                           this.objWriteSock = new Socket(var8, this.objComm.getIpPort());
                           this.log("Serverhandshake: Socket Created");
                        }
                     } else if (this.objComm.getIpPort() == 0) {
                        if (!this.boolDisconnecting) {
                           this.objWriteSock = new Socket(var8, Constants.TR_PORT_BASE + 1);
                        }
                     } else if (!this.boolDisconnecting) {
                        this.objWriteSock = new Socket(var8, this.objComm.getIpPort() + 1);
                        this.log("Serverhandshake: Write Socket Created");
                     }

                     this.objWriteSock.setTcpNoDelay(true);
                     this.objWriteSock.setSoTimeout(174000);
                  }

                  if (this.boolSingleTCPPortProtocol) {
                     Object var30 = null;
                     var30 = this.objReadSock;
                     this.objReadSock = this.objWriteSock;
                     var3 = this.negotiateCSC(var7);
                     if (var3 < 0) {
                        this.dbNotify(1017, 233);
                        return false;
                     }

                     if (this.boolDisconnecting) {
                        return false;
                     }

                     this.objReadSock = (Socket)var30;
                     this.createBufferInputStream();
                  }

                  if (this.boolNeedSSL) {
                     var1 = this.initializeSSL(this.objComm.getInetAddress().getHostAddress(), false);
                     if (!var1) {
                        this.dbNotify(1015, 25);
                        return false;
                     }
                  }

                  if (this.objReferral.getVersion() > 0) {
                     Socket var32 = this.objReadSock;
                     SecureSocket var11 = this.objReadSSLSocket;
                     this.objReadSock = this.objWriteSock;
                     this.objReadSSLSocket = this.objWriteSSLSocket;
                     DataOutputStream var12 = this.objFilterOutputStream;
                     this.createFilterOutputStream();
                     DataInputStream var13 = this.objBufferedInputStream;
                     this.createBufferInputStream();
                     var3 = this.CSC_Test(this.objReferral.getSessionKey());
                     this.objReadSock = var32;
                     this.objReadSSLSocket = var11;
                     this.objBufferedInputStream = var13;
                     this.createFilterOutputStream();
                     if (var3 < 0) {
                        this.dbNotify(1017, 192);
                        return false;
                     }
                  }

                  if (this.boolSingleTCPPortProtocol) {
                     var1 = this.svrHndshakeAftSocketCreation(var5, true);
                     if (this.boolDisconnecting) {
                        return false;
                     }

                     if (!var1) {
                        this.dbNotify(1017, 227);
                        return false;
                     }

                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 4, "Serverhandshake:  svrHndshakeAftSocketCreation returned " + var1);
                     }
                  } else {
                     var1 = this.write(var5.toByteArray(), 34);
                     if (!var1) {
                        this.dbNotify(1017, 327);
                        return false;
                     }
                  }

                  if (this.boolDisconnecting) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 4, "Serverhandshake: DISCONNECTING 3 " + var3);
                     }

                     return false;
                  }

                  var1 = this.read(this.objTRBaseCommand.toByteArray(), 0, 4);
                  if (!var1) {
                     this.dbNotify(1017, 31);
                     return false;
                  }

                  if (this.boolDisconnecting) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 4, "Serverhandshake: DISCONNECTING 4 " + var3);
                     }

                     return false;
                  }

                  if (this.objTRBaseCommand.getCommand() != 2 || this.objTRBaseCommand.getCmdLength() != 4) {
                     if (this.objTRBaseCommand.getCommand() == 3 && this.objTRBaseCommand.getCmdLength() == 8) {
                        byte var34 = -1;
                        TRRSP_NACK_DATA var35 = new TRRSP_NACK_DATA();
                        var35.fromByteArray(this.objTRBaseCommand.toByteArray());
                        var1 = this.read(var35.toByteArray(), 4, 4);
                        if (this.boolDisconnecting) {
                           if (RRCLogger.logEnabled) {
                              RRCLogger.log(200, 4, "Serverhandshake: DISCONNECTING 4 " + var3);
                           }

                           return false;
                        }

                        if (!var1) {
                           this.dbNotify(1017, 28);
                           return false;
                        }

                        if (this.objTRBaseCommand.getInt(4) == 11) {
                           this.dbNotify(1012, 29);
                           if (RRCLogger.logEnabled) {
                              RRCLogger.log(300, 4, "SERVER BUSY");
                           }

                           this.boolOrderlyShutdown = true;
                        }

                        if (RRCLogger.logEnabled) {
                           RRCLogger.log(200, 4, "Serverhandshake: this.objTRBaseCommand.getCommand() == TRRSP.NACK)");
                        }

                        return false;
                     }

                     this.dbNotify(1016, 30);
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "Serverhandshake: NOTIFY BAD DATA - What???");
                     }

                     return false;
                  }

                  this.log("CONNECTION: Everything is OK");
                  if (this.boolSingleTCPPortProtocol) {
                     var6.setProtocolVersion(30);
                     var6.setOSType(0);
                     var6.setFlags(0);
                     var6.setExtraData(0);
                     var6.setReserved(0, 0);
                     var6.setReserved(0, 1);
                     var6.setReserved(0, 2);
                     var6.setReserved(0, 3);
                     var6.setCommand((byte)42);
                     var6.setCmdLength((short)36);
                     var6.setPktID((byte)0);
                     var1 = this.sendTRCmd(var6);
                     if (!var1) {
                        this.dbNotify(1017, 32);
                     }
                  }
               }

               synchronized (this.objCriticalSection) {
                  if (!this.boolDisconnecting) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(300, 4, "CONNECTION Successful");
                     }

                     this.boolConnected = true;
                  }
               }

               return this.boolConnected;
            }
         }
      } catch (Exception var17) {
         RRCLogger.logException(var17);
         return false;
      }
   }

   private void prepareSocket() throws IOException {
      InetAddress var1 = this.objComm.getInetAddress();
      synchronized (this.objCriticalSection) {
         if (!this.boolDisconnecting) {
            if (this.objComm.getIpPort() == 0) {
               this.objReadSock = new Socket(var1, Constants.TR_PORT_BASE + 0);
               this.log("Serverhandshake Read & Event Socket Created 1");
            } else {
               this.objReadSock = new Socket(var1, this.objComm.getIpPort() + 0);
               this.log("Serverhandshake ReadSock: " + this.objReadSock);
            }
         }
      }
   }

   public boolean closeRFPSocketConnection() {
      if (this.isKX2Device()) {
         try {
            if (this.objRFPSock != null) {
               this.objRFPSock.close();
               this.objRFPSock = null;
            }

            if (this.objRFPSSLSocket != null) {
               this.objRFPSSLSocket = null;
            }
         } catch (IOException var2) {
            this.objRFPSock = null;
            if (RRCLogger.logEnabled) {
               RRCLogger.logException(var2);
            }

            return false;
         }
      }

      return true;
   }

   public boolean createRFPSocketConnection() {
      if (this.isKX2Device()) {
         try {
            Object var1 = null;
            byte[] var10000 = new byte[]{0, 0, 0, 0};
            var1 = this.objComm.getInetAddress();
            int var3 = 0;
            if (this.objComm.getIpPort() == 0) {
               var3 = Constants.TR_PORT_BASE;
            } else {
               var3 = this.objComm.getIpPort();
            }

            int var4 = this.connect((InetAddress)var1, var3, RFP);
            if (var4 < 0) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(200, 4, "sendRFPTRCmd:  not able to connect to RFP socket " + var4);
               }

               return false;
            }

            byte[] var5 = this.GetCSCInfo(RFP);
            int var6 = 0;
            if (this.getRdmSessionID() != null && this.getRdmSessionID().length() != 0) {
               var6 = this.startReferralCSCSession("RFP", this.getRdmSessionID(), this.getRdmSessionKey(), RFP);
            } else {
               var6 = this.startNewCSCSession("RFP", (InetAddress)var1, var3, RFP);
            }

            if (var6 < 0) {
               return false;
            }
         } catch (Exception var7) {
            if (RRCLogger.logEnabled) {
               RRCLogger.logException(var7);
            }
         }
      }

      return true;
   }

   public void readRFPResponseMessage() {
      try {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "Reading RFP Message");
         }

         while (this.boolConnected && this.objRFPSock != null) {
            Object var1 = null;
            int var2 = this.readFromStream(this.objTRBaseCommand.toByteArray(), 0, 4, RFP);
            this.iReadCount = 4;
            if (var2 < 0) {
               if (!this.boolDisconnecting && !this.boolOrderlyShutdown && RRCLogger.logEnabled) {
                  RRCLogger.log(100, 4, "Failed to read RFP Message");
               }
               break;
            }

            this.dbLogCmd(true, this.objTRBaseCommand);

            try {
               byte var3 = this.objTRBaseCommand.getCommand();
               if (var3 >= 0 && var3 < this.objRSPDEFList.length) {
                  var1 = this.objRSPDEFList[var3];
               } else {
                  var1 = null;
               }
            } catch (Exception var11) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.logException(var11);
               }

               var1 = null;
            }

            if (var1 == null) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(
                     100, 4, "Connection:RFP Command received does not have a Valid handler Command Received = " + this.objTRBaseCommand.getCommand()
                  );
               }

               this.dbNotify(1016, 8);
               this.boolOrderlyShutdown = false;
               break;
            }

            this.lTimeLastMsg = System.currentTimeMillis();
            int var18 = this.switchRFPFunction((RSPDEF)var1);
            if (var18 == 0) {
               this.log("RFPswitchFunction :entered " + ((RSPDEF)var1).getWhatToDo() + " AFTER SWITCH FUNCTION iResult=" + var18);
               byte var17 = -1;
               if (!this.boolDisconnecting) {
                  this.dbNotify(1017, 10);
               }
               break;
            }

            if (var18 == 1) {
               boolean var15 = false;
            } else if (var18 == 2) {
               continue;
            }

            boolean var4 = false;
            Method var5 = null;
            var1 = this.objRSPDEFList[this.objTRBaseCommand.getCommand()];
            Object var6 = null;
            Class var7 = Class.forName("javaclientlib.clientlib.TRConnection");
            var5 = var7.getDeclaredMethod(((RSPDEF)var1).getMethodName(), (Class<?>[])var6);
            if (var5 == null) {
               this.dbNotify(1016, 9);
               break;
            }

            Object var8 = null;
            Object var9 = var5.invoke(this, (Object[])var8);
            var4 = (Boolean)var9;
            this.log("RFP Invoked Response Handler returned " + var4 + " for method " + var5);
            if (!var4 && this.iReadCount < this.objTRBaseCommand.getCmdLength()) {
               boolean var10 = this.sinkRFPData(this.objTRBaseCommand.getCmdLength() - this.iReadCount);
               if (!var10) {
                  byte var16 = -1;
               }
            }
         }
      } catch (Exception var12) {
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var12);
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(100, 4, "FAILED TO RECIEVE RFP MESSAGE");
         }
      }
   }

   public boolean sendRFPTRCmd(TRCOMMAND var1) {
      if (this.isKx2Device) {
         try {
            var1.setPktID((byte)0);
            if (RRCLogger.shouldLog(300, 4)) {
               this.dbLogCmd(false, var1);
            }

            int var2 = this.writeToStream(var1.toByteArray(), var1.getCmdLength(), RFP);
            return var2 != -20;
         } catch (Exception var3) {
            RRCLogger.logException(var3);
            return false;
         }
      } else {
         return this.sendTRCmd(var1);
      }
   }

   public boolean sendTRCmd(TRCOMMAND var1) {
      try {
         var1.setPktID((byte)0);
         if (RRCLogger.shouldLog(300, 4)) {
            this.dbLogCmd(false, var1);
         }

         this.write(var1.toByteArray(), var1.getCmdLength());
         return true;
      } catch (Exception var3) {
         RRCLogger.logException(var3);
         return false;
      }
   }

   public boolean sendTRCmdEx(TRCOMMAND var1, boolean var2, Monitor var3, int var4) {
      return this.sendTRCmdExx(var1, var2, var3, var4, false, 0);
   }

   public boolean sendTRCmdEx(TRCOMMAND var1, boolean var2, Monitor var3, int var4, int var5) {
      return this.sendTRCmdExx(var1, var2, var3, var4, false, var5);
   }

   public boolean sendTRCmdExx(TRCOMMAND var1, boolean var2, Monitor var3, int var4, boolean var5, int var6) {
      boolean var7 = false;

      try {
         boolean var8 = false;
         TRCMDWAIT var9 = null;
         Monitor var10 = null;
         if (!this.boolConnected) {
            setLastError(536870913);
            return false;
         } else {
            if (var2) {
               if (var1.toByteArray().length < 4) {
                  return false;
               }

               var9 = new TRCMDWAIT();
               var9.setResponse(var1);
               var9.setEvent(var3);
               var9.setStartTime(System.currentTimeMillis());
               var9.setExpRespCommand(var4);
               var9.setSync(var5);
               var9.setPktID(this.byPktID);
               if (var3 == null) {
                  var10 = new Monitor();
                  var9.setEvent(var10);
               }

               synchronized (this.objCriticalSection) {
                  var8 = true;
                  var1.setPktID(this.byPktID);
                  this.objCmdWaitHashtable.put(this.byPktID + "", var9);
                  this.byPktID++;
                  if (this.byPktID == 0) {
                     this.byPktID++;
                  }
               }
            } else {
               var1.setPktID((byte)0);
            }

            if (RRCLogger.shouldLog(300, 4)) {
               this.dbLogCmd(false, var1);
            }

            int var17 = var1.getCmdLength();
            this.log("b4:write");
            var7 = this.write(var1.toByteArray(), var17);
            this.log("aft:write");
            if (!var7) {
               setLastError(536870917);
               return false;
            } else {
               if (var3 == null) {
                  this.log("before:wait" + var10);
                  if (var10.waiting(var6)) {
                     this.log("expired:wait");
                     this.cancelIO(var9);
                     setLastError(536870923);
                     return false;
                  }

                  this.log("after:wait");
               }

               return true;
            }
         }
      } catch (Exception var14) {
         RRCLogger.logException(var14);
         return false;
      }
   }

   public boolean sendTRCmdExxx(TRCOMMAND var1, TRCMDWAIT var2, int var3, boolean var4, int var5) {
      boolean var6 = false;

      try {
         boolean var7 = false;
         Monitor var8 = null;
         if (var2 != null) {
            var8 = var2.getEvent();
         }

         if (!this.boolConnected) {
            setLastError(536870913);
            return false;
         } else if (var1.toByteArray().length < 4) {
            return false;
         } else {
            if (var2 == null) {
               var2 = new TRCMDWAIT();
            }

            var2.setResponse(var1);
            var2.setStartTime(System.currentTimeMillis());
            var2.setExpRespCommand(var3);
            var2.setSync(var4);
            var2.setPktID(this.byPktID);
            if (var8 == null) {
               var8 = new Monitor();
               var2.setEvent(var8);
            }

            synchronized (this.objCriticalSection) {
               var7 = true;
               var1.setPktID(this.byPktID);
               this.objCmdWaitHashtable.put(this.byPktID + "", var2);
               this.byPktID++;
               if (this.byPktID == 0) {
                  this.byPktID++;
               }
            }

            if (RRCLogger.shouldLog(300, 4)) {
               this.dbLogCmd(false, var1);
            }

            int var15 = var1.getCmdLength();
            this.log("b4:write");
            var6 = this.write(var1.toByteArray(), var15);
            this.log("aft:write");
            if (!var6) {
               return false;
            } else {
               this.log("before:wait" + var8);
               if (var8.waiting(var5)) {
                  this.log("expired:wait");
                  this.cancelIO(var2);
                  setLastError(536870917);
                  return false;
               } else {
                  this.log("after:wait");
                  return true;
               }
            }
         }
      } catch (Exception var12) {
         RRCLogger.logException(var12);
         return false;
      }
   }

   private boolean response() throws Exception {
      try {
         TRCMDWAIT var1;
         synchronized (this.objCriticalSection) {
            var1 = (TRCMDWAIT)this.objCmdWaitHashtable.get(this.objTRBaseCommand.getPktID() + "");
            if (var1 != null) {
               this.objCmdWaitHashtable.remove(this.objTRBaseCommand.getPktID() + "");
            }
         }

         TRRSP_NACK_DATA var6 = new TRRSP_NACK_DATA(this.objTRBaseCommand.toByteArray());
         if (var1 != null) {
            if (this.objTRBaseCommand.getCommand() == 3) {
               var6.setError(var6.getError() + 536875008);
            } else if (var1.getExpRespCommand() != 0 && this.objTRBaseCommand.getCommand() != var1.getExpRespCommand()) {
               var6.setCommand((byte)3);
               var6.setCmdLength((short)8);
               var6.setError(536870916);
            }

            if (this.iReadCount > 4108) {
               var6.setCommand((byte)3);
               var6.setCmdLength((short)8);
               var6.setError(536870915);
            }

            System.arraycopy(this.objTRBaseCommand.toByteArray(), 0, var1.getResponse().toByteArray(), 0, this.iReadCount);
            if (var1.getEvent() != null) {
               this.log("b4Notify - Response()" + var1.getEvent());
               var1.getEvent().notifying();
               this.log("After Notify - Response()" + var1.getEvent());
            }

            if (this.objTRBaseCommand.getCommand() == 2 && this.boolPassWordChangeInprocess) {
               this.boolPassWordChangeInprocess = false;
               this.sendAccessRequest(false);
            }

            if (var1.getSync()) {
               this.objSyncMonitor.waiting(0);
            }
         }

         return var1 != null;
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         throw var5;
      }
   }

   private boolean responseWithAvailableData() throws Exception {
      try {
         TRCMDWAIT var1;
         synchronized (this.objCriticalSection) {
            var1 = (TRCMDWAIT)this.objCmdWaitHashtable.get(this.objTRBaseCommand.getPktID() + "");
            if (var1 != null) {
               this.objCmdWaitHashtable.remove(this.objTRBaseCommand.getPktID() + "");
            }
         }

         TRRSP_NACK_DATA var6 = new TRRSP_NACK_DATA(this.objTRBaseCommand.toByteArray());
         if (var1 != null) {
            if (this.objTRBaseCommand.getCommand() == 3) {
               var6.setError(var6.getError() + 536875008);
            } else if (var1.getExpRespCommand() != 0 && this.objTRBaseCommand.getCommand() != var1.getExpRespCommand()) {
               var6.setCommand((byte)3);
               var6.setCmdLength((short)8);
               var6.setError(536870916);
            }

            if (this.iReadCount > 4108) {
               var6.setCommand((byte)3);
               var6.setCmdLength((short)8);
               var6.setError(536870915);
            }

            System.arraycopy(this.objTRBaseCommand.toByteArray(), 0, var1.getResponse().toByteArray(), 0, this.iReadCount);
            if (this.responseTotalSize > 0) {
               byte[] var3 = new byte[this.responseTotalSize];
               this.read(var3, 0, this.responseTotalSize);
               this.iReadCount = this.iReadCount + this.responseTotalSize;
               var1.setAvailableData(var3);
            } else {
               var1.setAvailableData(null);
            }

            if (var1.getEvent() != null) {
               this.log("b4Notify - Response()" + var1.getEvent());
               var1.getEvent().notifying();
               this.log("After Notify - Response()" + var1.getEvent());
            }

            if (this.objTRBaseCommand.getCommand() == 2 && this.boolPassWordChangeInprocess) {
               this.boolPassWordChangeInprocess = false;
               this.sendAccessRequest(false);
            }

            if (var1.getSync()) {
               this.objSyncMonitor.waiting(0);
            }
         } else {
            this.sinkData(this.objTRBaseCommand.getCmdLength() - this.iReadCount);
            this.iReadCount = this.objTRBaseCommand.getCmdLength();
         }

         return var1 != null;
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         throw var5;
      }
   }

   private int negotiateCSC(TRSRVR_SERVER_ID var1) throws Exception {
      boolean var2 = this.boolNeedSSL;
      this.boolNeedSSL = false;
      this.createBufferInputStream();
      this.createFilterOutputStream();
      byte[] var3 = new byte[74];
      Object var4 = null;
      Object var5 = null;
      int var6 = 0;
      boolean var7 = false;
      if (this.objReferral.getConnectionID()[0] != 0) {
         var4 = "<CSC_Connect ConnectionID=\"" + new String(this.objReferral.getConnectionID()) + "\"/>";
         var7 = this.writeCSCMessage(var4.getBytes(), 0);
         if (!var7) {
            this.boolNeedSSL = var2;
            return -1;
         }
      }

      var7 = this.read(var3, 0, 4);
      if (!var7) {
         this.boolNeedSSL = var2;
         return -1;
      } else {
         int var8 = ((var3[3] & 255) << 24) + ((var3[2] & 255) << 16) + ((var3[1] & 255) << 8) + ((var3[0] & 255) << 0);
         var6 = ((var3[0] & 255) << 24) + ((var3[1] & 255) << 16) + ((var3[2] & 255) << 8) + ((var3[3] & 255) << 0);
         if (var6 != 74 && var8 != 74) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "CSC Negotiation: Talking to a CSC-compliant server.");
            }

            var6 -= 4;
            if (var6 > 2000) {
               return -1;
            } else {
               byte[] var9 = new byte[var6 + 1];
               var7 = this.read(var9, 0, var6);
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(400, 4, "CSC Negotiation: Searching for <CSC/>, got: " + new String(var9));
               }

               if (!var7) {
                  this.boolNeedSSL = var2;
                  return -1;
               } else {
                  var7 = this.writeCSCMessage("<CSC_Ack/>".getBytes(), 0);
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(400, 4, "CSC Negotiation: Writing <CSC_Ack/>.");
                  }

                  var5 = this.readCSCMessage(4096, 0);
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(400, 4, "CSC Negotiation: Received for CSC_Info: " + new String((byte[])var5));
                  }

                  if (var5 == null) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(100, 4, "CSC Negotiation: Received NULL when expecting CSC_Info element.");
                     }

                     this.boolNeedSSL = var2;
                     return -1;
                  } else {
                     this.isKx2Device = this.checkForKX2Device(new String((byte[])var5).substring(0, ((Object[])var5).length - 1));
                     var5 = null;
                     if (this.objReferral.getVersion() > 0) {
                        var4 = "<CSC_Start_Session ProtocolID=\""
                           + (this.isKx2Device ? "RDM" : "IP-Reach")
                           + "\" SessionID=\""
                           + new String(this.objReferral.getSessionID())
                           + "\"/>";
                     } else {
                        var4 = "<CSC_Start_Session ProtocolID=\"" + (this.isKx2Device ? "RDM" : "IP-Reach") + "\"/>";
                     }

                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(400, 4, "CSC Negotiation: Writing CSC_Session: " + var4);
                     }

                     var7 = this.writeCSCMessage(var4.getBytes(), 0);
                     if (!var7) {
                        if (RRCLogger.logEnabled) {
                           RRCLogger.log(100, 4, "CSC Negotiation: Failure writing request for CSC_Session.");
                        }

                        this.boolNeedSSL = var2;
                        return -1;
                     } else {
                        if (!this.isKx2Device) {
                           var7 = this.read(var3, 0, 74);
                           var1.populate(var3);
                           if (!var7) {
                              this.boolNeedSSL = var2;
                              return -1;
                           }
                        }

                        this.boolNeedSSL = var2;
                        return 1;
                     }
                  }
               }
            }
         } else {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "CSC Negotiation: found an older, non-CSC server.");
            }

            var7 = this.read(var3, 4, 70);
            if (!var7) {
               this.boolNeedSSL = var2;
               return -1;
            } else {
               return 0;
            }
         }
      }
   }

   public int startNewCSCSession(String var1, InetAddress var2, int var3, String var4) {
      String var5 = new String("<CSC_Start_Session ProtocolID=\"" + var1 + "\"/>");
      int var6 = var5.length() + 1 + 4;
      int var8 = this.writeToStream(RRCUtil.getBytesForInt(var6), 4, var4);
      var8 = this.writeToStream(var5.getBytes(), var5.length(), var4);
      var8 = this.writeToStream(byNull, 1, var4);
      if (var8 < 0) {
         return var8;
      } else {
         try {
            if (EVENT.equals(var4)) {
               this.objEventSSLSocket = new SecureSocket(this.objEventSock, this.objComm.getInetAddress().getHostAddress(), var3, this.getUseTLS());
               this.objEventSSLSocket.connect();
            }

            if (RFP.equals(var4)) {
               this.objRFPSSLSocket = new SecureSocket(this.objRFPSock, this.objComm.getInetAddress().getHostAddress(), var3, this.getUseTLS());
               this.objRFPSSLSocket.connect();
            }

            boolean var10 = this.boolNeedSSL;
            this.boolNeedSSL = true;
            this.createBufferInputTypeStream(var4);
            this.createFilterOutputTypeStream(var4);
            var8 = this.doCSCAuthentication(var4);
            this.boolNeedSSL = var10;
         } catch (Exception var11) {
            var8 = -1;
            if (RRCLogger.logEnabled) {
               RRCLogger.logException(var11);
            }
         }

         return var8;
      }
   }

   private int doCSCAuthentication(String var1) {
      String var2 = Util.escapeXML(new String(this.objUserInfo.getPassword()));
      String var3 = "<CSC_Auth UserName=\"" + new String(this.objUserInfo.getName()) + "\" Password=\"" + var2 + "\"/>";
      int var4 = this.writeMessage(var3.getBytes(), var1);
      byte[] var5 = this.readMessage(256, var1);
      String var6 = new String(var5).substring(0, var5.length - 1);
      return var6.equals("<CSC_Pass/>") ? 0 : -1;
   }

   public int connect(InetAddress var1, int var2, String var3) {
      try {
         if (var2 == 0) {
            var2 = Constants.TR_PORT_BASE;
         }

         if (var3.equals(EVENT)) {
            this.iConnected = 0;
            this.objEventSock = new Socket(var1, var2);
            if (this.objEventSock == null) {
               return -2;
            }

            this.objEventSock.setTcpNoDelay(true);
         }

         if (var3.equals(RFP)) {
            this.rfpConnected = 0;
            this.objRFPSock = new Socket(var1, var2);
            if (this.objRFPSock == null) {
               return -2;
            }

            this.objRFPSock.setTcpNoDelay(true);
         }

         this.boolNeedSSL = false;
         this.createBufferInputTypeStream(var3);
         this.createFilterOutputTypeStream(var3);
         if (var3.equals(EVENT)) {
            this.iConnected = 1;
         } else if (var3.equals(RFP)) {
            this.rfpConnected = 1;
         }

         if (this.objReferral.getConnectionID()[0] != 0) {
            String var4 = new String(this.objReferral.getConnectionID());
            byte[] var7 = new byte[]{0};
            String var5 = "<CSC_Connect ConnectionID=\"" + var4 + "\"/>";
            int var6 = 4 + var5.getBytes().length + 1;
            this.writeToStream(RRCUtil.getBytesForInt(var6), 4, var3);
            this.writeToStream(var5.getBytes(), var5.getBytes().length, var3);
            this.writeToStream(var7, 1, var3);
         }

         return 0;
      } catch (Exception var8) {
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var8);
         }

         return -2;
      }
   }

   public String getNodeString(String var1, String var2) {
      if (var1 == null) {
         return null;
      } else {
         int var3 = var1.indexOf("<" + var2 + ">");
         int var4 = var1.indexOf("</" + var2 + ">");
         return var3 != -1 && var4 != -1 ? var1.substring(var3 + var2.length() + 2, var4) : null;
      }
   }

   public byte[] GetCSCInfo(String var1) {
      String var2 = new String("<CSC_Ack/>");
      byte[] var3 = new byte[200];
      byte[] var6 = new byte[4];
      boolean var8 = false;
      int var7 = this.readFromStream(var3, 0, 4, var1);
      if (var7 < 0) {
         return null;
      } else {
         int var4 = this.getIntForBytes(var3, 0);
         if (var4 > 200) {
            return null;
         } else {
            var7 = this.readFromStream(var3, 0, var4, var1);
            var4 = var2.length() + 4 + 1;
            var7 = this.writeToStream(RRCUtil.getBytesForInt(var4), 4, var1);
            var7 = this.writeToStream(var2.getBytes(), var2.length(), var1);
            var7 = this.writeToStream(byNull, 1, var1);
            if (var7 < 0) {
               return null;
            } else {
               var7 = this.readFromStream(var6, 0, 4, var1);
               if (var7 < 0) {
                  return null;
               } else {
                  var4 = this.getIntForBytes(var6, 0);
                  var4 -= 4;
                  var6 = new byte[var4];
                  if (var6 == null) {
                     return null;
                  } else {
                     var7 = this.readFromStream(var6, 0, var4, var1);
                     return var7 < 0 ? null : var6;
                  }
               }
            }
         }
      }
   }

   public int writeMessage(byte[] var1, String var2) {
      int var4 = 0;
      int var5 = 4 + var1.length + 1;
      var4 = this.writeToStream(RRCUtil.getBytesForInt(var5), 4, var2);
      if (var4 < 0) {
         return var4;
      } else {
         var4 = this.writeToStream(var1, var5 - 4 - 1, var2);
         if (var4 < 0) {
            return var4;
         } else {
            var4 = this.writeToStream(byNull, 1, var2);
            return var4 < 0 ? var4 : var4;
         }
      }
   }

   public byte[] readMessage(int var1, String var2) {
      byte[] var6 = new byte[4];
      int var4 = this.readFromStream(var6, 0, 4, var2);
      if (var4 < 0) {
         return null;
      } else {
         int var3 = this.getIntForBytes(var6, 0);
         if (var1 > 0 && var3 > var1) {
            return null;
         } else if (var3 < 9) {
            return null;
         } else {
            byte[] var5 = new byte[var3 - 4];
            if (var5 == null) {
               return null;
            } else {
               var4 = this.readFromStream(var5, 0, var3 - 4, var2);
               return var4 < 0 ? null : var5;
            }
         }
      }
   }

   public int writeToStream(byte[] var1, int var2, String var3) {
      byte var4 = 0;

      try {
         if (var3.equals(EVENT)) {
            this.objFilterOutputEventStream.write(var1, 0, var2);
            this.objFilterOutputEventStream.flush();
         }

         if (var3.equals(RFP)) {
            this.objFilterOutputRFPStream.write(var1, 0, var2);
            this.objFilterOutputRFPStream.flush();
         }
      } catch (Exception var7) {
         this.boolConnected = false;
         this.boolSocketOK = false;
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var7);
         }

         if (var3.equals(EVENT)) {
            this.iConnected = 0;
         } else if (var3.equals(RFP)) {
            this.rfpConnected = 0;
         }

         var4 = -20;
      }

      try {
         if (var4 == -20) {
            RRCLogger.log(300, 4, "Calling rspProcExitFunction, iOk: " + var4);
            this.rspProcExitFunction();
         }
      } catch (Exception var6) {
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var6);
         }
      }

      return var4;
   }

   public int readFromStream(byte[] var1, int var2, int var3, String var4) {
      boolean var5 = true;
      byte var6 = 0;
      int var7 = -1;

      try {
         if (var4.equals(EVENT)) {
            if (this.iConnected == 0) {
               return -10;
            }

            var7 = this.objBufferedInputEventStream.read(var1, var2, var3);
         }

         if (var4.equals(RFP)) {
            if (this.rfpConnected == 0) {
               return -10;
            }

            var7 = this.objBufferedInputRFPStream.read(var1, var2, var3);
         }
      } catch (Exception var9) {
         RRCLogger.log(300, -1, "byData : " + var1 + " byDataLen : " + var1.length + " iOffset : " + var2 + " iCount : " + var3);
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var9);
         }

         var5 = false;
      }

      if (var7 < 0 || !var5) {
         if (var4.equals(EVENT)) {
            this.iConnected = 0;
         } else if (var4.equals(RFP)) {
            this.rfpConnected = 0;
         }

         var6 = -20;
      }

      return var6;
   }

   private int getIntForBytes(byte[] var1, int var2) {
      return ((var1[var2 + 0] & 0xFF) << 24) + ((var1[var2 + 1] & 0xFF) << 16) + ((var1[var2 + 2] & 0xFF) << 8) + ((var1[var2 + 3] & 0xFF) << 0);
   }

   public int startReferralCSCSession(String var1, String var2, String var3, String var4) {
      String var5 = null;
      if (var2 != null) {
         var5 = new String("<CSC_Start_Session ProtocolID=\"" + var1 + "\" SessionID=\"" + var2 + "\"/>");
      } else {
         var5 = new String("<CSC_Start_Session ProtocolID=\"" + var1 + "\"/>");
      }

      int var7 = 0;
      int var6 = var5.length() + 1 + 4;
      this.writeToStream(RRCUtil.getBytesForInt(var6), 4, var4);
      this.writeToStream(var5.getBytes(), var6 - 5, var4);
      this.writeToStream(byNull, 1, var4);

      try {
         if (var4.equals(EVENT)) {
            if (this.objComm.getIpPort() == 0) {
               this.objEventSSLSocket = new SecureSocket(
                  this.objEventSock, this.objComm.getInetAddress().getHostAddress(), Constants.TR_PORT_BASE, this.getUseTLS()
               );
            } else {
               this.objEventSSLSocket = new SecureSocket(
                  this.objEventSock, this.objComm.getInetAddress().getHostAddress(), this.objComm.getIpPort(), this.getUseTLS()
               );
            }

            this.objEventSSLSocket.connect();
         }

         if (var4.equals(RFP)) {
            if (this.objComm.getIpPort() == 0) {
               this.objRFPSSLSocket = new SecureSocket(
                  this.objRFPSock, this.objComm.getInetAddress().getHostAddress(), Constants.TR_PORT_BASE, this.getUseTLS()
               );
            } else {
               this.objRFPSSLSocket = new SecureSocket(
                  this.objRFPSock, this.objComm.getInetAddress().getHostAddress(), this.objComm.getIpPort(), this.getUseTLS()
               );
            }

            this.objRFPSSLSocket.connect();
         }

         boolean var8 = this.boolNeedSSL;
         this.boolNeedSSL = true;
         this.createBufferInputTypeStream(var4);
         this.createFilterOutputTypeStream(var4);
         var7 = this.authReferralCSCSession(var3.getBytes(), var4);
         this.boolNeedSSL = var8;
      } catch (Exception var9) {
         var9.printStackTrace();
         var7 = -1;
         if (RRCLogger.logEnabled) {
            RRCLogger.log(100, 4, "startReferralCSCSession: Failure Creating Sockets.");
            RRCLogger.logException(var9);
         }
      }

      return var7;
   }

   public boolean isAdminUser() {
      return this.boolIsAdministrator;
   }

   public boolean isKX2Device() {
      return this.isKx2Device;
   }

   public boolean hasGNULicenseInfo() {
      return this.isKx2Device
         && (
            this.deviceType.equals("Dominion_KX2")
               || this.deviceType.equals("Dominion_KSX2")
               || this.deviceType.equals("Dominion_KX2_101")
               || this.deviceType.equals("Dominion_LX")
         );
   }

   private int authReferralCSCSession(byte[] var1, String var2) {
      try {
         Object var4 = null;
         Object var5 = null;
         Object var6 = null;
         Object var7 = null;
         Object var9 = null;
         Object var10 = null;
         String var11 = "1234567890";
         Object var12 = null;
         Object var13 = null;
         Object var14 = null;
         var9 = new BASE64Decoder().decodeBuffer(new String(var1));
         var12 = this.readMessage(0, var2);
         new String((byte[])var12);
         if (var12 == null) {
            return -10;
         } else {
            var13 = this.getAttributeValue(new String((byte[])var12), "ClearText");
            var12 = null;
            if (var13 == null) {
               return -1;
            } else {
               var4 = new BASE64Decoder().decodeBuffer(new String((byte[])var13));
               int var15 = ((Object[])var4).length;
               RC4Cipher var16 = new RC4Cipher((byte[])var9);
               var16.encrypt((byte[])var4, 0, (byte[])var4, 0, var15);
               RC4Cipher var37 = null;
               var6 = new BASE64Encoder().encode((byte[])var4).getBytes();
               var15 = (int)System.currentTimeMillis();
               byte[] var18 = var11.getBytes();
               var5 = new byte[var18.length];

               for (int var19 = 0; var19 < var18.length; var19++) {
                  ((Object[])var5)[var19] = (byte)(var18[var19] ^ (char)var15);
                  var15 >>= 3;
                  var15 = (int)(var15 ^ System.currentTimeMillis());
               }

               var7 = new BASE64Encoder().encode((byte[])var5).getBytes();
               var15 = ((Object[])var7).length;
               String var8 = "<CSC_Test2 Encrypted=\"" + new String((byte[])var6) + "\" ClearText=\"" + new String((byte[])var7) + "\"/>";
               var15 = this.writeMessage(var8.getBytes(), var2);
               if (var15 < 0) {
                  return var15;
               } else {
                  var12 = this.readMessage(0, var2);
                  if (var12 == null) {
                     return -10;
                  } else {
                     var14 = this.getAttributeValue(new String((byte[])var12), "Encrypted");
                     var12 = null;
                     if (var14 == null) {
                        return -1;
                     } else {
                        var4 = new BASE64Decoder().decodeBuffer(new String((byte[])var14));
                        var37 = new RC4Cipher((byte[])var9);
                        var37.decrypt((byte[])var4, 0, (byte[])var4, 0, ((Object[])var4).length);
                        if (((Object[])var4).length != var18.length) {
                           return -1;
                        } else {
                           for (int var39 = 0; var39 < var18.length; var39++) {
                              if (((Object[])var5)[var39] != ((Object[])var4)[var39]) {
                                 return -1;
                              }
                           }

                           return 0;
                        }
                     }
                  }
               }
            }
         }
      } catch (Exception var20) {
         RRCLogger.logException(var20);
         return -1;
      }
   }

   private int CSC_Test(byte[] var1) {
      try {
         Object var3 = null;
         Object var4 = null;
         Object var5 = null;
         Object var6 = null;
         Object var8 = null;
         Object var9 = null;
         String var10 = "!@%!@#%$%#$%";
         Object var11 = null;
         Object var12 = null;
         Object var13 = null;
         Object var14 = null;
         var11 = var10.getBytes();
         var8 = new BASE64Decoder().decodeBuffer(new String(var1));
         var12 = this.readCSCMessage(1024, 1);
         if (var12 == null) {
            return 0;
         } else {
            var13 = this.getAttributeValue(new String((byte[])var12), "ClearText");
            var12 = null;
            if (var13 == null) {
               return -1;
            } else {
               var3 = new BASE64Decoder().decodeBuffer(new String((byte[])var13));
               int var15 = ((Object[])var3).length;
               RC4Cipher var16 = new RC4Cipher((byte[])var8);
               var16.encrypt((byte[])var3, 0, (byte[])var3, 0, var15);
               RC4Cipher var35 = null;
               var5 = new BASE64Encoder().encode((byte[])var3).getBytes();
               var15 = (int)System.currentTimeMillis();
               var4 = new byte[((Object[])var11).length];

               for (int var17 = 0; var17 < ((Object[])var11).length; var17++) {
                  ((Object[])var4)[var17] = (byte)(((Object[])var11)[var17] ^ (char)var15);
                  var15 >>= 3;
                  var15 = (int)(var15 ^ System.currentTimeMillis());
               }

               var6 = new BASE64Encoder().encode((byte[])var4).getBytes();
               var15 = ((Object[])var6).length;
               String var7 = "<CSC_Test2 Encrypted=\"" + new String((byte[])var5) + "\" ClearText=\"" + new String((byte[])var6) + "\"/>";
               boolean var2 = this.writeCSCMessage(var7.getBytes(), 1);
               if (!var2) {
                  return var15;
               } else {
                  var12 = this.readCSCMessage(1024, 1);
                  if (var12 == null) {
                     return -1;
                  } else {
                     var14 = this.getAttributeValue(new String((byte[])var12), "Encrypted");
                     var12 = null;
                     if (var14 == null) {
                        return -1;
                     } else {
                        var3 = new BASE64Decoder().decodeBuffer(new String((byte[])var14));
                        var35 = new RC4Cipher((byte[])var8);
                        var35.decrypt((byte[])var3, 0, (byte[])var3, 0, ((Object[])var3).length);
                        if (((Object[])var3).length != ((Object[])var11).length) {
                           return -1;
                        } else {
                           for (int var37 = 0; var37 < ((Object[])var11).length; var37++) {
                              if (((Object[])var4)[var37] != ((Object[])var3)[var37]) {
                                 System.out.println("Not matching at " + var37);
                                 return -1;
                              }
                           }

                           return 0;
                        }
                     }
                  }
               }
            }
         }
      } catch (Exception var18) {
         RRCLogger.logException(var18);
         return -1;
      }
   }

   public boolean writeCSCMessage(byte[] var1, int var2) {
      byte[] var4 = new byte[]{0};
      int var5 = 4 + var1.length + 1;
      synchronized (this.objWriteCR) {
         boolean var3 = this.write(RRCUtil.getBytesForInt(var5), 4);
         if (!var3) {
            return var3;
         } else {
            var3 = this.write(var1, var5 - 4 - 1);
            return this.write(var4, 1);
         }
      }
   }

   public byte[] readCSCMessage(int var1, int var2) {
      synchronized (this.objWriteCR) {
         byte[] var8 = new byte[4];
         boolean var3 = this.read(var8, 0, 4);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(100, 17, "READ CSC MESSAGE - 4 byte header: " + new String(var8));
         }

         if (!var3) {
            return null;
         } else {
            int var4 = ((var8[0] & 255) << 24) + ((var8[1] & 255) << 16) + ((var8[2] & 255) << 8) + ((var8[3] & 255) << 0);
            if (var1 > 0 && var4 > var1) {
               return null;
            } else if (var4 < 9) {
               return null;
            } else {
               byte[] var6 = new byte[var4 - 4];
               if (var6 == null) {
                  return null;
               } else {
                  var3 = this.read(var6, 0, var4 - 4);
                  return !var3 ? null : var6;
               }
            }
         }
      }
   }

   private byte[] getAttributeValue(String var1, String var2) {
      String var3 = " " + var2 + "=\"";
      int var4 = -1;
      if (var1 == null) {
         return null;
      } else {
         var4 = var1.indexOf(var3);
         if (var4 == -1) {
            var3 = " " + var2 + "= \"";
            var4 = var1.indexOf(var3);
            if (var4 == -1) {
               var3 = " " + var2 + " =\"";
               var4 = var1.indexOf(var3);
               if (var4 == -1) {
                  var3 = " " + var2 + " = \"";
                  var4 = var1.indexOf(var3);
               }
            }
         }

         if (var4 == -1) {
            return null;
         } else {
            int var5 = var4 + var3.length();
            int var6 = var1.indexOf("\"", var5);
            int var7 = var4 + var3.length();
            if (var6 != -1) {
               String var8 = var1.substring(var5, var6);
               if (var8.charAt(var8.length() - 1) == '\n') {
                  var8 = var8.substring(0, var8.length() - 1);
               }

               if (var8 != null) {
                  return var8.getBytes();
               }
            }

            return null;
         }
      }
   }

   private boolean initializeSSL(String var1, boolean var2) {
      try {
         int var3 = 0;
         this.log("Inside InitializeSSL()");
         if (this.objComm.getIpPort() == 0) {
            var3 = Constants.TR_PORT_BASE + 0;
         } else {
            var3 = this.objComm.getIpPort() + 0;
         }

         if (var2) {
            this.objReadSSLSocket = new SecureSocket(this.objReadSock, var1, var3, this.getUseTLS());
            this.log("this.objReadSSLSocket  " + this.objReadSSLSocket);
            this.objReadSSLSocket.connect();
            this.log("this.objReadSSLSocket.connect()  ");
         } else {
            this.objWriteSSLSocket = new SecureSocket(this.objWriteSock, var1, var3, this.getUseTLS());
            this.objWriteSSLSocket.connect();
         }

         return true;
      } catch (Exception var4) {
         RRCLogger.logException(var4);
         return false;
      }
   }

   private void createBufferInputStream() throws Exception {
      if (this.boolNeedRC4) {
         this.objBufferedInputStream = new DataInputStream(new BufferedInputStream(this.objReadSock.getInputStream()));
      } else if (this.boolNeedSSL) {
         this.objBufferedInputStream = new DataInputStream(new BufferedInputStream(this.objReadSSLSocket.getSecureInputStream()));
      } else {
         this.objBufferedInputStream = new DataInputStream(new BufferedInputStream(this.objReadSock.getInputStream()));
      }
   }

   private void createFilterOutputStream() throws Exception {
      if (this.boolNeedRC4) {
         this.objFilterOutputStream = new DataOutputStream(this.objWriteSock.getOutputStream());
      } else if (this.boolNeedSSL) {
         this.objFilterOutputStream = new DataOutputStream(this.objWriteSSLSocket.getSecureOutputStream());
      } else {
         this.objFilterOutputStream = new DataOutputStream(this.objWriteSock.getOutputStream());
      }
   }

   private void createBufferInputTypeStream(String var1) throws Exception {
      if (var1.equals(EVENT)) {
         if (this.boolNeedRC4) {
            this.objBufferedInputEventStream = new DataInputStream(new BufferedInputStream(this.objEventSock.getInputStream()));
         } else if (this.boolNeedSSL) {
            this.objBufferedInputEventStream = new DataInputStream(new BufferedInputStream(this.objEventSSLSocket.getSecureInputStream()));
         } else {
            this.objBufferedInputEventStream = new DataInputStream(new BufferedInputStream(this.objEventSock.getInputStream()));
         }
      }

      if (var1.equals(RFP)) {
         if (this.boolNeedRC4) {
            this.objBufferedInputRFPStream = new DataInputStream(new BufferedInputStream(this.objRFPSock.getInputStream()));
         } else if (this.boolNeedSSL) {
            this.objBufferedInputRFPStream = new DataInputStream(new BufferedInputStream(this.objRFPSSLSocket.getSecureInputStream()));
         } else {
            this.objBufferedInputRFPStream = new DataInputStream(new BufferedInputStream(this.objRFPSock.getInputStream()));
         }
      }
   }

   private void createFilterOutputTypeStream(String var1) throws Exception {
      if (var1.equals(EVENT)) {
         if (this.boolNeedRC4) {
            this.objFilterOutputEventStream = new DataOutputStream(this.objEventSock.getOutputStream());
         } else if (this.boolNeedSSL) {
            this.objFilterOutputEventStream = new DataOutputStream(this.objEventSSLSocket.getSecureOutputStream());
         } else {
            this.objFilterOutputEventStream = new DataOutputStream(this.objEventSock.getOutputStream());
         }
      }

      if (var1.equals(RFP)) {
         if (this.boolNeedRC4) {
            this.objFilterOutputRFPStream = new DataOutputStream(this.objRFPSock.getOutputStream());
         } else if (this.boolNeedSSL) {
            this.objFilterOutputRFPStream = new DataOutputStream(this.objRFPSSLSocket.getSecureOutputStream());
         } else {
            this.objFilterOutputRFPStream = new DataOutputStream(this.objRFPSock.getOutputStream());
         }
      }
   }

   public static void setLastError(int var0) {
      try {
         iLastError = var0;
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "SetLastError" + var0);
         }
      } catch (Exception var2) {
         RRCLogger.logException(var2);
      }
   }

   public static int getLastError() {
      return iLastError;
   }

   private boolean rspProc() {
      boolean var1 = false;

      try {
         this.dbLog(System.currentTimeMillis() + " Connect ----------------");
         if (!this.isGDMode()) {
            this.dbNotify(1001, 1);
         }

         if (!this.isGDMode()) {
            try {
               this.prepareSocket();
            } catch (IOException var25) {
               RRCLogger.log(300, 4, var25, "Unable to connect to " + this.objComm.getInetAddress());
               this.dbNotify(1050, 0);
               return false;
            }
         }

         if (!this.isGDMode()) {
            var1 = this.serverHandshake();
         } else {
            this.boolSocketOK = true;
            this.objReadSock.setTcpNoDelay(true);
            this.objReadSock.setSoTimeout(174000);
            this.objWriteSock = this.objReadSock;
            var1 = true;
            synchronized (this.objCriticalSection) {
               if (!this.boolDisconnecting) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "CONNECTION Successful");
                  }

                  this.boolConnected = true;
               }
            }
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "CONNECTION::RspProc: calling serverHandshake returned " + var1);
         }

         if (!var1) {
            this.rspProcExitFunction();
            return false;
         }

         this.dbNotify(1006, 9);
         if (!this.isKx2Device) {
            this.objKeepAliveThrd = new TRKeepAliveThread(this);
            this.objKeepAliveThrd.start();
         }

         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "objReferral.getVersion() = " + this.objReferral.getVersion());
         }

         var1 = this.startAuthentication();
         if (!var1 && !this.isGDMode()) {
            this.rspProcExitFunction();
            return false;
         }

         if (this.isGDMode()) {
            return true;
         }

         if (this.isKx2Device) {
            try {
               Object var41 = null;
               byte[] var10000 = new byte[]{0, 0, 0, 0};
               var41 = this.objComm.getInetAddress();
               int var4 = 0;
               if (this.objComm.getIpPort() == 0) {
                  var4 = Constants.TR_PORT_BASE;
               } else {
                  var4 = this.objComm.getIpPort();
               }

               int var5 = this.connect((InetAddress)var41, var4, EVENT);
               if (var5 < 0 && RRCLogger.logEnabled) {
                  RRCLogger.log(200, 4, "Serverhandshake:  negotiateCSC not able to connect to event socket " + var5);
               }

               byte[] var6 = this.GetCSCInfo(EVENT);
            } catch (Exception var31) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.logException(var31);
               }
            }
         }

         this.lConnectTime = System.currentTimeMillis();
         this.boolPassWordChangeInprocess = false;
         int var43 = 0;
         if (this.isKx2Device) {
            Object var46 = null;
            Object var58 = null;
            if (this.sessionKey != null) {
               var43 = this.startReferralCSCSession("RDMEvent", this.sessionId, this.sessionKey, EVENT);
            }

            if ((var43 < 0 || this.sessionKey == null) && RRCLogger.logEnabled) {
               RRCLogger.log(100, 4, "RSP Proc: Failure to create CSC_Session for Events.");
            }

            while (this.boolConnected) {
               int var52 = 0;
               int var56 = this.objEventSock.getSoTimeout();
               this.objEventSock.setSoTimeout(500);
               var46 = new byte[4];
               Thread.sleep(250L);
               synchronized (this.objCriticalSection) {
                  try {
                     var43 = this.objBufferedInputEventStream.read((byte[])var46, 0, 4);
                     if (var43 < 0 && !this.updateActive) {
                        RRCLogger.log(300, 4, "Server dropped the connection iRes: " + var43 + "  updateActive: " + this.updateActive);
                        this.dbNotify(1010, 9);
                        this.rspProcExitFunction();
                        break;
                     }
                  } catch (SocketTimeoutException var27) {
                     this.cnt++;
                     if (this.cnt >= 60 && this.isPingDevice()) {
                        this.cnt = 0;
                        this.databaseRequest(
                           "<Database><Get><Select>/System/Device</Select><Nodes> Device </Nodes><SubNodes> Name SerialNo @id</SubNodes></Get></Database>",
                           30000
                        );
                     }

                     this.objEventSock.setSoTimeout(var56);
                     continue;
                  } catch (SocketException var28) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.logException(var28);
                     }

                     this.dbNotify(1017, 10);
                     this.rspProcExitFunction();
                     break;
                  }

                  if (var43 != 4) {
                     this.objEventSock.setSoTimeout(var56);
                  } else {
                     var52 = ((((Object[])var46)[0] & 255) << 24)
                        + ((((Object[])var46)[1] & 255) << 16)
                        + ((((Object[])var46)[2] & 255) << 8)
                        + ((((Object[])var46)[3] & 255) << 0);
                     if (var52 < 5) {
                        this.objEventSock.setSoTimeout(var56);
                     } else {
                        var46 = new byte[1024];
                        int var60 = this.objEventSock.getSoTimeout();

                        try {
                           this.objEventSock.setSoTimeout(120000);
                           if (this.readFromStream((byte[])var46, 0, var52 - 4, EVENT) < 0) {
                              this.dbNotify(1020, 10);
                              this.rspProcExitFunction();
                              break;
                           }
                        } finally {
                           this.objEventSock.setSoTimeout(var60);
                        }

                        this.event((byte[])var46);
                     }
                  }
               }
            }
         } else {
            while (this.boolConnected) {
               Object var3 = null;
               var1 = this.read(this.objTRBaseCommand.toByteArray(), 0, 4);
               this.iReadCount = 4;
               if (!var1) {
                  if (!this.boolDisconnecting && !this.boolOrderlyShutdown) {
                     this.dbNotify(1017, 7);
                  }
                  break;
               }

               this.dbLogCmd(true, this.objTRBaseCommand);

               try {
                  byte var50 = this.objTRBaseCommand.getCommand();
                  if (var50 >= 0 && var50 < this.objRSPDEFList.length) {
                     var3 = this.objRSPDEFList[var50];
                  } else {
                     var3 = null;
                  }
               } catch (Exception var30) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.logException(var30);
                  }

                  var3 = null;
               }

               if (var3 == null) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(
                        100, 4, "Connection:RspProc Command received does not have a Valid handler Command Received = " + this.objTRBaseCommand.getCommand()
                     );
                  }

                  this.dbNotify(1016, 8);
                  this.boolOrderlyShutdown = false;
                  break;
               }

               this.lTimeLastMsg = System.currentTimeMillis();
               int var51 = this.switchFunction((RSPDEF)var3);
               if (var51 == 0) {
                  this.log("switchFunction :entered " + ((RSPDEF)var3).getWhatToDo() + " AFTER SWITCH FUNCTION iResult=" + var51);
                  var1 = false;
                  if (!this.boolDisconnecting) {
                     this.dbNotify(1017, 10);
                  }
                  break;
               }

               if (var51 == 1) {
                  var1 = true;
               } else if (var51 == 2) {
                  continue;
               }

               boolean var54 = false;
               Method var57 = null;
               if (this.objTRBaseCommand.getCommand() == 45) {
                  var54 = this.TRRSP_Cell_Data();
               } else {
                  Object var7 = null;
                  Class var8 = Class.forName("javaclientlib.clientlib.TRConnection");
                  var57 = var8.getDeclaredMethod(((RSPDEF)var3).getMethodName(), (Class<?>[])var7);
                  if (var57 == null) {
                     this.dbNotify(1016, 9);
                     break;
                  }

                  Object var9 = null;
                  Object var10 = var57.invoke(this, (Object[])var9);
                  var54 = (Boolean)var10;
               }

               this.log("Invoked Response Handler returned " + var54 + " for method " + var57);
               if (!var54 && this.iReadCount < this.objTRBaseCommand.getCmdLength()) {
                  var1 = this.sinkData(this.objTRBaseCommand.getCmdLength() - this.iReadCount);
               }
            }
         }
      } catch (InvocationTargetException var32) {
         RRCLogger.logException(var32);
      } catch (InterruptedException var33) {
         RRCLogger.logException(var33);
      } catch (Exception var34) {
         RRCLogger.logException(var34);
         this.dbNotify(1010, 9);
      }

      this.log("\t\t OUT OF WHILE ");
      this.boolConnected = false;

      try {
         this.rspProcExitFunction();
      } catch (Exception var23) {
         RRCLogger.logException(var23);
      }

      return true;
   }

   private int switchFunction(RSPDEF var1) {
      boolean var2 = false;
      int var3 = this.objTRBaseCommand.getCmdLength() - 4;
      switch (var1.getWhatToDo()) {
         case 0:
            break;
         case 1:
            if (this.objTRBaseCommand.getCmdLength() != var1.getDataSize()) {
               var2 = this.sinkData(var3);
               return 2;
            }
            break;
         case 2:
            if (this.objTRBaseCommand.getCmdLength() != var1.getDataSize()) {
               var2 = this.sinkData(var3);
               return 2;
            }

            var2 = this.read(this.objTRBaseCommand.toByteArray(), 4, var3);
            this.iReadCount += var3;
            break;
         case 3:
            if (this.objTRBaseCommand.getCmdLength() > var1.getDataSize()) {
               var2 = this.sinkData(this.objTRBaseCommand.getCmdLength());
               return 2;
            }

            var2 = this.read(this.objTRBaseCommand.toByteArray(), 4, var3);
            this.iReadCount += var3;
            break;
         case 4:
            if (this.objTRBaseCommand.getCmdLength() < var1.getDataSize()) {
               var2 = this.sinkData(var3);
               return 2;
            }

            var2 = this.read(this.objTRBaseCommand.toByteArray(), 4, var1.getDataSize() - 4);
            byte[] var4 = new byte[4];
            var4 = this.objTRBaseCommand.getBytes(4, 4);
            this.responseTotalSize = this.getInt(0, var4);
            this.iReadCount = this.iReadCount + (var1.getDataSize() - 4);
            break;
         default:
            return 2;
      }

      return var2 ? 1 : 0;
   }

   private int switchRFPFunction(RSPDEF var1) {
      boolean var2 = false;
      int var3 = this.objTRBaseCommand.getCmdLength() - 4;
      switch (var1.getWhatToDo()) {
         case 0:
            break;
         case 1:
            if (this.objTRBaseCommand.getCmdLength() != var1.getDataSize()) {
               var2 = this.sinkRFPData(var3);
               return 2;
            }
            break;
         case 2:
            if (this.objTRBaseCommand.getCmdLength() != var1.getDataSize()) {
               var2 = this.sinkRFPData(var3);
               return 2;
            }

            int var11 = this.readFromStream(this.objTRBaseCommand.toByteArray(), 4, var3, RFP);
            var2 = var11 == 0;
            this.iReadCount += var3;
            break;
         case 3:
            if (this.objTRBaseCommand.getCmdLength() > var1.getDataSize()) {
               var2 = this.sinkRFPData(this.objTRBaseCommand.getCmdLength());
               return 2;
            }

            int var10 = this.readFromStream(this.objTRBaseCommand.toByteArray(), 4, var3, RFP);
            var2 = var10 == 0;
            this.iReadCount += var3;
            break;
         case 4:
            if (this.objTRBaseCommand.getCmdLength() < var1.getDataSize()) {
               var2 = this.sinkRFPData(var3);
               return 2;
            }

            int var4 = this.readFromStream(this.objTRBaseCommand.toByteArray(), 4, var1.getDataSize() - 4, RFP);
            var2 = var4 == 0;
            byte[] var5 = new byte[4];
            var5 = this.objTRBaseCommand.getBytes(4, 4);
            this.responseTotalSize = this.getInt(0, var5);
            this.iReadCount = this.iReadCount + (var1.getDataSize() - 4);
            break;
         default:
            return 2;
      }

      return var2 ? 1 : 0;
   }

   public int getInt(int var1, byte[] var2) {
      int var3 = (var2[var1 + 0] & 255) >> 0;
      int var4 = (var2[var1 + 1] & 255) >> 0;
      int var5 = (var2[var1 + 2] & 255) >> 0;
      int var6 = (var2[var1 + 3] & 255) >> 0;
      return (var3 << 24) + (var4 << 16) + (var5 << 8) + (var6 << 0);
   }

   private void rspProcExitFunction() throws Exception {
      boolean var1 = this.disConnect();
      this.dbLog(System.currentTimeMillis() + " Disconnect -------------\n");
      if (!this.isKx2Device) {
         this.log(this.objKeepAliveThrd + "==");
         if (this.objKeepAliveThrd != null) {
            this.log("Interputting " + this.objKeepAliveThrd + "==");
            this.objKeepAliveThrd.interrupt();
            this.objKeepAliveThrd = null;
         }
      }

      synchronized (this.objCriticalSection) {
         this.objReadSSLSocket = null;
         this.objReadSock = null;
         this.objWriteSSLSocket = null;
         this.objWriteSock = null;
      }
   }

   public boolean disConnect() {
      this.log("::Disconnect");

      try {
         boolean var1 = false;
         synchronized (this.objCriticalSection) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "::Disconnect - this.boolDisconnecting=" + this.boolDisconnecting);
            }

            if (!this.boolDisconnecting) {
               synchronized (this.objWriteCR) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "::Disconnect - this.boolConnected=" + this.boolConnected);
                  }

                  if (this.boolConnected) {
                     if (this.getAuthenticated()) {
                        if (!this.isKx2Device) {
                           this.objTRBaseCommand.setCommand((byte)7);
                           this.objTRBaseCommand.setCmdLength((short)4);
                           this.objTRBaseCommand.setPktID((byte)0);
                           this.boolOrderlyShutdown = this.write(this.objTRBaseCommand.toByteArray(), 4);
                        }
                     } else {
                        this.boolOrderlyShutdown = true;
                     }
                  }

                  this.boolDisconnecting = true;
               }

               if (!this.isKx2Device) {
                  this.cancelIO();
               }

               if (!this.boolOrderlyShutdown) {
                  this.dbNotify(1010, 0);
               } else {
                  this.dbNotify(1020, 1);
               }

               this.boolConnected = false;
               this.boolIsAdministrator = false;
               if (this.objReadSock != null) {
                  this.objReadSock.close();
                  this.objReadSock = null;
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "closing read sockets" + this.objBufferedInputStream);
                  }
               }

               if (this.objEventSock != null) {
                  this.objEventSock.close();
                  this.objEventSock = null;
               }

               if (this.objRFPSock != null) {
                  this.objRFPSock.close();
                  this.objRFPSock = null;
               }

               if (this.objWriteSock != null) {
                  this.objWriteSock.close();
                  this.objWriteSock = null;
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "closing write sockets" + this.objFilterOutputStream);
                  }
               }

               if (this.objComm.getConnType() == 1) {
               }
            }
         }
      } catch (Exception var8) {
         RRCLogger.logException(var8);
      }

      this.log("this.boolDisconnecting=" + this.boolDisconnecting);
      return this.boolOrderlyShutdown;
   }

   private int CalcHandshakeChecksum(TRCMD_HANDSHAKE_ACK_DATA var1) {
      long var2 = 0L;
      long var4 = var1.getClientIp() & -1;
      int var6 = var1.getClientPort() & '\uffff';
      var2 = var1.getSignature() + var4 + var6 + var1.getTimeStamp() + var1.getIndex() + var1.getRandom() + var1.getConnCount();
      return (int)(var2 & -1L);
   }

   private boolean isServerSendingInNetworkByteOrder(byte[] var1) {
      return (var1[0] & var1[1]) == 0;
   }

   private boolean nop() throws Exception {
      this.objTRBaseCommand.setCmdLength((short)4);
      this.objTRBaseCommand.setCommand((byte)2);
      return this.sendTRCmd(this.objTRBaseCommand);
   }

   private boolean nack() throws Exception {
      boolean var1 = false;
      return this.response();
   }

   private boolean TRRSP_Notify() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(12));
      if (var1 != null) {
         if (this.objTRBaseCommand.getCmdLength() > 13) {
            this.objTRBaseCommand.setInt(13, 8);
         }

         var1.TRRSP_Notify(this.objTRBaseCommand);
         return true;
      } else {
         return true;
      }
   }

   private boolean pong() {
      return true;
   }

   private String getXMLNodeValue(String var1, String var2) {
      try {
         Document var3 = xmlParser.getDocument(var1);
         NodeList var4 = var3.getElementsByTagName(var2);
         if (var4.getLength() != 1) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(100, 4, "There are " + var4.getLength() + " " + var2 + " nodes.  Cannot determine " + var2);
            }

            return null;
         }

         Node var5 = var4.item(0);
         if (!var5.hasChildNodes()) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(100, 4, var2 + " has no child nodes!  Cannot determine " + var2);
            }

            return null;
         }

         var5 = var5.getFirstChild();
         if (!(var5 instanceof Text)) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(100, 4, var2 + "'s child isn't a text node!  Cannot determine " + var2);
            }

            return null;
         }

         return var5.getNodeValue();
      } catch (ParserConfigurationException var6) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "Parser config Exception parsing the following XML string:\n\t " + var1 + "\nException Message: " + var6.getMessage());
         }
      } catch (SAXException var7) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(
               200, 4, "SAXException getting node " + var2 + " from the following XML string:\n\t" + var1 + "\nException Message: " + var7.getMessage()
            );
         }
      } catch (IOException var8) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(
               200, 4, "IOException getting node " + var2 + " from the following XML string:\n\t" + var1 + "\nException Message: " + var8.getMessage()
            );
         }
      }

      return null;
   }

   private void setSessionInfo() throws Exception {
      xmlParser = getXmlParserInstance();
      xmlParser = new XMLParser();
      this.boolIsAdministrator = false;
      String var1 = "<Session><GetSessionID/></Session>";
      Object var2 = null;
      String var3 = null;
      synchronized (this.objWriteCR) {
         if (!this.writeCSCMessage(var1.getBytes(), 0)) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(200, 4, "setSessionInfo: unable to write RDM GetSessionID request.");
            }
         } else {
            var2 = this.readCSCMessage(0, 0);
            if (var2 == null) {
               RRCLogger.log(200, 4, "setSessionInfo: unable to read RDM GetSessionID response.");
            } else {
               var3 = new String((byte[])var2);
               if (var3.indexOf(0) > 0) {
                  var3 = var3.substring(0, var3.indexOf(0));
               }

               this.sessionId = this.getXMLNodeValue(var3, "SessionID");
               this.sessionKey = this.getXMLNodeValue(var3, "SessionKey");
               if (this.sessionId == null || this.sessionKey == null) {
                  RRCLogger.log(100, 4, "sessionId or sessionKey is null");
               }

               var1 = "<Database><Get><Select>/System/Sessions/Session[@id=\""
                  + this.sessionId
                  + "\"]/User</Select>"
                  + "<Nodes>User</Nodes><SubNodes>GroupID</SubNodes></Get></Database>";
               if (!this.writeCSCMessage(var1.getBytes(), 0)) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(200, 4, "setSessionInfo: unable to write RDM group ID request.");
                  }
               } else {
                  var2 = this.readCSCMessage(0, 0);
                  if (var2 == null) {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "setSessionInfo: unable to read RDM group ID response.");
                     }
                  } else {
                     var3 = new String((byte[])var2);
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "setSessionInfo: RDM group ID response.: " + var3);
                     }

                     if (var3.indexOf(0) > 0) {
                        var3 = var3.substring(0, var3.indexOf(0));
                     }

                     String var5 = this.getXMLNodeValue(var3, "GroupID");
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(200, 4, "setSessionInfo: GroupID: " + var5);
                     }

                     if (var5 == null) {
                        RRCLogger.log(200, 4, "GroupId is null");
                     } else if (var5.equals("Group0")) {
                        this.boolIsAdministrator = true;
                     }
                  }
               }
            }
         }
      }
   }

   private boolean startAuthentication() throws Exception {
      if (this.isKx2Device) {
         boolean var8 = this.boolNeedSSL;
         this.boolNeedSSL = true;
         if (!this.isGDMode()) {
            this.initializeSSL(this.objComm.getInetAddress().getHostAddress(), false);
            this.createFilterOutputStream();
         }

         this.objReadSSLSocket = this.objWriteSSLSocket;
         this.createBufferInputStream();
         if (this.objReferral.getVersion() > 0) {
            int var2 = this.CSC_Test(this.objReferral.getSessionKey());
            if (var2 < 0) {
               this.dbNotify(1017, 192);
               return false;
            } else {
               this.sessionId = new String(this.objReferral.getSessionID());
               this.sessionKey = new String(this.objReferral.getSessionKey());
               this.boolAuthenticated = true;
               return true;
            }
         } else {
            String var3 = Util.escapeXML(new String(this.objUserInfo.getPassword()));
            String var4 = "<CSC_Auth UserName=\"" + new String(this.objUserInfo.getName()) + "\" Password=\"" + var3 + "\"/>";
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "Attempting CSC Authentication.");
            }

            boolean var5 = this.writeCSCMessage(var4.getBytes(), 0);
            if (!var5) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(300, 4, "CSC Authentication could not be done: failure writing CSC message.");
               }

               this.boolNeedSSL = var8;
               return false;
            } else {
               byte[] var6 = this.readCSCMessage(256, 0);
               if (var6 == null) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "CSC Authentication failure: returned null!");
                  }

                  this.boolNeedSSL = var8;
                  return false;
               } else {
                  String var7 = new String(var6);
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(300, 4, "CSC Authentication result: " + new String(var6));
                  }

                  if (var7.startsWith("<CSC_Pass/>")) {
                     this.dbNotify(1007, 0);
                     this.setSessionInfo();
                     this.boolAuthenticated = true;
                  } else {
                     this.boolAuthenticated = false;
                     if (var7.startsWith("<CSC_Fail>-18177</CSC_Fail>")) {
                        this.dbNotify(1040, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19931</CSC_Fail>")) {
                        this.dbNotify(1041, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19937</CSC_Fail>")) {
                        this.dbNotify(1042, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19960</CSC_Fail>")) {
                        this.dbNotify(1043, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19959</CSC_Fail>")) {
                        this.dbNotify(1044, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19938</CSC_Fail>")) {
                        this.dbNotify(1045, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19939</CSC_Fail>")) {
                        this.dbNotify(1026, 0);
                     } else if (var7.startsWith("<CSC_Fail>-20240</CSC_Fail>")) {
                        this.dbNotify(1047, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19944</CSC_Fail>")) {
                        this.dbNotify(1048, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19930</CSC_Fail>")) {
                        this.dbNotify(1049, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19911</CSC_Fail>")) {
                        this.setGDMode(true);
                        this.dbNotify(1051, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19896</CSC_Fail>")) {
                        this.setGDMode(true);
                        this.dbNotify(1052, 0);
                     } else if (var7.startsWith("<CSC_Fail>-19895</CSC_Fail>")) {
                        this.setGDMode(true);
                        this.dbNotify(1053, 0);
                     } else {
                        this.dbNotify(1008, 0);
                     }
                  }

                  return this.boolAuthenticated;
               }
            }
         }
      } else {
         TRCMD_CLIENT_CHALLENGE_DATA var1 = new TRCMD_CLIENT_CHALLENGE_DATA();
         this.getRandomData(this.byRand1, 64);
         this.getRandomData(this.byRand2, 64);
         var1.setR1(this.byRand1);
         var1.setR2(this.byRand2);
         var1.setFlags(0);
         var1.setCommand((byte)4);
         var1.setCmdLength((short)136);
         this.dbLogCmd(false, var1);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "sending TRCMD_CLIENT_CHALLENGE_DATA");
         }

         return this.write(var1.toByteArray(), 136);
      }
   }

   private boolean TRRSP_Server_Challenge() throws Exception {
      TRRSP_SERVER_CHALLENGE_DATA var1 = new TRRSP_SERVER_CHALLENGE_DATA(this.objTRBaseCommand.toByteArray());
      byte[] var2 = new byte[136];
      String var3 = "TeleReach Client";
      byte[] var4 = var3.getBytes();
      TRCMD_CLIENT_RESPONSE_DATA var5 = new TRCMD_CLIENT_RESPONSE_DATA();
      this.byRand3 = var1.getR3();
      this.byRand4 = var1.getR4();
      byte[] var6 = new byte[24];
      Arrays.fill(var6, (byte)0);
      System.arraycopy(this.objComm.getPrivateKey(), 0, var6, 0, this.objComm.getPrivateKey().length);
      this.objComm.setPrivateKey(var6);
      MD5 var7 = new MD5();
      var7.update(var4);
      var7.update(this.byRand1);
      var7.update(this.byRand3);
      var7.update(this.objComm.getPrivateKey());
      byte[] var8 = var7.encode();
      var5.setMD5(var8);
      var5.setFlags(0);
      var5.setCommand((byte)5);
      var5.setCmdLength((short)24);
      this.dbLogCmd(false, var5);
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "sending TRCMD.CLIENT_RESPONSE");
      }

      return this.write(var5.toByteArray(), 24);
   }

   private boolean TRRSP_Server_Response() throws Exception {
      TRRSP_SERVER_RESPONSE_DATA var1 = new TRRSP_SERVER_RESPONSE_DATA(this.objTRBaseCommand.toByteArray());
      boolean var2 = false;
      String var3 = "TeleReach Server";
      byte[] var4 = var3.getBytes();
      Object var5 = null;
      boolean var6 = false;
      MD5 var7 = new MD5();
      var7.update(var4);
      var7.update(this.byRand2);
      var7.update(this.byRand4);
      var7.update(this.objComm.getPrivateKey());
      var5 = var7.encode();
      var6 = Arrays.equals((byte[])var5, var1.getMd5());
      if (!var6) {
         this.dbNotify(1019, 35);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "---MD5 MISMATCH----");
         }

         var2 = false;
      } else {
         this.byChapID = var1.getChapID();
         this.byChapData = var1.getChap();
         var7 = new MD5();
         var7.update(this.byRand1);
         var7.update(this.byRand3);
         var7.update(this.objComm.getPrivateKey());
         var5 = var7.encode();
         var7 = new MD5();
         var7.update(this.byRand2);
         var7.update(this.byRand4);
         var7.update(this.objComm.getPrivateKey());
         var5 = var7.encode();
         this.RC4Key = (byte[])var5;
         this.log("Calling sendAccessRequest()");
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "Calling sendAccessRequest()");
         }

         var2 = this.sendAccessRequest(true);
      }

      return var2;
   }

   private boolean sendAccessRequest(boolean var1) throws Exception {
      this.log("Inside SendAccessRequest");
      TRCMD_ACCESS_REQUEST_DATA var2 = new TRCMD_ACCESS_REQUEST_DATA();
      RADIUS_PACKET var3 = new RADIUS_PACKET();
      RadiusPacket var4 = new RadiusPacket();
      byte[] var5 = new byte[17];
      boolean var6 = false;
      if (RRCLogger.logEnabled) {
         RRCLogger.log(
            300,
            4,
            "TRConnection.sendAccessRequest  boolHaveLoginData = "
               + this.boolHaveLoginData
               + ", boolFirstAttempt = "
               + var1
               + ", objReferral.getVersion() = "
               + this.objReferral.getVersion()
         );
      }

      if ((!this.boolHaveLoginData || !var1) && this.objReferral.getVersion() == 0) {
         if (this.objUserInfo == null) {
            this.objUserInfo = new TRLIB_USERINFO();
         }

         this.objUserInfo.getPassword()[0] = 0;
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "sending login request to TRServer objUserInfo = " + this.objUserInfo + ", objSvrID = " + this.objSvrID);
         }

         var6 = this.login(this.objSvrID, this.objUserInfo, !var1);
         if (!var6) {
            this.boolOrderlyShutdown = true;
            this.disConnect();
            return var6;
         }
      }

      var4.clearPacket(var3);
      var3.setCode((byte)1);
      var3.setIdentifier((byte)0);
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "IRadius.ACCESS_REQUEST = 1");
      }

      if (this.objReferral.getVersion() == 1) {
         if (this.objUserInfo == null) {
            this.objUserInfo = new TRLIB_USERINFO();
         }

         var6 = var4.appendStringAttribute(var3, (byte)1, 0, this.objUserInfo.getName());
      } else {
         var6 = var4.appendStringAttribute(var3, (byte)1, this.objUserInfo.getName().length, this.objUserInfo.getName());
      }

      if (RRCLogger.logEnabled) {
         RRCLogger.log(
            300,
            4,
            "objRadiusPacket.appendStringAttribute = "
               + var6
               + ", this.objSvrID = "
               + this.objSvrID
               + ", this.objSvrID.getSecurityFlags() = "
               + Integer.toHexString(this.objSvrID.getSecurityFlags())
               + ", TR_SECURITY.LOGIN_MASK = "
               + Integer.toHexString(61440)
               + ", TR_SECURITY.PAP_LOGIN = "
               + Integer.toHexString(0)
         );
      }

      if ((this.objSvrID.getSecurityFlags() & 61440) == 0) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "adding PAP Password, objUserInfo.getPassword() = " + this.objUserInfo.getPassword());
         }

         this.log("PAP PASSWORD");
         if (this.objReferral.getVersion() == 1) {
            var4.appendPasswordAttribute(var3, 0, this.objUserInfo.getPassword(), null, 0);
         } else {
            var4.appendPasswordAttribute(var3, this.objUserInfo.getPassword().length, this.objUserInfo.getPassword(), null, 0);
         }
      } else {
         byte[] var7 = new byte[]{this.byChapID};
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "calling computeCHAPResponse chapID = " + this.byChapID);
         }

         var4.computeCHAPResponse(var7, this.objUserInfo.getPassword(), this.byChapData, var5);
         var5[0] = this.byChapID;
         var4.appendStringAttribute(var3, (byte)3, 17, var5);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, "objRadiusPacket.appendStringAttribute with IRadius.CHAP_PASSWORD = " + var6);
         }
      }

      var2.setRadiusPacketData(var3.getDataBytes());
      short var11 = (short)(12 + var3.getPktLength());
      var2.setCommand((byte)6);
      var2.setCmdLength(var11);
      byte[] var8 = var2.toByteArray();
      this.dbLogCmd(false, var2);
      return this.write(var8, var11);
   }

   private boolean TRRSP_Access_Response() throws Exception {
      TRRSP_ACCESS_RESPONSE_DATA var1 = new TRRSP_ACCESS_RESPONSE_DATA(this.objTRBaseCommand.toByteArray());
      byte[] var2 = new byte[4096];
      System.arraycopy(this.objTRBaseCommand.toByteArray(), 12, var2, 0, var2.length);
      RADIUS_PACKET var3 = new RADIUS_PACKET();
      var3.populate(var2);
      new RADIUS_ATTRIB_HEADER();
      new RADIUS_ATTRIB_STRING();
      RADIUS_PACKET var6 = new RADIUS_PACKET();
      byte var7 = 0;
      int var8 = 0;
      Object var9 = null;
      byte[] var10 = new byte[129];
      boolean var11 = false;
      RadiusPacket var12 = new RadiusPacket();
      TRCMD_ACCESS_REQUEST_DATA var13 = new TRCMD_ACCESS_REQUEST_DATA();
      RADIUS_PACKET var14 = new RADIUS_PACKET();
      if (var1.getCommand() == 9 && var1.getFlags() == 4096) {
         this.dbNotify(1026, 0);
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "Connection:TRRSP_Access_Response: NOTIFY - CHANGE USER PASSWORD ");
         }

         this.boolPassWordChangeInprocess = true;
      }

      switch (var3.getCode()) {
         case 2:
            this.log("Connection:TRRSP_Access_Response: ACCEPT");
            if (!this.boolPassWordChangeInprocess) {
               this.endAuthenticationPhase();
               this.lPermissions = var1.getPermissions() & 4294967295L;
               this.boolAuthenticated = true;
               this.dbNotify(1007, 36);
            }
            break;
         case 3:
            this.log("Connection:TRRSP_Access_Response: REJECT");
            this.dbNotify(1008, 37);
            if ((var1.getFlags() & 1) != 0) {
               var11 = this.sendAccessRequest(false);
            } else {
               this.dbNotify(1009, 38);
               this.boolOrderlyShutdown = false;
            }
            break;
         case 4:
         case 5:
         default:
            var11 = false;
            break;
         case 6:
            this.log("Connection:TRRSP_Access_Response: CHALLENGE");
            RADIUS_ATTRIB_HEADER var4 = var12.findAttribute(var3, null, (byte)18);

            for (RADIUS_ATTRIB_STRING var5 = (RADIUS_ATTRIB_STRING)var4; var5 != null; var5 = (RADIUS_ATTRIB_STRING)var4) {
               var6.appendAttributeData(var5.getAttribute(), var7, var5.getAttribute().length);
               var9 = var6.getDataBytes();
               ((Object[])var9)[var6.getDataBytes().length - 2 - 1] = 0;
               var7 = var4.getLengthAttribute();
               var8++;
               var4 = var12.findAttribute(var3, var4, (byte)18);
            }

            var9 = var6.getDataBytes();
            ((Object[])var9)[var6.getDataBytes().length - 1] = 0;
            ((Object[])var9)[var6.getDataBytes().length] = 0;
            var11 = this.loginChallenge(var8, (byte[])var9, var10);
            if (!var11) {
               this.boolOrderlyShutdown = true;
               this.disConnect();
               var11 = false;
            } else {
               var12.clearPacket(var14);
               var14.setCode((byte)1);
               var14.setIdentifier((byte)0);
               var12.appendPasswordAttribute(var14, var10.length, var10, null, 0);
               var12.appendStringAttribute(var14, (byte)1, this.objUserInfo.getName().length, this.objUserInfo.getName());
               var4 = var12.findAttribute(var3, null, (byte)24);
               if (var4 != null) {
                  var12.appendAttribute(var3, var4);
               }

               for (RADIUS_ATTRIB_HEADER var17 = var12.findAttribute(var3, null, (byte)33); var17 != null; var17 = var12.findAttribute(var3, var17, (byte)33)) {
                  var12.appendAttribute(var14, var17);
               }

               var13.setRadiusPacketData(var14.getDataBytes());
               var13.setCommand((byte)6);
               int var15 = 12 + var14.getPktLength();
               var13.setCmdLength((short)var15);
               this.dbLogCmd(false, var13);
               var11 = this.write(var13.toByteArray(), var15);
            }
      }

      return var11;
   }

   private boolean endAuthenticationPhase() throws Exception {
      boolean var1 = false;
      synchronized (this.objWriteCR) {
         sleep(500L);
         switch (this.objSvrID.getSecurityFlags() & 3840) {
            case 256:
            case 2048:
               break;
            case 512:
               var1 = true;
               this.boolNeedSSL = false;
               break;
            case 1024:
               var1 = true;
               this.boolNeedRC4 = true;
               break;
            default:
               this.dbNotify(1018, 45);
               this.disConnect();
         }

         this.createBufferInputStream();
         this.createFilterOutputStream();
         if (var1) {
         }

         return true;
      }
   }

   private void cancelIO() {
      Enumeration var2 = this.objCmdWaitHashtable.keys();

      while (var2.hasMoreElements()) {
         Object var3 = var2.nextElement();
         TRCMDWAIT var1 = (TRCMDWAIT)this.objCmdWaitHashtable.get(var3);
         if (var1 != null && var1.getEvent() != null) {
            var1.getEvent().notifying();
         }
      }
   }

   private void cancelIO(TRCMDWAIT var1) {
      if (var1 != null) {
         Enumeration var2 = this.objCmdWaitHashtable.keys();

         while (var2.hasMoreElements()) {
            Object var3 = var2.nextElement();
            TRCMDWAIT var4 = (TRCMDWAIT)this.objCmdWaitHashtable.get(var3);
            if (var4 != null && var1.getPktID() == var4.getPktID()) {
               this.objCmdWaitHashtable.remove(var3);
               if (var4.getEvent() != null) {
                  var4.getEvent().notifying();
               }
            }
         }
      }
   }

   private boolean targetParamsChanged() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(4));
      if (var1 != null) {
         TRRSP_TARGET_PARAMS_DATA var2 = new TRRSP_TARGET_PARAMS_DATA(this.objTRBaseCommand.toByteArray());

         try {
            TRSRVR_TARGET_PARAMS var3 = var2.getParams();
            var1.targetParamsChanged(var3);
            return true;
         } catch (Exception var4) {
            return false;
         }
      } else {
         return false;
      }
   }

   private boolean TRRSP_New_Video_Mode() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(64));
      return var1 != null ? var1.TRRSP_New_Video_Mode(this.objTRBaseCommand) : false;
   }

   private boolean TRRSP_Cache() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(8));
      return var1 != null ? var1.TRRSP_Cache(this.objTRBaseCommand) : false;
   }

   private boolean TRRSP_Compressed() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(14));
      return var1 != null ? var1.TRRSP_Compressed(this.objTRBaseCommand) : false;
   }

   private boolean TRRSP_Cell_Data() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(6));
      return var1 != null ? var1.TRRSP_Cell_Data(this.objTRBaseCommand) : false;
   }

   private boolean TRRSP_Bitplane() throws Exception {
      TRVideoStream var1 = this.getVideoStreamDevice(this.objTRBaseCommand.getByte(13));
      return var1 != null ? var1.TRRSP_Bitplane(this.objTRBaseCommand) : false;
   }

   private boolean TRRSP_Packed() {
      return false;
   }

   private boolean TRRSP_Video_Marker() throws Exception {
      TRRSP_VIDEO_MARKER_DATA var1 = new TRRSP_VIDEO_MARKER_DATA(this.objTRBaseCommand.toByteArray());
      TRVideoStream var2 = this.getVideoStreamDevice(var1.getDeviceID());
      short var3 = 0;
      byte var4 = 0;
      if (var2 != null && var2.isConnected()) {
         var3 = var1.getCount();
         var4 = var1.getDeviceID();
         var1.setCommand((byte)48);
         var1.setCmdLength((short)7);
         var1.setCount(var3);
         var1.setDeviceID(var4);
         this.sendTRCmd(this.objTRBaseCommand);
      }

      return true;
   }

   private boolean TRRSP_KB_Status() {
      TRRSP_KB_STATUS_DATA var1 = new TRRSP_KB_STATUS_DATA(this.objTRBaseCommand.toByteArray());
      Object var2 = null;
      if (this.objSvrID.getProtocolVersion() < 16) {
         var2 = this.getVideoStreamDevice((byte)0);
      } else {
         var2 = this.getVideoStreamDevice(var1.getDeviceID());
      }

      return var2 != null ? ((TRVideoStream)var2).TRRSP_KB_Status(this.objTRBaseCommand) : false;
   }

   private boolean TRRSP_Receive_Serial() throws Exception {
      TRSerialStream var1 = this.getSerialStreamDevice(this.objTRBaseCommand.getByte(6));
      return var1 != null ? var1.TRRSP_Receive_Serial(this.objTRBaseCommand) : false;
   }

   private boolean externalResponse() throws Exception {
      RSPDEF var1 = this.objRSPDEFList[this.objTRBaseCommand.getCommand()];
      Method var2 = var1.getExtMethod();
      if (var2 != null) {
         Object[] var3 = new Object[]{this.objTRBaseCommand, var1.getUserData()};
         Object var4 = var2.invoke(var1.getExtObject(), var3);
         return true;
      } else {
         return true;
      }
   }

   public void setExtRspHandler(int var1, Method var2, Object var3, Object var4, Method var5, Object var6, Object var7) {
      try {
         if (var1 >= 48) {
            return;
         }

         if (var5 != null) {
            var5 = this.objRSPDEFList[var1].getExtMethod();
         }

         if (var6 != null) {
            var6 = this.objRSPDEFList[var1].getExtObject();
         }

         if (var7 != null) {
            var7 = this.objRSPDEFList[var1].getUserData();
         }

         this.objRSPDEFList[var1].setExtMethod(var2);
         this.objRSPDEFList[var1].setExtObject(var3);
         this.objRSPDEFList[var1].setUserData(var4);
      } catch (Exception var9) {
         RRCLogger.logException(var9);
      }
   }

   private boolean TRRSP_RDM_Event() {
      TRRSP_RDM_EVENT_DATA var1 = new TRRSP_RDM_EVENT_DATA(this.objTRBaseCommand.toByteArray());
      this.event(var1.getRdmEventData());
      return true;
   }

   public String databaseRequest(String var1) {
      return this.databaseRequest(var1, 0);
   }

   public String databaseRequest(String var1, int var2) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(200, 17, "Database request: " + var1);
      }

      if (this.isKx2Device) {
         int var21 = 0;
         int var22 = 0;
         String var23 = "";
         boolean var24 = false;
         synchronized (this.objWriteCR) {
            if (var2 > 0) {
               var24 = true;

               try {
                  var21 = this.objReadSock.getSoTimeout();
                  var22 = this.objWriteSock.getSoTimeout();
                  this.objReadSock.setSoTimeout(var2);
                  this.objWriteSock.setSoTimeout(var2);
               } catch (SocketException var16) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(
                        200,
                        17,
                        "Unable to adjust timeout period for databaseRequest(String cmd, int timeout).\n\tSocketException: "
                           + var16.getMessage()
                           + "\nWill attempt to perform command with default timeout."
                     );
                  }

                  var24 = false;
               }
            }

            if (!this.writeCSCMessage(var1.getBytes(), 0)) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(100, 17, "Writing database request to device failed!");
               }
            } else {
               byte[] var8 = this.readCSCMessage(0, 0);
               RRCLogger.log(500, 17, var8);
               if (var8 == null) {
                  RRCLogger.log(200, 17, "No ping response for device " + this.objReadSock);
                  throw new IllegalStateException("Null response for CSC");
               }

               var23 = new String(var8);
               String var26 = var23;
               if (var23.contains("<Password>")) {
                  Pattern var12 = Pattern.compile("<Password>(.*)</Password>");
                  Matcher var13 = var12.matcher(var23);
                  var26 = var13.replaceAll("<Password>########</Password>");
               }

               RRCLogger.log(200, 17, "Result of database request: " + var26);
               var26 = null;
            }

            if (var24) {
               try {
                  this.objReadSock.setSoTimeout(var21);
                  this.objReadSock.setSoTimeout(var22);
               } catch (SocketException var15) {
                  if (RRCLogger.logEnabled) {
                     RRCLogger.log(
                        100,
                        17,
                        "DANGER: Unable to restore original socket timeout in databaseRequest(String cmd, int timeout)!!\n\tSocketException: "
                           + var15.getMessage()
                     );
                  }
               }
            }
         }

         return var23.indexOf(0) < 1 ? var23 : var23.substring(0, var23.indexOf(0));
      } else {
         boolean var3 = false;
         String var4 = null;
         TRCMD_DATABASE_REQUEST_DATA var5 = new TRCMD_DATABASE_REQUEST_DATA((short)4108);
         int var6 = var1.length() + 1;

         try {
            var5.setCommand((byte)54);
            var5.setCmdLength((short)(18 + var6));
            var5.setTotalSize(var6);
            var5.setSize(var6);
            var5.setOffset(0);
            var5.setCompFlags((short)0);
            System.arraycopy(var1.getBytes(), 0, var5.toByteArray(), 18, var6 - 1);
            var5.toByteArray()[18 + var6] = 0;
            TRCMDWAIT var7 = new TRCMDWAIT();
            var3 = this.sendTRCmdExxx(var5, var7, 36, true, var2);
            if (var3) {
               if (var5.getCommand() == 36) {
                  new TRRSP_DATABASE_RESPONSE_DATA(var5.toByteArray());
                  int var9 = 0;
                  byte[] var10 = var7.getAvailableData();

                  while (var10 != null && var10.length > var9 && var10[var9] != 0) {
                     var9++;
                  }

                  if (var9 > 0) {
                     var4 = new String(var10, 0, var9);
                  }
               }

               var3 = this.processResponse(var3, var5);
            }

            this.syncTRCmd();
         } catch (Exception var18) {
            if (RRCLogger.logEnabled) {
               RRCLogger.logException(var18);
            }
         }

         return var4;
      }
   }

   public boolean isConnected() {
      return this.boolConnected;
   }

   public boolean isAuthenticated() {
      return this.boolAuthenticated;
   }

   public boolean isMultiVideoStream() {
      return this.objSvrID.getProtocolVersion() >= 16 && this.objSvrID.getNumVideoDevices() > 1;
   }

   public boolean isDialUpConnection() {
      return this.objComm.getConnType() == 1;
   }

   public TRConnection enumCTRConnection(int var1) {
      return objConnVectorList.get(var1) != null ? (TRConnection)objConnVectorList.get(var1) : null;
   }

   public boolean getResolvedComm(TRLIB_COMM var1) {
      return this.boolCommResolved;
   }

   public boolean ChangeUserPassword(TRCMD_CHANGE_PASSWORD_DATA var1) {
      TRCOMMAND var2 = new TRCOMMAND((short)4108);
      boolean var3 = false;

      try {
         var1.setCommand((byte)39);
         var1.setCmdLength((short)52);
         System.arraycopy(var1.toByteArray(), 0, var2.toByteArray(), 0, 52);
         var3 = this.sendTRCmdEx(var2, true, null, 2);
         var1.fromByteArray(var2.toByteArray());
      } catch (Exception var5) {
         RRCLogger.logException(var5);
      }

      return this.processResponse(var3, var2);
   }

   @Override
   public void notify(int var1, int var2) {
   }

   public void event(byte[] var1) {
   }

   @Override
   public boolean login(TRSRVR_SERVER_ID var1, TRLIB_USERINFO var2, boolean var3) {
      return false;
   }

   @Override
   public boolean loginChallenge(int var1, byte[] var2, byte[] var3) {
      return false;
   }

   public boolean enumVideoDevices(int var1, TRSRVR_CHANNEL_DATA var2) {
      boolean var3 = false;

      try {
         TRCMD_ENUM_VIDEO_DEVICES_DATA var4 = new TRCMD_ENUM_VIDEO_DEVICES_DATA((short)4108);
         var4.setCommand((byte)8);
         var4.setCmdLength((short)9);
         var4.setDeviceID((byte)var1);
         var4.setFlags(0);
         var3 = this.sendTRCmdEx(var4, true, null, 26);
         if (var3) {
            var2.populate(var4.toByteArray());
         }

         return this.processResponse(var3, var4);
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         return false;
      }
   }

   public void syncTRCmd() {
      this.log("=syncTRCmd=" + this.objSyncMonitor);
      this.objSyncMonitor.notifying();
   }

   public boolean setDataItemByte(byte var1, short var2, byte var3) {
      boolean var4 = false;

      try {
         TRCMD_SET_DATA_ITEM_DATA var5 = new TRCMD_SET_DATA_ITEM_DATA((short)4108);
         var5.setCommand((byte)51);
         var5.setCmdLength((short)9);
         var5.setDeviceID(var1);
         var5.setItemID(var2);
         var5.setItemdata(var3);
         var4 = this.sendTRCmd(var5);
      } catch (Exception var6) {
         RRCLogger.logException(var6);
      }

      return var4;
   }

   public void setExtRspHandler() {
   }

   public boolean addVideoStream(TRVideoStream var1) {
      synchronized (this.objCriticalSection) {
         this.objVSList.addElement(var1);
         return true;
      }
   }

   public TRVideoStream getVideoStreamDevice(byte var1) {
      int var2 = var1 & 255;
      return var2 < 256 ? this.objVSArray[var2] : null;
   }

   public boolean setVideoStreamDevice(TRVideoStream var1, byte var2) {
      boolean var3 = false;
      int var4 = var2 & 255;

      try {
         synchronized (this.objCriticalSection) {
            if (var4 < 256 && (this.objVSArray[var4] == null || var1 == null)) {
               var3 = true;
               this.objVSArray[var4] = var1;
            }
         }
      } catch (Exception var8) {
         RRCLogger.logException(var8);
      }

      return true;
   }

   public void removeVideoStream(TRVideoStream var1) {
      boolean var3 = false;

      try {
         synchronized (this.objCriticalSection) {
            for (int var8 = 0; var8 < 256; var8++) {
               if (this.objVSArray[var8] == var1) {
                  this.objVSArray[var8] = null;
               }
            }

            this.objVSList.remove(var1);
         }
      } catch (Exception var7) {
         RRCLogger.logException(var7);
      }
   }

   public boolean addSerialStream(TRSerialStream var1) {
      synchronized (this.objCriticalSection) {
         this.objSSList.addElement(var1);
         return true;
      }
   }

   public TRSerialStream getSerialStreamDevice(byte var1) {
      int var2 = var1 & 255;
      if (var2 < 32) {
         return this.objSSArray[var2];
      } else {
         return var2 == 255 ? this.objSSAdmin : null;
      }
   }

   public boolean setSerialStreamDevice(TRSerialStream var1, byte var2) {
      int var3 = var2 & 255;
      boolean var4 = false;

      try {
         synchronized (this.objCriticalSection) {
            if (var3 < 32) {
               if (this.objSSArray[var3] == null || var1 == null) {
                  var4 = true;
                  this.objSSArray[var3] = var1;
               }
            } else if (var3 == 255 && (this.objSSAdmin == null || var1 == null)) {
               var4 = true;
               this.objSSAdmin = var1;
            }
         }
      } catch (Exception var8) {
         RRCLogger.logException(var8);
      }

      return var4;
   }

   public void removeSerialStream(TRSerialStream var1) {
      try {
         synchronized (this.objCriticalSection) {
            Object var3 = null;
            boolean var4 = false;

            for (int var8 = 0; var8 < 32; var8++) {
               if (this.objSSArray[var8] == var1) {
                  this.objSSArray[var8] = null;
               }
            }

            if (this.objSSAdmin == var1) {
               this.objSSAdmin = null;
            }

            this.objSSList.remove(var1);
         }
      } catch (Exception var7) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "TRConnection:removeSerialStream() " + var7.getMessage());
         }
      }
   }

   private void getRandomData(byte[] var1, int var2) {
      long var3 = 0L;
      Random var5 = null;
      byte var6 = 53;
      var3 = System.currentTimeMillis();
      var3 = var3 ^ this.lLastSeed ^ this.lLastSeed << 16;
      var5 = new Random(var3);

      for (int var7 = 0; var7 < var2; var7++) {
         var1[var7] = (byte)(var5.nextLong() >> 1 & 255L ^ var6);
         var6 += (byte)var5.nextLong();
         if ((var6 & 1) != 0) {
            var6 = (byte)(var6 + 7);
         }
      }

      var5.nextBytes(var1);
      this.lLastSeed = var3;
   }

   public long getTimeLastMsg() {
      return this.lTimeLastMsg;
   }

   public long getTimeLastMsgSent() {
      return this.lTimeLastMsgSent;
   }

   public boolean getAuthenticated() {
      return this.boolAuthenticated;
   }

   public boolean read(byte[] var1, int var2, int var3) {
      int var4 = 0;
      int var5 = 0;
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "---------- Beginning new Read: offset = " + var2 + "   bytes to read = " + var3);
      }

      try {
         while (var3 > 0) {
            if (this.boolDisconnecting || !this.boolSocketOK) {
               setLastError(536870913);
               break;
            }

            try {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(400, 4, "***read***available=" + this.objBufferedInputStream.available() + "***iCount" + var3 + "***iOffset" + var2);
               }

               var4 = this.objBufferedInputStream.read(var1, var2, var3);
            } catch (SocketTimeoutException var8) {
               break;
            } catch (Exception var9) {
               byte[] var7 = new byte[var3];
               this.objBufferedInputStream.read(var7, var2, var3);
               var7 = null;
               RRCLogger.log(100, 4, var7);
               this.dbLog(System.currentTimeMillis() + " read socket Error  -------------" + var9.getMessage());
               if (!this.boolDisconnecting && !this.boolOrderlyShutdown && RRCLogger.logEnabled) {
                  RRCLogger.logException(var9);
               }
               break;
            }

            if (var4 == -1) {
               this.dbLog(System.currentTimeMillis() + " read connection closed -------------");
               break;
            }

            var2 += var4;
            var5 += var4;
            var3 -= var4;
         }
      } catch (Exception var10) {
         RRCLogger.logException(var10);
      }

      if (var3 != 0) {
         this.boolConnected = false;
         this.boolSocketOK = false;
         return false;
      } else {
         this.iDataIn += var5;
         var2 -= var5;
         if (this.boolNeedRC4) {
            if (this.readRC4 == null) {
               this.readRC4 = new RC4Cipher(this.RC4Key);
            }

            this.readRC4.decrypt(var1, var2, var1, var2, var5);
         }

         return true;
      }
   }

   public boolean write(byte[] var1, int var2) {
      boolean var3 = true;
      if (var1 != null) {
         try {
            String var4 = new String(var1);
            if (var4.indexOf("<CSC_Auth UserName") == -1) {
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(
                     400, 4, "---------- Beginning new Write: data length = " + var1.length + " requested # of bytes to write: " + var2 + "\n\tdata: " + var4
                  );
               }
            } else if (RRCLogger.logEnabled) {
               RRCLogger.log(400, 4, "Csc_Auth Sent.");
            }

            var4 = null;
            synchronized (this.objWriteCR) {
               if (this.boolNeedRC4) {
                  this.log("Inside WRITE RC4");
                  if (this.writeRC4 == null) {
                     this.writeRC4 = new RC4Cipher(this.RC4Key);
                  }

                  this.writeRC4.encrypt(var1, 0, var1, 0, var2);
               }

               this.lTimeLastMsgSent = System.currentTimeMillis();
               if (!this.boolDisconnecting && this.boolSocketOK) {
                  this.iDataOut += var2;

                  try {
                     if (RRCLogger.logEnabled) {
                        RRCLogger.log(
                           400, 4, "***write***outputstream.size=" + this.objFilterOutputStream.size() + "***iCount" + var2 + " byInData length " + var1.length
                        );
                     }

                     this.objFilterOutputStream.write(var1, 0, var2);
                     this.objFilterOutputStream.flush();
                  } catch (Exception var8) {
                     this.dbLog(System.currentTimeMillis() + " send error in write -------------" + var8.getMessage());
                     if (RRCLogger.logEnabled) {
                        RRCLogger.logException(var8);
                     }

                     var3 = false;
                     this.boolConnected = false;
                     this.boolSocketOK = false;
                  }
               } else {
                  setLastError(536870913);
                  var3 = false;
               }
            }

            this.log("**written " + var2);
         } catch (Exception var10) {
            if (RRCLogger.logEnabled) {
               RRCLogger.logException(var10);
            }

            var3 = false;
         }
      } else if (RRCLogger.logEnabled) {
         RRCLogger.log(400, 4, "Bytes to be sent inData is NULL");
      }

      return var3;
   }

   private boolean sinkRFPData(int var1) {
      boolean var2 = false;
      int var3 = 0;
      boolean var4 = false;
      int var5 = 0;
      if (var1 < 0) {
         var1 &= 65535;
      }

      byte[] var6 = new byte[var1];

      while (var1 > 0) {
         if (var1 > 65535) {
            var3 = 65535;
         } else {
            var3 = var1;
         }

         var5 = this.readFromStream(var6, 0, var3, RFP);
         var1 -= var3;
      }

      var6 = null;
      return var5 < 0 ? false : var2;
   }

   private boolean sinkData(int var1) {
      boolean var2 = false;
      int var3 = 0;
      boolean var4 = false;
      if (var1 < 0) {
         var1 &= 65535;
      }

      byte[] var5 = new byte[var1];

      while (var1 > 0) {
         if (var1 > 65535) {
            var3 = 65535;
         } else {
            var3 = var1;
         }

         var2 = this.read(var5, 0, var3);
         var1 -= var3;
      }

      var5 = null;
      return var2;
   }

   public void dbLog(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(200, 4, var1);
      }
   }

   public void dbLog2(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(200, 4, var1);
      }
   }

   public void dbLog3(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(200, 4, var1);
      }
   }

   private void dbLogCmd(boolean var1, TRCOMMAND var2) {
      if (RRCLogger.shouldLog(300, 4)) {
         if (var1) {
            switch (var2.getCommand()) {
               case 16:
               case 20:
               case 31:
               case 32:
               case 41:
               case 42:
               case 43:
               case 45:
                  if (!RRCLogger.shouldLog(400, 4)) {
                     return;
                  }
               case 17:
               case 18:
               case 19:
               case 21:
               case 22:
               case 23:
               case 24:
               case 25:
               case 26:
               case 27:
               case 28:
               case 29:
               case 30:
               case 33:
               case 34:
               case 35:
               case 36:
               case 37:
               case 38:
               case 39:
               case 40:
               case 44:
               default:
                  this.dbLog2(
                     System.currentTimeMillis()
                        + " In  "
                        + Integer.toHexString(var2.getCommand())
                        + " "
                        + Integer.toHexString(var2.getPktID())
                        + " "
                        + Integer.toHexString(var2.getCmdLength())
                  );
            }
         } else {
            switch (var2.getCommand()) {
               case 17:
               case 18:
               case 19:
               case 24:
               case 48:
                  if (!RRCLogger.shouldLog(400, 4)) {
                     return;
                  }
               default:
                  this.dbLog2(
                     System.currentTimeMillis()
                        + " Out "
                        + Integer.toHexString(var2.getCommand())
                        + " "
                        + Integer.toHexString(var2.getPktID())
                        + " "
                        + Integer.toHexString(var2.getCmdLength())
                  );
            }
         }
      }
   }

   public boolean processResponse(boolean var1, TRCOMMAND var2) {
      try {
         TRRSP_NACK_DATA var3 = new TRRSP_NACK_DATA(var2.toByteArray());
         if (!var1) {
            return false;
         }

         if (var3.getCommand() == 3) {
            setLastError(var3.getError() - 536875008);
            return false;
         }
      } catch (Exception var4) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(200, 4, "TRConnection:processResponse() " + var4.getMessage());
         }
      }

      return true;
   }

   private boolean svrHndshakeAftSocketCreation(TRCMD_HANDSHAKE_ACK_DATA var1, boolean var2) throws Exception {
      boolean var3 = false;
      if (var2) {
         var1.setSignature(1203501117);
      } else {
         this.objWriteSock = this.objReadSock;
         this.objWriteSSLSocket = this.objReadSSLSocket;
         var1.setSignature(1547540642);
      }

      var1.setChecksum(this.CalcHandshakeChecksum(var1));
      this.createFilterOutputStream();
      var3 = this.write(var1.toByteArray(), 34);
      if (!var3) {
         return false;
      } else {
         if (!var2) {
            this.objWriteSock = null;
            this.objWriteSSLSocket = null;
         }

         return var3;
      }
   }

   private void log(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 4, "CONNECTION::" + var1);
      }
   }

   public void myassert(boolean var1) {
   }

   public TRLIB_COMM getResolvedComm() {
      return this.objComm;
   }

   public long getPermissions() {
      return this.lPermissions;
   }

   public TRSRVR_SERVER_ID getServerID() {
      return this.objSvrID;
   }

   public int getProtocolVersion() {
      return this.objSvrID.getProtocolVersion();
   }

   public static XMLParser getXmlParserInstance() {
      if (xmlParser == null) {
         xmlParser = new XMLParser();
      }

      return xmlParser;
   }

   public boolean checkForKX2Device(String var1) {
      boolean var2 = false;

      try {
         xmlParser = getXmlParserInstance();
         Document var3 = xmlParser.getDocument(var1);
         if (var3 == null) {
            return var2;
         }

         Element var4 = var3.getDocumentElement();
         Object var25 = null;
         NodeList var5 = var4.getElementsByTagName("Device");
         if (var5 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device>");
            }

            return var2;
         }

         if (var5.getLength() > 1) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device> length");
            }

            return var2;
         }

         Node var6 = var5.item(0);
         NamedNodeMap var7 = var6.getAttributes();
         if (var7 == null) {
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "No <Device> attributes");
            }

            return var2;
         }

         Node var8 = var7.getNamedItem("ProductCode");
         Node var9 = var7.getNamedItem("Type");
         this.deviceType = var9.getNodeValue();
         Node var10 = var7.getNamedItem("ProductName");
         Node var11 = var7.getNamedItem("Model");
         Node var12 = var7.getNamedItem("Version");
         this.productVersion = var12.getNodeValue();
         if (var10 != null && var11 != null && var10.getNodeValue().toUpperCase().equals("KX101") && var11.getNodeValue().toUpperCase().equals("KX_KIM")) {
            this.setKX101G1Device(true);
            return var2;
         }

         if (var8 != null && var9 != null) {
            String var13 = var8.getNodeValue();
            String var14 = var9.getNodeValue();
            if ((
                     var13.toUpperCase().equals("HK8")
                        || var13.toUpperCase().equals("HK9")
                        || var13.toUpperCase().equals("HKA")
                        || var13.toUpperCase().equals("HKB")
                        || var13.toUpperCase().equals("HKC")
                        || var13.toUpperCase().equals("HKD")
                        || var13.toUpperCase().equals("HKE")
                        || var13.toUpperCase().equals("HKF")
                        || var13.toUpperCase().equals("HKG")
                        || var13.toUpperCase().equals("HKH")
                        || var13.toUpperCase().equals("HKI")
                        || var13.toUpperCase().equals("QAW")
                        || var13.toUpperCase().equals("AAK")
                        || var13.toUpperCase().equals("AAY")
                        || var13.toUpperCase().equals("AE2")
                        || var13.toUpperCase().equals("AE1")
                        || var13.toUpperCase().equals("HKL")
                        || var13.toUpperCase().equals("HKK")
                        || var13.toUpperCase().equals("HKJ")
                  )
                  && var14.equals("Dominion_KX2")
               || "Dominion_KX2_101".equals(var14)
               || "Dominion_KSX2".equals(var14)
               || "Dominion_LX".equals(var14)) {
               var2 = true;
               if (RRCLogger.logEnabled) {
                  RRCLogger.log(300, 4, "Connecting to a G2 Device.");
               }
            }

            if ((var13.toUpperCase().equals("AAK") || var13.toUpperCase().equals("AAY")) && var14.equals("Dominion_KX2_101")) {
               this.setKX101G2Device(true);
            }
         }

         NodeList var26 = var4.getElementsByTagName("Protocol");
         Node var27 = null;
         if (var26.getLength() > 0) {
            var27 = var26.item(0);
         }

         NamedNodeMap var15 = var27.getAttributes();
         if (var15 != null) {
            Node var16 = var15.getNamedItem("id");
            String var17 = null;
            if (var16 != null) {
               var17 = var16.getNodeValue();
            }

            if (var17 != null && var17.equals("RDM")) {
               Node var18 = var15.getNamedItem("RequireTLS");
               String var19 = null;
               if (var18 != null) {
                  var19 = var18.getNodeValue();
               }

               if (var19 != null && var19.equals("1.0")) {
                  this.setUseTLS(true);
               }
            }
         }
      } catch (NumberFormatException var20) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var20.getMessage());
         }
      } catch (DOMException var21) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var21.getMessage());
         }
      } catch (IOException var22) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var22.getMessage());
         }
      } catch (SAXException var23) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var23.getMessage());
         }
      } catch (ParserConfigurationException var24) {
         if (RRCLogger.logEnabled) {
            RRCLogger.log(300, 4, var24.getMessage());
         }
      }

      return var2;
   }

   public boolean isPingDevice() {
      return this.pingDevice;
   }

   public void setPingDevice(boolean var1) {
      this.pingDevice = var1;
   }

   public String getRdmSessionID() {
      return this.sessionId;
   }

   public String getRdmSessionKey() {
      return this.sessionKey;
   }

   public boolean isKX101G1Device() {
      return this.isKX101G1Device;
   }

   public void setKX101G1Device(boolean var1) {
      this.isKX101G1Device = var1;
   }

   public boolean isKX101G2Device() {
      return this.isKX101G2Device;
   }

   public void setKX101G2Device(boolean var1) {
      this.isKX101G2Device = var1;
   }

   protected TRLIB_COMM getTrlib_comm() {
      return this.objComm;
   }

   public boolean isGDMode() {
      return this.gdMode;
   }

   public void setGDMode(boolean var1) {
      this.gdMode = var1;
   }

   public void setUseTLS(boolean var1) {
      this.useTLS = var1;
   }

   public boolean getUseTLS() {
      return this.useTLS;
   }

   public static void main(String[] var0) {
      TRLIB_COMM var1 = new TRLIB_COMM();
      TRLIB_USERINFO var2 = new TRLIB_USERINFO();
      TRLIB_REFERRAL_COMM var3 = new TRLIB_REFERRAL_COMM();
      boolean var4 = false;
      Object var5 = null;

      try {
         var5 = InetAddress.getByName("10.0.0.229");
         var1.setIpAddress(var5.hashCode());
         var1.setConnType(2);
         var1.setServerName("IPR229".getBytes());
         var1.setDnsName("IPR229".getBytes());
         var1.setIpPort(5000);
         var1.setFindBy(0);
         var2.setName("admin".getBytes());
         var2.setPassword(Constants.DEFAULT_PASSWORD.getBytes());
         var3.setVersion(1);
         TRConnection var6 = new TRConnection();
         boolean var7 = var6.connect(var1, var2, null, null);

         for (int var8 = 0; !var6.getAuthenticated(); var8++) {
            Thread.sleep(500L);
            if (var8 > 20) {
               var7 = false;
               break;
            }
         }

         if (!var7) {
            System.out.println("**************+Authentication Failure **********");
            System.exit(1);
         } else {
            System.out.println("************** Connect Successful **********");
         }

         TRCOMMAND var9 = new TRCOMMAND();
         var9.setCommand((byte)3);
         var9.setCmdLength((short)4);
         var9.setPktID((byte)0);
         if (!var6.sendTRCmd(var9)) {
            var6.disConnect();
            if (RRCLogger.logEnabled) {
               RRCLogger.log(300, 4, "PING Error");
            }
         }

         String var10 = "<Database><Get><Select>/System</Select><Nodes>*</Nodes><SubNodes>*</SubNodes></Get></Database>";
         System.out.println("**************+Database Request **********");
         System.out.println(var6.databaseRequest(var10));
         Thread.sleep(6000L);
         var6.disConnect();
         System.out.println("**************+Disconnect Successful **********");
      } catch (Exception var11) {
         if (RRCLogger.logEnabled) {
            RRCLogger.logException(var11);
         }
      }
   }
}
