package javaclientlib.clientlib;

import java.net.InetAddress;
import javaclientlib.tr.Constants;
import javaclientlib.tr.TRBASECOMMAND;
import javaclientlib.tr.TRCMD_GET_SERIAL_PARAMS_DATA;
import javaclientlib.tr.TRCMD_SEND_SERIAL_DATA;
import javaclientlib.tr.TRCMD_STOP_SERIAL_STREAM_DATA;
import javaclientlib.tr.TRCOMMAND;
import javaclientlib.tr.TRLIB_COMM;
import javaclientlib.tr.TRLIB_REFERRAL_COMM;
import javaclientlib.tr.TRLIB_USERINFO;
import javaclientlib.tr.TRRSP_CONNECTED_DATA;
import javaclientlib.tr.TRRSP_RECEIVE_SERIAL_DATA;
import javaclientlib.tr.TRRSP_SERIAL_PARAMS_DATA;
import javaclientlib.tr.TRSRVR_SERIAL_PARAMS;
import javaclientlib.utils.RRCLogger;

public class TRSerialStream implements ISerialStream {
   private TRSerialStream objSerialStreamNext;
   private boolean boolObjectGood = true;
   private byte byDeviceID;
   private boolean boolConnected;
   private TRConnection objConnection;

   public TRSerialStream(TRConnection var1) {
      this.objSerialStreamNext = null;
      this.byDeviceID = 0;
      this.boolConnected = false;
      if (var1 != null) {
         this.objConnection = var1;
         var1.addSerialStream(this);
      }
   }

   @Override
   protected void finalize() throws Exception {
      if (this.boolConnected) {
         this.stopSerialStream();
      }

      if (this.objConnection != null) {
         this.objConnection.removeSerialStream(this);
      }
   }

   public boolean connectSerialStream(String var1, String var2) {
      boolean var3 = false;

      try {
         String var4 = "<Connect><Portal>" + var1 + "</Portal><Target>" + var2 + "</Target></Connect>";
         TRRSP_CONNECTED_DATA var5 = new TRRSP_CONNECTED_DATA((short)4108);
         var5.setCommand((byte)56);
         System.arraycopy(var4.getBytes(), 0, var5.toByteArray(), 4, var4.getBytes().length);
         var5.setCmdLength((short)(4 + var4.getBytes().length));
         var3 = this.objConnection.sendTRCmdExx(var5, true, null, 38, true, 0);
         var3 = this.objConnection.processResponse(var3, var5);
         if (var3) {
            this.byDeviceID = var5.getDeviceID();
            this.log("The Got Device Id " + var5.getDeviceID());
            this.objConnection.setSerialStreamDevice(this, this.byDeviceID);
            this.boolConnected = true;
         }

         this.objConnection.syncTRCmd();
         return var3;
      } catch (Exception var6) {
         RRCLogger.logException(var6);
         return false;
      }
   }

   public boolean stopSerialStream() throws Exception {
      boolean var1 = false;

      try {
         TRCMD_STOP_SERIAL_STREAM_DATA var2 = new TRCMD_STOP_SERIAL_STREAM_DATA();
         var2.setCommand((byte)23);
         var2.setCmdLength((short)5);
         var2.setDeviceID(this.byDeviceID);
         this.boolConnected = false;
         var1 = this.objConnection.sendTRCmdEx(var2, true, null, 2);
         this.objConnection.setSerialStreamDevice(null, this.byDeviceID);
         if (this.objConnection != null) {
            this.objConnection.removeSerialStream(this);
         }

         return var1;
      } catch (Exception var3) {
         RRCLogger.logException(var3);
         return false;
      }
   }

   public boolean setSerialStream(TRSRVR_SERIAL_PARAMS var1) throws Exception {
      boolean var2 = false;

      try {
         TRCOMMAND var3 = new TRCOMMAND((short)4108);
         if (var1 == null && RRCLogger.logEnabled) {
            RRCLogger.log(200, 256, "Invalid objTRSrvrSerialParams object");
         }

         var3.setCommand((byte)25);
         var3.setCmdLength((short)53);
         var3.setByte(this.byDeviceID, 52);
         System.arraycopy(var1.getDataBytes(), 0, var3.toByteArray(), 4, 16);
         return this.objConnection.sendTRCmdEx(var3, true, null, 2);
      } catch (Exception var4) {
         RRCLogger.logException(var4);
         return false;
      }
   }

   public boolean getSerialStream(TRSRVR_SERIAL_PARAMS var1) throws Exception {
      try {
         boolean var2 = false;
         TRCMD_GET_SERIAL_PARAMS_DATA var3 = new TRCMD_GET_SERIAL_PARAMS_DATA((short)4108);
         if (var1 == null && RRCLogger.logEnabled) {
            RRCLogger.log(200, 256, "Invalid objTRSrvrSerialParams object");
         }

         var3.setCommand((byte)26);
         var3.setCmdLength((short)5);
         var3.setDeviceID(this.byDeviceID);
         var2 = this.objConnection.sendTRCmdEx(var3, true, null, 19);
         if (var2) {
            Object var4 = null;
            var4 = new TRRSP_SERIAL_PARAMS_DATA(var3.toByteArray());
            var1.setParams(((TRRSP_SERIAL_PARAMS_DATA)var4).getParams());
         }

         return var2;
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         return false;
      }
   }

   @Override
   public boolean serialOut(int var1, byte[] var2) throws Exception {
      try {
         boolean var3 = false;
         TRCMD_SEND_SERIAL_DATA var4 = new TRCMD_SEND_SERIAL_DATA((short)4108);
         var4.setCommand((byte)24);
         if (var1 > 4103) {
            var1 = 4103;
         }

         var4.setCmdLength((short)(5 + var1));
         var4.setDeviceID(this.byDeviceID);
         var4.setPktData(var2);
         return this.objConnection.sendTRCmd(var4);
      } catch (Exception var5) {
         RRCLogger.logException(var5);
         return false;
      }
   }

   @Override
   public void serialIn(int var1, byte[] var2) {
   }

   public boolean TRRSP_Receive_Serial(TRBASECOMMAND var1) {
      try {
         boolean var2 = false;
         TRRSP_RECEIVE_SERIAL_DATA var3 = new TRRSP_RECEIVE_SERIAL_DATA(var1.toByteArray());
         if (var3 == null && RRCLogger.logEnabled) {
            RRCLogger.log(200, 256, "Invalid objTRRSPReceiveSerialData object");
         }

         short var4 = (short)(var3.getCmdLength() - 7);
         byte[] var5 = new byte[var4];
         var2 = this.objConnection.read(var5, 0, var4);
         this.serialIn(var4, var5);
         return var2;
      } catch (Exception var6) {
         RRCLogger.logException(var6);
         return false;
      }
   }

   public byte getDeviceID() {
      return this.byDeviceID;
   }

   public boolean sendSunBreak() throws Exception {
      try {
         boolean var1 = false;
         TRCOMMAND var2 = new TRCOMMAND();
         var2.setCommand((byte)58);
         var2.setCmdLength((short)4);
         return this.objConnection.sendTRCmd(var2);
      } catch (Exception var3) {
         RRCLogger.logException(var3);
         return false;
      }
   }

   private void log(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 256, "Video Stream::" + var1);
      }
   }

   public static void main(String[] var0) {
      TRLIB_COMM var1 = new TRLIB_COMM();
      TRLIB_USERINFO var2 = new TRLIB_USERINFO();
      TRLIB_REFERRAL_COMM var3 = new TRLIB_REFERRAL_COMM();
      new TRSRVR_SERIAL_PARAMS();
      boolean var5 = false;
      TRRSP_RECEIVE_SERIAL_DATA var6 = new TRRSP_RECEIVE_SERIAL_DATA();
      byte var7 = 0;
      byte var8 = 0;
      var6.setFlags(var7);
      var6.setDeviceID((byte)var8);
      Object var9 = null;

      try {
         var9 = InetAddress.getByName("10.0.0.240");
         var1.setIpAddress(var9.hashCode());
         var1.setConnType(2);
         var1.setServerName("IP Reach".getBytes());
         var1.setDnsName("IP Reach".getBytes());
         var1.setIpPort(5000);
         var1.setFindBy(0);
         var2.setName("admin".getBytes());
         var2.setPassword(Constants.DEFAULT_PASSWORD.getBytes());
         var3.setVersion(1);
         TRConnection var10 = new TRConnection();
         boolean var12 = var10.connect(var1, var2, null, null);

         while (!var10.getAuthenticated()) {
            Thread.sleep(100L);
         }

         TRSerialStream var11 = new TRSerialStream(var10);
         Thread.sleep(200L);
         var11.stopSerialStream();
      } catch (Exception var13) {
         var13.printStackTrace();
      }
   }
}
