package javaclientlib.common;

import java.io.BufferedInputStream;
import java.io.ByteArrayInputStream;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.security.KeyFactory;
import java.security.PublicKey;
import java.security.Signature;
import java.security.spec.KeySpec;
import java.security.spec.X509EncodedKeySpec;
import javaclientlib.tr.Constants;
import javaclientlib.tr.RFP;
import javaclientlib.tr.RFP_FILE;
import javaclientlib.utils.RRCLogger;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class RFPParser {
   private int iCurFile;
   private RFP_FILE curFile;
   private RFP objRfp;
   private int iHeaderOffset;
   private int iHeaderLength;
   private int iSignatureOffset;
   private int iSignatureLength;
   protected int iDataOffset = 0;
   public static final int RFP_MAX_HEADER_SIZE = 65536;
   public static final int RFP_MAX_SIGNATURE_SIZE = 300;
   public static final int RFP_ERROR_MEMORY = 1;
   public static final int RFP_ERROR_TOO_MANY_FILES = 2;
   public static final int RFP_ERROR_CANNOT_READ_RSA_FILE = 3;
   public static final int RFP_ERROR_RSA_BAD = 4;
   public static final int RFP_ERROR_BAD_SIGNATURE = 5;
   public static final int RFP_ERROR_CANNOT_READ_FILE = 6;
   public static final int RFP_FILE_META_FILENAME = 1;

   public int parseHeader(String var1) {
      return this.parse(var1, var1.length());
   }

   public int parseFile(RandomAccessFile var1) {
      int var3 = 0;
      byte[] var2 = new byte[65836];

      try {
         int var4 = var1.read(var2, 0, 65836);
         if (var4 <= 0) {
            byte var8 = 6;
         }

         var3 = this.parseHeaderAndSignature(var2, var4);
      } catch (Exception var6) {
         RRCLogger.logException(var6);
         var3 = 6;
      }

      return var3;
   }

   public int parseHeaderAndSignature(byte[] var1, int var2) {
      int var4 = 0;
      String var5 = "</" + Constants.COMPANY_NAME_NOSPACE + "_File_Package>";
      String var6 = new String(var1);
      int var7 = var6.indexOf(var5);
      if (var7 == -1) {
         return var4;
      } else {
         String var8 = var6.substring(0, var7 + var5.length());
         this.iHeaderLength = this.iSignatureOffset = var8.length();
         var4 = this.parseHeader(new String(var8));
         if (this.objRfp.getIsSigned() != 0) {
            this.iSignatureLength = this.objRfp.getRfpFile(0).getSignature().length;
            this.iDataOffset = this.iHeaderLength + this.iSignatureLength;
         } else {
            this.iDataOffset = this.iHeaderLength;
         }

         return var4;
      }
   }

   public int verifyHeaderSignature(String var1, String var2, String var3) {
      int var4 = 0;
      Object var6 = null;
      if (this.objRfp.getIsSigned() == 0) {
         return 0;
      } else {
         int var5 = var1.length() + 1;
         var6 = new ByteArrayInputStream(var1.getBytes());
         var4 = this.verifySignature((InputStream)var6, var2.getBytes(), var3);
         var6 = null;
         return var4;
      }
   }

   public int verifyFileSignatures(String var1) {
      int var2 = 0;

      for (int var3 = 0; var3 < this.objRfp.getFileCount(); var3++) {
         var2 = this.verifyFileSignature(this.objRfp.getRfpFile(var3), null, var1);
         if (var2 != 0) {
            break;
         }
      }

      return var2;
   }

   public int verifyFileSignature(RFP_FILE var1, String var2, String var3) {
      boolean var4 = false;
      if (var1.getIsSigned() == 0) {
         return 0;
      } else {
         if (var2 == null) {
            var2 = new String(var1.getFileName());
         }

         FileInputStream var5;
         try {
            var5 = new FileInputStream(var2);
         } catch (Exception var7) {
            RRCLogger.logException(var7);
            return 6;
         }

         return this.verifySignature(var5, var1.getSignature(), var3);
      }
   }

   public int verifyFileSignature_SSLOBJECT(RFP_FILE var1, InputStream var2, String var3) {
      boolean var4 = false;
      return var1.getIsSigned() == 0 ? 0 : this.verifySignature(var2, var1.getSignature(), var3);
   }

   public RFP_FILE enumFile(int var1) {
      return var1 < this.objRfp.getFileCount() ? this.objRfp.getRfpFile(var1) : null;
   }

   public RFP getHeader() {
      return this.objRfp;
   }

   public int verifySignature(InputStream var1, byte[] var2, String var3) {
      Object var4 = null;
      Object var5 = null;
      Object var6 = null;
      boolean var7 = false;

      try {
         try {
            var4 = new byte[var1.available()];
            var1.read((byte[])var4);
            var1.close();
         } catch (Exception var13) {
            return 3;
         }

         var5 = new X509EncodedKeySpec((byte[])var4);
         KeyFactory var8 = KeyFactory.getInstance("DSA", "SUN");
         var6 = var8.generatePublic((KeySpec)var5);
         Signature var9 = Signature.getInstance("SHA1withDSA", "SUN");
         var9.initVerify((PublicKey)var6);
         BufferedInputStream var10 = new BufferedInputStream(var1);
         byte[] var11 = new byte[1024];

         while (var10.available() != 0) {
            int var12 = var10.read(var11);
            var9.update(var11, 0, var12);
         }

         var10.close();
         var7 = var9.verify(var2);
      } catch (Exception var14) {
         RRCLogger.logException(var14);
      }

      return !var7 ? 5 : 0;
   }

   public int parse(String var1, int var2) {
      this.log("parsing file *************" + var2);

      try {
         this.objRfp = this.convertXML(var1);
      } catch (Exception var4) {
         RRCLogger.logException(var4);
      }

      return 0;
   }

   public RFP convertXML(String var1) {
      RFP var2 = null;
      RFP_FILE[] var3 = new RFP_FILE[64];
      int var4 = 0;

      try {
         DocumentBuilderFactory var5 = DocumentBuilderFactory.newInstance();
         DocumentBuilder var6 = var5.newDocumentBuilder();
         Document var7 = var6.parse(new ByteArrayInputStream(var1.getBytes()));
         NodeList var8 = var7.getChildNodes();
         Node var9 = var8.item(0);
         NodeList var10 = var9.getChildNodes();

         for (int var11 = 0; var11 < var10.getLength(); var11++) {
            if (var10.item(var11).getNodeType() == 1) {
               Node var12 = var10.item(var11);
               if (var12 != null) {
                  if (var2 == null) {
                     var2 = new RFP();
                  }

                  if (var12.getNodeName().equals("Title")) {
                     var2.setTitle(this.getNodeTextValue(var12));
                  } else if (var12.getNodeName().equals("Description")) {
                     var2.setDescription(this.getNodeTextValue(var12));
                  } else if (var12.getNodeName().equals("Publisher")) {
                     var2.setPublisher(this.getNodeTextValue(var12));
                  } else if (var12.getNodeName().equals("Copyright")) {
                     var2.setCopyRight(this.getNodeTextValue(var12));
                  } else if (var12.getNodeName().equals("Signed")) {
                     var2.setIsSigned(1);
                  } else if (var12.getNodeName().equals("RFP_File")) {
                     if (var3 != null) {
                        var3[var4] = this.getRFPFile(var12);
                        var4++;
                     }
                  } else if (var12.getNodeName().equals("RP")) {
                     var2.addRPID(var12.getAttributes().getNamedItem("rpid").getNodeValue());
                  }
               }
            }
         }

         var2.setFileCount(var4);
         var2.setRfpFile(var3);
      } catch (Exception var13) {
         RRCLogger.logException(var13);
      }

      return var2;
   }

   private byte[] getNodeTextValue(Node var1) {
      return var1.getFirstChild() != null && var1.getFirstChild().getNodeValue() != null ? var1.getFirstChild().getNodeValue().getBytes() : null;
   }

   private int getNodeIntValue(Node var1) {
      if (var1.getFirstChild() != null && var1.getFirstChild().getNodeValue() != null) {
         String var2 = var1.getFirstChild().getNodeValue();
         return Integer.parseInt(var2);
      } else {
         return 0;
      }
   }

   public RFP_FILE getRFPFile(Node var1) {
      RFP_FILE var2 = null;
      NodeList var3 = var1.getChildNodes();

      for (int var4 = 0; var4 < var3.getLength(); var4++) {
         if (var3.item(var4).getNodeType() == 1) {
            if (var2 == null) {
               var2 = new RFP_FILE();
            }

            Node var5 = var3.item(var4);
            if (var5 != null) {
               if (var5.getNodeName().equals("Length")) {
                  var2.setLength(this.getNodeIntValue(var5));
               } else if (var5.getNodeName().equals("Signature")) {
                  var2.setSignature(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("Encrypted")) {
                  var2.setIsEncrypted(this.getNodeIntValue(var5));
               } else if (var5.getNodeName().equals("FileName")) {
                  var2.setFileName(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("Model")) {
                  var2.setModel(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("Version")) {
                  var2.setVersion(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("VersionMin")) {
                  var2.setVersionMin(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("VersionMax")) {
                  var2.setVersionMax(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("Script")) {
                  var2.setScript(this.getNodeTextValue(var5));
               } else if (var5.getNodeName().equals("MetaFileName")) {
                  var2.setFileName(this.getNodeTextValue(var5));
                  var2.setMetaFileName(1);
               }
            }
         }
      }

      return var2;
   }

   private void log(String var1) {
      if (RRCLogger.logEnabled) {
         RRCLogger.log(300, 64, "RFPParser::" + var1);
      }
   }
}
