package javaclientlib.common;

import javaclientlib.tr.RADIUS_ATTRIB_HEADER;
import javaclientlib.tr.RADIUS_ATTRIB_STRING;
import javaclientlib.tr.RADIUS_ATTRIB_VALUE;
import javaclientlib.tr.RADIUS_PACKET;
import javaclientlib.utils.MD5;

public class RadiusPacket {
   public boolean appendAttribute(RADIUS_PACKET var1, RADIUS_ATTRIB_HEADER var2) {
      if (this.validateAttribute(var2) == 2) {
         return false;
      } else if (var2.getLengthAttribute() > 4096) {
         return false;
      } else {
         var1.appendAttributePacket(var2);
         return true;
      }
   }

   public boolean appendValueAttribute(RADIUS_PACKET var1, byte var2, int var3) {
      RADIUS_ATTRIB_VALUE var4 = new RADIUS_ATTRIB_VALUE();
      var4.setType(var2);
      var4.setLengthAttribute(6);
      var4.setValue(var3);
      return this.appendAttribute(var1, var4);
   }

   public boolean appendStringAttribute(RADIUS_PACKET var1, byte var2, int var3, byte[] var4) {
      RADIUS_ATTRIB_STRING var5 = new RADIUS_ATTRIB_STRING();
      if (var3 > 253) {
         return false;
      } else {
         var5.setType(var2);
         var5.setLengthAttribute((byte)(2 + var3));
         var5.setAttribute(var4);
         return this.appendAttribute(var1, var5);
      }
   }

   public boolean insertAttribute(RADIUS_PACKET var1, RADIUS_ATTRIB_HEADER var2, RADIUS_ATTRIB_HEADER var3) {
      if (this.validateAttribute(var3) == 2) {
         return false;
      } else if (var3.getLengthAttribute() > 4096) {
         return false;
      } else {
         int var4 = var1.findAttributePosition(0, var2.getType());
         if (var4 == -1) {
            return false;
         } else {
            var1.insertAttributeData(var4, var3);
            return true;
         }
      }
   }

   public boolean insertValueAttribute(RADIUS_PACKET var1, RADIUS_ATTRIB_HEADER var2, byte var3, int var4) {
      RADIUS_ATTRIB_VALUE var5 = new RADIUS_ATTRIB_VALUE();
      var5.setType(var3);
      var5.setLengthAttribute(6);
      var5.setValue(var4);
      return this.insertAttribute(var1, var2, var5);
   }

   public boolean insertStringAttribute(RADIUS_PACKET var1, RADIUS_ATTRIB_HEADER var2, byte var3, int var4, byte[] var5) {
      RADIUS_ATTRIB_STRING var6 = new RADIUS_ATTRIB_STRING();
      if (var4 > 253) {
         return false;
      } else {
         var6.setType(var3);
         var6.setLengthAttribute((byte)(2 + var4));
         var6.setAttribute(var5);
         return this.insertAttribute(var1, var2, var6);
      }
   }

   public RADIUS_ATTRIB_HEADER findAttribute(RADIUS_PACKET var1, RADIUS_ATTRIB_HEADER var2, byte var3) {
      int var6;
      if (var2 == null) {
         var6 = var1.findAttributePosition(0, var3);
      } else {
         var6 = var1.findAttributePosition(0, var2.getType());
         var6 = var1.findAttributePosition(var6, var3);
      }

      if (var6 == -1) {
         return null;
      } else {
         byte var4 = var1.getAttributeData(var6 + 1);
         String var7 = var1.getAttributeData(var6 + 2, var4 - 2);
         if (var7.getClass().isAssignableFrom(int.class)) {
            RADIUS_ATTRIB_VALUE var10 = new RADIUS_ATTRIB_VALUE();
            var10.setType(var1.getAttributeData(var6));
            var10.setLengthAttribute((int)var4);
            var10.setValue(Integer.parseInt(var7));
            return var10;
         } else {
            RADIUS_ATTRIB_STRING var8 = new RADIUS_ATTRIB_STRING();
            var8.setType(var1.getAttributeData(var6));
            var8.setLengthAttribute((int)var4);
            var8.setAttribute(var7);
            return var8;
         }
      }
   }

   public boolean removeAttribute(RADIUS_PACKET var1, RADIUS_ATTRIB_HEADER var2) {
      int var3 = var1.findAttributePosition(0, var2.getType());
      if (var3 == -1) {
         return false;
      } else {
         var1.removeAttributeData(var3, var2.getLengthAttribute());
         return true;
      }
   }

   private int validateAttribute(RADIUS_ATTRIB_HEADER var1) {
      if (var1.getLengthAttribute() < 2) {
         return 2;
      } else {
         switch (var1.getType()) {
            case 1:
            case 11:
            case 18:
            case 19:
            case 20:
            case 22:
            case 24:
            case 25:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 39:
            case 44:
            case 50:
            case 63:
               if (var1.getLengthAttribute() < 2) {
                  return 2;
               }
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 12:
            case 13:
            case 14:
            case 15:
            case 16:
            case 17:
            case 21:
            case 23:
            case 26:
            case 27:
            case 28:
            case 29:
            case 36:
            case 37:
            case 38:
            case 40:
            case 41:
            case 42:
            case 43:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 51:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            case 60:
            case 61:
            case 62:
         }

         switch (var1.getType()) {
            case 2:
               if (var1.getLengthAttribute() < 18 || var1.getLengthAttribute() > 130) {
                  return 2;
               }
               break;
            case 3:
               if (var1.getLengthAttribute() != 19) {
                  return 2;
               }
               break;
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
            case 10:
            case 12:
            case 13:
            case 14:
            case 15:
            case 16:
            case 23:
            case 27:
            case 28:
            case 29:
            case 37:
            case 38:
            case 40:
            case 41:
            case 42:
            case 43:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 51:
            case 61:
            case 62:
               if (var1.getLengthAttribute() != 6) {
                  return 2;
               }
               break;
            case 11:
            case 17:
            case 18:
            case 19:
            case 20:
            case 21:
            case 22:
            case 24:
            case 25:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 39:
            case 44:
            case 50:
            case 52:
            case 53:
            case 54:
            case 55:
            case 56:
            case 57:
            case 58:
            case 59:
            default:
               return 1;
            case 26:
               if (var1.getLengthAttribute() < 7) {
                  return 2;
               }
               break;
            case 36:
               if (var1.getLengthAttribute() != 34) {
                  return 2;
               }
               break;
            case 60:
               if (var1.getLengthAttribute() < 7) {
                  return 2;
               }
         }

         return 0;
      }
   }

   public int validatePacket(RADIUS_PACKET var1) {
      byte var3 = 0;
      byte var4 = 20;
      int var5 = 0;
      switch (var1.getCode()) {
         case 1:
         case 2:
         case 3:
         case 4:
         case 5:
         case 6:
            if (var1.getPktLength() <= 4096 && var1.getPktLength() >= 20) {
               RADIUS_ATTRIB_HEADER var7 = new RADIUS_ATTRIB_HEADER();
               short var2 = var1.getPktLength();

               while (var3 < var2) {
                  var7.setType(var1.getAttributeData(var3));
                  var7.setLengthAttribute(var1.getAttributeData(var3 + 1));
                  if (var7.getLengthAttribute() + var4 > var1.getPktLength()) {
                     return 3;
                  }

                  var3 += var7.getLengthAttribute();
                  int var6 = this.validateAttribute(var7);
                  if (var6 > var5) {
                     var5 = var6;
                  }
               }

               return var5;
            }

            return 3;
         default:
            return 3;
      }
   }

   public int deleteAttributeType(RADIUS_PACKET var1, byte var2) {
      int var5 = 0;
      new RADIUS_ATTRIB_HEADER();
      int var3 = var1.findAttributePosition(0, var2);
      if (var3 == -1) {
         return 0;
      } else {
         do {
            byte var4 = var1.getAttributeData(var3 + 1);
            var1.removeAttributeData(var3, var4);
            var5++;
            var3 = var1.findAttributePosition(0, var2);
         } while (var3 != -1);

         return var5;
      }
   }

   public int deleteAllButStateAttributes(RADIUS_PACKET var1) {
      byte var4 = 2;
      byte var5 = 0;
      StringBuffer var6 = new StringBuffer();
      int var2 = var1.findAttributePosition(0, (byte)24);
      if (var2 != -1) {
         byte var3 = var1.getAttributeData(var2 + 1);
         var6.append(var1.getAttributeData(var2, var3));
         var5 += var3;
      }

      var2 = var1.findAttributePosition(0, (byte)33);
      if (var2 != -1) {
         byte var8 = var1.getAttributeData(var2 + 1);
         var6.append(var1.getAttributeData(var2, var8));
         var5 += var8;
      }

      var1.clearAttributeData();
      var1.setAttributeData(var6.toString());
      var1.setPktLength((int)var5);
      return var4;
   }

   public void clearPacket(RADIUS_PACKET var1) {
      var1.clearPacket();
      var1.setPktLength(20);
   }

   public void computeCHAPResponse(byte[] var1, byte[] var2, byte[] var3, byte[] var4) throws Exception {
      MD5 var5 = new MD5();
      var5.update(var1);
      var5.update(var2);
      var5.update(var3);
      byte[] var6 = var5.encode();
      System.arraycopy(var6, 0, var4, 1, 16);
   }

   public boolean appendPasswordAttribute(RADIUS_PACKET var1, int var2, byte[] var3, byte[] var4, int var5) throws Exception {
      short var6 = 0;
      int var7 = 0;
      boolean var8 = false;
      byte[] var9 = new byte[128];
      var7 = var2 + 15 & -16;
      if (var7 == 0) {
         var7 = 16;
      }

      if (var2 > 128) {
         var6 = 128;
      }

      for (int var12 = 0; var12 < var7; var12++) {
         var9[var12] = 0;
      }

      if (var4 != null) {
         this.encryptPassword(var1, var3, var7, var4, var5);
      }

      return this.appendStringAttribute(var1, (byte)2, var7, var3);
   }

   private void encryptPassword(RADIUS_PACKET var1, byte[] var2, int var3, byte[] var4, int var5) throws Exception {
      byte[] var9 = new byte[16];
      byte[] var10 = new byte[16];
      MD5 var11 = new MD5();
      var9 = var1.getAuthenticator();
      int var6 = 0;

      while (var6 < var3) {
         var11.update(var4, var5);
         var11.update(var9, 16);
         var9 = var1.getAuthenticator(var6, 16);
         var10 = var11.encode();

         for (int var7 = 0; var7 < 16; var6++) {
            var2[var6] ^= var10[var7];
            var7++;
         }
      }
   }
}
