package javaclientlib.tr;

import java.util.Arrays;
import javaclientlib.utils.RRCUtil;

public class RADIUS_PACKET extends TRDATASTRUCTURE {
   protected static final TRDATASTRUCTURE_DEF definition = new TRDATASTRUCTURE_DEF(
      RADIUS_PACKET.class,
      new String[]{"code", "identifier", "pktLength", "authenticator", "attributeData"},
      new Class[]{byte.class, byte.class, short.class, byte.class, byte.class},
      new int[]{0, 0, 0, -1, -1}
   );
   private byte code;
   private byte identifier;
   private short pktLength;
   private byte[] authenticator = new byte[16];
   private byte[] attributeData;
   public static final short CMD_LEN = 4096;

   @Override
   public TRDATASTRUCTURE_DEF getDefinition() {
      return definition;
   }

   public RADIUS_PACKET() {
      this.pktLength = 0;
      this.attributeData = new byte[4076];
   }

   @Override
   public short getLength() {
      return 4096;
   }

   public byte getCode() {
      return this.code;
   }

   public void setCode(byte var1) {
      this.code = var1;
   }

   public byte getIdentifier() {
      return this.identifier;
   }

   public void setIdentifier(byte var1) {
      this.identifier = var1;
   }

   public short getPktLength() {
      return this.pktLength;
   }

   public void setPktLength(short var1) {
      this.pktLength = var1;
   }

   public void setPktLength(int var1) {
      this.pktLength = (short)var1;
   }

   public byte[] getAuthenticator() {
      return this.authenticator;
   }

   public int getAuthenticatorLength() {
      return this.authenticator.length;
   }

   public byte[] getAuthenticator(int var1, int var2) {
      byte[] var3 = new byte[var2 + 1];
      System.arraycopy(this.authenticator, var1, var3, 0, var2);
      return var3;
   }

   public String getAuthenticatorAsString() {
      return this.authenticator.toString();
   }

   public void setAuthenticator(byte[] var1) {
      this.authenticator = var1;
   }

   public void setAuthenticator(String var1) {
      this.authenticator = var1.getBytes();
   }

   public byte[] getAttributeData() {
      return this.attributeData;
   }

   public byte getAttributeData(int var1) {
      return this.attributeData[var1];
   }

   public String getAttributeData(int var1, int var2) {
      byte[] var3 = new byte[var2 + 1];
      System.arraycopy(this.attributeData, var1, var3, 0, var2);
      return var3.toString();
   }

   public int getAttributeDataLength() {
      return this.attributeData.length;
   }

   public String getAttributeDataAsString() {
      return this.authenticator.toString();
   }

   public void setAttributeData(byte[] var1) {
      this.attributeData = var1;
   }

   public void setAttributeData(String var1) {
      this.attributeData = var1.getBytes();
   }

   public void appendAttributeData(byte[] var1, int var2, int var3) {
      System.arraycopy(var1, var2, this.attributeData, this.pktLength - 20, var3);
   }

   public void insertAttributeData(int var1, RADIUS_ATTRIB_HEADER var2) {
      int var3 = this.pktLength - var1;
      this.pktLength = (short)var1;
      byte[] var4 = new byte[4076];
      System.arraycopy(this.attributeData, this.pktLength, var4, 0, var3);
      this.appendAttributePacket(var2);
      this.appendAttributeData(var4, 0, var3);
      this.pktLength = (short)(this.pktLength + var3);
   }

   public void appendAttributePacket(RADIUS_ATTRIB_HEADER var1) {
      byte var2 = 0;
      byte[] var3 = new byte[257];
      var3[0] = var1.getType();
      var3[1] = var1.getLengthAttribute();
      var2 = 2;
      if (var1 instanceof RADIUS_ATTRIB_STRING) {
         int var4 = 0;
         RADIUS_ATTRIB_STRING var5 = (RADIUS_ATTRIB_STRING)var1;
         var4 = var5.getAttribute().length;
         System.arraycopy(var5.getAttribute(), 0, var3, 2, var4);
         var2 = var3[1];
      } else if (var1 instanceof RADIUS_ATTRIB_VALUE) {
         RADIUS_ATTRIB_VALUE var8 = (RADIUS_ATTRIB_VALUE)var1;
         System.arraycopy(RRCUtil.getBytesForInt(var8.getValue()), 0, var3, 2, 4);
         var2 += 4;
      }

      this.appendAttributeData(var3, 0, var2);
      this.pktLength = (short)(this.pktLength + var2);
   }

   public void removeAttributeData(int var1, int var2) {
      int var3 = var2 + var1;
      byte[] var4 = new byte[4076];
      System.arraycopy(this.attributeData, var3, var4, 0, this.pktLength - var3);
      Arrays.fill(this.attributeData, var1, this.pktLength, (byte)0);
      System.arraycopy(var4, 0, this.attributeData, var2, this.pktLength - var3);
      this.pktLength = (short)(this.pktLength - var2);
   }

   public int findAttributePosition(int var1, byte var2) {
      for (int var3 = var1; var3 < this.pktLength; var3++) {
         if (this.attributeData[var3] == var2) {
            return var3;
         }
      }

      return -1;
   }

   public void clearAttributeData() {
      Arrays.fill(this.attributeData, (byte)0);
   }

   public void clearPacket() {
      this.clearAttributeData();
      this.pktLength = 0;
   }
}
