package javaclientlib.tr;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import javaclientlib.utils.BigEndianInputStream;
import javaclientlib.utils.BigEndianOutputStream;
import javaclientlib.utils.RRCGeneralException;

public abstract class TRDATASTRUCTURE {
   private int readBytes = 0;
   private int writeBytes = 0;
   private boolean boolBigEndian = false;

   public abstract TRDATASTRUCTURE_DEF getDefinition();

   public short getLength() throws Exception {
      throw new Exception("Length() not Implemented in " + this);
   }

   public void populate(byte[] var1) throws Exception {
      this.boolBigEndian = false;
      this.readBytes = 0;
      ByteArrayInputStream var2 = new ByteArrayInputStream(var1);
      if (this.getDefinition() != null) {
         DataInputStream var3 = new DataInputStream(var2);

         try {
            this.readBytes = this.readBytes + this.getDefinition().read(this, var3);
         } catch (Exception var5) {
            var5.printStackTrace(System.err);
            throw var5;
         }
      } else {
         System.err.println("TODO-READ[ " + this.getClass().getName() + " ]");
         throw new RRCGeneralException("TRDATASTRUCTURE_DEF not implemented for class: " + this.getClass().getName());
      }
   }

   public void populateBigEndian(byte[] var1) throws Exception {
      this.boolBigEndian = true;
      this.readBytes = 0;
      ByteArrayInputStream var2 = new ByteArrayInputStream(var1);
      if (this.getDefinition() != null) {
         BigEndianInputStream var3 = new BigEndianInputStream(var2);

         try {
            this.readBytes = this.readBytes + this.getDefinition().read(this, var3);
         } catch (Exception var5) {
            throw var5;
         }
      } else {
         System.err.println("TODO[ " + this.getClass().getName() + " ]");
         throw new RRCGeneralException("TRDATASTRUCTURE_DEF not implemented for class: " + this.getClass().getName());
      }
   }

   public byte[] getDataBytes() throws Exception {
      this.boolBigEndian = false;
      this.writeBytes = 0;
      ByteArrayOutputStream var1 = new ByteArrayOutputStream(this.getLength());
      if (this.getDefinition() != null) {
         DataOutputStream var2 = new DataOutputStream(var1);
         this.writeBytes = this.writeBytes + this.getDefinition().write(this, var2);
         var1.close();
         return var1.toByteArray();
      } else {
         System.err.println("TODO-WRITE[ " + this.getClass().getName() + " ]");
         throw new RRCGeneralException("TRDATASTRUCTURE_DEF not implemented for class: " + this.getClass().getName());
      }
   }

   public byte[] getBigEndianBytes() throws Exception {
      this.boolBigEndian = true;
      this.writeBytes = 0;
      ByteArrayOutputStream var1 = new ByteArrayOutputStream(this.getLength());
      if (this.getDefinition() != null) {
         BigEndianOutputStream var2 = new BigEndianOutputStream(var1);
         this.writeBytes = this.writeBytes + this.getDefinition().write(this, var2);
         var1.close();
         return var1.toByteArray();
      } else {
         System.err.println("TODO-WRITE[ " + this.getClass().getName() + " ]");
         throw new RRCGeneralException("TRDATASTRUCTURE_DEF not implemented for class: " + this.getClass().getName());
      }
   }

   private void log(String var1) {
   }
}
