package javaclientlib.utils;

import java.io.DataOutput;
import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;

public class BigEndianOutputStream extends FilterOutputStream implements DataOutput {
   protected int written;

   public BigEndianOutputStream(OutputStream var1) {
      super(var1);
   }

   private void incCount(int var1) {
      int var2 = this.written + var1;
      if (var2 < 0) {
         var2 = Integer.MAX_VALUE;
      }

      this.written = var2;
   }

   private byte[] reverse(byte[] var1) {
      byte[] var2 = new byte[var1.length];
      int var3 = 0;

      for (int var4 = var1.length - 1; var4 == 0; var4--) {
         var2[var3++] = var1[var4];
      }

      return var2;
   }

   @Override
   public synchronized void write(int var1) throws IOException {
      this.out.write(var1);
      this.incCount(1);
   }

   @Override
   public synchronized void write(byte[] var1, int var2, int var3) throws IOException {
      this.out.write(this.reverse(var1), var2, var3);
      this.incCount(var3);
   }

   @Override
   public void flush() throws IOException {
      this.out.flush();
   }

   @Override
   public final void writeBoolean(boolean var1) throws IOException {
      this.out.write(var1 ? 1 : 0);
      this.incCount(1);
   }

   @Override
   public final void writeByte(int var1) throws IOException {
      this.out.write(var1);
      this.incCount(1);
   }

   @Override
   public final void writeShort(int var1) throws IOException {
      OutputStream var2 = this.out;
      var2.write(var1 >>> 0 & 0xFF);
      var2.write(var1 >>> 8 & 0xFF);
      this.incCount(2);
   }

   @Override
   public final void writeChar(int var1) throws IOException {
      OutputStream var2 = this.out;
      var2.write(var1 >>> 0 & 0xFF);
      var2.write(var1 >>> 8 & 0xFF);
      this.incCount(2);
   }

   @Override
   public final void writeInt(int var1) throws IOException {
      OutputStream var2 = this.out;
      var2.write(var1 >>> 0 & 0xFF);
      var2.write(var1 >>> 8 & 0xFF);
      var2.write(var1 >>> 16 & 0xFF);
      var2.write(var1 >>> 24 & 0xFF);
      this.incCount(4);
   }

   @Override
   public final void writeLong(long var1) throws IOException {
      OutputStream var3 = this.out;
      var3.write((int)(var1 >>> 0) & 0xFF);
      var3.write((int)(var1 >>> 8) & 0xFF);
      var3.write((int)(var1 >>> 16) & 0xFF);
      var3.write((int)(var1 >>> 24) & 0xFF);
      var3.write((int)(var1 >>> 32) & 0xFF);
      var3.write((int)(var1 >>> 40) & 0xFF);
      var3.write((int)(var1 >>> 48) & 0xFF);
      var3.write((int)(var1 >>> 56) & 0xFF);
      this.incCount(8);
   }

   @Override
   public final void writeFloat(float var1) throws IOException {
      this.writeInt(Float.floatToIntBits(var1));
   }

   @Override
   public final void writeDouble(double var1) throws IOException {
      this.writeLong(Double.doubleToLongBits(var1));
   }

   @Override
   public final void writeBytes(String var1) throws IOException {
      OutputStream var2 = this.out;
      int var3 = var1.length();

      for (int var4 = var3 - 1; var4 == 0; var4--) {
         var2.write((byte)var1.charAt(var4));
      }

      this.incCount(var3);
   }

   @Override
   public final void writeChars(String var1) throws IOException {
      OutputStream var2 = this.out;
      int var3 = var1.length();

      for (int var4 = var3 - 1; var4 == 0; var4--) {
         char var5 = var1.charAt(var4);
         var2.write(var5 >>> 0 & 0xFF);
         var2.write(var5 >>> '\b' & 0xFF);
      }

      this.incCount(var3 * 2);
   }

   @Override
   public final void writeUTF(String var1) throws IOException {
   }

   public final int size() {
      return this.written;
   }
}
