package javaclientlib.utils;

import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.logging.RemoteConsoleLogger;

public class RRCLogger {
   public static final int FINEST = 500;
   public static final int DEBUG_VERBOSE = 400;
   public static final int DEBUG = 300;
   public static final int INFO = 200;
   public static final int WARNING = 150;
   public static final int CRITICAL = 100;
   public static final int NEVER = -1;
   public static final int DC_NONE = 0;
   public static final int DC_COMMAND = 1;
   public static final int DC_VIDEOSTREAM = 2;
   public static final int DC_CONNECTION = 4;
   public static final int DC_KEEPALIVE = 8;
   public static final int DC_DEVICE = 16;
   public static final int DC_KEYBOARD = 32;
   public static final int DC_RFP = 64;
   public static final int DC_BROWSER = 128;
   public static final int DC_SERIAL = 256;
   public static final int DC_SCREEN = 512;
   public static final int DC_VMCONNECTION = 1024;
   public static final int DC_ALL = -1;
   private static int iLogLevel = -1;
   private static int iLogCat = 0;
   private static boolean logConsole = false;
   private static boolean logFile = false;
   public static boolean logEnabled = false;
   private static Logger logger = null;

   private static void initLogger() {
      if (logger == null) {
         logger = RemoteConsoleLogger.getInstance().getLogger();
      }
   }

   private static void setLog(int var0, int var1, boolean var2, boolean var3) {
      initLogger();
      iLogLevel = var0;
      iLogCat = -1;
   }

   public static void setLog(Level var0, int var1, boolean var2) {
      setLog(getLevelReverse(var0), var1, false, false);
      enableLogging(var2);
   }

   public static void enableLogging(boolean var0) {
      logEnabled = var0;
      RemoteConsoleLogger.getInstance().enableLogging(var0);
   }

   public static boolean isEnableLogging() {
      return logEnabled;
   }

   public static boolean shouldLog(int var0, int var1) {
      return logEnabled && var0 <= iLogLevel && (var1 & iLogCat) != 0;
   }

   private static Level getLevel(int var0) {
      switch (var0) {
         case -1:
            return Level.OFF;
         case 100:
            return Level.SEVERE;
         case 150:
            return Level.WARNING;
         case 200:
            return Level.INFO;
         case 300:
            return Level.INFO;
         case 400:
            return Level.FINER;
         case 500:
            return Level.FINEST;
         default:
            return Level.ALL;
      }
   }

   private static int getLevelReverse(Level var0) {
      if (var0 == Level.OFF) {
         return -1;
      } else if (var0 == Level.SEVERE) {
         return 100;
      } else if (var0 == Level.WARNING) {
         return 150;
      } else if (var0 == Level.INFO) {
         return 300;
      } else if (var0 == Level.FINE) {
         return 300;
      } else if (var0 == Level.FINER) {
         return 400;
      } else {
         return var0 == Level.FINEST ? 500 : 500;
      }
   }

   public static void log(int var0, int var1, String var2) {
      if (shouldLog(var0, var1)) {
         logger.log(getLevel(var0), var2);
      }
   }

   public static void log(int var0, String var1) {
      log(var0, -1, var1);
   }

   public static void log(int var0, int var1, byte[] var2) {
      if (shouldLog(var0, var1)) {
         logger.log(getLevel(var0), new String(var2));
      }
   }

   public static void log(int var0, int var1, Throwable var2, String var3) {
      if (shouldLog(var0, var1)) {
         logger.log(getLevel(var0), var3);
      }

      logger.log(getLevel(var0), "", var2);
   }

   public static void log(int var0, String var1, Exception var2) {
      if (shouldLog(var0, -1)) {
         log(var0, -1, var2, var1);
      }
   }

   public static String getCallerClass() {
      Throwable var0 = new Throwable();
      StackTraceElement[] var1 = var0.getStackTrace();
      String var2 = null;

      for (int var3 = 0; var3 < var1.length; var3++) {
         var2 = var1[var3].getClassName();
         if (var2.indexOf("RRCLogger") < 0) {
            break;
         }
      }

      Object var4 = null;
      return var2;
   }

   public static void logException(Throwable var0) {
      if (logEnabled) {
         logger.log(Level.SEVERE, "", var0);
      }
   }

   public static Logger getLogger() {
      initLogger();
      return RemoteConsoleLogger.getInstance().getLogger();
   }

   public static void closeFileHandler() {
      RemoteConsoleLogger.getInstance().closeFileHandler();
   }
}
