package nn.pp.audiocore;

import java.util.List;
import java.util.Vector;
import javax.sound.sampled.Mixer;
import javax.sound.sampled.Mixer.Info;
import nn.pp.audiocore.impl.audio.DeviceEnumerator;
import nn.pp.core.T;

public class AudioDevice {
   private Mixer mixer;
   private List<AudioFormat> formats;

   public AudioDevice(Mixer var1, List<AudioFormat> var2) {
      this.mixer = var1;
      this.formats = var2;
   }

   @Override
   public String toString() {
      return this.mixer == null ? T._("Default Audio Device") : this.mixer.getMixerInfo().getName();
   }

   @Override
   public boolean equals(Object var1) {
      return var1 != null && var1 instanceof AudioDevice ? var1.toString().equals(this.toString()) : false;
   }

   public List<AudioFormat> getSupportedFormats() {
      return this.formats;
   }

   public Info getMixer() {
      return this.mixer == null ? null : this.mixer.getMixerInfo();
   }

   public static List<AudioDevice> enumeratePlaybackDevices() {
      return DeviceEnumerator.enumeratePlaybackDevices();
   }

   public static List<AudioDevice> enumerateCaptureDevices() {
      return DeviceEnumerator.enumerateCaptureDevices();
   }

   public static boolean audioDevicesAvailable() {
      return !enumeratePlaybackDevices().isEmpty() || !enumerateCaptureDevices().isEmpty();
   }

   static List<AudioDevice.ConnectedDevice> getConnectedDevices() {
      return DeviceEnumerator.getConnectedDevices();
   }

   List<AudioCore> getConnections() {
      List var1 = getConnectedDevices();
      Vector var2 = new Vector();

      for (AudioDevice.ConnectedDevice var4 : var1) {
         if (this.equals(var4.getDevice()) && !var2.contains(var4.getCore())) {
            var2.add(var4.getCore());
         }
      }

      return var2;
   }

   public static class ConnectedDevice {
      private AudioDevice dev;
      private AudioCore core;

      public ConnectedDevice(AudioDevice var1, AudioCore var2) {
         this.dev = var1;
         this.core = var2;
      }

      public AudioDevice getDevice() {
         return this.dev;
      }

      public AudioCore getCore() {
         return this.core;
      }
   }
}
