package nn.pp.audiocore.impl;

import java.io.IOException;
import java.util.logging.ConsoleHandler;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.X509TrustManager;
import javax.sound.sampled.Mixer.Info;
import nn.pp.audiocore.AudioAdapter;
import nn.pp.audiocore.AudioCore;
import nn.pp.audiocore.AudioDevice;
import nn.pp.audiocore.AudioEventListener;
import nn.pp.audiocore.AudioException;
import nn.pp.audiocore.AudioFormat;
import nn.pp.audiocore.impl.audio.DeviceEnumerator;
import nn.pp.audiocore.impl.rap.RapHandler;
import nn.pp.core.NotificationListener;
import nn.pp.core.T;
import nn.pp.core.impl.DeviceConnector;

public class AudioCoreImpl implements AudioCore {
   protected Logger logger;
   private AudioDevice playbackDevice;
   private AudioDevice captureDevice;
   private AudioAdapter adapter = new AudioAdapter() {
      @Override
      public void audioConnected(boolean var1) {
         if (var1) {
            DeviceEnumerator.addConnection(new AudioDevice[]{AudioCoreImpl.this.playbackDevice, AudioCoreImpl.this.captureDevice}, AudioCoreImpl.this);
         }
      }

      @Override
      public void disconnected(Exception var1) {
         AudioCoreImpl.this.disconnect();
      }
   };
   private X509TrustManager trustManager;
   private DeviceConnector connector;
   private boolean connected = false;
   private RapHandler rapHandler;
   ListenerLists listeners = new ListenerLists();

   public AudioCoreImpl(Logger var1) {
      if (var1 == null) {
         var1 = Logger.getLogger("Audio");
         var1.setUseParentHandlers(false);
         var1.addHandler(new ConsoleHandler());
         var1.setLevel(Level.SEVERE);
      }

      this.logger = var1;
      this.addAudioEventListener(this.adapter);
      this.addNotificationListener(this.adapter);
   }

   @Override
   public void dispose() {
      if (this.rapHandler != null) {
         this.rapHandler = null;
      }

      this.removeAudioEventListener(this.adapter);
      this.removeNotificationListener(this.adapter);
   }

   @Override
   public void setX509TrustManager(X509TrustManager var1) {
      this.trustManager = var1;
   }

   @Override
   public void connectAudioWithUserLogin(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      int var6,
      AudioDevice var7,
      AudioFormat var8,
      AudioDevice var9,
      AudioFormat var10,
      String var11,
      String var12
   ) throws IOException, AudioException {
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8, var9, var10, var11, var12, null, null, null, null);
   }

   @Override
   public void connectAudioWithRdmSession(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      int var6,
      AudioDevice var7,
      AudioFormat var8,
      AudioDevice var9,
      AudioFormat var10,
      String var11,
      String var12,
      String var13
   ) throws IOException, AudioException {
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8, var9, var10, null, null, null, var11, var12, var13);
   }

   @Override
   public void connectAudioWithEricKey(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      int var6,
      AudioDevice var7,
      AudioFormat var8,
      AudioDevice var9,
      AudioFormat var10,
      String var11
   ) throws IOException, AudioException {
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8, var9, var10, null, null, var11, null, null, null);
   }

   private void connectToHost(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      int var6,
      AudioDevice var7,
      AudioFormat var8,
      AudioDevice var9,
      AudioFormat var10,
      String var11,
      String var12,
      String var13,
      String var14,
      String var15,
      String var16
   ) throws IOException, AudioException {
      if (this.connected) {
         throw new AudioException(T._("Already connected"));
      } else {
         this.playbackDevice = var7;
         this.captureDevice = var9;

         try {
            this.connector = new DeviceConnector(this.logger, this.trustManager);
            this.connector.connect(var1, var2, var3);
            if (!var3 && var15 != null && var16 != null) {
               this.connector.writeCCSGproxyModePrefix(var15);
               if (var16.equals("yes")) {
                  System.out.println("CC-Proxy[Audio] mode: SSL enabled .. \n");
                  this.connector.connectSSLWithSocket(var1, var2);
               } else {
                  System.out.println("CC-Proxy[Audio] mode: plaintext .. \n");
               }
            }

            Info var17 = var7 != null ? var7.getMixer() : null;
            Info var18 = var9 != null ? var9.getMixer() : null;
            this.rapHandler = RapHandler.loadRapHandler(this.connector, this.logger, this.listeners, var17, var8, var18, var10, var5, var6);
            this.rapHandler.connect(var4, var11, var12, var13, var14);
            this.connected = true;
            this.logger.log(Level.INFO, T._("Audio capable device connected"));
         } catch (AudioException var19) {
            this.logger.log(Level.SEVERE, T._("Could not establish Audio session"), (Throwable)var19);
            this.disconnect();
            throw var19;
         } catch (IOException var20) {
            this.logger.log(Level.SEVERE, T._("Could not establish Audio session"), (Throwable)var20);
            this.disconnect();
            throw var20;
         }
      }
   }

   @Override
   public void disconnect() {
      DeviceEnumerator.removeConnection(this);
      if (this.rapHandler != null) {
         this.rapHandler.close();
         this.connector.disconnect();
         this.rapHandler.dispose();
         this.rapHandler = null;
         this.connector = null;
      }

      this.connected = false;
   }

   @Override
   public void setCaptureBufferSizeMs(int var1) throws IOException {
      if (this.rapHandler != null) {
         this.rapHandler.setCaptureBlockSize(var1);
      }
   }

   @Override
   public int getCaptureBufferSizeMs() {
      return this.rapHandler != null ? this.rapHandler.getCaptureBlockSize() : 120;
   }

   @Override
   public void setPlaybackBufferSizeMs(int var1) throws IOException {
      if (this.rapHandler != null) {
         this.rapHandler.setPlaybackBlockSize(var1);
      }
   }

   @Override
   public int getPlaybackBufferSizeMs() {
      return this.rapHandler != null ? this.rapHandler.getPlaybackBlockSize() : 120;
   }

   @Override
   public void addNotificationListener(NotificationListener var1) {
      this.listeners.notificationListenerList.addListener(var1);
   }

   @Override
   public void removeNotificationListener(NotificationListener var1) {
      this.listeners.notificationListenerList.removeListener(var1);
   }

   @Override
   public void addAudioEventListener(AudioEventListener var1) {
      this.listeners.audioEventListenerList.addListener(var1);
   }

   @Override
   public void removeAudioEventListener(AudioEventListener var1) {
      this.listeners.audioEventListenerList.removeListener(var1);
   }
}
