package nn.pp.audiocore.impl.audio;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.Mixer;
import javax.sound.sampled.SourceDataLine;
import javax.sound.sampled.TargetDataLine;
import javax.sound.sampled.Mixer.Info;
import nn.pp.audiocore.AudioCore;
import nn.pp.audiocore.AudioDevice;
import nn.pp.audiocore.AudioFormat;

public class DeviceEnumerator {
   private static AudioFormat[] allPlaybackFormats = new AudioFormat[]{
      new AudioFormat(44100.0F, 16, 2),
      new AudioFormat(44100.0F, 16, 1),
      new AudioFormat(22050.0F, 16, 2),
      new AudioFormat(22050.0F, 16, 1),
      new AudioFormat(11025.0F, 16, 2),
      new AudioFormat(11025.0F, 16, 1)
   };
   private static AudioFormat[] allCaptureFormats = new AudioFormat[]{
      new AudioFormat(44100.0F, 16, 2),
      new AudioFormat(44100.0F, 16, 1),
      new AudioFormat(22050.0F, 16, 2),
      new AudioFormat(22050.0F, 16, 1),
      new AudioFormat(11025.0F, 16, 2),
      new AudioFormat(11025.0F, 16, 1)
   };
   private static List<AudioDevice.ConnectedDevice> devices = new Vector<>();

   private DeviceEnumerator() {
   }

   public static List<AudioDevice> enumeratePlaybackDevices() {
      return enumerateDevices(SourceDataLine.class, allPlaybackFormats);
   }

   public static List<AudioDevice> enumerateCaptureDevices() {
      return enumerateDevices(TargetDataLine.class, allCaptureFormats);
   }

   private static List<AudioDevice> enumerateDevices(Class<?> var0, AudioFormat[] var1) {
      Object var2 = new Vector();
      Info[] var3 = AudioSystem.getMixerInfo();

      for (int var4 = 0; var4 < var3.length; var4++) {
         Mixer var5 = AudioSystem.getMixer(var3[var4]);
         javax.sound.sampled.Line.Info var6 = new javax.sound.sampled.Line.Info(var0);
         if (var5.isLineSupported(var6)) {
            var2 = addMixer(var0, var5, (List<AudioDevice>)var2, var1);
         }
      }

      return (List<AudioDevice>)var2;
   }

   private static List<AudioDevice> addMixer(Class<?> var0, Mixer var1, List<AudioDevice> var2, AudioFormat[] var3) {
      Vector var4 = new Vector();

      for (AudioFormat var8 : var3) {
         javax.sound.sampled.DataLine.Info var9 = new javax.sound.sampled.DataLine.Info(var0, var8);
         if (var1.isLineSupported(var9)) {
            var4.add(var8);
         }
      }

      if (var4.isEmpty()) {
         return var2;
      } else {
         var2.add(new AudioDevice(var1, var4));
         return var2;
      }
   }

   public static List<AudioDevice.ConnectedDevice> getConnectedDevices() {
      return devices;
   }

   public static void addConnection(AudioDevice[] var0, AudioCore var1) {
      for (AudioDevice var5 : var0) {
         if (var5 != null) {
            devices.add(new AudioDevice.ConnectedDevice(var5, var1));
         }
      }
   }

   public static void removeConnection(AudioCore var0) {
      Iterator var1 = devices.iterator();

      while (var1.hasNext()) {
         AudioDevice.ConnectedDevice var2 = (AudioDevice.ConnectedDevice)var1.next();
         if (var2.getCore() == var0) {
            var1.remove();
         }
      }
   }
}
