package nn.pp.audiocore.impl.rap;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.sound.sampled.Mixer.Info;
import nn.pp.audiocore.AudioEventListener;
import nn.pp.audiocore.AudioException;
import nn.pp.audiocore.AudioFormat;
import nn.pp.audiocore.impl.ListenerLists;
import nn.pp.audiocore.impl.audio.AudioConsumer;
import nn.pp.audiocore.impl.audio.Capture;
import nn.pp.audiocore.impl.audio.Playback;
import nn.pp.core.NotificationEvent;
import nn.pp.core.T;
import nn.pp.core.impl.DeviceConnector;
import nn.pp.core.impl.ProtocolHandler;

public abstract class RapHandler extends ProtocolHandler<AudioException> implements AudioConsumer {
   protected ListenerLists listeners;
   protected byte[] dataBuffer = null;
   protected Playback playback;
   protected Capture capture;
   protected AudioFormat audioFormatPlayback;
   protected AudioFormat audioFormatCapture;
   protected Info mixerPlayback;
   protected Info mixerCapture;
   protected boolean connectionRequestSent = false;
   protected int notificationCode = 0;
   protected int rfbSessionId;
   protected int msIndex;
   protected int connectionResponseReason;
   protected int blkSizeReason;
   protected int pendingBlockDurationCapture = 0;
   protected int pendingBlockDurationPlayback = 0;
   protected int blockDurationCapture = 120;
   protected int blockDurationPlayback = 120;
   protected AudioFormat audioFormatPlaybackRead;

   public static RapHandler loadRapHandler(
      DeviceConnector var0, Logger var1, ListenerLists var2, Info var3, AudioFormat var4, Info var5, AudioFormat var6, int var7, int var8
   ) throws IOException, AudioException {
      RapVersionNegotiator var9 = new RapVersionNegotiator();
      var9.init(var0, var1, var2, var3, var4, var5, var6, var7, var8);
      var9.negotiateProtocolVersion();
      RapHandler var10 = loadRapHandler(var0, var1, var2, var3, var4, var5, var6, var7, var8, var9.versionMajor, var9.versionMinor);
      var10.versionMajor = var9.versionMajor;
      var10.versionMinor = var9.versionMinor;
      var1.log(Level.FINE, "RAP handler initialized");
      return var10;
   }

   public static RapHandler loadRapHandler(
      DeviceConnector var0, Logger var1, ListenerLists var2, Info var3, AudioFormat var4, Info var5, AudioFormat var6, int var7, int var8, int var9, int var10
   ) throws IOException, AudioException {
      RapHandler var11;
      try {
         String var12 = getVersionString(var9, var10, '_');
         String var15 = "nn.pp.audiocore.impl.rap.V" + var12 + ".RapHandlerV" + var12;
         var1.log(Level.FINE, T._("Trying to load protocol handler:") + " " + var15);
         var11 = (RapHandler)Class.forName(var15).newInstance();
      } catch (Throwable var14) {
         String var13 = T._("Unable to load protocol handler!");
         var1.log(Level.SEVERE, var13, var14);
         throw new AudioException(var13);
      }

      var11.init(var0, var1, var2, var3, var4, var5, var6, var7, var8);
      return var11;
   }

   @Override
   protected String getProtocolName() {
      return "RAP";
   }

   protected AudioException loadException(String var1) {
      return new AudioException(var1);
   }

   @Override
   public void close() {
      this.shouldRun = false;
      if (this.capture != null) {
         this.capture.close();
         this.capture = null;
      }

      if (this.playback != null) {
         this.playback.close();
         this.playback = null;
      }

      this.listeners.audioEventListenerList.firePlaybackDeviceStateChanged(AudioEventListener.DeviceState.DISCONNECTED);
      this.listeners.audioEventListenerList.fireCaptureDeviceStateChanged(AudioEventListener.DeviceState.DISCONNECTED);
   }

   @Override
   protected void disconnected(Exception var1) {
      this.listeners.audioEventListenerList.fireDisconnected(var1);
      this.listeners.audioEventListenerList.firePlaybackDeviceStateChanged(AudioEventListener.DeviceState.DISCONNECTED);
      this.listeners.audioEventListenerList.fireCaptureDeviceStateChanged(AudioEventListener.DeviceState.DISCONNECTED);
   }

   public void init(DeviceConnector var1, Logger var2, ListenerLists var3, Info var4, AudioFormat var5, Info var6, AudioFormat var7, int var8, int var9) throws IOException {
      this.listeners = var3;
      this.rfbSessionId = var8;
      this.msIndex = var9;
      this.mixerPlayback = var4;
      this.audioFormatPlayback = var5;
      this.mixerCapture = var6;
      this.audioFormatCapture = var7;
      super.init(var1, var2);
   }

   @Override
   protected void initialHandshakeFinished() throws IOException {
      super.initialHandshakeFinished();
      if (this.audioFormatPlayback != null) {
         this.playback = new Playback(this.logger, this.mixerPlayback, this.audioFormatPlayback);
         this.playback.activate();
      }

      if (this.audioFormatCapture != null) {
         this.capture = new Capture(this.logger, this.mixerCapture, this.audioFormatCapture, this);
         this.capture.activate();
      }
   }

   protected void writeAuthLoginMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeAuthSessionIdMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeAuthRdmSessionIdMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeChallengeResponseMsg(String var1) throws IOException, AudioException {
      throw new UnsupportedOperationException();
   }

   protected void writePingMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writePongMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeDataMsg(AudioFormat var1, byte[] var2, int var3, int var4) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeConnectionRequestMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeSetBlkSizeMsg(int var1, int var2) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected byte[] readAuthChallengeMsg() throws IOException, AudioException {
      throw new UnsupportedOperationException();
   }

   protected void readPingMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readPongMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected NotificationEvent readNotificationMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected boolean readResponseMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected int readDataMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected boolean readRspBlkSizeMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   @Override
   protected void negotiateProtocolVersion() throws IOException, AudioException {
      throw new UnsupportedOperationException();
   }

   private void sendAuthentication() throws IOException, AudioException {
      if (this.rdmSessionID != null) {
         this.authenticateRdmSessionId();
      } else if (this.username != null && this.password != null) {
         this.authenticateUsername();
      } else {
         if (this.httpSessionID == null) {
            throw new AudioException(T._("No proper authentication scheme found"));
         }

         this.authenticateHttpSessionId();
      }
   }

   private void authenticateRdmSessionId() throws IOException {
      this.logger.log(Level.INFO, T._("RDM session authentication"));
      this.writeAuthRdmSessionIdMsg();
   }

   private void authenticateUsername() throws IOException {
      this.logger.log(Level.INFO, T._("Username authentication"));
      this.writeAuthLoginMsg();
   }

   private void authenticateHttpSessionId() throws IOException, AudioException {
      this.logger.log(Level.INFO, T._("Session ID authentication"));
      this.writeAuthSessionIdMsg();
      byte[] var1 = this.readAuthChallengeMsg();
      String var2 = null;

      try {
         var2 = new String(var1, "ISO-8859-1");
      } catch (UnsupportedEncodingException var5) {
      }

      String var3;
      if (var2.startsWith("{SHA256}")) {
         var3 = "SHA-256";
      } else {
         var3 = "MD5";
      }

      String var4 = this.getChallengeResponse(var1, var3);
      this.writeChallengeResponseMsg(var4);
   }

   protected void sendConnectionRequest() throws IOException {
      this.writeConnectionRequestMsg();
   }

   private void processResponse() throws IOException, AudioException {
      boolean var1 = this.readResponseMsg();
      if (var1) {
         if (this.connectionRequestSent) {
            this.listeners.audioEventListenerList.fireAudioConnected(true);
            this.listeners
               .audioEventListenerList
               .firePlaybackDeviceStateChanged(
                  this.audioFormatPlayback == null ? AudioEventListener.DeviceState.DISCONNECTED : AudioEventListener.DeviceState.MUTED
               );
            this.listeners
               .audioEventListenerList
               .fireCaptureDeviceStateChanged(
                  this.audioFormatCapture == null ? AudioEventListener.DeviceState.DISCONNECTED : AudioEventListener.DeviceState.MUTED
               );
         }
      } else {
         RapNotificationEvent var2 = new RapNotificationEvent(0, this.connectionResponseReason);
         this.listeners.notificationListenerList.fireNotification(var2);
         this.logger.log(Level.WARNING, "Received error during handshake process: " + var2.getMessage());
         if (var2.isError() || var2.isQuit()) {
            this.close();
            throw new AudioException(this.connectionResponseReason, RapNotificationEvent.getMessageString(this.connectionResponseReason));
         }
      }
   }

   private void processDataMessage() throws IOException {
      int var1 = this.readDataMsg();
      if (this.audioFormatPlayback.matches(this.audioFormatPlaybackRead) && this.playback != null) {
         this.playback.consumeAudioData(this.audioFormatPlaybackRead, this.dataBuffer, 0, var1);
      }
   }

   private void processPingMessage() throws IOException {
      this.readPingMsg();
      this.writePongMsg();
   }

   private void processPongMessage() throws IOException {
      this.readPongMsg();
   }

   private void processNotificationMessage() throws IOException, AudioException {
      NotificationEvent var1 = this.readNotificationMsg();
      if (var1.getErrorCode() == -1845362682) {
         this.listeners.audioEventListenerList.fireCaptureDeviceStateChanged(AudioEventListener.DeviceState.PLAYING);
         if (this.capture != null) {
            this.capture.resumeCapture();
         }
      } else if (var1.getErrorCode() == -1845362681) {
         this.listeners.audioEventListenerList.fireCaptureDeviceStateChanged(AudioEventListener.DeviceState.MUTED);
         if (this.capture != null) {
            this.capture.pauseCapture();
         }
      } else if (var1.getErrorCode() == -1845362679) {
         this.listeners.audioEventListenerList.firePlaybackDeviceStateChanged(AudioEventListener.DeviceState.MUTED);
      } else if (var1.getErrorCode() == -1845362680) {
         this.listeners.audioEventListenerList.firePlaybackDeviceStateChanged(AudioEventListener.DeviceState.PLAYING);
         if (this.playback != null) {
            this.playback.flushBuffers();
         }
      } else {
         this.listeners.notificationListenerList.fireNotification(var1);
         if (var1.isQuit()) {
            throw new AudioException(var1.getErrorCode(), RapNotificationEvent.getMessageString(var1.getErrorCode()));
         }
      }
   }

   public void setCaptureBlockSize(int var1) throws IOException {
      this.pendingBlockDurationCapture = var1;
      this.writeSetBlkSizeMsg(2, var1);
   }

   public int getCaptureBlockSize() {
      return this.pendingBlockDurationCapture != 0 ? this.pendingBlockDurationCapture : this.blockDurationCapture;
   }

   public void setPlaybackBlockSize(int var1) throws IOException {
      this.pendingBlockDurationPlayback = var1;
      this.writeSetBlkSizeMsg(1, var1);
   }

   public int getPlaybackBlockSize() {
      return this.pendingBlockDurationPlayback != 0 ? this.pendingBlockDurationPlayback : this.blockDurationPlayback;
   }

   private void processRspBlkSizeMessage() throws IOException, AudioException {
      boolean var1 = this.readRspBlkSizeMsg();
      if (!var1) {
         RapNotificationEvent var2 = new RapNotificationEvent(0, this.connectionResponseReason);
         this.listeners.notificationListenerList.fireNotification(var2);
         this.logger.log(Level.WARNING, "Could not set block size: " + var2.getMessage());
         if (var2.isError() || var2.isQuit()) {
            this.close();
            throw new AudioException(this.connectionResponseReason, RapNotificationEvent.getMessageString(this.connectionResponseReason));
         }
      }

      if (this.pendingBlockDurationCapture != 0) {
         if (this.capture != null) {
            this.capture.setBlockDuration(this.pendingBlockDurationCapture);
         }

         this.blockDurationCapture = this.pendingBlockDurationCapture;
         this.pendingBlockDurationCapture = 0;
      } else if (this.pendingBlockDurationPlayback != 0) {
         if (this.playback != null) {
            this.playback.setBlockDuration(this.pendingBlockDurationPlayback);
         }

         this.blockDurationPlayback = this.pendingBlockDurationPlayback;
         this.pendingBlockDurationPlayback = 0;
      }
   }

   @Override
   public void consumeAudioData(AudioFormat var1, byte[] var2, int var3, int var4) {
      try {
         this.writeDataMsg(var1, var2, var3, var4);
      } catch (IOException var6) {
         if (this.shouldRun) {
            this.logger.log(Level.SEVERE, T._("Could not send capture data"));
            this.disconnected(var6);
         }
      }
   }

   @Override
   protected void processProtocol() throws IOException, AudioException {
      this.sendAuthentication();

      while (this.shouldRun) {
         int var1 = this.readServerMessageType();
         switch (var1) {
            case 0:
               this.processPingMessage();
               break;
            case 1:
               this.processPongMessage();
               break;
            case 2:
               this.processNotificationMessage();
               break;
            case 3:
               this.processDataMessage();
               break;
            case 128:
               this.processResponse();
               break;
            case 129:
               this.processRspBlkSizeMessage();
               break;
            default:
               this.logger.log(Level.SEVERE, T._("Unknown Protocol message received:") + " " + var1);
               throw new AudioException(T._("Protocol Error: Unknown Protocol message received"));
         }

         if (this.inInitialHandshake) {
            this.processInitialHandshake(var1);
         }
      }
   }
}
