package nn.pp.common;

import com.util.kbd.KeyHIDValue;
import com.util.kbd.KeyboardKey;
import com.util.kbd.KeyboardMappings;
import java.util.Collection;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Set;
import java.util.Vector;
import java.util.logging.Level;
import nn.pp.common.ui.helpers.IKVMTargetViewer;
import nn.pp.common.ui.helpers.IMacroCreatorDialog;
import nn.pp.core.T;
import nn.pp.logging.RemoteConsoleLogger;
import nn.pp.rccore.KeyboardMacro;
import nn.pp.rccore.impl.keyboard.CharTranslatorConstants;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping;
import nn.pp.rccore.impl.keyboard.CharTranslatorMappingBase;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_da_DK;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_de_CH;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_de_DE;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_en_GB;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_es_ES;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_fr_BE;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_fr_FR;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_hu_HU;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_it_IT;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_no_NO;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_pt_PT;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_sl_SL;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_sv_SE;
import nn.pp.rccore.impl.keyboard.CharTranslatorMapping_us_intl;

public class CommonFunctions implements CharTranslatorConstants {
   private static final String PRESS_TEXT = T._("Press ");
   private static final String RELEASE_TEXT = T._("Release ");

   private static Vector<Integer> constructKeyEventList(char var0, Hashtable<Character, Vector<Integer>> var1) {
      Collection var2 = (Collection)var1.get(var0);
      if (var2 == null) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "No lookup code available for character: [" + var0 + "] - skipping");
         return new Vector<>(0);
      } else {
         Vector var3 = new Vector(var2);
         if (Character.isUpperCase(var0)) {
            if (var3.contains(1966080)) {
               var3.set(var3.indexOf(1966080), 131072);
            } else if (!var3.contains(131072) && !var3.contains(262144)) {
               var3.insertElementAt(131072, 0);
            }
         }

         boolean var4 = false;
         boolean var5 = false;

         for (int var6 = 0; var6 < var3.size(); var6++) {
            switch (var3.get(var6)) {
               case 131072:
                  var3.remove(var6);
                  if (var4) {
                     var6--;
                  } else {
                     var4 = true;
                     var3.insertElementAt(16, var6);
                  }
                  break;
               case 262144:
               case 393216:
                  var3.remove(var6);
                  if (var4) {
                     var4 = false;
                     var3.insertElementAt(65552, var6);
                  } else {
                     var6--;
                  }
                  break;
               case 524288:
                  var3.remove(var6);
                  if (var5) {
                     var6--;
                  } else {
                     var5 = true;
                     var3.insertElementAt(65406, var6);
                  }
                  break;
               case 1048576:
               case 1572864:
                  var3.remove(var6);
                  if (var5) {
                     var5 = false;
                     var3.insertElementAt(130942, var6);
                  } else {
                     var6--;
                  }
                  break;
               case 1966080:
                  var3.remove(var6);
                  var3.insertElementAt(393216, var6);
                  var3.insertElementAt(1572864, var6);
                  var6--;
            }
         }

         if (var5) {
            var3.add(130942);
         }

         if (var4) {
            var3.add(65552);
         }

         return var3;
      }
   }

   private static String convertKeyCodeToMacroCode(int var0, KeyboardMappings var1) {
      int var3 = (var0 | 65536) ^ 65536;
      String var4 = (var0 & 65536) == 65536 ? "r " : "p ";
      if (var3 == 65406) {
         var3 = 274;
      }

      short var5 = KeyHIDValue.HIDMAP[var3];

      for (int var6 = 0; var6 < var1.length(); var6++) {
         KeyboardKey var2 = var1.getItem(var6);
         if (var2.getKeyCode() == var5 && !var2.getKeyName().contains("ms Delay")) {
            return var4 + String.valueOf(var2.getIndex());
         }
      }

      RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "Character HIDMAP table: Code not found: " + var3);
      return "";
   }

   private static CharTranslatorMapping getCharMappings(int var0) {
      switch (var0) {
         case 0:
         case 1:
         case 5:
            return new CharTranslatorMappingBase();
         case 2:
            return new CharTranslatorMapping_en_GB();
         case 3:
            return new CharTranslatorMapping_de_DE();
         case 4:
            return new CharTranslatorMapping_fr_FR();
         case 6:
            return new CharTranslatorMapping_fr_BE();
         case 7:
            return new CharTranslatorMapping_no_NO();
         case 8:
            return new CharTranslatorMapping_da_DK();
         case 9:
            return new CharTranslatorMapping_sv_SE();
         case 10:
            return new CharTranslatorMapping_de_CH();
         case 11:
            return new CharTranslatorMapping_hu_HU();
         case 12:
            return new CharTranslatorMapping_es_ES();
         case 13:
            return new CharTranslatorMapping_it_IT();
         case 14:
            return new CharTranslatorMapping_sl_SL();
         case 15:
            return new CharTranslatorMapping_pt_PT();
         default:
            return new CharTranslatorMapping_us_intl();
      }
   }

   private static Vector<Integer> constructKeyListFromText(String var0, CharTranslatorMapping var1) {
      Vector var2 = new Vector();

      for (int var3 = 0; var3 < var0.length(); var3++) {
         var2.addAll(constructKeyEventList(var0.charAt(var3), var1));
      }

      if (var2.size() > 1) {
         char var6 = '\uffff';
         int var7 = 1;

         while (var7 < var2.size()) {
            int var4 = (Integer)var2.get(var7);
            int var5 = (Integer)var2.get(var7 - 1);
            switch (var4) {
               case 16:
               case 17:
               case 18:
               case 65406:
                  if (var4 == (var5 & var6) && var4 != var5) {
                     var2.remove(var7);
                     var2.remove(var7 - 1);
                     var7--;
                  }
               default:
                  var7++;
            }
         }
      }

      return var2;
   }

   public static void sendTextToTarget(int var0, String var1, IKVMTargetViewer var2) {
      CharTranslatorMapping var3 = getCharMappings(var0);
      Vector var4 = constructKeyListFromText(var1, var3);
      KeyboardMacro var5 = new KeyboardMacro("", "", null, false);
      Vector var6 = new Vector();
      int var8 = 65535;
      if (var4.size() >= 1) {
         int var7 = (Integer)var4.get(0);

         for (int var9 = 0; var9 < var4.size(); var9++) {
            var7 = (Integer)var4.get(var9);
            switch (var7 & var8) {
               case 16:
               case 17:
               case 18:
                  var6.add(var5.new KeyCode(var2.getEricKeyCode(var7 & var8, '\u0000', 2), (var7 & 65536) == 0));
                  break;
               case 65406:
                  var6.add(var5.new KeyCode(var2.getEricKeyCode(var7 & var8, '\u0000', 3), (var7 & 65536) == 0));
                  break;
               default:
                  var6.add(var5.new KeyCode(var2.getEricKeyCode(var7 & var8, '\u0000', 1), (var7 & 65536) == 0));
            }
         }

         var5 = new KeyboardMacro("", "", var6.toArray(new KeyboardMacro.KeyCode[0]), false);
         var2.sendKeyboardMacroDirect(var5);
      }
   }

   private static int spaceNeededForKeyReleases(Set<String> var0) {
      switch (var0.size()) {
         case 0:
            return 0;
         default:
            int var1 = 0;

            for (String var3 : var0) {
               var1 += var3.length() + 2;
            }

            return var1;
      }
   }

   public static void constructMacroFromText(int var0, String var1, KeyboardMappings var2, IMacroCreatorDialog var3) {
      KeyHIDValue.setHIDMap(var0);
      CharTranslatorMapping var4 = getCharMappings(var0);
      Vector var5 = constructKeyListFromText(var1, var4);
      if (var5.size() >= 1) {
         HashSet var6 = new HashSet();
         StringBuilder var7 = new StringBuilder();
         var7.append(convertKeyCodeToMacroCode((Integer)var5.get(0), var2));

         for (int var9 = 1; var9 < var5.size(); var9++) {
            String var8 = convertKeyCodeToMacroCode((Integer)var5.get(var9), var2);
            if (var8.startsWith("p")) {
               var6.add(var8.replaceFirst("p", "r"));
            }

            if (var7.length() + var8.length() + spaceNeededForKeyReleases(var6) > 8192) {
               RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "Converting text to macro results in a macro that's too long, truncating...");
               if (var8.startsWith("p")) {
                  var6.remove(var8.replaceFirst("p", "r"));
               }

               for (String var11 : var6) {
                  var7.append("&&" + var11);
               }
               break;
            }

            if (var8.startsWith("r")) {
               var6.remove(var8);
            }

            var7.append("&&" + var8);
         }

         var3.fillSequenceModel(var7.toString());
      }
   }

   public static Vector<String> getMacroSequenceForModel(String var0, KeyboardMappings var1) {
      String[] var2 = var0.split("&&");
      Vector var3 = new Vector();
      if (var2.length != 0 && var2[0].length() >= 3) {
         String var4 = "";

         for (int var7 = 0; var7 < var2.length && var2[var7].length() > 0; var7++) {
            char var6 = var2[var7].charAt(0);
            int var5 = Integer.parseInt(var2[var7].substring(2));
            switch (var6) {
               case 'p':
                  if (var5 == 112 || var5 == 113) {
                     continue;
                  }

                  var4 = PRESS_TEXT + var1.getItem(var5).getKeyName();
               case 'q':
               default:
                  break;
               case 'r':
                  var4 = (var5 != 112 && var5 != 113 ? RELEASE_TEXT : "") + var1.getItem(var5).getKeyName();
                  break;
               case 's':
                  var4 = var1.getItem(var5).getKeyName();
            }

            var3.add(var4);
         }

         return var3;
      } else {
         return var3;
      }
   }

   public static String getGNULicenseHTML(String var0) {
      return "<html>"
         + T._("Open Source License Notification")
         + "<br>&nbsp;&nbsp;"
         + T._("Raritan, Inc. uses Open Source software in this product,")
         + "<br>&nbsp;&nbsp;"
         + T._("Including software licensed under the ")
         + "<a href=\"http://"
         + var0
         + "/license/licenseGPL.txt\">"
         + T._("GNU General Public License (\"GPL\")")
         + "</a><br>&nbsp;&nbsp;"
         + T._("and the ")
         + "<a href=\"http://"
         + var0
         + "/license/licenseLGPL.txt\">"
         + T._("GNU Lesser General Public License (\"LGPL\")")
         + "</a></html>";
   }

   public static String getOldLicenseFilePath() {
      return "/license/licences.asp.in";
   }

   public static String getLicenseFilePath() {
      return "/license/licences.asp";
   }

   public static String getLicenseActionDescr() {
      return "get license info.";
   }

   public static String getCopyrightFilePath() {
      return "/license/copyrights.txt";
   }

   public static String getCopyrightActionDescr() {
      return "get copyrights.";
   }
}
