package nn.pp.common;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.ArrayList;
import java.util.List;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.Timer;

public class DoubleClickHandler extends MouseAdapter {
   private static int dblClickDelay;
   private final Timer timer;
   private MouseEvent mouseEvent;
   private final List<MouseListener> listerners;

   public DoubleClickHandler() {
      this.timer = new Timer(dblClickDelay, new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            DoubleClickHandler.this.fireMouseEvent(DoubleClickHandler.this.mouseEvent);
            DoubleClickHandler.this.mouseEvent = null;
         }
      });
      this.listerners = new ArrayList<>();
      this.timer.setRepeats(false);
   }

   @Override
   public void mouseClicked(MouseEvent var1) {
      if (var1.getButton() == 1) {
         if (var1.getClickCount() > 1) {
            if (this.timer.isRunning()) {
               this.fireMouseEvent(var1);
               this.timer.stop();
               this.mouseEvent = null;
            }
         } else {
            this.mouseEvent = var1;
            this.timer.restart();
         }
      }
   }

   public void addMouseListener(MouseListener var1) {
      if (!this.listerners.contains(var1)) {
         this.listerners.add(var1);
      }
   }

   public void removeMouseListener(MouseListener var1) {
      this.listerners.remove(var1);
   }

   private void fireMouseEvent(MouseEvent var1) {
      for (MouseListener var3 : this.listerners) {
         var3.mouseClicked(var1);
      }
   }

   public static void main(String[] var0) {
      JFrame var1 = new JFrame("DblClickHandler");
      var1.setDefaultCloseOperation(3);
      JPanel var2 = new JPanel();
      DoubleClickHandler var3 = new DoubleClickHandler();
      var3.addMouseListener(new MouseAdapter() {
         @Override
         public void mouseClicked(MouseEvent var1) {
            if (var1.getClickCount() == 1) {
               System.out.println("Single Clicked");
            } else {
               System.out.println("Double Clicked");
            }
         }
      });
      var2.addMouseListener(var3);
      var1.add(var2);
      var1.setSize(new Dimension(200, 200));
      var1.setVisible(true);
   }

   static {
      try {
         dblClickDelay = (Integer)Toolkit.getDefaultToolkit().getDesktopProperty("awt.multiClickInterval");
      } catch (Exception var1) {
         dblClickDelay = 500;
      }
   }
}
