package nn.pp.common;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.ProtocolException;
import java.net.URL;
import java.net.URLEncoder;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.LinkedHashMap;
import java.util.logging.Level;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import nn.pp.logging.RemoteConsoleLogger;
import sun.misc.BASE64Encoder;

public class KXHttpConnection {
   private String userName = null;
   private String password = null;
   private String httpURL = null;
   private boolean isCC = false;
   private LinkedHashMap<String, String> paramValueMap = new LinkedHashMap<>();
   private static String PARAM_NAME = "param name=";
   private static String ENDING_QUOTE = "\"";
   private static String PARAM_VALUE = "value=";
   private static String TITLE_APP_ASP = "/title_app.asp";
   private static String BANNER_PAGE = "/sec_banner.asp";
   private static String BANNER_LOG_PAGE = "/sec_banner_mpc.asp";
   private static String BANNER_CONTENTS_PAGE = "/sec_banner_agreement.asp";

   public KXHttpConnection(String var1, String var2, String var3, boolean var4) {
      if (var1 != null && var2 != null && var3 != null) {
         this.userName = var1;
         this.password = var2;
         this.httpURL = var3;
         this.isCC = var4;
      } else {
         throw new NullPointerException("All the parameters are necessary");
      }
   }

   public KXHttpConnection(String var1, String var2, String var3) {
      if (var1 != null && var2 != null && var3 != null) {
         this.userName = var1;
         this.password = var2;
         this.httpURL = var3;
      } else {
         throw new NullPointerException("All the parameters are necessary");
      }
   }

   private static void exceptionHandler(Exception var0, String var1) {
      if (var0 instanceof MalformedURLException) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "MalformedURLException trying to " + var1 + ".", (Throwable)var0);
      } else if (var0 instanceof NoSuchAlgorithmException) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "NoSuchAlgorithmException trying to " + var1 + ".", (Throwable)var0);
      } else if (var0 instanceof KeyManagementException) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "KeyManagementException trying to " + var1 + ".", (Throwable)var0);
      } else if (var0 instanceof ProtocolException) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "ProtocolException trying to " + var1 + ".", (Throwable)var0);
      } else if (var0 instanceof IOException) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "IOException trying to " + var1 + ".", (Throwable)var0);
      } else {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "Unanticipated Exception type trying to " + var1 + ".", (Throwable)var0);
      }
   }

   private static HttpsURLConnection getHttpsURLConnection(String var0, String var1, String var2, String var3, String var4) throws IOException, ProtocolException, MalformedURLException, KeyManagementException, NoSuchAlgorithmException {
      HttpsURLConnection var5 = null;
      URL var6 = new URL(var0 + var1);
      TrustManager[] var7 = new TrustManager[]{new KXHttpConnection.DummyTrustManager()};
      SSLContext var8 = SSLContext.getInstance("TLSv1");
      var8.init(null, var7, null);
      var5 = (HttpsURLConnection)var6.openConnection();
      var5.setSSLSocketFactory(var8.getSocketFactory());
      var5.setHostnameVerifier(new KXHttpConnection.DummyHostNameVerifier());
      var5.setRequestMethod(var2);
      var5.setAllowUserInteraction(false);
      var5.setDoInput(true);
      var5.setDoOutput(true);
      var5.setUseCaches(false);
      if (var3 != null && var4 != null) {
         String var9 = var3 + ":" + var4;
         String var10 = (new BASE64Encoder() {
            protected int bytesPerLine() {
               return 250;
            }
         }).encode(var9.getBytes());
         var5.setRequestProperty("Authorization", "Basic " + var10);
      }

      return var5;
   }

   public LinkedHashMap<String, String> getAppletParameterMap() throws IOException, ProtocolException, MalformedURLException, KeyManagementException, NoSuchAlgorithmException {
      Object var1 = null;
      HttpsURLConnection var2 = null;

      try {
         var2 = getHttpsURLConnection(this.httpURL, TITLE_APP_ASP, "GET", this.userName, this.password);
      } catch (Exception var4) {
         var4.printStackTrace();
         exceptionHandler(var4, "get applet parameter map");
      }

      if (var2 == null) {
         return null;
      } else {
         BufferedReader var3 = new BufferedReader(new InputStreamReader(var2.getInputStream()));

         while ((var1 = var3.readLine()) != null) {
            this.parseLine((String)var1);
         }

         var3.close();
         var2.disconnect();
         return this.paramValueMap;
      }
   }

   public boolean changePwd(String var1, String var2, String var3, String var4, boolean var5) {
      Object var6 = null;
      StringBuffer var7 = new StringBuffer();
      HttpsURLConnection var8 = null;
      String var9;
      if (var5) {
         var9 = "/pwchangeforced.asp?pw_change_forced=yes&FV_0_umpwchange="
            + URLEncoder.encode(var2)
            + "&FV_1_umpwchange="
            + URLEncoder.encode(var3)
            + "&FV_2_umpwchange="
            + URLEncoder.encode(var4)
            + "&action_apply=1&__templates__=umpwchange";
      } else {
         var9 = "/pwchange.asp?FV_0_umpwchange="
            + URLEncoder.encode(var2)
            + "&FV_1_umpwchange="
            + URLEncoder.encode(var3)
            + "&FV_2_umpwchange="
            + URLEncoder.encode(var4)
            + "&action_apply=1&__templates__=umpwchange";
      }

      try {
         var8 = getHttpsURLConnection(this.httpURL, var9, "GET", this.userName, this.password);
         BufferedReader var10 = new BufferedReader(new InputStreamReader(var8.getInputStream()));

         while ((var6 = var10.readLine()) != null) {
            var7.append((String)var6);
         }

         var10.close();
      } catch (Exception var11) {
         exceptionHandler(var11, "change " + (var5 ? "expired " : "") + "password.  Message: " + var11.getMessage());
      }

      if (var8 == null) {
         return false;
      } else {
         var8.disconnect();
         return var7 == null ? false : var7.toString().indexOf("ERIC_RESPONSE_ERROR") < 0;
      }
   }

   public static String getArbitraryURL(String var0, String var1, String var2) {
      Object var3 = null;
      StringBuilder var4 = new StringBuilder("");
      HttpsURLConnection var5 = null;

      try {
         var5 = getHttpsURLConnection(var0, var1, "GET", null, null);
         if (var5 != null) {
            BufferedReader var6 = new BufferedReader(new InputStreamReader(var5.getInputStream(), "UTF-8"));

            while ((var3 = var6.readLine()) != null) {
               var4.append(var3 + "\n");
            }

            var6.close();
            var5.disconnect();
         }
      } catch (IOException var9) {
         if (var1.equals(CommonFunctions.getLicenseFilePath())) {
            try {
               var5 = getHttpsURLConnection(var0, CommonFunctions.getOldLicenseFilePath(), "GET", null, null);
               if (var5 != null) {
                  BufferedReader var7 = new BufferedReader(new InputStreamReader(var5.getInputStream(), "UTF-8"));

                  while ((var3 = var7.readLine()) != null) {
                     var4.append(var3 + "\n");
                  }

                  var7.close();
                  var5.disconnect();
               }
            } catch (Exception var8) {
               exceptionHandler(var8, var2);
            }
         }
      } catch (Exception var10) {
         exceptionHandler(var10, var2);
      }

      return var4.toString();
   }

   public KXHttpConnection.BannerSettings getSecurityBannerSettings() throws ProtocolException, MalformedURLException, KeyManagementException, NoSuchAlgorithmException {
      KXHttpConnection.BannerSettings var1 = new KXHttpConnection.BannerSettings();
      StringBuffer var2 = new StringBuffer();
      Object var3 = null;
      HttpsURLConnection var4 = null;

      try {
         var4 = getHttpsURLConnection(this.httpURL, BANNER_CONTENTS_PAGE, "GET", this.userName, this.password);
      } catch (Exception var9) {
         exceptionHandler(var9, "get Banner Page Settings");
      }

      if (var4 == null) {
         return null;
      } else {
         try {
            BufferedReader var5 = new BufferedReader(new InputStreamReader(var4.getInputStream()));

            while ((var3 = var5.readLine()) != null) {
               var2.append(var3 + "\n");
            }

            String var6 = new String(var2);
            String var7 = this.parseBannerMessage(var6);
            var1.setRsaText(var7);
            String var8 = this.parseBannerTitle(var6);
            var1.setRsaTitle(var8);
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Security Banner Text :" + var1.getRsaText());
            var5.close();
            var4.disconnect();
            var6 = null;
            Object var11 = null;
            return var1;
         } catch (IOException var10) {
            exceptionHandler(var10, "get Banner Page Settings");
            return var1;
         }
      }
   }

   private String parseBannerMessage(String var1) {
      String var2 = "";

      try {
         int var3 = var1.indexOf("<textarea name=\"_message_text\"");
         String var4 = var1.substring(var3);
         int var5 = var4.indexOf("</textarea>");
         String var6 = var4.substring(0, var5 + 11);
         int var7 = var6.indexOf("</textarea>");
         return var6.substring(var6.indexOf(">") + 1, var7);
      } catch (StringIndexOutOfBoundsException var8) {
         RemoteConsoleLogger.getInstance()
            .getLogger()
            .log(Level.WARNING, "StringIndexOutOfBoundsException trying to get security banner message.", (Throwable)var8);
         return "";
      }
   }

   private String parseBannerTitle(String var1) {
      String var2 = "";

      try {
         int var3 = var1.indexOf("<td class=\"wdgt_header\">");
         String var4 = var1.substring(var3);
         int var5 = var4.indexOf("</td>");
         String var6 = var4.substring(0, var5);
         return var6.substring(var6.indexOf(">") + 2);
      } catch (StringIndexOutOfBoundsException var7) {
         RemoteConsoleLogger.getInstance()
            .getLogger()
            .log(Level.WARNING, "StringIndexOutOfBoundsException trying to get security banner title.", (Throwable)var7);
         return "";
      }
   }

   public void callSecurityBannerAcceptPage(int var1) {
      Object var2 = null;
      HttpsURLConnection var4 = null;

      try {
         String var5 = var1 == 1 ? "accept" : "decline";
         new URL(this.httpURL + BANNER_LOG_PAGE + "?" + var5);

         try {
            var4 = getHttpsURLConnection(this.httpURL, BANNER_LOG_PAGE + "?" + var5, "GET", this.userName, this.password);
         } catch (Exception var12) {
            exceptionHandler(var12, "get Banner Page Settings");
         }

         if (var4 == null) {
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "CONNECTION IS NULL WHILE ACCESSING SECURITY BANNER LOG PAGE");
         } else {
            BufferedReader var3 = new BufferedReader(new InputStreamReader(var4.getInputStream()));

            while (var3.readLine() != null) {
            }

            var3.close();
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "User accepted Security Banner:" + var5.toUpperCase());
         }
      } catch (Exception var13) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "Exception occured when calling Security Banner Log page.", (Throwable)var13);
      } finally {
         if (var4 != null) {
            var4.disconnect();
         }
      }
   }

   private void parseLine(String var1) {
      int var2 = -1;
      int var3 = -1;
      int var4 = -1;
      int var5 = -1;
      var2 = var1.indexOf(PARAM_NAME);
      var4 = var1.indexOf(PARAM_VALUE);
      if (var2 >= 0 && var4 >= 0) {
         var2 += PARAM_NAME.length() + 1;
         var4 += PARAM_VALUE.length() + 1;
         var3 = var1.indexOf(ENDING_QUOTE, var2);
         var5 = var1.indexOf(ENDING_QUOTE, var4);
         if (var3 >= 0 && var5 >= 0) {
            String var6 = var1.substring(var2, var3);
            String var7 = var1.substring(var4, var5);
            this.paramValueMap.put(var6, var7);
         }
      }
   }

   public static void main(String[] var0) {
      try {
         KXHttpConnection var1 = new KXHttpConnection("admin", "111", "https://192.168.52.141");
         System.out.println(var1.getAppletParameterMap());
         KXHttpConnection.BannerSettings var2 = var1.getSecurityBannerSettings();
      } catch (Exception var3) {
         var3.printStackTrace();
      }
   }

   public class BannerSettings {
      private String rsaText = "";
      private String rsaTitle = "";

      public String getRsaText() {
         return this.rsaText;
      }

      public void setRsaText(String var1) {
         this.rsaText = var1;
      }

      public String getRsaTitle() {
         return this.rsaTitle;
      }

      public void setRsaTitle(String var1) {
         this.rsaTitle = var1;
      }
   }

   static class DummyHostNameVerifier implements HostnameVerifier {
      @Override
      public boolean verify(String var1, SSLSession var2) {
         return true;
      }
   }

   static class DummyTrustManager implements X509TrustManager {
      @Override
      public void checkClientTrusted(X509Certificate[] var1, String var2) throws CertificateException {
      }

      @Override
      public void checkServerTrusted(X509Certificate[] var1, String var2) throws CertificateException {
      }

      @Override
      public X509Certificate[] getAcceptedIssuers() {
         return new X509Certificate[0];
      }
   }
}
