package nn.pp.common.audio;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nn.pp.audiocore.AudioAdapter;
import nn.pp.audiocore.AudioCore;
import nn.pp.common.DialogAdapter;
import nn.pp.common.ui.helpers.SpringUtilities;
import nn.pp.core.T;
import nn.pp.ext.devPref.DevicePrefs;

public class AudioSettingsDialog implements ActionListener, ChangeListener, DialogAdapter {
   private JDialog dlg;
   private AudioCore audioCore;
   private AudioBean audioBean;
   private DevicePrefs prefs;
   private int micBlkSize = 120;
   private int spkBlkSize = 120;
   private JButton okButton;
   private JButton cancelButton;
   private JSlider micSlider;
   private JSlider spkSlider;
   private JTextField micField;
   private JTextField spkField;
   private AudioAdapter audioAdapter = new AudioAdapter() {
      @Override
      public void audioConnected(boolean var1) {
         AudioSettingsDialog.this.resetValues();
      }

      @Override
      public void disconnected(Exception var1) {
         AudioSettingsDialog.this.resetValues();
      }
   };

   public AudioSettingsDialog(Frame var1, AudioCore var2, AudioBean var3) {
      this.dlg = new JDialog(var1, T._("Audio Settings"), true);
      this.createGui();
      this.setAudioBean(var3);
      this.setAudioCore(var2);
   }

   public AudioSettingsDialog(JDialog var1) {
      this.dlg = var1;
      var1.setTitle(T._("Audio Settings"));
      this.createGui();
   }

   public void setAudioCore(AudioCore var1) {
      if (this.audioCore != null) {
         this.audioCore.removeAudioEventListener(this.audioAdapter);
      }

      this.audioCore = var1;
      var1.addAudioEventListener(this.audioAdapter);
      this.resetValues();
   }

   public void setAudioBean(AudioBean var1) {
      this.audioBean = var1;
      this.resetValues();
   }

   public void setPrefs(DevicePrefs var1) {
      this.prefs = var1;
   }

   @Override
   public void setVisible(boolean var1) {
      if (var1) {
         this.dlg.setLocationRelativeTo(this.dlg.getOwner());
         this.resetValues();
      }

      this.dlg.setVisible(var1);
   }

   private void resetValues() {
      DevicePrefs var1 = this.prefs != null ? this.prefs : (this.audioBean != null ? DevicePrefs.getNode(this.audioBean.getHost()) : null);
      this.micSlider.setEnabled(this.audioBean != null ? this.audioBean.getCaptureFormat() != null : false);
      this.spkSlider.setEnabled(this.audioBean != null ? this.audioBean.getPlaybackFormat() != null : false);
      this.micField.setEnabled(this.micSlider.isEnabled());
      this.spkField.setEnabled(this.spkSlider.isEnabled());
      this.micBlkSize = this.audioCore != null && this.micSlider.isEnabled()
         ? this.audioCore.getCaptureBufferSizeMs()
         : (var1 != null && var1.getCaptureBufferSize() >= 0 ? var1.getCaptureBufferSize() : 120);
      this.spkBlkSize = this.audioCore != null && this.spkSlider.isEnabled()
         ? this.audioCore.getPlaybackBufferSizeMs()
         : (var1 != null && var1.getPlaybackBufferSize() >= 0 ? var1.getPlaybackBufferSize() : 120);
      this.setValue(this.micSlider, this.micBlkSize);
      this.micField.setText("" + this.micBlkSize);
      this.setValue(this.spkSlider, this.spkBlkSize);
      this.spkField.setText("" + this.spkBlkSize);
   }

   private void undoValues() {
      this.setValue(this.micSlider, this.micBlkSize);
      this.setValue(this.spkSlider, this.spkBlkSize);
   }

   protected final JPanel createButtonPanel() {
      this.okButton = new JButton(T._("OK"));
      this.okButton.addActionListener(this);
      this.cancelButton = new JButton(T._("Cancel"));
      this.cancelButton.addActionListener(this);
      JPanel var1 = new JPanel(new FlowLayout(4));
      var1.add(this.okButton);
      var1.add(this.cancelButton);
      this.dlg.getRootPane().setDefaultButton(this.okButton);
      this.okButton.setPreferredSize(this.cancelButton.getPreferredSize());
      JPanel var2 = new JPanel(new SpringLayout());
      var2.add(var1);
      SpringUtilities.makeCompactGrid(var2, 1, 1, 0, 0, 10, 5);
      return var2;
   }

   private final JPanel createMainPanel() {
      JPanel var1 = new JPanel(new SpringLayout());
      var1.add(new JLabel("Capture Buffer Size:"));
      this.micSlider = new JSlider(1, 10);
      this.micSlider.setSnapToTicks(true);
      this.micSlider.addChangeListener(this);
      var1.add(this.micSlider);
      this.micField = new JTextField("888888");
      this.micField.setEditable(false);
      var1.add(this.micField);
      var1.add(new JLabel("milliseconds"));
      var1.add(new JLabel("Playback Buffer Size:"));
      this.spkSlider = new JSlider(1, 10);
      this.spkSlider.setSnapToTicks(true);
      this.spkSlider.addChangeListener(this);
      var1.add(this.spkSlider);
      this.spkField = new JTextField("888888");
      this.spkField.setEditable(false);
      var1.add(this.spkField);
      var1.add(new JLabel("milliseconds"));
      SpringUtilities.makeCompactGrid(var1, 2, 4, 20, 20, 20, 20);
      return var1;
   }

   private void createGui() {
      JPanel var1 = this.createButtonPanel();
      JPanel var2 = this.createMainPanel();
      this.dlg.setLayout(new BorderLayout());
      this.dlg.add(var2, "Center");
      this.dlg.add(var1, "Last");
      this.dlg.pack();
      this.dlg.setResizable(false);
      this.resetValues();
   }

   @Override
   public void actionPerformed(ActionEvent var1) {
      DevicePrefs var2 = this.prefs != null ? this.prefs : DevicePrefs.getNode(this.audioBean.getHost());
      if (var2 == null) {
         var2 = new DevicePrefs();
      }

      if (var1.getSource() == this.cancelButton) {
         this.undoValues();
         this.setVisible(false);
      } else if (var1.getSource() == this.okButton) {
         if (this.micSlider.isEnabled()) {
            this.micBlkSize = this.getValue(this.micSlider);
            System.out.println("New mic value: " + this.micBlkSize);

            try {
               this.audioCore.setCaptureBufferSizeMs(this.micBlkSize);
            } catch (Exception var5) {
               System.out.println("Could not set capture buffer size");
               var5.printStackTrace();
            }

            var2.setCaptureBufferSize(this.micBlkSize);
         }

         if (this.spkSlider.isEnabled()) {
            this.spkBlkSize = this.getValue(this.spkSlider);
            System.out.println("New spkeaker value: " + this.spkBlkSize);

            try {
               this.audioCore.setPlaybackBufferSizeMs(this.spkBlkSize);
            } catch (Exception var4) {
               System.out.println("Could not set playback buffer size");
               var4.printStackTrace();
            }

            var2.setPlaybackBufferSize(this.spkBlkSize);
         }

         var2.exportPreferences(this.audioBean.getHost());
         this.setVisible(false);
      }
   }

   @Override
   public void stateChanged(ChangeEvent var1) {
      if (var1.getSource() == this.micSlider) {
         this.micField.setText("" + this.getValue(this.micSlider));
      } else if (var1.getSource() == this.spkSlider) {
         this.spkField.setText("" + this.getValue(this.spkSlider));
      }
   }

   private void setValue(JSlider var1, int var2) {
      var1.setValue(var2 / 40);
   }

   private int getValue(JSlider var1) {
      return var1.getValue() * 40;
   }

   public boolean isAutoClosed() {
      return false;
   }
}
