package nn.pp.common.help;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Image;
import java.awt.Point;
import java.awt.Toolkit;
import java.awt.Window;
import java.io.IOException;
import java.net.URL;
import java.util.ResourceBundle;
import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;

public class HelpManager {
   private ResourceBundle bundle;
   private final ClassLoader clsLoader;
   private final String prefix;
   private JFrame frame;
   private final JEditorPane htmlPane = new JEditorPane();
   private final String title;
   private final Image windowImage;

   public HelpManager(ResourceBundle var1, ClassLoader var2, String var3, String var4, Image var5) {
      this.clsLoader = var2;

      assert this.clsLoader != null : "clsLoader for loading html files null";

      if (var3 == null) {
         this.prefix = "";
      } else {
         this.prefix = var3;
      }

      this.bundle = var1;

      assert this.bundle != null;

      this.title = var4;
      this.windowImage = var5;
   }

   public HelpManager(ClassLoader var1, String var2, String var3, Image var4) {
      this.clsLoader = var1;

      assert this.clsLoader != null : "clsLoader for loading html files null";

      if (var2 == null) {
         this.prefix = "";
      } else {
         this.prefix = var2;
      }

      this.title = var3;
      this.windowImage = var4;
   }

   public void setHelpWindowOnTop(boolean var1) {
      if (this.frame != null) {
         this.frame.setAlwaysOnTop(var1);
      }
   }

   public void showHelp(String var1, Component var2) {
      assert var1 != null : " Null topic to display";

      String var3 = var1;
      if (this.bundle != null) {
         var3 = this.bundle.getString(var1);
      }

      URL var4 = this.getHelpURL(var3);

      try {
         this.htmlPane.setPage(var4);
      } catch (IOException var6) {
         var6.printStackTrace();
      }

      this.getFrame(var2).setVisible(true);
   }

   private JFrame getFrame(Component var1) {
      if (this.frame == null) {
         this.frame = new JFrame();
         this.frame.setDefaultCloseOperation(1);
         this.htmlPane.setEditable(false);
         JScrollPane var2 = new JScrollPane(this.htmlPane);
         this.frame.getContentPane().add(var2);
         if (var1 != null) {
            Object var3 = var1 instanceof Window ? var1 : SwingUtilities.getWindowAncestor(var1);
            if (var3 != null) {
               Point var4 = var3.getLocationOnScreen();
               int var5 = var4.x + var3.getWidth();
               int var6 = var4.y;
               Dimension var7 = Toolkit.getDefaultToolkit().getScreenSize();
               var5 = Math.min(var5, var7.width - 800);
               var6 = Math.min(var6, var7.height - 600);
               this.frame.setLocation(var5, var6);
            }
         }

         this.frame.setSize(800, 600);
         this.frame.setTitle(this.title);
         this.frame.setIconImage(this.windowImage);
      }

      return this.frame;
   }

   private URL getHelpURL(String var1) {
      assert var1 != null : "Null html help file to display";

      String var2 = this.prefix + var1;
      URL var3 = this.clsLoader.getResource(var2);

      assert var3 != null : "Unable to find the HTML help file: " + var2;

      return var3;
   }

   public void cleanup() {
      if (this.frame != null) {
         this.frame.dispose();
      }
   }
}
