package nn.pp.common.scan;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Image;
import java.awt.Rectangle;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.border.Border;
import nn.pp.common.DoubleClickHandler;
import nn.pp.common.RemoteConsoleParameters;
import nn.pp.common.ResourceLoader;
import nn.pp.common.Util;
import nn.pp.core.INotificationEvent;

public class ScanPanelHelper {
   private static final String NO_VIDEO_FROM_TARGET_SERVER = "No video from target server";
   private static final Map<Integer, Image> overlayImages = new HashMap<>();
   private static final Border EMPTY_BORDER_4 = BorderFactory.createEmptyBorder(4, 4, 4, 4);
   private static final Border LINE_BORDER_4 = BorderFactory.createLineBorder(Color.BLUE, 4);
   private final ScanPanelHelper.SequentialScanEventHandler sequentialScanEventHandler = new ScanPanelHelper.SequentialScanEventHandler();
   private final ScanPanelHelper.ThumbnailScanEventHandler thumbnailScanEventHandler = new ScanPanelHelper.ThumbnailScanEventHandler();
   private final List<RemoteConsoleParameters> remoteConsoleParamsList;
   private final Map<String, RemoteConsoleParameters> portIdToRemoteConsoleParams = new HashMap<>();
   private final JComponent scanPanel;
   private final ScanConnector scanConnector;
   private Dimension thumbnailSize = new Dimension(320, 240);
   private int splitPaneOrientation = 0;

   public ScanPanelHelper(List<RemoteConsoleParameters> var1, ScanConnector var2, Dimension var3, int var4) {
      this.remoteConsoleParamsList = var1;
      this.scanConnector = var2;
      this.thumbnailSize = var3;
      this.splitPaneOrientation = var4;
      this.scanPanel = this.createAndInitScanPanel();

      for (RemoteConsoleParameters var6 : var1) {
         this.portIdToRemoteConsoleParams.put(var6.targetPortId, var6);
      }
   }

   private JComponent createAndInitScanPanel() {
      ScanSplitPane var1 = new ScanSplitPane(this.splitPaneOrientation);
      ResizeableVideoSnapshotViewer var2 = this.sequentialScanEventHandler.getSequentialViewer();
      JComponent var3 = this.thumbnailScanEventHandler.getThumbnailComponent();
      var1.setTopComponent(this.createGlsPaneBackedPanel(var2));
      var1.setBottomComponent(var3);
      this.scanConnector.addScanEventListener(this.sequentialScanEventHandler);
      this.scanConnector.addScanEventListener(this.thumbnailScanEventHandler.getStateUpdater());
      this.scanConnector.addScanEventListener(this.thumbnailScanEventHandler.getLoupeUpdater());
      this.scanConnector.addScanEventListener(this.sequentialScanEventHandler.getSnapshotUpdater());
      var1.addTopComponentListener(new ScanPanelHelper.SequentialViewerVisiblityHandler());
      JComponent var4 = this.thumbnailScanEventHandler.getNewThumbnailComponent();
      Dimension var5 = var1.getSize();
      Dimension var6 = var4.getPreferredSize();
      if (this.splitPaneOrientation == 1) {
         var1.setOrientation(0);
      } else if (this.splitPaneOrientation == 0) {
         var1.setOrientation(1);
      }

      return var1;
   }

   private JPanel createGlsPaneBackedPanel(ResizeableVideoSnapshotViewer var1) {
      JPanel var2 = new JPanel();
      var2.setMinimumSize(new Dimension());
      var2.setLayout(new StackLayout());
      JComponent var3 = new JComponent() {};
      DoubleClickHandler var4 = new DoubleClickHandler();
      var4.addMouseListener(this.sequentialScanEventHandler.getMouseClickHandler());
      var3.addMouseListener(var4);
      var2.add(var3, "top");
      var2.add(var1, "bottom");
      return var2;
   }

   public ScanConnector getScanConnector() {
      return this.scanConnector;
   }

   public JComponent getScanPanel() {
      return this.scanPanel;
   }

   public Dimension getThumbnailSize() {
      return this.thumbnailSize;
   }

   public void setThumbnailSize(Dimension var1) {
      this.thumbnailSize = var1;
      this.thumbnailScanEventHandler.setThumbnailSize(var1);
      this.setSplitPaneDividerLocation();
   }

   private void setSplitPaneDividerLocation() {
      JSplitPane var1 = (JSplitPane)this.scanPanel;
      JComponent var2 = this.thumbnailScanEventHandler.getNewThumbnailComponent();
      Dimension var3 = var1.getSize();
      Dimension var4 = var2.getPreferredSize();
      if (!this.isExpanded()) {
         if (this.splitPaneOrientation == 1) {
            var1.setDividerLocation((double)(1.0F - var4.height / ((float)var3.height - var1.getDividerSize())));
         } else {
            var1.setDividerLocation((double)(1.0F - var4.width / ((float)var3.width - var1.getDividerSize())));
         }
      }
   }

   private boolean isExpanded() {
      JSplitPane var1 = (JSplitPane)this.scanPanel;
      return this.isExpanded(var1.getLeftComponent()) || this.isExpanded(var1.getRightComponent());
   }

   private boolean isExpanded(Component var1) {
      JSplitPane var2 = (JSplitPane)this.scanPanel;
      return (var2.getOrientation() == 1 ? var1.getWidth() : var1.getHeight()) == 0;
   }

   public void setSplitPaneOrientation(int var1) {
      JSplitPane var2 = (JSplitPane)this.scanPanel;
      if (this.splitPaneOrientation != var1) {
         this.splitPaneOrientation = var1;
         JComponent var3 = this.thumbnailScanEventHandler.getNewThumbnailComponent();
         JScrollPane var4 = (JScrollPane)var3;
         Dimension var5 = var2.getSize();
         switch (var1) {
            case 0:
               var2.setBottomComponent(var3);
               Dimension var7 = var3.getPreferredSize();
               var2.setOrientation(1);
               var2.setDividerLocation((double)(1.0F - var7.width / ((float)var5.width - var2.getDividerSize())));
               var4.setHorizontalScrollBarPolicy(31);
               var4.setVerticalScrollBarPolicy(20);
               break;
            case 1:
               var2.setBottomComponent(var3);
               Dimension var6 = var3.getPreferredSize();
               var2.setOrientation(0);
               var2.setDividerLocation((double)(1.0F - var6.height / ((float)var5.height - var2.getDividerSize())));
               var4.setHorizontalScrollBarPolicy(30);
               var4.setVerticalScrollBarPolicy(21);
         }
      }
   }

   public int getSplitPaneOrientation() {
      return this.splitPaneOrientation;
   }

   public void addVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<RemoteConsoleParameters> var1) {
      this.thumbnailScanEventHandler.addVideoSnapshotSelectionListener(var1);
      this.sequentialScanEventHandler.addVideoSnapshotSelectionListener(var1);
   }

   public void removeVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<RemoteConsoleParameters> var1) {
      this.thumbnailScanEventHandler.removeVideoSnapshotSelectionListener(var1);
      this.sequentialScanEventHandler.removeVideoSnapshotSelectionListener(var1);
   }

   static {
      overlayImages.put(320, ResourceLoader.loadImageIcon("Common_loupe_320.png").getImage());
      overlayImages.put(160, ResourceLoader.loadImageIcon("Common_loupe_160.png").getImage());
   }

   private class SequentialScanEventHandler implements ScanEventListener {
      private String portId;
      private ScanConnectorState scanConnectorState = ScanConnectorState.INIT;
      private final List<VideoSnapshotSelectionListener<RemoteConsoleParameters>> listeners = new ArrayList<>();
      private final ResizeableVideoSnapshotViewer sequentialViewer = new ResizeableVideoSnapshotViewer();
      private final ScanPanelHelper.SequentialScanEventHandler.SnapshotUpdater snapshotUpdater = new ScanPanelHelper.SequentialScanEventHandler.SnapshotUpdater(
         
      );
      private final ScanPanelHelper.SequentialScanEventHandler.MouseClickHandler mouseClickHandler = new ScanPanelHelper.SequentialScanEventHandler.MouseClickHandler(
         
      );

      private SequentialScanEventHandler() {
      }

      public ScanPanelHelper.SequentialScanEventHandler.MouseClickHandler getMouseClickHandler() {
         return this.mouseClickHandler;
      }

      public void setPortId(String var1) {
         this.portId = var1;
      }

      public void setScanConnectorState(ScanConnectorState var1) {
         this.scanConnectorState = var1;
      }

      public ScanPanelHelper.SequentialScanEventHandler.SnapshotUpdater getSnapshotUpdater() {
         return this.snapshotUpdater;
      }

      public ResizeableVideoSnapshotViewer getSequentialViewer() {
         return this.sequentialViewer;
      }

      public String getPortId() {
         return this.portId;
      }

      public ScanConnectorState getScanConnectorState() {
         return this.scanConnectorState;
      }

      public JComponent getVideoComponent() {
         return (JComponent)this.sequentialViewer.getComponent(0);
      }

      @Override
      public void videoComponentAvailable(String var1, JComponent var2) {
         this.scanConnectorState = ScanConnectorState.COMP_AVAILABLE;
         this.portId = var1;
         var2.setVisible(false);
         this.sequentialViewer.add(var2);

         assert this.sequentialViewer.getComponentCount() == 1;
      }

      @Override
      public void displayVideoStart(String var1, boolean var2) {
         this.scanConnectorState = ScanConnectorState.VIDEO_START;
         this.sequentialViewer.getComponent(0).setVisible(true);
      }

      @Override
      public void displayVideoEnd(String var1, Image var2) {
         this.scanConnectorState = ScanConnectorState.VIDEO_END;
         ResizeableVideoSnapshotViewer var3 = this.sequentialViewer;
         if (var3.getComponentCount() > 0) {
            var3.remove(var3.getComponent(0));
         }

         assert this.sequentialViewer.getComponentCount() == 0;
      }

      @Override
      public void displayVideoError(String var1, int var2) {
         this.scanConnectorState = ScanConnectorState.VIDEO_ERROR;
         ResizeableVideoSnapshotViewer var3 = this.sequentialViewer;
         var3.remove(var3.getComponent(0));

         assert this.sequentialViewer.getComponentCount() == 0;
      }

      @Override
      public void displayVideoCommunicationError(String var1) {
         this.scanConnectorState = ScanConnectorState.COMM_ERROR;
         ResizeableVideoSnapshotViewer var2 = this.sequentialViewer;
         var2.remove(var2.getComponent(0));

         assert this.sequentialViewer.getComponentCount() == 0;
      }

      @Override
      public void scanAborted(INotificationEvent var1) {
         this.scanConnectorState = ScanConnectorState.SCAN_ABORTED;
      }

      @Override
      public void scanAbortedOnConnectError() {
         this.scanConnectorState = ScanConnectorState.SCAN_ABORTED_ON_COMM_ERROR;
      }

      public void addVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<RemoteConsoleParameters> var1) {
         if (!this.listeners.contains(var1)) {
            this.listeners.add(var1);
         }
      }

      public boolean removeVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<RemoteConsoleParameters> var1) {
         return this.listeners.remove(var1);
      }

      private void fireSingleClickSelection() {
         RemoteConsoleParameters var1 = ScanPanelHelper.this.portIdToRemoteConsoleParams.get(this.portId);

         for (VideoSnapshotSelectionListener var3 : this.listeners) {
            var3.videoSnapshotSingleClickSelected(var1);
         }
      }

      private void fireDoubleClickSelection() {
         RemoteConsoleParameters var1 = ScanPanelHelper.this.portIdToRemoteConsoleParams.get(this.portId);

         for (VideoSnapshotSelectionListener var3 : this.listeners) {
            var3.videoSnapshotDoubleClickSelected(var1);
         }
      }

      @Override
      public void osdMessageReceived(String var1, String var2) {
      }

      private class MouseClickHandler extends MouseAdapter {
         private MouseClickHandler() {
         }

         @Override
         public void mouseClicked(MouseEvent var1) {
            if (var1.getClickCount() == 1) {
               SequentialScanEventHandler.this.fireSingleClickSelection();
            } else {
               SequentialScanEventHandler.this.fireDoubleClickSelection();
            }
         }
      }

      private class SnapshotUpdater implements ScanEventListener {
         private SnapshotUpdater() {
         }

         @Override
         public void videoComponentAvailable(String var1, JComponent var2) {
         }

         @Override
         public void displayVideoStart(String var1, boolean var2) {
            SequentialScanEventHandler.this.sequentialViewer.clearShanpshot();
         }

         @Override
         public void displayVideoEnd(String var1, Image var2) {
            if (var2 != null) {
               SequentialScanEventHandler.this.sequentialViewer.setSnapshot(var2, new Dimension(var2.getWidth(null), var2.getHeight(null)));
            }
         }

         @Override
         public void displayVideoCommunicationError(String var1) {
            SequentialScanEventHandler.this.sequentialViewer.clearShanpshot();
         }

         @Override
         public void displayVideoError(String var1, int var2) {
            SequentialScanEventHandler.this.sequentialViewer.clearShanpshot();
         }

         @Override
         public void scanAborted(INotificationEvent var1) {
         }

         @Override
         public void scanAbortedOnConnectError() {
         }

         @Override
         public void osdMessageReceived(String var1, String var2) {
         }
      }
   }

   private class SequentialViewerVisiblityHandler extends ComponentAdapter {
      private SequentialViewerVisiblityHandler() {
      }

      @Override
      public void componentShown(ComponentEvent var1) {
         ScanPanelHelper.this.scanConnector.removeScanEventListener(ScanPanelHelper.this.thumbnailScanEventHandler);
         ScanPanelHelper.this.scanConnector.addScanEventListener(ScanPanelHelper.this.sequentialScanEventHandler);
         ScanPanelHelper.this.scanConnector.addScanEventListener(ScanPanelHelper.this.thumbnailScanEventHandler.getLoupeUpdater());
         switch (ScanPanelHelper.this.thumbnailScanEventHandler.getScanConnectorState()) {
            case COMP_AVAILABLE:
               ScanPanelHelper.this.sequentialScanEventHandler
                  .videoComponentAvailable(
                     ScanPanelHelper.this.thumbnailScanEventHandler.getPortId(), ScanPanelHelper.this.thumbnailScanEventHandler.getVideoComponent()
                  );
               ScanPanelHelper.this.thumbnailScanEventHandler.setOverlayImage(ScanPanelHelper.this.thumbnailScanEventHandler.getPortId());
               break;
            case VIDEO_START:
               ScanPanelHelper.this.sequentialScanEventHandler
                  .videoComponentAvailable(
                     ScanPanelHelper.this.thumbnailScanEventHandler.getPortId(), ScanPanelHelper.this.thumbnailScanEventHandler.getVideoComponent()
                  );
               ScanPanelHelper.this.sequentialScanEventHandler.displayVideoStart(ScanPanelHelper.this.thumbnailScanEventHandler.getPortId(), false);
               ScanPanelHelper.this.thumbnailScanEventHandler.setOverlayImage(ScanPanelHelper.this.thumbnailScanEventHandler.getPortId());
               break;
            case VIDEO_END:
               ScanPanelHelper.this.thumbnailScanEventHandler.setOverlayImage(ScanPanelHelper.this.thumbnailScanEventHandler.getPortId());
            case INIT:
            case COMM_ERROR:
            case VIDEO_ERROR:
            case SCAN_ABORTED:
            case SCAN_ABORTED_ON_COMM_ERROR:
               break;
            default:
               throw new AssertionError("Handle new ScanConnectorState");
         }

         ScanPanelHelper.this.sequentialScanEventHandler.setPortId(ScanPanelHelper.this.thumbnailScanEventHandler.getPortId());
         ScanPanelHelper.this.sequentialScanEventHandler.setScanConnectorState(ScanPanelHelper.this.thumbnailScanEventHandler.getScanConnectorState());
      }

      @Override
      public void componentHidden(ComponentEvent var1) {
         ScanPanelHelper.this.scanConnector.removeScanEventListener(ScanPanelHelper.this.sequentialScanEventHandler);
         ScanPanelHelper.this.scanConnector.addScanEventListener(ScanPanelHelper.this.thumbnailScanEventHandler);
         ScanPanelHelper.this.scanConnector.removeScanEventListener(ScanPanelHelper.this.thumbnailScanEventHandler.getLoupeUpdater());
         ScanPanelHelper.this.thumbnailScanEventHandler.clearOverlayImage();
         switch (ScanPanelHelper.this.sequentialScanEventHandler.getScanConnectorState()) {
            case COMP_AVAILABLE:
               ScanPanelHelper.this.thumbnailScanEventHandler
                  .videoComponentAvailable(
                     ScanPanelHelper.this.sequentialScanEventHandler.getPortId(), ScanPanelHelper.this.sequentialScanEventHandler.getVideoComponent()
                  );
               break;
            case VIDEO_START:
               ScanPanelHelper.this.thumbnailScanEventHandler
                  .videoComponentAvailable(
                     ScanPanelHelper.this.sequentialScanEventHandler.getPortId(), ScanPanelHelper.this.sequentialScanEventHandler.getVideoComponent()
                  );
               ScanPanelHelper.this.thumbnailScanEventHandler.displayVideoStart(ScanPanelHelper.this.sequentialScanEventHandler.getPortId(), false);
            case VIDEO_END:
            case INIT:
            case COMM_ERROR:
            case VIDEO_ERROR:
            case SCAN_ABORTED:
            case SCAN_ABORTED_ON_COMM_ERROR:
               break;
            default:
               throw new AssertionError("Handle new ScanConnectorState");
         }

         ScanPanelHelper.this.thumbnailScanEventHandler.setPortId(ScanPanelHelper.this.sequentialScanEventHandler.getPortId());
         ScanPanelHelper.this.thumbnailScanEventHandler.setScanConnectorState(ScanPanelHelper.this.sequentialScanEventHandler.getScanConnectorState());
      }
   }

   private class ThumbnailScanEventHandler implements ScanEventListener {
      private String portId;
      private ScanConnectorState scanConnectorState = ScanConnectorState.INIT;
      private final HashMap<String, VideoSnapshotPanel<RemoteConsoleParameters>> snapshotPanelsMap = new LinkedHashMap<>();
      private final HashMap<String, VideoSnapshotViewer> scanViewerMap = new HashMap<>();
      private final ScanPanelHelper.ThumbnailScanEventHandler.StateUpdater stateUpdater = new ScanPanelHelper.ThumbnailScanEventHandler.StateUpdater();
      private final ScanPanelHelper.ThumbnailScanEventHandler.LoupeUpdater loupeUpdater = new ScanPanelHelper.ThumbnailScanEventHandler.LoupeUpdater();
      private final ScanPanelHelper.ThumbnailScanEventHandler.SelectionListener selectionListener = new ScanPanelHelper.ThumbnailScanEventHandler.SelectionListener(
         
      );
      private JScrollPane thumbnailComponent;
      private JPanel thumbnailPanel;

      private ThumbnailScanEventHandler() {
      }

      public void setPortId(String var1) {
         this.portId = var1;
      }

      public void setScanConnectorState(ScanConnectorState var1) {
         this.scanConnectorState = var1;
      }

      public ScanPanelHelper.ThumbnailScanEventHandler.LoupeUpdater getLoupeUpdater() {
         return this.loupeUpdater;
      }

      public ScanPanelHelper.ThumbnailScanEventHandler.StateUpdater getStateUpdater() {
         return this.stateUpdater;
      }

      public String getPortId() {
         return this.portId;
      }

      public ScanConnectorState getScanConnectorState() {
         return this.scanConnectorState;
      }

      public JComponent getVideoComponent() {
         return (JComponent)this.scanViewerMap.get(this.portId).getComponent(0);
      }

      public void setThumbnailSize(Dimension var1) {
         for (VideoSnapshotViewer var3 : this.scanViewerMap.values()) {
            var3.setThumbnailSize(var1);
         }

         this.thumbnailPanel.invalidate();
         this.thumbnailPanel.validate();
         this.thumbnailPanel.revalidate();
      }

      public void addVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<RemoteConsoleParameters> var1) {
         for (VideoSnapshotPanel var3 : this.snapshotPanelsMap.values()) {
            var3.addVideoSnapshotSelectionListener(var1);
         }
      }

      public void removeVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<RemoteConsoleParameters> var1) {
         for (VideoSnapshotPanel var3 : this.snapshotPanelsMap.values()) {
            var3.removeVideoSnapshotSelectionListener(var1);
         }
      }

      public JComponent getThumbnailComponent() {
         if (this.thumbnailComponent == null) {
            this.thumbnailPanel = (JPanel)(ScanPanelHelper.this.splitPaneOrientation == 1 ? new ScrollableVerticalFlowPanel() : new ScrollableFlowPanel());
            JScrollPane var1 = new JScrollPane(this.thumbnailPanel);
            if (ScanPanelHelper.this.splitPaneOrientation == 1) {
               var1.setHorizontalScrollBarPolicy(30);
               var1.setVerticalScrollBarPolicy(21);
            } else if (ScanPanelHelper.this.splitPaneOrientation == 0) {
               var1.setVerticalScrollBarPolicy(20);
               var1.setHorizontalScrollBarPolicy(31);
            }

            var1.setMinimumSize(new Dimension());

            for (RemoteConsoleParameters var3 : ScanPanelHelper.this.remoteConsoleParamsList) {
               VideoSnapshotViewer var4 = new VideoSnapshotViewer();
               var4.setThumbnailSize(ScanPanelHelper.this.thumbnailSize);
               this.scanViewerMap.put(var3.targetPortId, var4);
               VideoSnapshotPanel var5 = new VideoSnapshotPanel<>(var4, var3);
               var5.setInformation(this.getFormattedPortNumber(var3.portIndex) + var3.portName);
               var5.setBorder(ScanPanelHelper.EMPTY_BORDER_4);
               var5.addVideoSnapshotSelectionListener(this.selectionListener);
               this.thumbnailPanel.add(var5);
               this.snapshotPanelsMap.put(var3.targetPortId, var5);
            }

            this.thumbnailComponent = var1;
         }

         return this.thumbnailComponent;
      }

      private String getFormattedPortNumber(String var1) {
         String var2 = "";

         try {
            if (var1.contains(".")) {
               int[] var3 = Util.getPortNumber(var1);
               String var4 = Integer.toString(var3[0] + 1);
               String var5 = Integer.toString(var3[1]);
               var2 = var4 + "-" + var5 + " - ";
            } else {
               int var8 = Integer.parseInt(var1) + 1;
               var2 = Integer.toString(var8) + " - ";
            }

            return var2;
         } catch (NumberFormatException var6) {
            return "";
         }
      }

      public JComponent getNewThumbnailComponent() {
         Object var1 = ScanPanelHelper.this.splitPaneOrientation == 1 ? new ScrollableFlowPanel() : new ScrollableVerticalFlowPanel();

         for (VideoSnapshotPanel var3 : this.snapshotPanelsMap.values()) {
            var1.add(var3);
         }

         this.thumbnailPanel = (JPanel)var1;
         this.thumbnailComponent.setViewportView(this.thumbnailPanel);
         return this.thumbnailComponent;
      }

      @Override
      public void videoComponentAvailable(String var1, JComponent var2) {
         this.scanConnectorState = ScanConnectorState.COMP_AVAILABLE;
         this.portId = var1;
         var2.setVisible(false);
         this.scanViewerMap.get(var1).add(var2);

         assert this.scanViewerMap.get(var1).getComponentCount() == 1;
      }

      @Override
      public void displayVideoStart(String var1, boolean var2) {
         this.scanConnectorState = ScanConnectorState.VIDEO_START;
         this.scanViewerMap.get(var1).getComponent(0).setVisible(true);
      }

      @Override
      public void displayVideoEnd(String var1, Image var2) {
         this.scanConnectorState = ScanConnectorState.VIDEO_END;
         VideoSnapshotViewer var3 = this.scanViewerMap.get(var1);
         var3.remove(var3.getComponent(0));

         assert this.scanViewerMap.get(var1).getComponentCount() == 0;
      }

      @Override
      public void displayVideoError(String var1, int var2) {
         this.scanConnectorState = ScanConnectorState.VIDEO_ERROR;
         VideoSnapshotViewer var3 = this.scanViewerMap.get(var1);
         var3.remove(var3.getComponent(0));

         assert this.scanViewerMap.get(var1).getComponentCount() == 0;
      }

      @Override
      public void displayVideoCommunicationError(String var1) {
         this.scanConnectorState = ScanConnectorState.COMM_ERROR;
         VideoSnapshotViewer var2 = this.scanViewerMap.get(var1);
         var2.remove(var2.getComponent(0));

         assert this.scanViewerMap.get(var1).getComponentCount() == 0;
      }

      @Override
      public void scanAborted(INotificationEvent var1) {
         this.scanConnectorState = ScanConnectorState.SCAN_ABORTED;
      }

      @Override
      public void scanAbortedOnConnectError() {
         this.scanConnectorState = ScanConnectorState.SCAN_ABORTED_ON_COMM_ERROR;
      }

      public void clearOverlayImage() {
         for (VideoSnapshotViewer var2 : this.scanViewerMap.values()) {
            var2.setOverlayImage(null);
         }
      }

      public void clearBorder() {
         for (VideoSnapshotPanel var2 : this.snapshotPanelsMap.values()) {
            if (!var2.getBorder().equals(ScanPanelHelper.EMPTY_BORDER_4)) {
               var2.setBorder(ScanPanelHelper.EMPTY_BORDER_4);
            }
         }
      }

      public void clearLedState() {
         for (VideoSnapshotPanel var2 : this.snapshotPanelsMap.values()) {
            var2.setTargetState(TargetState.INACTIVE);
         }
      }

      public void setOverlayImage(String var1) {
         this.scanViewerMap.get(var1).setOverlayImage(ScanPanelHelper.overlayImages);
      }

      @Override
      public void osdMessageReceived(String var1, String var2) {
      }

      private class LoupeUpdater implements ScanEventListener {
         private LoupeUpdater() {
         }

         @Override
         public void videoComponentAvailable(String var1, JComponent var2) {
            ThumbnailScanEventHandler.this.clearOverlayImage();
            ThumbnailScanEventHandler.this.setOverlayImage(var1);
         }

         @Override
         public void displayVideoStart(String var1, boolean var2) {
         }

         @Override
         public void displayVideoEnd(String var1, Image var2) {
         }

         @Override
         public void displayVideoCommunicationError(String var1) {
            ThumbnailScanEventHandler.this.scanViewerMap.get(var1).setOverlayImage(null);
         }

         @Override
         public void displayVideoError(String var1, int var2) {
            ThumbnailScanEventHandler.this.scanViewerMap.get(var1).setOverlayImage(null);
         }

         @Override
         public void scanAborted(INotificationEvent var1) {
         }

         @Override
         public void scanAbortedOnConnectError() {
         }

         @Override
         public void osdMessageReceived(String var1, String var2) {
         }
      }

      private class SelectionListener implements VideoSnapshotSelectionListener<RemoteConsoleParameters> {
         private SelectionListener() {
         }

         public void videoSnapshotDoubleClickSelected(RemoteConsoleParameters var1) {
         }

         public void videoSnapshotSingleClickSelected(RemoteConsoleParameters var1) {
            ScanPanelHelper.this.scanConnector.pause();
            ScanPanelHelper.this.scanConnector.resumeAt(var1.targetPortId);
         }
      }

      private class StateUpdater implements ScanEventListener {
         private StateUpdater() {
         }

         @Override
         public void videoComponentAvailable(String var1, JComponent var2) {
            VideoSnapshotPanel var3 = ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1);
            var3.setTargetState(TargetState.INACTIVE);
            ThumbnailScanEventHandler.this.clearBorder();
            ThumbnailScanEventHandler.this.clearLedState();
            var3.setBorder(ScanPanelHelper.LINE_BORDER_4);
            var3.scrollRectToVisible(new Rectangle(0, 0, var3.getWidth(), var3.getHeight()));
         }

         @Override
         public void displayVideoStart(String var1, boolean var2) {
            VideoSnapshotPanel var3 = ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1);
            if (var3.getTargetState() == TargetState.INACTIVE) {
               var3.setTargetState(TargetState.CONNECTED);
            }

            ThumbnailScanEventHandler.this.scanViewerMap.get(var1).clearShanpshot();
         }

         @Override
         public void displayVideoEnd(String var1, Image var2) {
            ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1).setTargetState(TargetState.INACTIVE);
            if (var2 != null) {
               ThumbnailScanEventHandler.this.scanViewerMap
                  .get(var1)
                  .setSnapshot(
                     var2, nn.pp.core.Util.getScaledDimension(ScanPanelHelper.this.thumbnailSize, new Dimension(var2.getWidth(null), var2.getHeight(null)))
                  );
            }
         }

         @Override
         public void displayVideoCommunicationError(String var1) {
            ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1).setTargetState(TargetState.BUSY);
            ThumbnailScanEventHandler.this.scanViewerMap.get(var1).clearShanpshot();
         }

         @Override
         public void displayVideoError(String var1, int var2) {
            ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1).setTargetState(TargetState.BUSY);
            ThumbnailScanEventHandler.this.scanViewerMap.get(var1).clearShanpshot();
         }

         @Override
         public void scanAborted(INotificationEvent var1) {
         }

         @Override
         public void scanAbortedOnConnectError() {
         }

         @Override
         public void osdMessageReceived(String var1, String var2) {
            if ("No video from target server".equals(var2)) {
               ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1).setTargetState(TargetState.DOWN);
            } else {
               ThumbnailScanEventHandler.this.snapshotPanelsMap.get(var1).setTargetState(TargetState.CONNECTED);
            }
         }
      }
   }
}
