package nn.pp.common.scan;

import java.awt.Component;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.awt.event.ComponentListener;
import java.awt.event.ContainerEvent;
import java.awt.event.ContainerListener;
import java.util.ArrayList;
import javax.swing.JSplitPane;

public class ScanSplitPane extends JSplitPane {
   private final ScanSplitPane.CompResizeListener compResizeListener = new ScanSplitPane.CompResizeListener();
   private final ArrayList<ComponentListener> listeners = new ArrayList<>();
   private boolean compVisible;
   private boolean initialStateSent;

   public ScanSplitPane(int var1) {
      super(var1, true);
      this.setOneTouchExpandable(true);
      this.setResizeWeight(1.0);
      this.setDividerSize(10);
      this.addContainerListener(new ScanSplitPane.CompAddRemoveListener());
   }

   @Override
   protected void addImpl(Component var1, Object var2, int var3) {
      super.addImpl(var1, var2, var3);
      if ("left".equals(var2)) {
         var1.addComponentListener(this.compResizeListener);
      }
   }

   private void fireCompVisiblity(boolean var1, ComponentEvent var2) {
      for (ComponentListener var4 : this.listeners) {
         if (var1) {
            var4.componentShown(var2);
         } else {
            var4.componentHidden(var2);
         }
      }
   }

   public void addTopComponentListener(ComponentListener var1) {
      if (!this.listeners.contains(var1)) {
         this.listeners.add(var1);
      }
   }

   public void removeTopComponentListener(ComponentListener var1) {
      this.listeners.remove(var1);
   }

   private class CompAddRemoveListener implements ContainerListener {
      private CompAddRemoveListener() {
      }

      @Override
      public void componentAdded(ContainerEvent var1) {
      }

      @Override
      public void componentRemoved(ContainerEvent var1) {
         var1.getComponent().removeComponentListener(ScanSplitPane.this.compResizeListener);
      }
   }

   private class CompResizeListener extends ComponentAdapter {
      private CompResizeListener() {
      }

      @Override
      public void componentResized(ComponentEvent var1) {
         boolean var2 = ScanSplitPane.this.compVisible;
         int var3 = ScanSplitPane.this.getOrientation() == 1 ? var1.getComponent().getWidth() : var1.getComponent().getHeight();
         ScanSplitPane.this.compVisible = var3 > 0;
         if (!ScanSplitPane.this.initialStateSent) {
            ScanSplitPane.this.fireCompVisiblity(ScanSplitPane.this.compVisible, var1);
            ScanSplitPane.this.initialStateSent = true;
         } else {
            if (var2 != ScanSplitPane.this.compVisible) {
               ScanSplitPane.this.fireCompVisiblity(ScanSplitPane.this.compVisible, var1);
            }
         }
      }
   }
}
