package nn.pp.common.scan;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.LayoutManager2;
import java.awt.Rectangle;
import java.util.Arrays;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.Scrollable;

public class ScrollableVerticalFlowPanel extends JPanel implements Scrollable {
   private static final Dimension MAX_DIMENSION = new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   private static final int VGAP = 6;
   private static final int HGAP = 6;
   private static final ScrollableVerticalFlowPanel.VerticalFlowLayout VERTICAL_FLOW_LAYOUT = new ScrollableVerticalFlowPanel.VerticalFlowLayout();

   public ScrollableVerticalFlowPanel() {
      this.setLayout(VERTICAL_FLOW_LAYOUT);
   }

   @Override
   public Dimension getPreferredScrollableViewportSize() {
      return VERTICAL_FLOW_LAYOUT.minimumLayoutSize(this);
   }

   @Override
   public int getScrollableBlockIncrement(Rectangle var1, int var2, int var3) {
      return 20;
   }

   @Override
   public boolean getScrollableTracksViewportHeight() {
      Insets var1 = this.getInsets();
      Dimension var2 = this.getParent().getSize();
      int var3 = var2.width - (var1.left + var1.right);
      int var4 = var2.height - (var1.top + var1.bottom);
      int var5 = 0;
      int var6 = 0;

      for (Component var10 : this.getComponents()) {
         Dimension var11 = var10.getPreferredSize();
         var5 = Math.max(var11.width, var5);
         var6 = Math.max(var11.height, var6);
      }

      var3 -= 6;
      int var14 = var3 / (var5 + 6);
      if (var14 > 1) {
         var4 -= 6;
         int var15 = var4 / (var6 + 6);
         if (var14 * var15 > this.getComponentCount()) {
            return true;
         }
      }

      return false;
   }

   @Override
   public boolean getScrollableTracksViewportWidth() {
      return true;
   }

   @Override
   public int getScrollableUnitIncrement(Rectangle var1, int var2, int var3) {
      return 1;
   }

   public static void main(String[] var0) {
      JFrame var1 = new JFrame("ScrollableFlowPanel");
      var1.setDefaultCloseOperation(3);
      var1.setExtendedState(6);
      JSplitPane var2 = new JSplitPane();
      var2.setResizeWeight(1.0);
      var2.setTopComponent(new JPanel());
      ScrollableVerticalFlowPanel var3 = new ScrollableVerticalFlowPanel();

      for (int var4 = 0; var4 < 10; var4++) {
         var3.add(new JButton("Val " + var4));
      }

      for (int var5 = 0; var5 < 10; var5++) {
         var3.add(new JButton(var5 + " Val"));
      }

      for (int var6 = 0; var6 < 10; var6++) {
         var3.add(new JButton("V " + var6 + "al"));
      }

      for (int var7 = 0; var7 < 10; var7++) {
         var3.add(new JButton("Va " + var7 + "l"));
      }

      for (int var8 = 0; var8 < 10; var8++) {
         var3.add(new JButton("V " + var8 + "al"));
      }

      for (int var9 = 0; var9 < 10; var9++) {
         var3.add(new JButton("V " + var9 + "al"));
      }

      for (int var10 = 0; var10 < 3; var10++) {
         var3.add(new JButton("V " + var10 + "al"));
      }

      JScrollPane var11 = new JScrollPane(var3) {
         @Override
         public Dimension getMinimumSize() {
            return new Dimension();
         }
      };
      var11.setHorizontalScrollBarPolicy(31);
      var2.setBottomComponent(var11);
      var1.add(var2);
      var1.setVisible(true);
   }

   private static class VerticalFlowLayout implements LayoutManager2 {
      private VerticalFlowLayout() {
      }

      @Override
      public void addLayoutComponent(Component var1, Object var2) {
      }

      @Override
      public void addLayoutComponent(String var1, Component var2) {
      }

      @Override
      public void removeLayoutComponent(Component var1) {
      }

      @Override
      public float getLayoutAlignmentX(Container var1) {
         return 0.5F;
      }

      @Override
      public float getLayoutAlignmentY(Container var1) {
         return 0.5F;
      }

      @Override
      public void invalidateLayout(Container var1) {
      }

      @Override
      public Dimension maximumLayoutSize(Container var1) {
         return ScrollableVerticalFlowPanel.MAX_DIMENSION;
      }

      @Override
      public Dimension minimumLayoutSize(Container var1) {
         int var2 = 0;
         int var3 = 0;
         synchronized (var1.getTreeLock()) {
            for (Component var8 : var1.getComponents()) {
               Dimension var9 = var8.getPreferredSize();
               var2 = Math.max(var9.width, var2);
               var3 += var9.height;
            }

            int var14 = var1.getComponentCount();
            if (var14 > 0) {
               var2 += 12;
               var3 += 6 * (var14 + 1);
            }
         }

         Insets var4 = var1.getInsets();
         var2 += var4.left + var4.right;
         var3 += var4.top + var4.bottom;
         return new Dimension(var2, var3);
      }

      @Override
      public Dimension preferredLayoutSize(Container var1) {
         synchronized (var1.getTreeLock()) {
            Insets var3 = var1.getInsets();
            Dimension var4 = var1.getSize();
            int var5 = var4.width - (var3.left + var3.right);
            int var6 = 0;
            int var7 = 0;

            for (Component var11 : var1.getComponents()) {
               Dimension var12 = var11.getPreferredSize();
               var6 = Math.max(var12.width, var6);
               var7 = Math.max(var12.height, var7);
            }

            var5 -= 6;
            int var16 = var5 / (var6 + 6);
            int var17 = var1.getComponentCount();
            int var18 = var17;
            if (var16 > 1) {
               var18 = var17 / var16;
               if (var17 % var16 != 0) {
                  var18++;
               }
            }

            int var19 = (var7 + 6) * var18 + 6 + var3.top + var3.bottom;
            return new Dimension(var4.width, var19);
         }
      }

      @Override
      public void layoutContainer(Container var1) {
         synchronized (var1.getTreeLock()) {
            Insets var3 = var1.getInsets();
            Dimension var4 = var1.getSize();
            int var5 = var4.width - (var3.left + var3.right);
            int var6 = var4.height - (var3.top + var3.bottom);
            int var7 = 0;
            int var8 = 0;

            for (Component var12 : var1.getComponents()) {
               Dimension var13 = var12.getPreferredSize();
               var7 = Math.max(var13.width, var7);
               var8 = Math.max(var13.height, var8);
            }

            var5 -= 6;
            int var23 = var5 / (var7 + 6);
            int[] var24 = new int[var23 == 0 ? 1 : var23];
            if (var23 == 0) {
               var23 = 1;
            }

            int var25 = var1.getComponentCount();
            if (var23 == 1) {
               var24[0] = var25;
            } else {
               var6 -= 6;
               int var26 = var6 / (var8 + 6);
               if (var26 * var23 >= var25) {
                  Arrays.fill(var24, var26);
               } else {
                  Arrays.fill(var24, var25 / var23);

                  for (int var29 = 0; var29 < var25 % var23; var29++) {
                     var24[var29]++;
                  }
               }
            }

            int var27 = 6 + var3.left;
            int var30 = 6 + var3.top;
            int var14 = 0;

            for (int var15 = 0; var15 < var23; var15++) {
               for (int var16 = 0; var16 < var24[var15]; var16++) {
                  if (var14 >= var25) {
                     return;
                  }

                  Component var17 = var1.getComponent(var14++);
                  Dimension var18 = var17.getPreferredSize();
                  var17.setBounds(var27, var30, var18.width, var18.height);
                  var30 += var18.height;
                  var30 += 6;
               }

               var27 += 6;
               var27 += var7;
               var30 = 6 + var3.top;
            }
         }
      }
   }
}
