package nn.pp.common.scan;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.LayoutManager2;
import java.awt.Rectangle;
import java.util.LinkedList;
import java.util.List;

public class StackLayout implements LayoutManager2 {
   public static final String BOTTOM = "bottom";
   public static final String TOP = "top";
   private List<Component> components = new LinkedList<>();

   @Override
   public void addLayoutComponent(Component var1, Object var2) {
      synchronized (var1.getTreeLock()) {
         if ("bottom".equals(var2)) {
            this.components.add(0, var1);
         } else if ("top".equals(var2)) {
            this.components.add(var1);
         } else {
            this.components.add(var1);
         }
      }
   }

   @Override
   public void addLayoutComponent(String var1, Component var2) {
      this.addLayoutComponent(var2, "top");
   }

   @Override
   public void removeLayoutComponent(Component var1) {
      synchronized (var1.getTreeLock()) {
         this.components.remove(var1);
      }
   }

   @Override
   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   @Override
   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   @Override
   public void invalidateLayout(Container var1) {
   }

   @Override
   public Dimension preferredLayoutSize(Container var1) {
      synchronized (var1.getTreeLock()) {
         int var3 = 0;
         int var4 = 0;

         for (Component var6 : this.components) {
            Dimension var7 = var6.getPreferredSize();
            var3 = Math.max(var7.width, var3);
            var4 = Math.max(var7.height, var4);
         }

         Insets var12 = var1.getInsets();
         var3 += var12.left + var12.right;
         var4 += var12.top + var12.bottom;
         return new Dimension(var3, var4);
      }
   }

   @Override
   public Dimension minimumLayoutSize(Container var1) {
      synchronized (var1.getTreeLock()) {
         int var3 = 0;
         int var4 = 0;

         for (Component var6 : this.components) {
            Dimension var7 = var6.getMinimumSize();
            var3 = Math.max(var7.width, var3);
            var4 = Math.max(var7.height, var4);
         }

         Insets var12 = var1.getInsets();
         var3 += var12.left + var12.right;
         var4 += var12.top + var12.bottom;
         return new Dimension(var3, var4);
      }
   }

   @Override
   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   @Override
   public void layoutContainer(Container var1) {
      synchronized (var1.getTreeLock()) {
         Insets var3 = var1.getInsets();
         int var4 = var1.getWidth() - (var3.left + var3.right);
         int var5 = var1.getHeight() - (var3.top + var3.bottom);
         Rectangle var6 = new Rectangle(var3.left, var3.top, var4, var5);
         int var7 = this.components.size();

         for (int var8 = 0; var8 < var7; var8++) {
            Component var9 = this.components.get(var8);
            var9.setBounds(var6);
            var1.setComponentZOrder(var9, var7 - var8 - 1);
         }
      }
   }
}
