package nn.pp.common.scan;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;
import java.util.EnumMap;
import java.util.List;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import nn.pp.common.DoubleClickHandler;
import nn.pp.common.ResourceLoader;

public class VideoSnapshotPanel<M> extends JPanel {
   private VideoSnapshotViewer videoSnapshotViewer;
   private final JLabel targetInfo = new VideoSnapshotPanel.SizeRestrictedLabel();
   private final M momento;
   private TargetState targetState = TargetState.INACTIVE;
   private final List<VideoSnapshotSelectionListener<M>> listeners = new ArrayList<>();
   private static final EnumMap<TargetState, ImageIcon> ICON_MAP = new EnumMap<>(TargetState.class);

   public VideoSnapshotPanel(VideoSnapshotViewer var1, M var2) {
      this.videoSnapshotViewer = var1;
      this.momento = (M)var2;
      this.layoutComponents();
   }

   private void layoutComponents() {
      JPanel var1 = new JPanel();
      var1.setLayout(new StackLayout());
      JComponent var2 = new JComponent() {};
      DoubleClickHandler var3 = new DoubleClickHandler();
      var3.addMouseListener(new VideoSnapshotPanel.MouseClickHandler());
      var2.addMouseListener(var3);
      var1.add(var2, "top");
      var1.add(this.videoSnapshotViewer, "bottom");
      this.setLayout(new GridBagLayout());
      GridBagConstraints var4 = new GridBagConstraints();
      var4.gridx = 0;
      var4.gridy = 0;
      this.add(var1, var4);
      var4.gridy = 1;
      var4.insets = new Insets(6, 0, 0, 0);
      var4.fill = 2;
      this.targetInfo.setText("ASAS");
      this.setTargetState(TargetState.INACTIVE);
      this.add(this.targetInfo, var4);
   }

   public void setInformation(String var1) {
      this.targetInfo.setText(var1);
      this.targetInfo.setToolTipText(var1);
   }

   public TargetState getTargetState() {
      return this.targetState;
   }

   public void setTargetState(TargetState var1) {
      this.setTargetState0(var1);
   }

   private void setTargetState0(TargetState var1) {
      this.targetState = var1;
      this.targetInfo.setIcon(ICON_MAP.get(var1));
   }

   public void addVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<M> var1) {
      if (!this.listeners.contains(var1)) {
         this.listeners.add(var1);
      }
   }

   public boolean removeVideoSnapshotSelectionListener(VideoSnapshotSelectionListener<M> var1) {
      return this.listeners.remove(var1);
   }

   private void fireSingleClickSelection() {
      for (VideoSnapshotSelectionListener var2 : this.listeners) {
         var2.videoSnapshotSingleClickSelected(this.momento);
      }
   }

   private void fireDoubleClickSelection() {
      for (VideoSnapshotSelectionListener var2 : this.listeners) {
         var2.videoSnapshotDoubleClickSelected(this.momento);
      }
   }

   static {
      ICON_MAP.put(TargetState.CONNECTED, ResourceLoader.loadImageIcon("Common_led_green.gif"));
      ICON_MAP.put(TargetState.DOWN, ResourceLoader.loadImageIcon("Common_led_yellow.gif"));
      ICON_MAP.put(TargetState.BUSY, ResourceLoader.loadImageIcon("Common_led_red.gif"));
      ICON_MAP.put(TargetState.INACTIVE, ResourceLoader.loadImageIcon("Common_led_white.gif"));
   }

   private class MouseClickHandler extends MouseAdapter {
      private MouseClickHandler() {
      }

      @Override
      public void mouseClicked(MouseEvent var1) {
         if (var1.getClickCount() == 1) {
            VideoSnapshotPanel.this.fireSingleClickSelection();
         } else {
            VideoSnapshotPanel.this.fireDoubleClickSelection();
         }
      }
   }

   private class SizeRestrictedLabel extends JLabel {
      private SizeRestrictedLabel() {
      }

      @Override
      public Dimension getPreferredSize() {
         Dimension var1 = super.getPreferredSize();
         return new Dimension(10, var1.height);
      }

      @Override
      public Dimension getMinimumSize() {
         return this.getPreferredSize();
      }
   }
}
