package nn.pp.common.scan;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Insets;
import java.awt.RenderingHints;
import java.util.Map;
import javax.swing.BorderFactory;
import javax.swing.JPanel;

public class VideoSnapshotViewer extends JPanel {
   private Image image;
   private Map<Integer, Image> overlayImages;
   private Integer thumbnailWidth = 320;
   private static final RenderingHints renderingHints = new RenderingHints(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_DEFAULT);

   public VideoSnapshotViewer() {
      this.setLayout(new BorderLayout());
      this.setBorder(BorderFactory.createLoweredBevelBorder());
   }

   @Override
   protected void paintComponent(Graphics var1) {
      super.paintComponent(var1);
      if (this.getComponentCount() == 0) {
         Dimension var2 = this.getPreferredSize();
         if (this.image != null) {
            int var3 = this.image.getWidth(null);
            int var4 = this.image.getHeight(null);
            int var5 = (var2.width - var3) / 2;
            int var6 = (var2.height - var4) / 2;
            var1.drawImage(this.image, var5, var6, null);
         }

         if (this.overlayImages != null) {
            Image var8 = this.overlayImages.get(this.thumbnailWidth);
            int var9 = var8.getWidth(null);
            int var10 = var8.getHeight(null);
            int var11 = (var2.width - var9) / 2;
            int var7 = (var2.height - var10) / 2;
            var1.drawImage(var8, var11, var7, null);
         }
      }
   }

   public void setSnapshot(Image var1, Dimension var2) {
      this.createSnapshot(var1, var2);
      this.repaint();
   }

   public void clearShanpshot() {
      this.image = null;
      this.repaint();
   }

   private void createSnapshot(Image var1, Dimension var2) {
      this.image = this.getGraphicsConfiguration().createCompatibleImage(var2.width, var2.height);
      Graphics var3 = this.image.getGraphics();
      ((Graphics2D)var3).setRenderingHints(renderingHints);
      var3.drawImage(var1, 0, 0, var2.width, var2.height, null);
      var3.dispose();
   }

   public void setThumbnailSize(Dimension var1) {
      this.thumbnailWidth = var1.width;
      Insets var2 = this.getInsets();
      Dimension var3 = new Dimension(var1.width + var2.left + var2.right, var1.height + var2.top + var2.bottom);
      if (this.image != null) {
         this.createSnapshot(this.image, var1);
      }

      this.setPreferredSize(var3);
      this.setMinimumSize(var3);
      this.invalidate();
   }

   public void setOverlayImage(Map<Integer, Image> var1) {
      if (this.overlayImages != var1) {
         this.overlayImages = var1;
         this.repaint();
      }
   }

   static {
      renderingHints.add(new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR));
   }
}
