package nn.pp.common.smartcard;

import com.raritan.smartcard.CardAccessErrorsListener;
import com.raritan.smartcard.SmartCardCore;
import com.raritan.smartcard.SmartCardException;
import com.raritan.smartcard.SmartCardIncompatibleProtoException;
import com.raritan.smartcard.SmartCardReaderListener;
import com.raritan.smartcard.SmartCardReaderSession;
import com.raritan.smartcard.SmartCardSessionEventsListener;
import java.awt.Component;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.text.MessageFormat;
import javax.swing.AbstractAction;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.SwingUtilities;
import nn.pp.common.ui.helpers.SwingWorker;
import nn.pp.core.NotificationEvent;
import nn.pp.core.NotificationListener;
import nn.pp.core.T;
import nn.pp.ext.devPref.DevicePrefs;

public class MountInProgressDialog implements SmartCardDialogAdapter {
   private final SmartCardBean smartCardBean;
   private final String cardReaderName;
   private final SmartCardCore smartCardCore;
   private final String title;
   private final MountInProgressDialog.CancelAction cancelAction = new MountInProgressDialog.CancelAction();
   private final PropertyChangeListener cardAndReaderStateTracker = new MountInProgressDialog.CardAndReaderStateTracker();
   private final PropertyChangeListener notificationHandler = new MountInProgressDialog.NotificationHandler();
   private final PropertyChangeListener smartCardSessionEventsHandler = new MountInProgressDialog.SmartCardSessionEventsHandler();
   private final boolean autoMode;
   private static final String AUTO_MOUNT_MESSAGE = T._("Mount selected card reader automatically on connection to targets.");
   private static final int DIALOG_WIDTH = 440;
   private JProgressBar progressBar;
   private JCheckBox autoMount;
   private MountInProgressDialog.MountCardReaderWorker worker;
   private final JDialog dlg;

   public MountInProgressDialog(Dialog var1, SmartCardBean var2, SmartCardCore var3, String var4) {
      this.dlg = new JDialog(var1);
      this.title = var1.getTitle();
      this.smartCardBean = var2;
      this.cardReaderName = var4;
      this.smartCardCore = var3;
      this.autoMode = false;
      this.init();
   }

   public MountInProgressDialog(Frame var1, SmartCardBean var2, SmartCardCore var3, String var4) {
      this.dlg = new JDialog(var1);
      this.title = var1.getTitle();
      this.smartCardBean = var2;
      this.cardReaderName = var4;
      this.smartCardCore = var3;
      this.autoMode = true;
      this.init();
   }

   public MountInProgressDialog(JDialog var1, String var2, SmartCardBean var3, SmartCardCore var4, String var5) {
      this.dlg = var1;
      this.title = var2;
      this.smartCardBean = var3;
      this.cardReaderName = var5;
      this.smartCardCore = var4;
      this.autoMode = true;
      this.init();
   }

   private void init() {
      this.dlg.setResizable(false);
      this.dlg.setTitle(MessageFormat.format(T._("Mount {0}"), this.cardReaderName));
      this.dlg.setModal(true);
      this.dlg.setDefaultCloseOperation(0);
      this.dlg.getContentPane().add(this.createContentPanel());
      this.dlg.addWindowListener(new WindowAdapter() {
         @Override
         public void windowClosed(WindowEvent var1) {
            MountInProgressDialog.this.closeAction();
         }

         @Override
         public void windowClosing(WindowEvent var1) {
            MountInProgressDialog.this.cancelAction.actionPerformed(null);
         }
      });
   }

   public void startMounting() {
      assert SwingUtilities.isEventDispatchThread();

      MountInProgressDialog.OkAction var1 = new MountInProgressDialog.OkAction();
      var1.actionPerformed(null);
   }

   @Override
   public void setVisible(boolean var1) {
      if (var1) {
         this.smartCardBean.addPropertyChangeListener("QUIT_NOTIFICATION", this.notificationHandler);
         this.smartCardBean.addPropertyChangeListener("DISCONNECTED", this.smartCardSessionEventsHandler);
         this.smartCardBean.addPropertyChangeListener("CARD_READER_STATUS", this.cardAndReaderStateTracker);
         this.smartCardBean.addPropertyChangeListener("CARD_READER_MOUNTED", this.smartCardSessionEventsHandler);
      }

      this.dlg.setVisible(var1);
   }

   private void closeAction() {
      this.dlg.setVisible(false);
      this.smartCardBean.removePropertyChangeListener("CARD_READER_STATUS", this.cardAndReaderStateTracker);
      this.smartCardBean.removePropertyChangeListener("QUIT_NOTIFICATION", this.notificationHandler);
      this.smartCardBean.removePropertyChangeListener("CARD_READER_MOUNTED", this.smartCardSessionEventsHandler);
      this.smartCardBean.removePropertyChangeListener("DISCONNECTED", this.smartCardSessionEventsHandler);
   }

   public void pack() {
      this.dlg.pack();
   }

   public void dispose() {
      this.dlg.dispose();
   }

   public void setLocationRelativeTo(Component var1) {
      this.dlg.setLocationRelativeTo(var1);
   }

   private JPanel createContentPanel() {
      JPanel var1 = new JPanel() {
         @Override
         public Dimension getPreferredSize() {
            Dimension var1x = super.getPreferredSize();
            return new Dimension(var1x.width > 440 ? var1x.width : 440, var1x.height);
         }
      };
      var1.setLayout(new GridBagLayout());
      GridBagConstraints var2 = new GridBagConstraints();
      var2.gridx = 0;
      var2.gridy = -1;
      var2.gridwidth = 1;
      var2.gridheight = 1;
      var2.weightx = 1.0;
      var2.weighty = 1.0;
      var2.insets = new Insets(10, 10, 0, 10);
      var2.fill = 2;
      JLabel var3 = new JLabel(T._("Progress:"));
      var1.add(var3, var2);
      this.progressBar = new JProgressBar();
      var2.insets = new Insets(5, 10, 0, 10);
      var1.add(this.progressBar, var2);
      if (!this.isAutoMode()) {
         this.autoMount = new JCheckBox(AUTO_MOUNT_MESSAGE);
         this.autoMount.setVerticalTextPosition(1);
         var2.insets = new Insets(10, 10, 0, 10);
         var1.add(this.autoMount, var2);
      }

      var2.insets = new Insets(15, 10, 10, 10);
      var2.fill = 0;
      var2.anchor = 13;
      var1.add(this.createButtonPanel(), var2);
      return var1;
   }

   public JPanel createButtonPanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new GridLayout(1, this.isAutoMode() ? 1 : 2, 5, 0));
      JButton var2 = new JButton(this.cancelAction);
      if (!this.isAutoMode()) {
         JButton var3 = new JButton(new MountInProgressDialog.OkAction());
         var1.add(var3);
         this.dlg.getRootPane().setDefaultButton(var3);
      }

      var1.add(var2);
      return var1;
   }

   private boolean isAutoMode() {
      return this.autoMode;
   }

   private void handleMountFailure() {
      if (this.isAutoMode()) {
         saveNoneAsCardReaderName(this.smartCardBean.getHost());
      }
   }

   static void saveNoneAsCardReaderName(String var0) {
      DevicePrefs var1 = DevicePrefs.getNode(var0);
      if (var1 != null) {
         var1.setCardReaderName(null);
         var1.exportPreferences(var0);
      }
   }

   private class CancelAction extends AbstractAction {
      public CancelAction() {
         super(T._("Cancel"));
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         if (MountInProgressDialog.this.worker != null) {
            MountInProgressDialog.this.worker.setCancelled(true);
            MountInProgressDialog.this.smartCardBean.cancelSession();
            SmartCardReaderDialog.cleanState(MountInProgressDialog.this.smartCardBean);
         }

         MountInProgressDialog.this.dlg.dispose();
      }
   }

   private class CardAndReaderStateTracker implements PropertyChangeListener {
      private CardAndReaderStateTracker() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("CARD_READER_STATUS")) {
            MountInProgressDialog.this.dlg.dispose();
            MountInProgressDialog.this.handleMountFailure();
            MountInProgressDialog.this.smartCardBean
               .errorOrMessage(
                  SmartCardErrorsAndMessagesHandler.ErrorCodes.CARD_READER_DOES_NOT_EXIST,
                  null,
                  MountInProgressDialog.this.dlg.getOwner(),
                  MountInProgressDialog.this.title
               );
         }
      }
   }

   private class MountCardReaderWorker extends SwingWorker {
      private final SmartCardReaderSession session;
      private final SmartCardReaderListener scrl;
      private final NotificationListener nl;
      private final CardAccessErrorsListener cael;
      private final SmartCardSessionEventsListener scsel;
      private final SmartCardBean smartCardBean;
      private boolean cancelled;

      public MountCardReaderWorker(
         SmartCardReaderSession var2,
         SmartCardReaderListener var3,
         NotificationListener var4,
         CardAccessErrorsListener var5,
         SmartCardSessionEventsListener var6,
         SmartCardBean var7
      ) {
         this.session = var2;
         this.cael = var5;
         this.scrl = var3;
         this.scsel = var6;
         this.nl = var4;
         this.smartCardBean = var7;
      }

      @Override
      public Object construct() {
         try {
            this.session.start(this.scrl, this.cael, this.nl, this.scsel, this.smartCardBean.getWorkstationUnlockDetector());
         } catch (SmartCardException var2) {
            return var2;
         } catch (IOException var3) {
            return var3;
         } catch (Exception var4) {
            return var4;
         }

         return this.session;
      }

      @Override
      public void finished() {
         if (!this.isCancelled()) {
            Object var1 = this.get();
            if (var1 instanceof Exception) {
               MountInProgressDialog.this.dlg.dispose();
               SmartCardReaderDialog.cleanState(this.smartCardBean);
               if (var1 instanceof SmartCardIncompatibleProtoException) {
                  this.smartCardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.INCOMPATIBLE_VERSION_OF_DEVICE_PROTOCOL,
                        var1,
                        MountInProgressDialog.this.dlg.getOwner(),
                        MountInProgressDialog.this.title
                     );
               } else if (var1 instanceof IOException) {
                  this.smartCardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.COMMUNICATION_ERROR_OCCURED,
                        var1,
                        MountInProgressDialog.this.dlg.getOwner(),
                        MountInProgressDialog.this.title
                     );
               } else {
                  this.smartCardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.UNKNOWN_ERROR,
                        var1,
                        MountInProgressDialog.this.dlg.getOwner(),
                        MountInProgressDialog.this.title
                     );
               }
            }
         }
      }

      private boolean isCancelled() {
         return this.cancelled;
      }

      private void setCancelled(boolean var1) {
         this.cancelled = var1;
      }
   }

   private class NotificationHandler implements PropertyChangeListener {
      private NotificationHandler() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("QUIT_NOTIFICATION")) {
            MountInProgressDialog.this.dlg.dispose();
            MountInProgressDialog.this.smartCardBean
               .notificationReceived((NotificationEvent)var1.getNewValue(), MountInProgressDialog.this.dlg.getOwner(), MountInProgressDialog.this.title);
         }
      }
   }

   private class OkAction extends AbstractAction {
      public OkAction() {
         super(T._("OK"));
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         this.setEnabled(false);
         MountInProgressDialog.this.progressBar.setIndeterminate(true);
         MountInProgressDialog.this.smartCardBean.setCardReaderName(MountInProgressDialog.this.cardReaderName);
         if (!MountInProgressDialog.this.isAutoMode()) {
            MountInProgressDialog.this.autoMount.setEnabled(false);
         }

         SmartCardReaderSession var2;
         if (MountInProgressDialog.this.smartCardBean.getRdmSession() != null) {
            var2 = MountInProgressDialog.this.smartCardCore
               .createCardReaderSessionWithRdmSessionID(
                  MountInProgressDialog.this.cardReaderName,
                  MountInProgressDialog.this.smartCardBean.getHost(),
                  MountInProgressDialog.this.smartCardBean.getPort(),
                  MountInProgressDialog.this.smartCardBean.isSslMode(),
                  MountInProgressDialog.this.smartCardBean.getRfbSessionId(),
                  MountInProgressDialog.this.smartCardBean.getMsindex(),
                  MountInProgressDialog.this.smartCardBean.getRdmSession(),
                  MountInProgressDialog.this.smartCardBean.getTag()
               );
         } else {
            var2 = MountInProgressDialog.this.smartCardCore
               .createCardReaderSessionWithEricKey(
                  MountInProgressDialog.this.cardReaderName,
                  MountInProgressDialog.this.smartCardBean.getHost(),
                  MountInProgressDialog.this.smartCardBean.getPort(),
                  MountInProgressDialog.this.smartCardBean.isSslMode(),
                  MountInProgressDialog.this.smartCardBean.getRfbSessionId(),
                  MountInProgressDialog.this.smartCardBean.getMsindex(),
                  MountInProgressDialog.this.smartCardBean.getEricKey(),
                  MountInProgressDialog.this.smartCardBean.getTag()
               );
         }

         MountInProgressDialog.this.smartCardBean.setTransientSession(var2);
         MountInProgressDialog.this.worker = MountInProgressDialog.this.new MountCardReaderWorker(
            var2,
            MountInProgressDialog.this.smartCardBean.getNewSmartCardReaderListener(var2),
            MountInProgressDialog.this.smartCardBean.getNewNotificationListener(var2),
            MountInProgressDialog.this.smartCardBean.getNewCardAccessErrorsListener(var2),
            MountInProgressDialog.this.smartCardBean.getNewSmartCardSessionEventsListener(var2),
            MountInProgressDialog.this.smartCardBean
         );
         MountInProgressDialog.this.worker.start();
      }
   }

   private class SmartCardSessionEventsHandler implements PropertyChangeListener {
      private SmartCardSessionEventsHandler() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("CARD_READER_MOUNTED")) {
            MountInProgressDialog.this.dlg.dispose();
            MountInProgressDialog.this.smartCardBean.setSession(MountInProgressDialog.this.smartCardBean.getTransientSession());
            MountInProgressDialog.this.worker = null;
            if (!MountInProgressDialog.this.isAutoMode()) {
               DevicePrefs var2 = DevicePrefs.getNode(MountInProgressDialog.this.smartCardBean.getHost());
               if (MountInProgressDialog.this.autoMount.isSelected()) {
                  if (var2 == null) {
                     var2 = new DevicePrefs();
                  }

                  var2.setCardReaderName(MountInProgressDialog.this.smartCardBean.getCardReaderName());
                  var2.exportPreferences(MountInProgressDialog.this.smartCardBean.getHost());
               } else if (var2 != null && var2.getCardReaderName() != null) {
                  var2.setCardReaderName(null);
                  var2.exportPreferences(MountInProgressDialog.this.smartCardBean.getHost());
               }
            }
         } else if (var1.getPropertyName().equals("DISCONNECTED")) {
            MountInProgressDialog.this.dlg.dispose();
            Object var3 = var1.getNewValue();
            if (var3 != null) {
               if (var3 instanceof IOException) {
                  MountInProgressDialog.this.smartCardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.COMMUNICATION_ERROR_OCCURED,
                        var3,
                        MountInProgressDialog.this.dlg.getOwner(),
                        MountInProgressDialog.this.title
                     );
               } else {
                  MountInProgressDialog.this.smartCardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.UNKNOWN_ERROR,
                        var3,
                        MountInProgressDialog.this.dlg.getOwner(),
                        MountInProgressDialog.this.title
                     );
               }
            }
         }
      }
   }
}
