package nn.pp.common.smartcard;

import com.raritan.smartcard.CardAccessErrorsListener;
import com.raritan.smartcard.SmartCardReaderListener;
import com.raritan.smartcard.SmartCardReaderSession;
import com.raritan.smartcard.SmartCardSessionEventsListener;
import java.awt.Window;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.HashMap;
import java.util.Map;
import java.util.Stack;
import javax.swing.JDialog;
import javax.swing.SwingUtilities;
import nn.pp.core.INotificationEvent;
import nn.pp.core.NotificationEvent;
import nn.pp.core.NotificationListener;
import nn.pp.core.WorkstationUnlockDetector;

public class SmartCardBean implements SmartCardErrorsAndMessagesHandler {
   public static final String PROPERTY_CARD_READER_MOUNTED = "CARD_READER_MOUNTED";
   public static final String PROPERTY_CARD_STATUS = "CARD_CARD_STATUS";
   public static final String PROPERTY_CARD_READER_SESSION = "CARD_READER_SESSION";
   public static final String PROPERTY_QUIT_ISSUED = "QUIT_ISSUED";
   public static final String PROPERTY_CANCEL_ISSUED = "CANCEL_ISSUED";
   public static final String PROPERTY_QUIT_NOTIFICATION_FROM_SERVER = "QUIT_NOTIFICATION";
   public static final String PROPERTY_DISCONNECTED = "DISCONNECTED";
   public static final String PROPERTY_CARD_READER_STATUS = "CARD_READER_STATUS";
   public static final String PROPERTY_NO_PROTO_SPPORTED = "NO_PROTO_SPPORTED";
   public static final String PROPERTY_NOTIFICATION_FROM_SERVER = "NOTIFICATION_FROM_SERVER";
   private final String host;
   private final int port;
   private final boolean sslMode;
   private final String rdmSession;
   private final String ericKey;
   private final WorkstationUnlockDetector workstationUnlockDetector;
   private int rfbSessionId;
   private int msindex;
   private String tag;
   private SmartCardReaderSession session;
   private SmartCardReaderSession transientSession;
   private JDialog statusDialog;
   private String cardReaderName;
   private final PropertyChangeSupport propChangeSupport;
   private SmartCardBean.Scrl scrl;
   private NotificationListener nl;
   private SmartCardSessionEventsListener scsel;
   private CardAccessErrorsListener cael;
   private Map<String, Stack<PropertyChangeListener>> listeners = new HashMap<>();
   private final SmartCardErrorsAndMessagesHandler smartCardErrorsAndMessagesHandler;

   public SmartCardBean(String var1, int var2, boolean var3, String var4, String var5, SmartCardErrorsAndMessagesHandler var6, WorkstationUnlockDetector var7) {
      this.host = var1;
      this.port = var2;
      this.sslMode = var3;
      this.rdmSession = var4;
      this.ericKey = var5;
      this.smartCardErrorsAndMessagesHandler = var6;
      this.workstationUnlockDetector = var7;
      this.propChangeSupport = new PropertyChangeSupport(this);
      this.propChangeSupport.addPropertyChangeListener(new SmartCardBean.LastInNotifier());
   }

   public SmartCardReaderSession getSession() {
      return this.session;
   }

   public void quitSession() {
      assert SwingUtilities.isEventDispatchThread();

      SmartCardReaderSession var1 = this.getSession();
      if (var1 != null) {
         this.setSession(null);
         var1.close();
         this.propChangeSupport.firePropertyChange("QUIT_ISSUED", null, "Quit");
      }
   }

   public void cancelSession() {
      assert SwingUtilities.isEventDispatchThread();

      SmartCardReaderSession var1 = this.getTransientSession();
      this.setTransientSession(null);
      var1.close();
      this.propChangeSupport.firePropertyChange("CANCEL_ISSUED", null, "Cancel");
   }

   public void setSession(SmartCardReaderSession var1) {
      if (var1 != this.session) {
         this.setTransientSession(null);
         SmartCardReaderSession var2 = this.session;
         this.session = var1;
         this.propChangeSupport.firePropertyChange("CARD_READER_SESSION", var2, this.session);
      }
   }

   public void setCardReaderName(String var1) {
      this.cardReaderName = var1;
   }

   public String getCardReaderName() {
      return this.cardReaderName;
   }

   public String getHost() {
      return this.host;
   }

   public int getPort() {
      return this.port;
   }

   public boolean isSslMode() {
      return this.sslMode;
   }

   public int getRfbSessionId() {
      return this.rfbSessionId;
   }

   public int getMsindex() {
      return this.msindex;
   }

   public String getRdmSession() {
      return this.rdmSession;
   }

   public String getEricKey() {
      return this.ericKey;
   }

   public String getTag() {
      return this.tag;
   }

   public JDialog getStatusDialog() {
      return this.statusDialog;
   }

   public void setStatusDialog(JDialog var1) {
      this.statusDialog = var1;
   }

   public void addPropertyChangeListener(String var1, PropertyChangeListener var2) {
      if (!var1.equals("QUIT_NOTIFICATION")
         && !var1.equals("NOTIFICATION_FROM_SERVER")
         && !var1.equals("DISCONNECTED")
         && !var1.equals("NO_PROTO_SPPORTED")
         && !var1.equals("CARD_READER_STATUS")) {
         this.propChangeSupport.addPropertyChangeListener(var1, var2);
      } else {
         Stack var3 = this.listeners.get(var1);
         if (var3 == null) {
            var3 = new Stack();
            this.listeners.put(var1, var3);
         }

         var3.push(var2);
      }
   }

   public void removePropertyChangeListener(String var1, PropertyChangeListener var2) {
      if (!var1.equals("QUIT_NOTIFICATION")
         && !var1.equals("NOTIFICATION_FROM_SERVER")
         && !var1.equals("DISCONNECTED")
         && !var1.equals("NO_PROTO_SPPORTED")
         && !var1.equals("CARD_READER_STATUS")) {
         this.propChangeSupport.removePropertyChangeListener(var1, var2);
      } else {
         Stack var3 = this.listeners.get(var1);
         if (var3 != null) {
            var3.remove(var2);
            if (var3.isEmpty()) {
               this.listeners.remove(var1);
            }
         }
      }
   }

   public SmartCardReaderListener getNewSmartCardReaderListener(SmartCardReaderSession var1) {
      this.scrl = new SmartCardBean.Scrl(var1);
      return this.scrl;
   }

   public NotificationListener getNewNotificationListener(SmartCardReaderSession var1) {
      this.nl = new SmartCardBean.Nl(var1);
      return this.nl;
   }

   public SmartCardSessionEventsListener getNewSmartCardSessionEventsListener(SmartCardReaderSession var1) {
      this.scsel = new SmartCardBean.Scsel(var1);
      return this.scsel;
   }

   public CardAccessErrorsListener getNewCardAccessErrorsListener(SmartCardReaderSession var1) {
      this.cael = new SmartCardBean.Cael(var1);
      return this.cael;
   }

   public void resetSmartCardReaderListener() {
      this.scrl = null;
   }

   public void resetNotificationListener() {
      this.nl = null;
   }

   public void resetSmartCardSessionEventsListener() {
      this.scsel = null;
   }

   public void resetCardAccessErrorsListener() {
      this.cael = null;
   }

   public boolean isCardInserted() {
      return this.scrl != null ? this.scrl.isCardInserted() : false;
   }

   private boolean isCorrectSessionToFireListener(SmartCardReaderSession var1) {
      return var1 == this.getSession() || var1 == this.getTransientSession();
   }

   public void setRfbSessionId(int var1) {
      this.rfbSessionId = var1;
   }

   public void setMsindex(int var1) {
      this.msindex = var1;
   }

   public void setTag(String var1) {
      this.tag = var1;
   }

   @Override
   public void errorOrMessage(SmartCardErrorsAndMessagesHandler.ErrorCodes var1, Object var2, Window var3, String var4) {
      this.smartCardErrorsAndMessagesHandler.errorOrMessage(var1, var2, var3, var4);
   }

   @Override
   public void notificationReceived(NotificationEvent var1, Window var2, String var3) {
      this.smartCardErrorsAndMessagesHandler.notificationReceived(var1, var2, var3);
   }

   SmartCardReaderSession getTransientSession() {
      return this.transientSession;
   }

   void setTransientSession(SmartCardReaderSession var1) {
      this.transientSession = var1;
   }

   @Override
   public String toString() {
      return "host : " + this.host + " port : " + this.port + " msindex : " + this.msindex + " rfbSessionId : " + this.rfbSessionId;
   }

   public WorkstationUnlockDetector getWorkstationUnlockDetector() {
      return this.workstationUnlockDetector;
   }

   private class Cael implements CardAccessErrorsListener {
      private final SmartCardReaderSession owningSession;

      public Cael(SmartCardReaderSession var2) {
         this.owningSession = var2;
      }

      @Override
      public void errorOnAccessingCard(String var1) {
      }

      @Override
      public void noProtocolSupported(String var1) {
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            SmartCardBean.this.propChangeSupport.firePropertyChange("NO_PROTO_SPPORTED", null, var1);
         }
      }
   }

   private class LastInNotifier implements PropertyChangeListener {
      private LastInNotifier() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         String var2 = var1.getPropertyName();
         SmartCardReaderSession var3 = SmartCardBean.this.getSession();
         SmartCardReaderSession var4 = SmartCardBean.this.getTransientSession();
         if (var2.equals("QUIT_NOTIFICATION")
            || var2.equals("DISCONNECTED")
            || var2.equals("QUIT_ISSUED")
            || var2.equals("CANCEL_ISSUED")
            || var2.equals("CARD_READER_STATUS")) {
            SmartCardBean.this.setCardReaderName(null);
            SmartCardBean.this.setSession(null);
            SmartCardBean.this.setTransientSession(null);
            SmartCardBean.this.resetSmartCardReaderListener();
            SmartCardBean.this.resetNotificationListener();
            SmartCardBean.this.resetSmartCardSessionEventsListener();
            SmartCardBean.this.resetCardAccessErrorsListener();
         }

         if ((var3 != null || var4 != null)
            && (
               var2.equals("QUIT_NOTIFICATION")
                  || var2.equals("NOTIFICATION_FROM_SERVER")
                  || var2.equals("DISCONNECTED")
                  || var2.equals("NO_PROTO_SPPORTED")
                  || var2.equals("CARD_READER_STATUS")
            )) {
            Stack var5 = SmartCardBean.this.listeners.get(var2);
            if (var5 != null) {
               ((PropertyChangeListener)var5.peek()).propertyChange(var1);
            }
         }
      }
   }

   private class Nl implements NotificationListener {
      private final SmartCardReaderSession owningSession;

      public Nl(SmartCardReaderSession var2) {
         this.owningSession = var2;
      }

      @Override
      public void receivedNotification(INotificationEvent var1) {
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            if (!var1.isQuit() && !var1.isError()) {
               SmartCardBean.this.propChangeSupport.firePropertyChange("NOTIFICATION_FROM_SERVER", null, var1);
            } else {
               SmartCardBean.this.propChangeSupport.firePropertyChange("QUIT_NOTIFICATION", null, var1);
            }
         }
      }

      @Override
      public void textNotification(String var1) {
      }
   }

   private class Scrl implements SmartCardReaderListener {
      private boolean cardInserted;
      private boolean cardReaderRemoved;
      private final SmartCardReaderSession owningSession;

      public Scrl(SmartCardReaderSession var2) {
         this.owningSession = var2;
      }

      @Override
      public void cardInserted(String var1) {
         this.cardInserted = true;
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            SmartCardBean.this.propChangeSupport.firePropertyChange("CARD_CARD_STATUS", false, true);
         }
      }

      @Override
      public void cardReaderRemoved(String var1) {
         this.cardReaderRemoved = true;
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            SmartCardBean.this.propChangeSupport.firePropertyChange("CARD_READER_STATUS", true, false);
         }
      }

      @Override
      public void cardRemoved(String var1) {
         this.cardInserted = false;
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            SmartCardBean.this.propChangeSupport.firePropertyChange("CARD_CARD_STATUS", true, false);
         }
      }

      public boolean isCardInserted() {
         return !this.cardReaderRemoved ? this.cardInserted : false;
      }
   }

   private class Scsel implements SmartCardSessionEventsListener {
      private final SmartCardReaderSession owningSession;

      public Scsel(SmartCardReaderSession var2) {
         this.owningSession = var2;
      }

      @Override
      public void cardReaderMounted(String var1) {
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            SmartCardBean.this.propChangeSupport.firePropertyChange("CARD_READER_MOUNTED", null, var1);
         }
      }

      @Override
      public void disconnected(Exception var1) {
         if (SmartCardBean.this.isCorrectSessionToFireListener(this.owningSession)) {
            SmartCardBean.this.propChangeSupport.firePropertyChange("DISCONNECTED", null, var1);
         }
      }
   }
}
