package nn.pp.common.smartcard;

import com.raritan.smartcard.SmartCardCore;
import com.raritan.smartcard.SmartCardReaderSession;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import javax.swing.AbstractAction;
import javax.swing.AbstractListModel;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.KeyStroke;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import nn.pp.core.NotificationEvent;
import nn.pp.core.T;

public class SmartCardReaderDialog implements SmartCardDialogAdapter {
   private static final String NONE_SELECTED = T._("None");
   private static final String vmLimitationMessage = "<html><font color=\"#0000ff\"><b><i>"
      + T._("Connecting a Card Reader limits Virtual Media to one Mass Storage Device.")
      + "<br>"
      + T._("Also, if you intend on mounting Virtual Media or Audio, do so before connecting Card Reader.")
      + "<i/></b></font></html>";
   private final JLabel selectedCardReader = new JLabel(NONE_SELECTED) {
      @Override
      public void setText(String var1) {
         super.setText(var1);
         this.setToolTipText(var1);
      }
   };
   private final JList cardReaderList = new JList();
   private final JButton refreshButton = new JButton();
   private final SmartCardCore smartCardCore;
   private final PropertyChangeListener mountUnmountListener = new SmartCardReaderDialog.CardReaderMountUnMountListener();
   private final PropertyChangeListener cardAndReaderStateTracker = new SmartCardReaderDialog.CardAndReaderStateTracker();
   private final PropertyChangeListener notificationHandler = new SmartCardReaderDialog.NotificationHandler();
   private final PropertyChangeListener smartCardSessionEventsHandler = new SmartCardReaderDialog.SmartCardSessionEventsHandler();
   private final PropertyChangeListener cardAccessErrorHandler = new SmartCardReaderDialog.CardAccessErrorHandler();
   private final SmartCardReaderDialog.RemoveReinsertAction removeReinsertAction = new SmartCardReaderDialog.RemoveReinsertAction();
   private final SmartCardReaderDialog.MountAction mountAction = new SmartCardReaderDialog.MountAction();
   private SmartCardBean smartcardBean;
   private final JDialog dlg;
   private AbstractAction closeAction = new AbstractAction(T._("Close")) {
      @Override
      public void actionPerformed(ActionEvent var1) {
         SmartCardReaderDialog.this.closeAction();
      }
   };
   private AbstractAction refreshAction = new AbstractAction(T._("Refresh List")) {
      @Override
      public void actionPerformed(ActionEvent var1) {
         SmartCardReaderDialog.this.loadCardReaders();
      }
   };
   private AbstractAction unmountAction = new AbstractAction(T._("Un-Mount")) {
      @Override
      public void actionPerformed(ActionEvent var1) {
         SmartCardReaderDialog.this.smartcardBean.quitSession();
         MountInProgressDialog.saveNoneAsCardReaderName(SmartCardReaderDialog.this.smartcardBean.getHost());
      }
   };

   public SmartCardReaderDialog(Frame var1, SmartCardCore var2) {
      this.dlg = new JDialog(var1, T._("Select Card Reader"));
      this.smartCardCore = var2;
      this.init();
   }

   public SmartCardReaderDialog(JDialog var1, SmartCardCore var2) {
      this.dlg = var1;
      this.dlg.setTitle(T._("Select Card Reader"));
      this.smartCardCore = var2;
      this.init();
   }

   private void init() {
      this.dlg.setModal(true);
      this.dlg.setResizable(false);
      this.dlg.setDefaultCloseOperation(0);
      this.dlg.addWindowListener(new WindowAdapter() {
         @Override
         public void windowClosing(WindowEvent var1) {
            SmartCardReaderDialog.this.closeAction();
         }
      });
      this.addComponents();
      this.cardReaderList.addListSelectionListener(new ListSelectionListener() {
         @Override
         public void valueChanged(ListSelectionEvent var1) {
            SmartCardReaderDialog.this.mountAction.setCardReaderName((String)SmartCardReaderDialog.this.cardReaderList.getSelectedValue());
         }
      });
   }

   private void addComponents() {
      this.dlg.getContentPane().add(this.createTopPanel());
      ((JComponent)this.dlg.getContentPane()).getInputMap(2).put(KeyStroke.getKeyStroke(27, 0), "SmartCardReaderDialogClose");
      ((JComponent)this.dlg.getContentPane()).getActionMap().put("SmartCardReaderDialogClose", this.closeAction);
   }

   private JPanel createTopPanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new GridBagLayout());
      GridBagConstraints var2 = new GridBagConstraints();
      var2.gridx = 0;
      var2.gridy = 0;
      var2.gridwidth = 1;
      var2.gridheight = 1;
      var2.weightx = 1.0;
      var2.weighty = 1.0;
      var2.insets = new Insets(10, 10, 0, 10);
      var2.fill = 2;
      this.selectedCardReader
         .setBorder(
            BorderFactory.createCompoundBorder(
               BorderFactory.createTitledBorder(T._("Card Reader Currently Mounted")), BorderFactory.createEmptyBorder(5, 5, 5, 5)
            )
         );
      var1.add(this.selectedCardReader, var2);
      final JScrollPane var3 = new JScrollPane(this.cardReaderList);
      final JPanel var4 = this.createButtonPanel();
      JPanel var5 = new JPanel() {
         @Override
         public Dimension getPreferredSize() {
            Dimension var1x = super.getPreferredSize();
            return new Dimension(var4.getPreferredSize().width, var1x.height + var3.getHorizontalScrollBar().getPreferredSize().height);
         }
      };
      var5.setBorder(
         BorderFactory.createCompoundBorder(BorderFactory.createTitledBorder(T._("Card Readers Detected")), BorderFactory.createEmptyBorder(5, 5, 5, 5))
      );
      var5.setLayout(new GridBagLayout());
      GridBagConstraints var6 = new GridBagConstraints();
      var6.weightx = 1.0;
      var6.weighty = 1.0;
      var6.fill = 1;
      var5.add(var3, var6);
      this.cardReaderList.setVisibleRowCount(8);
      this.cardReaderList.setModel(new SmartCardReaderDialog.CardReadersListModel(Arrays.asList("M")));
      this.cardReaderList.setSelectionMode(0);
      var2.gridy = 1;
      var1.add(var5, var2);
      var2.gridy = 2;
      var2.insets = new Insets(15, 10, 0, 10);
      var1.add(new JLabel(vmLimitationMessage), var2);
      var2.gridy = 3;
      var2.insets = new Insets(15, 10, 10, 10);
      var2.fill = 0;
      var2.anchor = 13;
      var1.add(var4, var2);
      return var1;
   }

   public JPanel createButtonPanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new GridLayout(1, 5, 5, 0));
      JButton var2 = new JButton();
      var2.setAction(this.mountAction);
      this.refreshButton.setAction(this.refreshAction);
      JButton var3 = new JButton();
      var3.setAction(this.removeReinsertAction);
      JButton var4 = new JButton();
      var4.setAction(this.unmountAction);
      JButton var5 = new JButton();
      var5.setAction(this.closeAction);
      var1.add(var2);
      var1.add(this.refreshButton);
      var1.add(var3);
      var1.add(var4);
      var1.add(var5);
      this.dlg.getRootPane().setDefaultButton(var2);
      return var1;
   }

   @Override
   public void setVisible(boolean var1) {
      if (var1) {
         this.loadCardReaders();
         this.smartcardBean.addPropertyChangeListener("CARD_READER_SESSION", this.mountUnmountListener);
         this.enableDisableOnMountUnMount(this.smartcardBean.getSession());
         this.smartcardBean.addPropertyChangeListener("CARD_CARD_STATUS", this.cardAndReaderStateTracker);
         this.removeReinsertAction.setCardInserted(this.smartcardBean.isCardInserted());
         this.smartcardBean.addPropertyChangeListener("QUIT_NOTIFICATION", this.notificationHandler);
         this.smartcardBean.addPropertyChangeListener("NOTIFICATION_FROM_SERVER", this.notificationHandler);
         this.smartcardBean.addPropertyChangeListener("DISCONNECTED", this.smartCardSessionEventsHandler);
         this.smartcardBean.addPropertyChangeListener("NO_PROTO_SPPORTED", this.cardAccessErrorHandler);
         this.dlg.setLocationRelativeTo(this.dlg.getOwner());
         if (this.cardReaderList.getModel().getSize() > 0) {
            this.cardReaderList.requestFocus();
         } else {
            this.refreshButton.requestFocus();
         }
      }

      this.dlg.setVisible(var1);
   }

   public void pack() {
      this.dlg.pack();
   }

   public void dispose() {
      this.dlg.dispose();
   }

   private void closeAction() {
      this.smartcardBean.removePropertyChangeListener("CARD_READER_SESSION", this.mountUnmountListener);
      this.smartcardBean.removePropertyChangeListener("CARD_CARD_STATUS", this.cardAndReaderStateTracker);
      this.smartcardBean.removePropertyChangeListener("QUIT_NOTIFICATION", this.notificationHandler);
      this.smartcardBean.removePropertyChangeListener("NOTIFICATION_FROM_SERVER", this.notificationHandler);
      this.smartcardBean.removePropertyChangeListener("DISCONNECTED", this.smartCardSessionEventsHandler);
      this.smartcardBean.removePropertyChangeListener("NO_PROTO_SPPORTED", this.cardAccessErrorHandler);
      this.smartcardBean = null;
      this.setVisible(false);
   }

   private void loadCardReaders() {
      List var1 = this.smartCardCore.getAvailableSmartCardReaders();
      this.cardReaderList.setModel(new SmartCardReaderDialog.CardReadersListModel(var1));
      if (this.cardReaderList.getModel().getSize() > 0) {
         this.cardReaderList.setSelectedIndex(0);
      }
   }

   private void enableDisableOnMountUnMount(SmartCardReaderSession var1) {
      boolean var2 = var1 != null;
      this.unmountAction.setEnabled(var2);
      this.removeReinsertAction.setMounted(var2);
      this.mountAction.setMounted(var2);
      if (var2) {
         this.selectedCardReader.setText(this.smartcardBean.getCardReaderName());
      } else {
         this.selectedCardReader.setText(NONE_SELECTED);
         this.enableDisableOnCardStatus(false);
      }
   }

   private void enableDisableOnCardStatus(boolean var1) {
      this.removeReinsertAction.setCardInserted(var1);
   }

   public void setSmartcardBean(SmartCardBean var1) {
      this.smartcardBean = var1;
   }

   static void cleanState(SmartCardBean var0) {
      var0.setTransientSession(null);
      var0.setCardReaderName(null);
      var0.resetSmartCardReaderListener();
      var0.resetNotificationListener();
      var0.resetSmartCardSessionEventsListener();
      var0.resetCardAccessErrorsListener();
   }

   private class CardAccessErrorHandler implements PropertyChangeListener {
      private CardAccessErrorHandler() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("NO_PROTO_SPPORTED")) {
            SmartCardReaderDialog.this.smartcardBean
               .errorOrMessage(
                  SmartCardErrorsAndMessagesHandler.ErrorCodes.NO_SUPPORTED_PROTOCOL,
                  null,
                  SmartCardReaderDialog.this.dlg,
                  SmartCardReaderDialog.this.dlg.getTitle()
               );
         }
      }
   }

   private class CardAndReaderStateTracker implements PropertyChangeListener {
      private CardAndReaderStateTracker() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("CARD_CARD_STATUS")) {
            SmartCardReaderDialog.this.enableDisableOnCardStatus((Boolean)var1.getNewValue());
         }
      }
   }

   private class CardReaderMountUnMountListener implements PropertyChangeListener {
      private CardReaderMountUnMountListener() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("CARD_READER_SESSION")) {
            SmartCardReaderDialog.this.enableDisableOnMountUnMount((SmartCardReaderSession)var1.getNewValue());
         }
      }
   }

   private static class CardReadersListModel extends AbstractListModel {
      private final List<String> cardReaders;

      public CardReadersListModel(List<String> var1) {
         Collections.sort(var1);
         this.cardReaders = var1;
      }

      @Override
      public Object getElementAt(int var1) {
         return this.cardReaders.get(var1);
      }

      @Override
      public int getSize() {
         int var1 = this.cardReaders.size();
         return var1 > 8 ? 8 : var1;
      }
   }

   private class MountAction extends AbstractAction {
      private boolean mounted;
      private String cardReaderName;

      public MountAction() {
         super(T._("Mount..."));
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         MountInProgressDialog var2 = new MountInProgressDialog(
            SmartCardReaderDialog.this.dlg, SmartCardReaderDialog.this.smartcardBean, SmartCardReaderDialog.this.smartCardCore, this.cardReaderName
         );
         var2.pack();
         var2.setLocationRelativeTo(SmartCardReaderDialog.this.dlg);
         var2.setVisible(true);
         var2.dispose();
      }

      public void setMounted(boolean var1) {
         this.mounted = var1;
         this.evaluateEnbled();
      }

      public void setCardReaderName(String var1) {
         this.cardReaderName = var1;
         this.evaluateEnbled();
      }

      private void evaluateEnbled() {
         this.setEnabled(!this.mounted && this.cardReaderName != null);
      }
   }

   private class NotificationHandler implements PropertyChangeListener {
      private NotificationHandler() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("QUIT_NOTIFICATION") || var1.getPropertyName().equals("NOTIFICATION_FROM_SERVER")) {
            SmartCardReaderDialog.this.smartcardBean
               .notificationReceived((NotificationEvent)var1.getNewValue(), SmartCardReaderDialog.this.dlg, SmartCardReaderDialog.this.dlg.getTitle());
         }
      }
   }

   private class RemoveReinsertAction extends AbstractAction {
      private boolean mounted;
      private boolean cardInserted;

      public RemoveReinsertAction() {
         super(T._("Remove/Reinsert Card"));
      }

      @Override
      public void actionPerformed(ActionEvent var1) {
         SmartCardReaderDialog.this.smartcardBean.getSession().simulateRemoveAndReinsert();
      }

      public void setMounted(boolean var1) {
         this.mounted = var1;
         this.evaluateEnabled();
      }

      public void setCardInserted(boolean var1) {
         this.cardInserted = var1;
         this.evaluateEnabled();
      }

      private void evaluateEnabled() {
         this.setEnabled(this.mounted && this.cardInserted);
      }
   }

   private class SmartCardSessionEventsHandler implements PropertyChangeListener {
      private SmartCardSessionEventsHandler() {
      }

      @Override
      public void propertyChange(PropertyChangeEvent var1) {
         if (var1.getPropertyName().equals("DISCONNECTED")) {
            Object var2 = var1.getNewValue();
            if (var2 != null) {
               if (var2 instanceof IOException) {
                  SmartCardReaderDialog.this.smartcardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.COMMUNICATION_ERROR_OCCURED,
                        var2,
                        SmartCardReaderDialog.this.dlg,
                        SmartCardReaderDialog.this.dlg.getTitle()
                     );
               } else {
                  SmartCardReaderDialog.this.smartcardBean
                     .errorOrMessage(
                        SmartCardErrorsAndMessagesHandler.ErrorCodes.UNKNOWN_ERROR,
                        var2,
                        SmartCardReaderDialog.this.dlg,
                        SmartCardReaderDialog.this.dlg.getTitle()
                     );
               }
            }
         }
      }
   }
}
