package nn.pp.common.ui;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GraphicsDevice;
import java.awt.GraphicsEnvironment;
import java.awt.Insets;
import java.awt.Rectangle;
import java.awt.Stroke;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;

public class MonitorDisplayer extends JPanel {
   private MonitorDisplayer.MonitorDisplayerModel model;
   private int ratio;
   private List<MonitorDisplayer.GDWithPad> xSortedList;
   private List<MonitorDisplayer.GDWithPad> ySortedList;
   private static final int PRIMARY_SCREEN_WIDTH_SIZE = 60;
   private static final Insets INSET = new Insets(10, 10, 10, 10);
   private static final int MONITOR_PAD = 8;
   private static final MonitorDisplayer.GDComparator GDXCOMPARATOR = new MonitorDisplayer.GDComparator(true);
   private static final MonitorDisplayer.GDComparator GDYCOMPARATOR = new MonitorDisplayer.GDComparator(false);
   private static final int STROKE_SIZE = 2;
   private static final BasicStroke SELECTED_PAINTER = new BasicStroke(2.0F);
   private static final String alphabets = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";

   public MonitorDisplayer(MonitorDisplayer.MonitorDisplayerModel var1) {
      this.setModel0(var1);
      this.setBackground(Color.WHITE);
   }

   private void setModel0(MonitorDisplayer.MonitorDisplayerModel var1) {
      this.model = var1;
      GraphicsDevice var2 = var1.getDefaultScreenDevice();
      int var3 = var2.getDefaultConfiguration().getBounds().width;
      this.ratio = var3 / 60;
      ArrayList var4 = new ArrayList();
      int var5 = 0;

      for (GraphicsDevice var7 : var1.getGraphicsDevices()) {
         var4.add(new MonitorDisplayer.GDWithPad(var7, "" + getDisplayAlphabet(var5)));
         var5++;
      }

      this.xSortedList = getSortedGraphicsDevices(var4, GDXCOMPARATOR);
      this.ySortedList = getSortedGraphicsDevices(var4, GDYCOMPARATOR);
      int var11 = 0;

      for (int var10 : getXPad(this.xSortedList)) {
         this.xSortedList.get(var11++).setPadX(var10);
      }

      var11 = 0;

      for (int var17 : getYPad(this.ySortedList)) {
         this.ySortedList.get(var11++).setPadY(var17);
      }

      this.setPreferredSize(getPreferredSize(this.ratio, this.xSortedList, this.ySortedList));
   }

   public void setModel(MonitorDisplayer.MonitorDisplayerModel var1) {
      this.setModel0(var1);
      this.revalidate();
      this.repaint();
   }

   private static Dimension getPreferredSize(int var0, List<MonitorDisplayer.GDWithPad> var1, List<MonitorDisplayer.GDWithPad> var2) {
      Rectangle var3 = new Rectangle();

      for (MonitorDisplayer.GDWithPad var5 : var1) {
         var3 = var3.union(var5.getGd().getDefaultConfiguration().getBounds());
      }

      int var8 = var3.width / var0;
      int var10 = var3.height / var0;
      var8 += INSET.left + INSET.right;
      var10 += INSET.top + INSET.bottom;

      for (MonitorDisplayer.GDWithPad var7 : var1) {
         var8 += var7.getPadX();
      }

      for (MonitorDisplayer.GDWithPad var13 : var2) {
         var10 += var13.getPadY();
      }

      return new Dimension(var8, var10);
   }

   private static int[] getXPad(List<MonitorDisplayer.GDWithPad> var0) {
      int var1 = 0;
      int[] var2 = new int[var0.size()];

      for (int var3 = 0; var3 < var0.size(); var3++) {
         MonitorDisplayer.GDWithPad var4 = (MonitorDisplayer.GDWithPad)var0.get(var3);
         if (var3 == 0) {
            Rectangle var9 = var4.getGd().getDefaultConfiguration().getBounds();
            var1 = var9.x < 0 ? Math.abs(var9.x) : 0;
         } else {
            Rectangle var5 = var4.getGd().getDefaultConfiguration().getBounds();
            int var6 = -1;

            for (int var7 = 0; var7 < var3; var7++) {
               Rectangle var8 = ((MonitorDisplayer.GDWithPad)var0.get(var7)).getGd().getDefaultConfiguration().getBounds();
               if (var5.x + var1 == var8.width + var8.x + var1) {
                  var6 = var6 < var2[var7] ? var2[var7] : var6;
               }
            }

            if (var6 != -1) {
               var2[var3] = 8 + var6;
            }
         }
      }

      return var2;
   }

   private static int[] getYPad(List<MonitorDisplayer.GDWithPad> var0) {
      int var1 = 0;
      int[] var2 = new int[var0.size()];

      for (int var3 = 0; var3 < var0.size(); var3++) {
         MonitorDisplayer.GDWithPad var4 = (MonitorDisplayer.GDWithPad)var0.get(var3);
         if (var3 == 0) {
            Rectangle var9 = var4.getGd().getDefaultConfiguration().getBounds();
            var1 = var9.y < 0 ? Math.abs(var9.y) : 0;
         } else {
            Rectangle var5 = var4.getGd().getDefaultConfiguration().getBounds();
            int var6 = -1;

            for (int var7 = 0; var7 < var3; var7++) {
               Rectangle var8 = ((MonitorDisplayer.GDWithPad)var0.get(var7)).getGd().getDefaultConfiguration().getBounds();
               if (var5.y + var1 == var8.height + var8.y + var1) {
                  var6 = var6 < var2[var7] ? var2[var7] : var6;
               }
            }

            if (var6 != -1) {
               var2[var3] = 8 + var6;
            }
         }
      }

      return var2;
   }

   public static <T> List<T> getSortedGraphicsDevices(List<T> var0, Comparator<T> var1) {
      ArrayList var2 = new ArrayList(var0);
      Collections.sort(var2, var1);
      return var2;
   }

   public boolean isSelectedMonitor(MonitorDisplayer.GDWithPad var1) {
      GraphicsDevice var2 = this.model.getSelectedDevice();
      return var2 == null ? false : var1.getGd().getIDstring().equals(var2.getIDstring());
   }

   @Override
   protected void paintComponent(Graphics var1) {
      super.paintComponent(var1);
      int var2 = -1;
      int var3 = 0;
      Dimension var4 = this.getSize();
      Dimension var5 = this.getPreferredSize();
      int var6 = (var4.width - var5.width) / 2;
      int var7 = (var4.height - var5.height) / 2;
      var6 = var6 < 0 ? 0 : var6;
      var7 = var7 < 0 ? 0 : var7;
      var6 += INSET.left;
      var7 += INSET.top;
      boolean var8 = this.model.getSelectedDevice() == null;

      for (MonitorDisplayer.GDWithPad var10 : this.xSortedList) {
         Rectangle var11 = var10.getGd().getDefaultConfiguration().getBounds();
         if (var2 == -1) {
            var2 = var11.x < 0 ? Math.abs(var11.x) : 0;
            int var12 = this.ySortedList.get(0).getGd().getDefaultConfiguration().getBounds().y;
            var3 = var12 < 0 ? Math.abs(var12) : 0;
         }

         int var25 = var6 + var10.getPadX() + (var2 + var11.x) / this.ratio;
         int var13 = var7 + var10.getPadY() + (var3 + var11.y) / this.ratio;
         int var14 = var11.width / this.ratio;
         int var15 = var11.height / this.ratio;
         var1.drawRect(var25, var13, var14, var15);
         if (!var8 && this.isSelectedMonitor(var10)) {
            Graphics2D var16 = (Graphics2D)var1;
            Stroke var17 = var16.getStroke();
            var16.setStroke(SELECTED_PAINTER);
            var1.drawRect(var25 + 2, var13 + 2, var14 - 3, var15 - 3);
            var16.setStroke(var17);
         }

         FontMetrics var26 = var1.getFontMetrics();
         int var27 = SwingUtilities.computeStringWidth(var26, var10.getName());
         int var18 = var26.getHeight() - var26.getLeading();
         int var19 = var25 + (var14 - var27) / 2;
         int var20 = var13 + 1 + ((var15 - var18) / 2 + var26.getAscent() - var26.getDescent());
         var1.drawString(var10.getName(), var19, var20);
      }
   }

   public static void main(String[] var0) {
      JFrame var1 = new JFrame("MonitorDisplayerTest");
      var1.setDefaultCloseOperation(3);
      MonitorDisplayer.DefaultMonitorDisplayerModel var2 = new MonitorDisplayer.DefaultMonitorDisplayerModel(
         GraphicsEnvironment.getLocalGraphicsEnvironment().getScreenDevices(), 0
      );
      MonitorDisplayer var3 = new MonitorDisplayer(var2);
      JScrollPane var4 = new JScrollPane();
      var4.getViewport().add(var3);
      var1.getContentPane().add(var4);
      var1.pack();
      var1.setVisible(true);
      var2.setSelectedDevice(1);
   }

   public static String getDisplayAlphabet(int var0) {
      return String.valueOf("ABCDEFGHIJKLMNOPQRSTUVWXYZ".charAt(var0));
   }

   public static class DefaultMonitorDisplayerModel implements MonitorDisplayer.MonitorDisplayerModel {
      private GraphicsDevice[] gds;
      private int defaultGD;
      private int selectedIndex = -1;

      public DefaultMonitorDisplayerModel(GraphicsDevice[] var1, int var2) {
         this.gds = var1;
         this.defaultGD = var2;
      }

      public DefaultMonitorDisplayerModel(GraphicsDevice[] var1, int var2, int var3) {
         this(var1, var2);
         this.setSelectedDevice(var3);
      }

      @Override
      public GraphicsDevice getDefaultScreenDevice() {
         return this.gds[this.defaultGD];
      }

      @Override
      public List<GraphicsDevice> getGraphicsDevices() {
         return Arrays.asList(this.gds);
      }

      public String getGraphicsDeviceDisplayString(int var1) {
         return MonitorDisplayer.getDisplayAlphabet(var1);
      }

      @Override
      public GraphicsDevice getSelectedDevice() {
         return this.selectedIndex >= 0 ? this.gds[this.selectedIndex] : null;
      }

      public void setSelectedDevice(int var1) {
         this.selectedIndex = var1;
      }
   }

   private static class GDComparator implements Comparator<MonitorDisplayer.GDWithPad> {
      private boolean x;

      public GDComparator(boolean var1) {
         this.x = var1;
      }

      public int compare(MonitorDisplayer.GDWithPad var1, MonitorDisplayer.GDWithPad var2) {
         Rectangle var3 = var1.getGd().getDefaultConfiguration().getBounds();
         Rectangle var4 = var2.getGd().getDefaultConfiguration().getBounds();
         if (this.x) {
            return var3.x < var4.x ? 0 : 1;
         } else {
            return var3.y < var4.y ? 0 : 1;
         }
      }
   }

   private static class GDWithPad {
      private final GraphicsDevice gd;
      private int padX = 0;
      private int padY = 0;
      private final String name;

      public GDWithPad(GraphicsDevice var1, String var2) {
         this.gd = var1;
         this.name = var2;
      }

      private GraphicsDevice getGd() {
         return this.gd;
      }

      private void setPadX(int var1) {
         this.padX = var1;
      }

      private int getPadX() {
         return this.padX;
      }

      private void setPadY(int var1) {
         this.padY = var1;
      }

      private int getPadY() {
         return this.padY;
      }

      private String getName() {
         return this.name;
      }
   }

   public interface MonitorDisplayerModel {
      List<GraphicsDevice> getGraphicsDevices();

      GraphicsDevice getDefaultScreenDevice();

      GraphicsDevice getSelectedDevice();
   }
}
