package nn.pp.common.ui.helpers;

import java.awt.AWTEvent;
import java.awt.AlphaComposite;
import java.awt.Color;
import java.awt.Component;
import java.awt.Composite;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GraphicsConfiguration;
import java.awt.Insets;
import java.awt.Point;
import java.awt.Toolkit;
import java.awt.event.AWTEventListener;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JLayeredPane;
import javax.swing.JMenuBar;
import javax.swing.JPanel;
import javax.swing.JToggleButton;
import javax.swing.MenuSelectionManager;
import javax.swing.OverlayLayout;
import javax.swing.SwingUtilities;
import javax.swing.Timer;
import nn.pp.common.ResourceLoader;
import nn.pp.core.T;

public class FullScreenMenuHandler {
   private static final int SLIDE_STEP = 3;
   private final JFrame frame;
   private final JMenuBar menuBar;
   private final Component[] mouseOverComponents;
   private final String keyboardHotkey;
   private JLabel txtLabel;
   private JLabel imgLabel;
   private JToggleButton pinButton;
   private GraphicsConfiguration graphicsConfiguration;
   private final Timer slideInTimer = new Timer(100, null);
   private final Timer slideOutTimer = new Timer(100, null);
   private final Timer slideInWaitTimer = new Timer(2000, null);
   private final Timer slideOutWaitTimer = new Timer(1000, null);
   private final FullScreenMenuHandler.MMAWTEventListener mmAWTEventListener = new FullScreenMenuHandler.MMAWTEventListener();
   private final FullScreenMenuHandler.MenuTrigger menuTrigger = new FullScreenMenuHandler.MenuTrigger();
   private FullScreenMenuHandler.FloatingMenuBarStates currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.NOT_VISIBLE;
   private boolean menuBarBorderPainting;
   private JPanel menuBarPanel;
   private JPanel glassPanel;
   boolean isSMM = false;
   private boolean pinState = false;
   public static final String PIN_ICON = "Common_pin.gif";
   public static final String UNPIN_ICON = "Common_unpin.gif";
   ImageIcon pinIcon;
   ImageIcon unpinIcon;
   JPanel p;

   public FullScreenMenuHandler(JFrame var1, JMenuBar var2, Component[] var3, String var4, boolean var5, GraphicsConfiguration var6) {
      this.frame = var1;
      this.menuBar = var2;
      this.mouseOverComponents = var3;
      this.keyboardHotkey = var4;
      this.pinState = var5;
      this.graphicsConfiguration = var6;
      this.attachTimerListeners();
      this.pinIcon = ResourceLoader.loadImageIcon("Common_pin.gif");
      this.unpinIcon = ResourceLoader.loadImageIcon("Common_unpin.gif");
   }

   public FullScreenMenuHandler(JFrame var1, JMenuBar var2, Component[] var3, String var4, boolean var5) {
      this(var1, var2, var3, var4, var5, null);
   }

   private void attachTimerListeners() {
      this.slideInTimer.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            if (FullScreenMenuHandler.this.currentMenuState != FullScreenMenuHandler.FloatingMenuBarStates.DISPOSED) {
               int var2 = FullScreenMenuHandler.this.menuBarPanel.getY() + 3;
               if (var2 >= 0) {
                  var2 = 0;
                  FullScreenMenuHandler.this.slideInTimer.stop();
                  FullScreenMenuHandler.this.slideInWaitTimer.start();
                  FullScreenMenuHandler.this.glassPanel.setVisible(false);
               }

               FullScreenMenuHandler.this.showHotKeyText(FullScreenMenuHandler.this.isSMM);
               FullScreenMenuHandler.this.menuBarPanel.setLocation(FullScreenMenuHandler.this.menuBarPanel.getX(), var2);
            }
         }
      });
      this.slideInWaitTimer.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            if (FullScreenMenuHandler.this.currentMenuState != FullScreenMenuHandler.FloatingMenuBarStates.DISPOSED) {
               FullScreenMenuHandler.this.slideInWaitTimer.stop();
               FullScreenMenuHandler.this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.SLIDED;
            }
         }
      });
      this.slideOutTimer.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            if (FullScreenMenuHandler.this.currentMenuState != FullScreenMenuHandler.FloatingMenuBarStates.DISPOSED) {
               MenuSelectionManager.defaultManager().clearSelectedPath();
               int var2 = FullScreenMenuHandler.this.menuBarPanel.getY() - 3;
               if (var2 + FullScreenMenuHandler.this.menuBarPanel.getHeight() <= 0) {
                  var2 = -FullScreenMenuHandler.this.menuBarPanel.getHeight();
                  FullScreenMenuHandler.this.slideOutTimer.stop();
                  FullScreenMenuHandler.this.glassPanel.setVisible(false);
                  FullScreenMenuHandler.this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.NOT_VISIBLE;
               }

               FullScreenMenuHandler.this.showHotKeyText(FullScreenMenuHandler.this.isSMM);
               FullScreenMenuHandler.this.menuBarPanel.setLocation(FullScreenMenuHandler.this.menuBarPanel.getX(), var2);
            }
         }
      });
      this.slideOutWaitTimer.addActionListener(new ActionListener() {
         @Override
         public void actionPerformed(ActionEvent var1) {
            if (FullScreenMenuHandler.this.currentMenuState != FullScreenMenuHandler.FloatingMenuBarStates.DISPOSED) {
               Toolkit.getDefaultToolkit().removeAWTEventListener(FullScreenMenuHandler.this.mmAWTEventListener);
               FullScreenMenuHandler.this.slideOutWaitTimer.stop();
               if (FullScreenMenuHandler.this.mmAWTEventListener.isWithinComponent()) {
                  if (!FullScreenMenuHandler.this.pinState) {
                     FullScreenMenuHandler.this.triggerSlideOut();
                  }
               } else {
                  FullScreenMenuHandler.this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.SLIDED;
               }
            }
         }
      });
   }

   private void triggerSlideOut() {
      this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.SLIDING_OUT;
      this.slideOutTimer.start();
      this.glassPanel.setVisible(true);
   }

   public void startSliding(boolean var1) {
      for (Component var5 : this.mouseOverComponents) {
         var5.addMouseMotionListener(this.menuTrigger);
      }

      this.menuBarBorderPainting = this.menuBar.isBorderPainted();
      this.menuBar.setBorderPainted(false);
      JPanel[] var6 = this.createMenuBarPanel(this.menuBar);
      this.menuBarPanel = var6[0];
      this.glassPanel = var6[1];
      this.showHotKeyText(this.isSMM);
      this.frame.getLayeredPane().add(this.menuBarPanel, JLayeredPane.PALETTE_LAYER, 0);
      Dimension var7 = this.graphicsConfiguration != null ? this.graphicsConfiguration.getBounds().getSize() : Toolkit.getDefaultToolkit().getScreenSize();
      Dimension var8 = this.menuBarPanel.getPreferredSize();
      this.menuBarPanel.setBounds((var7.width - var8.width) / 2, -var8.height, var8.width, var8.height);
      if (var1) {
         assert this.currentMenuState == FullScreenMenuHandler.FloatingMenuBarStates.NOT_VISIBLE;

         this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.SLIDING_IN;
         this.glassPanel.setVisible(true);
         this.slideInTimer.start();
      }
   }

   public void stopSliding() {
      this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.DISPOSED;
      this.menuBar.setBorderPainted(this.menuBarBorderPainting);
      Toolkit.getDefaultToolkit().removeAWTEventListener(this.mmAWTEventListener);

      for (Component var4 : this.mouseOverComponents) {
         var4.removeMouseMotionListener(this.menuTrigger);
      }

      this.menuBar.getParent().remove(this.menuBar);
   }

   private JPanel[] createMenuBarPanel(JMenuBar var1) {
      this.p = new JPanel();
      this.p.setBorder(BorderFactory.createEtchedBorder());
      this.p.setLayout(new OverlayLayout(this.p));
      JPanel var2 = new JPanel();
      FullScreenMenuHandler.GlassPanel var3 = new FullScreenMenuHandler.GlassPanel(var2);
      var3.setVisible(false);
      this.p.add(var3);
      var2.setAlignmentX(0.0F);
      var2.setAlignmentY(0.0F);
      this.pinButton = new JToggleButton(this.pinState ? this.pinIcon : this.unpinIcon);
      this.pinButton.setPreferredSize(new Dimension(this.pinIcon.getIconWidth(), this.pinIcon.getIconHeight()));
      this.pinButton.setOpaque(false);
      this.pinButton.addItemListener(new ItemListener() {
         @Override
         public void itemStateChanged(ItemEvent var1) {
            FullScreenMenuHandler.this.pinState = !FullScreenMenuHandler.this.pinState;
            if (!FullScreenMenuHandler.this.pinState) {
               FullScreenMenuHandler.this.triggerSlideOut();
            }

            FullScreenMenuHandler.this.togglePinState();
            if (FullScreenMenuHandler.this.mouseOverComponents[0] != null) {
               FullScreenMenuHandler.this.mouseOverComponents[0].requestFocusInWindow();
            }
         }
      });
      this.imgLabel = new JLabel(ResourceLoader.loadImageIcon("Common_Raritan_Title.gif"));
      this.txtLabel = new JLabel(this.keyboardHotkey + T._(" : Disable Single Mouse"));
      var2.add(this.pinButton);
      var2.add(this.txtLabel);
      var2.add(this.imgLabel);
      var2.add(var1);
      this.p.add(var2);
      return new JPanel[]{this.p, var3};
   }

   private void togglePinState() {
      this.pinButton.setIcon(this.pinState ? this.pinIcon : this.unpinIcon);
   }

   public void showHotKeyText(boolean var1) {
      if (this.txtLabel != null) {
         this.txtLabel.setVisible(var1);
      }

      Dimension var2 = this.graphicsConfiguration != null ? this.graphicsConfiguration.getBounds().getSize() : Toolkit.getDefaultToolkit().getScreenSize();
      Dimension var3 = this.menuBarPanel.getPreferredSize();
      this.menuBarPanel.setBounds((var2.width - var3.width) / 2, this.menuBarPanel.getLocation().y, var3.width, var3.height);
      this.menuBarPanel.validate();
   }

   public void setSMM(boolean var1) {
      this.isSMM = var1;
   }

   private static enum FloatingMenuBarStates {
      NOT_VISIBLE,
      SLIDING_IN,
      SLIDED,
      SLIDEOUT_WAIT,
      SLIDING_OUT,
      DISPOSED;
   }

   private static class GlassPanel extends JPanel {
      private final JComponent comp;
      private final Insets inset = new Insets(0, 0, 0, 0);

      public GlassPanel(JComponent var1) {
         this.setAlignmentX(0.0F);
         this.setAlignmentY(0.0F);
         this.setOpaque(false);
         this.enableEvents(32L);
         this.setLayout(null);
         this.comp = var1;
      }

      @Override
      public Dimension getPreferredSize() {
         return this.comp.getPreferredSize();
      }

      @Override
      public Dimension getMinimumSize() {
         return this.comp.getMinimumSize();
      }

      @Override
      public Dimension getMaximumSize() {
         return this.comp.getMaximumSize();
      }

      @Override
      protected void paintComponent(Graphics var1) {
         Color var2 = var1.getColor();
         Color var3 = var2.brighter();
         var1.setColor(var3);
         Graphics2D var4 = (Graphics2D)var1;
         Composite var5 = var4.getComposite();
         var4.setComposite(AlphaComposite.getInstance(3, 0.25F));
         Insets var6 = this.getInsets(this.inset);
         int var7 = var6.left;
         int var8 = var6.top;
         int var9 = this.getWidth() - var6.left - var6.right;
         int var10 = this.getHeight() - var6.top - var6.bottom;
         var4.fillRect(var7, var8, var9, var10);
         var4.setComposite(var5);
         var1.setColor(var2);
      }
   }

   private class MMAWTEventListener implements AWTEventListener {
      private MouseEvent compEvent;
      private MouseEvent other;

      private MMAWTEventListener() {
      }

      @Override
      public void eventDispatched(AWTEvent var1) {
         if (var1.getID() == 503) {
            MouseEvent var2 = (MouseEvent)var1;
            Object var3 = var2.getSource();

            for (Component var7 : FullScreenMenuHandler.this.mouseOverComponents) {
               if (var7 == var3) {
                  this.compEvent = var2;
                  return;
               }
            }

            this.other = var2;
         }
      }

      public void reset() {
         this.compEvent = null;
         this.other = null;
      }

      public boolean isWithinComponent() {
         if (this.compEvent == null) {
            return false;
         } else {
            return this.other == null ? true : this.compEvent.getWhen() > this.other.getWhen();
         }
      }
   }

   private class MenuTrigger implements MouseMotionListener {
      private MenuTrigger() {
      }

      @Override
      public void mouseDragged(MouseEvent var1) {
      }

      @Override
      public void mouseMoved(MouseEvent var1) {
         if (FullScreenMenuHandler.this.currentMenuState != FullScreenMenuHandler.FloatingMenuBarStates.DISPOSED) {
            Point var2 = SwingUtilities.convertPoint((Component)var1.getSource(), var1.getPoint(), FullScreenMenuHandler.this.frame.getContentPane());
            if (FullScreenMenuHandler.this.currentMenuState == FullScreenMenuHandler.FloatingMenuBarStates.NOT_VISIBLE && var2.y <= 3) {
               FullScreenMenuHandler.this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.SLIDING_IN;
               FullScreenMenuHandler.this.glassPanel.setVisible(true);
               FullScreenMenuHandler.this.slideInTimer.start();
            } else if (FullScreenMenuHandler.this.currentMenuState == FullScreenMenuHandler.FloatingMenuBarStates.SLIDED
               && !FullScreenMenuHandler.this.pinState) {
               FullScreenMenuHandler.this.currentMenuState = FullScreenMenuHandler.FloatingMenuBarStates.SLIDEOUT_WAIT;
               Toolkit.getDefaultToolkit().addAWTEventListener(FullScreenMenuHandler.this.mmAWTEventListener, 32L);
               FullScreenMenuHandler.this.mmAWTEventListener.reset();
               FullScreenMenuHandler.this.slideOutWaitTimer.start();
            }
         }
      }
   }
}
