package nn.pp.common.ui.pan;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Insets;
import java.awt.Point;
import java.awt.Rectangle;
import java.util.Hashtable;
import javax.swing.border.BevelBorder;

public class PanningBorder extends BevelBorder {
   private int width;
   private int pressedMask;
   private static final int[] directions = new int[]{1, 2, 4, 8, 16, 32, 64, 128};
   private Hashtable<Integer, Rectangle[]> positions;
   private Hashtable<Integer, Point[]> arrows;

   public PanningBorder(int var1, int var2) {
      super(1);
      this.width = var1;
      this.pressedMask = var2;
      this.positions = new Hashtable<>();
      this.arrows = new Hashtable<>();
      this.createDirection(1, 1);
      this.createDirection(2, 2);
      this.createDirection(4, 1);
      this.createDirection(8, 2);
      this.createDirection(16, 1);
      this.createDirection(32, 2);
      this.createDirection(64, 1);
      this.createDirection(128, 2);
   }

   private void createDirection(int var1, int var2) {
      Rectangle[] var3 = new Rectangle[var2];

      for (int var4 = 0; var4 < var2; var4++) {
         var3[var4] = new Rectangle();
      }

      this.positions.put(var1, var3);
      Point[] var6 = new Point[6];

      for (int var5 = 0; var5 < var6.length; var5++) {
         var6[var5] = new Point();
      }

      this.arrows.put(var1, var6);
   }

   public boolean pointInDirection(Point var1, int var2) {
      Rectangle[] var3 = this.positions.get(var2);
      if (var3 == null) {
         return false;
      } else {
         for (Rectangle var7 : var3) {
            if (var7.contains(var1)) {
               return true;
            }
         }

         return false;
      }
   }

   public int getDirectionFromPoint(Point var1) {
      int var2 = 0;

      for (int var6 : directions) {
         if (this.pointInDirection(var1, var6)) {
            var2 |= var6;
         }
      }

      return var2;
   }

   private void calculatePositions(int var1, int var2, int var3, int var4) {
      int var5 = var3 / 5;
      int var6 = var4 / 5;
      this.addPosition(1, 0, var1 + var5, var2, var3 - 2 * var5, this.width + 4);
      this.addPosition(2, 0, var1 + var3 - var5, var2, var5, this.width + 4);
      this.addPosition(2, 1, var1 + var3 - this.width - 4, var2, this.width + 4, var6);
      this.addPosition(4, 0, var1 + var3 - this.width - 4, var2 + var6, this.width + 4, var4 - 2 * var6);
      this.addPosition(8, 0, var1 + var3 - this.width - 4, var2 + var4 - var6, this.width + 4, var6);
      this.addPosition(8, 1, var1 + var3 - var5, var2 + var4 - this.width - 4, var5, this.width + 4);
      this.addPosition(16, 0, var1 + var5, var2 + var4 - this.width - 4, var3 - 2 * var5, this.width + 4);
      this.addPosition(32, 0, 0, var2 + var4 - this.width - 4, var5, this.width + 4);
      this.addPosition(32, 1, 0, var2 + var4 - var6, this.width + 4, var6);
      this.addPosition(64, 0, 0, var2 + var6, this.width + 4, var4 - 2 * var6);
      this.addPosition(128, 0, 0, 0, var5, this.width + 4);
      this.addPosition(128, 1, 0, 0, this.width + 4, var6);
   }

   private void addPosition(int var1, int var2, int var3, int var4, int var5, int var6) {
      Rectangle[] var7 = this.positions.get(var1);

      assert var7 != null && var7.length > var2;

      var7[var2].x = var3;
      var7[var2].y = var4;
      var7[var2].width = var5;
      var7[var2].height = var6;
   }

   private void calculateArrows(int var1, int var2, int var3, int var4) {
      this.addArrow(1, new Point(var3 / 2, 3), -1, 1, 1, 1, 0, 1);
      this.addArrow(2, new Point(var3 - 4 - this.width / 2, 2 + this.width / 2), -1, 0, 0, 1, 1, -1);
      this.addArrow(4, new Point(var3 - 5, var4 / 2), -1, -1, -1, 1, -1, 0);
      this.addArrow(8, new Point(var3 - 4 - this.width / 2, var4 - 4 - this.width / 2), -1, 0, 0, -1, 1, 1);
      this.addArrow(16, new Point(var3 / 2, var4 - 4), -1, -1, 1, -1, 0, -1);
      this.addArrow(32, new Point(3 + this.width / 2, var4 - 4 - this.width / 2), 1, 0, 0, -1, -1, 1);
      this.addArrow(64, new Point(3, var4 / 2), 1, -1, 1, 1, 1, 0);
      this.addArrow(128, new Point(3 + this.width / 2, 2 + this.width / 2), 1, 0, 0, 1, -1, -1);
   }

   private void addArrow(int var1, Point var2, int var3, int var4, int var5, int var6, int var7, int var8) {
      Point[] var9 = this.arrows.get(var1);
      if (var9 != null) {
         if (this.width >= 2) {
            var3 *= this.width - 4;
            var4 *= this.width - 4;
            var5 *= this.width - 4;
            var6 *= this.width - 4;
            var9[0] = var2;
            var9[1] = new Point(var2.x + var3, var2.y + var4);
            var9[2] = new Point(var2.x + var5, var2.y + var6);
            var9[3] = new Point(var9[0].x + var7, var9[0].y + var8);
            var9[4] = new Point(var9[1].x + var7, var9[1].y + var8);
            var9[5] = new Point(var9[2].x + var7, var9[2].y + var8);
         }
      }
   }

   private void paintDirection(int var1, Component var2, Graphics var3) {
      Rectangle[] var4 = this.positions.get(var1);
      if (var4 != null && var4.length != 0 && var4.length <= 2) {
         Color var5 = var2.getBackground().darker();
         Color var6 = var2.getBackground();
         boolean var7 = (this.pressedMask & var1) != 0;
         var3.setColor(var7 ? var5 : var6);

         for (int var8 = 0; var8 < var4.length; var8++) {
            var3.fillRect(var4[var8].x, var4[var8].y, var4[var8].width, var4[var8].height);
         }

         for (int var11 = 0; var11 < var4.length; var11++) {
            if (var7) {
               this.paintLoweredBevel(var2, var3, var4[var11].x, var4[var11].y, var4[var11].width, var4[var11].height);
            } else {
               this.paintRaisedBevel(var2, var3, var4[var11].x, var4[var11].y, var4[var11].width, var4[var11].height);
            }
         }

         var3.setColor(var7 ? var5 : var6);

         for (int var12 = 0; var12 < var4.length; var12++) {
            for (int var9 = 0; var9 < var4.length; var9++) {
               if (var12 != var9) {
                  Rectangle var10 = var4[var12].intersection(var4[var9]);
                  if (!var10.isEmpty()) {
                     var3.fillRect(var10.x, var10.y, var10.width, var10.height);
                  }
               }
            }
         }

         if (var4.length == 2) {
            Rectangle var13 = var4[0].union(var4[1]);
            if (var7) {
               this.paintLoweredBevel(var2, var3, var13.x, var13.y, var13.width, var13.height);
            } else {
               this.paintRaisedBevel(var2, var3, var13.x, var13.y, var13.width, var13.height);
            }
         }

         Point[] var14 = this.arrows.get(var1);
         if (var14 != null && var14.length == 6) {
            var3.setColor(Color.BLACK);
            var3.drawLine(var14[0].x, var14[0].y, var14[1].x, var14[1].y);
            var3.drawLine(var14[0].x, var14[0].y, var14[2].x, var14[2].y);
            var3.setColor(Color.BLACK);
            var3.drawLine(var14[3].x, var14[3].y, var14[4].x, var14[4].y);
            var3.drawLine(var14[3].x, var14[3].y, var14[5].x, var14[5].y);
         }
      }
   }

   @Override
   public void paintBorder(Component var1, Graphics var2, int var3, int var4, int var5, int var6) {
      this.calculatePositions(var3, var4, var5, var6);
      this.calculateArrows(var3, var4, var5, var6);
      Color var7 = var2.getColor();

      for (int var11 : directions) {
         this.paintDirection(var11, var1, var2);
      }

      var2.setColor(var7);
   }

   @Override
   public Insets getBorderInsets(Component var1) {
      int var2 = this.width + 4;
      return new Insets(var2, var2, var2, var2);
   }

   @Override
   public Insets getBorderInsets(Component var1, Insets var2) {
      var2.left = var2.right = var2.bottom = var2.top = this.width + 4;
      return var2;
   }

   @Override
   public boolean isBorderOpaque() {
      return true;
   }
}
