package nn.pp.common.ui.pan;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Point;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.Timer;
import java.util.TimerTask;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import javax.swing.event.EventListenerList;

public class PanningHolder extends JPanel {
   private int panningWidth;
   private EventListenerList listeners = new EventListenerList();
   private PanningBorder border;
   private Timer panningTimer;

   public PanningHolder(JComponent var1, int var2) {
      this.setLayout(new BorderLayout());
      this.add(var1, "Center");
      this.panningWidth = var2;
      this.setBorder(this.border = new PanningBorder(var2, 0));
      this.addMouseListener(new MouseAdapter() {
         @Override
         public void mousePressed(MouseEvent var1) {
            int var2x = PanningHolder.this.border.getDirectionFromPoint(new Point(var1.getX(), var1.getY()));
            PanningHolder.this.setBorder(PanningHolder.this.border = new PanningBorder(PanningHolder.this.panningWidth, var2x));
            PanningHolder.this.firePanningEvent(new PanningEvent(PanningHolder.this, var2x));
            PanningHolder.this.setupPanningTimer(var2x);
         }

         @Override
         public void mouseReleased(MouseEvent var1) {
            PanningHolder.this.setBorder(PanningHolder.this.border = new PanningBorder(PanningHolder.this.panningWidth, 0));
            PanningHolder.this.killPanningTimer();
         }
      });
   }

   public PanningHolder(JComponent var1) {
      this(var1, 10);
   }

   public void addPanningEventListener(PanningEventListener var1) {
      if (var1 != null) {
         this.listenerList.add(PanningEventListener.class, var1);
      }
   }

   public void removePanningEventListener(PanningEventListener var1) {
      if (var1 != null) {
         this.listenerList.remove(PanningEventListener.class, var1);
      }
   }

   private void firePanningEvent(PanningEvent var1) {
      for (PanningEventListener var5 : this.listenerList.getListeners(PanningEventListener.class)) {
         var5.panning(var1);
      }
   }

   private void setupPanningTimer(final int var1) {
      this.killPanningTimer();
      this.panningTimer = new Timer();
      this.panningTimer.schedule(new TimerTask() {
         @Override
         public void run() {
            Runnable var1x = new Runnable() {
               @Override
               public void run() {
                  PanningHolder.this.firePanningEvent(new PanningEvent(PanningHolder.this, var1));
               }
            };
            if (SwingUtilities.isEventDispatchThread()) {
               var1x.run();
            } else {
               SwingUtilities.invokeLater(var1x);
            }
         }
      }, 1000L, 25L);
   }

   private void killPanningTimer() {
      if (this.panningTimer != null) {
         this.panningTimer.cancel();
         this.panningTimer = null;
      }
   }

   public static void main(String[] var0) {
      JFrame var1 = new JFrame();
      var1.setDefaultCloseOperation(3);
      var1.setLayout(new BorderLayout());
      var1.add(new JLabel("North", 0), "North");
      var1.add(new JLabel("South", 0), "South");
      var1.add(new JLabel("East"), "East");
      var1.add(new JLabel("West"), "West");
      JButton var2 = new JButton("Hello World");
      var2.setPreferredSize(new Dimension(300, 200));
      PanningHolder var3 = new PanningHolder(var2);
      var1.add(var3, "Center");
      var3.addPanningEventListener(new PanningEventListener() {
         @Override
         public void panning(PanningEvent var1) {
            System.out.println("Panning to: " + var1.getDirection());
         }
      });
      var1.pack();
      var1.setVisible(true);
   }
}
