package nn.pp.core;

public abstract class NotificationEvent implements INotificationEvent {
   static byte upperNibbleMask = -16;
   static byte lowerNibbleMask = 15;
   protected int flags;
   protected int errorCode;
   private int severity;
   private INotificationEvent.Severity severityType;
   private int groupId;
   private int messageGroupId;
   private int messageGroupErrorCode;
   protected boolean clientGeneratedError = false;
   public static final byte ProtocolRFB = 1;
   public static final byte ProtocolRDM_1 = 2;
   public static final byte ProtocolMSP = 3;
   public static final byte ProtocolRDM_2 = 6;
   public static final byte SeverityError = 0;
   public static final byte SeverityWarning = 1;
   public static final byte SeverityInfo = 2;
   public static final byte SeverityDebug = 3;
   public static final byte UserNotfFlagQuit = 1;

   public NotificationEvent(int var1, int var2) {
      this.flags = var1;
      this.errorCode = var2;
      this.groupId = (var2 >> 24 & upperNibbleMask) >> 4;
      this.severity = var2 >> 24 & lowerNibbleMask;
      this.messageGroupId = var2 << 8 >> 24;
      this.messageGroupErrorCode = var2 << 16 >> 16;
   }

   public NotificationEvent(int var1, int var2, boolean var3, String var4) {
      this.setClientgeneratedError(var3);
      this.flags = var1;
      this.errorCode = var2;
      if (!this.isClientGeneratedError()) {
         this.groupId = (var2 >> 24 & upperNibbleMask) >> 4;
         this.severity = var2 >> 24 & lowerNibbleMask;
         this.messageGroupId = var2 << 8 >> 24;
         this.messageGroupErrorCode = var2 << 16 >> 16;
      }
   }

   @Override
   public int getErrorCode() {
      return this.errorCode;
   }

   @Override
   public int getGroupId() {
      return this.groupId;
   }

   @Override
   public int getMessageGroupErrorCode() {
      return this.messageGroupErrorCode;
   }

   @Override
   public int getMessageGroupId() {
      return this.messageGroupId;
   }

   @Override
   public INotificationEvent.Severity getSeverityType() {
      if (this.severity == 3) {
         return INotificationEvent.Severity.DEBUG;
      } else if (this.severity == 0) {
         return INotificationEvent.Severity.ERROR;
      } else if (this.severity == 1) {
         return INotificationEvent.Severity.WARNING;
      } else {
         return this.severity == 2 ? INotificationEvent.Severity.INFO : INotificationEvent.Severity.UNKNOWN;
      }
   }

   public int getSeverity() {
      return this.severity;
   }

   @Override
   public boolean isDebug() {
      return this.severity == 3;
   }

   @Override
   public boolean isError() {
      return this.severity == 0;
   }

   @Override
   public boolean isWarning() {
      return this.severity == 1;
   }

   @Override
   public boolean isInfo() {
      return this.severity == 2;
   }

   @Override
   public boolean isQuit() {
      return (this.flags & 1) != 0;
   }

   @Override
   public boolean isMSP() {
      return this.groupId == 3;
   }

   @Override
   public boolean isRFB() {
      return this.groupId == 1;
   }

   public void setClientgeneratedError(boolean var1) {
      this.clientGeneratedError = var1;
   }

   @Override
   public boolean isClientGeneratedError() {
      return this.clientGeneratedError;
   }

   @Override
   public abstract String getMessage();

   @Override
   public String toString() {
      return "[flags="
         + this.flags
         + " errorCode="
         + this.errorCode
         + " groupId="
         + this.groupId
         + " severity="
         + this.severity
         + " messageGroupId="
         + this.messageGroupId
         + " messageGroupErrorCode="
         + this.messageGroupErrorCode
         + "]";
   }

   @Override
   public abstract INotificationEvent clone();
}
