package nn.pp.core.impl;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.net.UnknownHostException;
import java.security.cert.X509Certificate;
import java.text.MessageFormat;
import java.util.HashMap;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import nn.pp.core.T;
import nn.pp.core.Util;

public class DeviceConnector {
   private static final int CONNECT_TIMEOUT = 15000;
   private Logger logger;
   private String sockerr = "";
   private X509TrustManager trustManager;
   private Socket socket;
   protected MonitoringDataInputStream inputStream;
   protected MonitoringDataOutputStream outputStream;
   protected Object streamMtx = new Object();
   private String host;
   private X509TrustManager trustAll = new X509TrustManager() {
      @Override
      public X509Certificate[] getAcceptedIssuers() {
         return null;
      }

      @Override
      public void checkClientTrusted(X509Certificate[] var1, String var2) {
      }

      @Override
      public void checkServerTrusted(X509Certificate[] var1, String var2) {
      }
   };
   private static HashMap<String, InetSocketAddress> addressCache = new HashMap<>();

   private static InetAddress getInetAddress(String var0) throws UnknownHostException {
      if (var0.charAt(0) == '[') {
         if (var0.length() <= 2 || var0.charAt(var0.length() - 1) != ']') {
            throw new UnknownHostException(var0 + ": invalid IPv6 address");
         }

         var0 = var0.substring(1, var0.length() - 1);
      }

      if (Character.digit(var0.charAt(0), 16) != -1 || var0.charAt(0) == ':') {
         Object var1 = null;
         var1 = IPAddressUtil.textToNumericFormatV4(var0);
         if (var1 == null) {
            var1 = IPAddressUtil.textToNumericFormatV6(var0);
         }

         if (var1 != null) {
            return InetAddress.getByAddress("", (byte[])var1);
         }
      }

      return InetAddress.getByName(var0);
   }

   private static synchronized InetSocketAddress getInetSocketAddress(String var0, int var1) throws UnknownHostException {
      String var2 = var0 + ":" + var1;
      if (addressCache.containsKey(var2)) {
         return addressCache.get(var2);
      } else {
         InetSocketAddress var3 = new InetSocketAddress(getInetAddress(var0), var1);
         addressCache.put(var2, var3);
         return var3;
      }
   }

   public DeviceConnector(Logger var1, X509TrustManager var2) {
      this.logger = var1;
   }

   public String getHost() {
      return this.host;
   }

   private Socket connect(String var1, int var2) {
      String var3 = "" + var1 + ':' + var2;
      this.logger.log(Level.INFO, MessageFormat.format(T._("Trying connection to {0}"), var3));
      Socket var4 = null;

      try {
         var4 = new Socket();
         var4.connect(getInetSocketAddress(var1, var2), 15000);
         this.logger.log(Level.INFO, MessageFormat.format(T._("Successfully connected to {0}"), var3));
      } catch (Exception var6) {
         this.logger.log(Level.SEVERE, MessageFormat.format(T._("Connection to {0} FAILED"), var3), (Throwable)var6);
         this.sockerr = var6.getMessage();
      }

      return var4;
   }

   public Socket connectSSLWithSocket(String var1, int var2) {
      String var3 = "" + var1 + ':' + var2;
      this.logger.log(Level.INFO, MessageFormat.format(T._("trying SSL connection to {0}"), var3));
      SSLSocket var4 = null;
      if (this.trustManager == null) {
         this.trustManager = this.trustAll;
      }

      TrustManager[] var5 = new TrustManager[]{this.trustManager};

      try {
         SSLContext var6 = SSLContext.getInstance("TLSv1");
         var6.init(null, var5, null);
         SSLSocketFactory var7 = var6.getSocketFactory();
         var4 = (SSLSocket)var7.createSocket(this.socket, var1, var2, true);
         this.socket = var4;
         synchronized (this.streamMtx) {
            this.outputStream = null;
            this.inputStream = null;
         }

         this.logger.log(Level.INFO, MessageFormat.format(T._("SSL connected successfully to {0}"), var3));
         this.logger.log(Level.FINE, T._("SSL running handshake..."));
         var4.startHandshake();
         this.logger.log(Level.FINE, T._("SSL handshake successful :-)"));
         this.logger.log(Level.FINER, MessageFormat.format(T._("SSL {0}"), var4.getSession()));
      } catch (Exception var11) {
         this.logger.log(Level.SEVERE, MessageFormat.format(T._("SSL connection to {0} FAILED"), var3), (Throwable)var11);
         this.sockerr = var11.getMessage();
         var4 = null;
      }

      return var4;
   }

   private Socket connectSSL(String var1, int var2) {
      String var3 = "" + var1 + ':' + var2;
      this.logger.log(Level.INFO, MessageFormat.format(T._("trying SSL connection to {0}"), var3));
      SSLSocket var4 = null;
      if (this.trustManager == null) {
         this.trustManager = this.trustAll;
      }

      TrustManager[] var5 = new TrustManager[]{this.trustManager};

      try {
         SSLContext var6 = SSLContext.getInstance("TLSv1");
         var6.init(null, var5, null);
         SSLSocketFactory var7 = var6.getSocketFactory();
         var4 = (SSLSocket)var7.createSocket();
         var4.connect(getInetSocketAddress(var1, var2), 15000);
         this.logger.log(Level.INFO, MessageFormat.format(T._("SSL connected successfully to {0}"), var3));
         this.logger.log(Level.FINE, T._("SSL running handshake..."));
         var4.startHandshake();
         this.logger.log(Level.FINE, T._("SSL handshake successful :-)"));
         this.logger.log(Level.FINER, MessageFormat.format(T._("SSL {0}"), var4.getSession()));
      } catch (Exception var8) {
         this.logger.log(Level.SEVERE, MessageFormat.format(T._("SSL connection to {0} FAILED"), var3), (Throwable)var8);
         this.sockerr = var8.getMessage();
         var4 = null;
      }

      return var4;
   }

   public void connect(String var1, int var2, boolean var3) throws IOException {
      var1 = Util.getURLCompatibleIP(var1);
      if (var3) {
         this.socket = this.connectSSL(var1, var2);
      } else {
         this.socket = this.connect(var1, var2);
      }

      if (this.socket == null) {
         throw new IOException(MessageFormat.format(T._("Cannot connect to device: {0}"), this.sockerr));
      } else {
         this.host = var1;
      }
   }

   public void disconnect() {
      if (this.socket != null) {
         try {
            this.socket.close();
         } catch (IOException var2) {
         }
      }
   }

   public MonitoringDataInputStream getInputStream() throws IOException {
      synchronized (this.streamMtx) {
         if (this.inputStream == null) {
            this.inputStream = new MonitoringDataInputStream(new BufferedInputStream(this.socket.getInputStream(), 32768));
         }

         return this.inputStream;
      }
   }

   public MonitoringDataOutputStream getOutputStream() throws IOException {
      synchronized (this.streamMtx) {
         if (this.outputStream == null) {
            this.outputStream = new MonitoringDataOutputStream(this.socket.getOutputStream());
         }

         return this.outputStream;
      }
   }

   public void setSocketTimeout(int var1) throws IOException {
      this.socket.setSoTimeout(var1);
   }

   public void setTcpNoDelay(boolean var1) throws IOException {
      this.socket.setTcpNoDelay(var1);
   }

   public void writeCCSGproxyModePrefix(String var1) throws IOException {
      String var3 = "<CSC_Connect ConnectionID=\"" + var1 + "\"/>";
      byte[] var2 = var3.getBytes();
      int var4 = 4 + var2.length + 1;
      MonitoringDataOutputStream var5 = this.getOutputStream();
      var5.writeInt(var4);
      var5.write(var2, 0, var2.length);
      var5.writeByte(0);
      var5.flush();
   }
}
