package nn.pp.core.impl;

public class IPAddressUtil {
   private static final int INADDR4SZ = 4;
   private static final int INADDR16SZ = 16;
   private static final int INT16SZ = 2;

   public static byte[] textToNumericFormatV4(String var0) {
      if (var0.length() == 0) {
         return null;
      } else {
         byte[] var1 = new byte[4];
         String[] var2 = var0.split("\\.", -1);

         try {
            switch (var2.length) {
               case 1:
                  long var11 = Long.parseLong(var2[0]);
                  if (var11 < 0L || var11 > 4294967295L) {
                     return null;
                  }

                  var1[0] = (byte)(var11 >> 24 & 255L);
                  var1[1] = (byte)((var11 & 16777215L) >> 16 & 255L);
                  var1[2] = (byte)((var11 & 65535L) >> 8 & 255L);
                  var1[3] = (byte)(var11 & 255L);
                  break;
               case 2:
                  long var9 = Integer.parseInt(var2[0]);
                  if (var9 < 0L || var9 > 255L) {
                     return null;
                  }

                  var1[0] = (byte)(var9 & 255L);
                  var9 = Integer.parseInt(var2[1]);
                  if (var9 < 0L || var9 > 16777215L) {
                     return null;
                  }

                  var1[1] = (byte)(var9 >> 16 & 255L);
                  var1[2] = (byte)((var9 & 65535L) >> 8 & 255L);
                  var1[3] = (byte)(var9 & 255L);
                  break;
               case 3:
                  for (int var12 = 0; var12 < 2; var12++) {
                     long var7 = Integer.parseInt(var2[var12]);
                     if (var7 < 0L || var7 > 255L) {
                        return null;
                     }

                     var1[var12] = (byte)(var7 & 255L);
                  }

                  long var8 = Integer.parseInt(var2[2]);
                  if (var8 < 0L || var8 > 65535L) {
                     return null;
                  }

                  var1[2] = (byte)(var8 >> 8 & 255L);
                  var1[3] = (byte)(var8 & 255L);
                  break;
               case 4:
                  for (int var5 = 0; var5 < 4; var5++) {
                     long var3 = Integer.parseInt(var2[var5]);
                     if (var3 < 0L || var3 > 255L) {
                        return null;
                     }

                     var1[var5] = (byte)(var3 & 255L);
                  }
                  break;
               default:
                  return null;
            }

            return var1;
         } catch (NumberFormatException var6) {
            return null;
         }
      }
   }

   public static byte[] textToNumericFormatV6(String var0) {
      if (var0.length() < 2) {
         return null;
      } else {
         char[] var5 = var0.toCharArray();
         byte[] var6 = new byte[16];
         int var7 = var5.length;
         int var8 = var0.indexOf("%");
         if (var8 == var7 - 1) {
            return null;
         } else {
            if (var8 != -1) {
               var7 = var8;
            }

            int var1 = -1;
            int var9 = 0;
            int var10 = 0;
            if (var5[var9] == ':') {
               if (var5[++var9] != ':') {
                  return null;
               }
            }

            int var11 = var9;
            boolean var3 = false;
            int var4 = 0;

            while (var9 < var7) {
               char var2 = var5[var9++];
               int var12 = Character.digit(var2, 16);
               if (var12 != -1) {
                  var4 <<= 4;
                  var4 |= var12;
                  if (var4 > 65535) {
                     return null;
                  }

                  var3 = true;
               } else {
                  if (var2 != ':') {
                     if (var2 != '.' || var10 + 4 > 16) {
                        return null;
                     }

                     String var13 = var0.substring(var11, var7);
                     int var14 = 0;

                     for (int var24 = 0; (var24 = var13.indexOf(46, var24)) != -1; var24++) {
                        var14++;
                     }

                     if (var14 != 3) {
                        return null;
                     }

                     byte[] var16 = textToNumericFormatV4(var13);
                     if (var16 == null) {
                        return null;
                     }

                     for (int var17 = 0; var17 < 4; var17++) {
                        var6[var10++] = var16[var17];
                     }

                     var3 = false;
                     break;
                  }

                  var11 = var9;
                  if (!var3) {
                     if (var1 != -1) {
                        return null;
                     }

                     var1 = var10;
                  } else {
                     if (var9 == var7) {
                        return null;
                     }

                     if (var10 + 2 > 16) {
                        return null;
                     }

                     var6[var10++] = (byte)(var4 >> 8 & 0xFF);
                     var6[var10++] = (byte)(var4 & 0xFF);
                     var3 = false;
                     var4 = 0;
                  }
               }
            }

            if (var3) {
               if (var10 + 2 > 16) {
                  return null;
               }

               var6[var10++] = (byte)(var4 >> 8 & 0xFF);
               var6[var10++] = (byte)(var4 & 0xFF);
            }

            if (var1 != -1) {
               int var22 = var10 - var1;
               if (var10 == 16) {
                  return null;
               }

               for (int var19 = 1; var19 <= var22; var19++) {
                  var6[16 - var19] = var6[var1 + var22 - var19];
                  var6[var1 + var22 - var19] = 0;
               }

               var10 = 16;
            }

            if (var10 != 16) {
               return null;
            } else {
               byte[] var23 = convertFromIPv4MappedAddress(var6);
               return var23 != null ? var23 : var6;
            }
         }
      }
   }

   public static boolean isIPv4LiteralAddress(String var0) {
      return textToNumericFormatV4(var0) != null;
   }

   public static boolean isIPv6LiteralAddress(String var0) {
      return textToNumericFormatV6(var0) != null;
   }

   public static byte[] convertFromIPv4MappedAddress(byte[] var0) {
      if (isIPv4MappedAddress(var0)) {
         byte[] var1 = new byte[4];
         System.arraycopy(var0, 12, var1, 0, 4);
         return var1;
      } else {
         return null;
      }
   }

   private static boolean isIPv4MappedAddress(byte[] var0) {
      return var0.length < 16
         ? false
         : var0[0] == 0
            && var0[1] == 0
            && var0[2] == 0
            && var0[3] == 0
            && var0[4] == 0
            && var0[5] == 0
            && var0[6] == 0
            && var0[7] == 0
            && var0[8] == 0
            && var0[9] == 0
            && var0[10] == -1
            && var0[11] == -1;
   }
}
