package nn.pp.core.impl;

import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;
import java.util.Map.Entry;
import javax.swing.SwingUtilities;

public class ListenerList<E> {
   private Vector<E> listenersWithoutMask;
   private HashMap<E, Integer> listenersWithMask;

   public synchronized void addListener(E var1) {
      if (this.listenersWithoutMask == null) {
         this.listenersWithoutMask = new Vector<>();
      }

      if (!this.listenersWithoutMask.contains(var1)) {
         this.listenersWithoutMask.add((E)var1);
      }
   }

   public synchronized void addListener(E var1, int var2) {
      if (this.listenersWithMask == null) {
         this.listenersWithMask = new HashMap<>();
      }

      if (!this.listenersWithMask.containsKey(var1)) {
         this.listenersWithMask.put((E)var1, var2);
      }
   }

   public synchronized void removeListener(E var1) {
      if (this.listenersWithoutMask != null) {
         this.listenersWithoutMask.remove(var1);
      }

      if (this.listenersWithMask != null) {
         this.listenersWithMask.remove(var1);
      }
   }

   private synchronized List<E> getListeners() {
      Vector var1 = new Vector();
      if (this.listenersWithoutMask != null) {
         var1.addAll(this.listenersWithoutMask);
      }

      if (this.listenersWithMask != null) {
         for (Entry var3 : this.listenersWithMask.entrySet()) {
            Object var4 = var3.getKey();
            var1.add(var4);
         }
      }

      return var1;
   }

   private synchronized List<E> getListeners(int var1) {
      Vector var2 = new Vector();
      if (this.listenersWithMask != null) {
         for (Entry var4 : this.listenersWithMask.entrySet()) {
            Object var5 = var4.getKey();
            Integer var6 = (Integer)var4.getValue();
            if ((var6 & var1) != 0) {
               var2.add(var5);
            }
         }
      }

      return var2;
   }

   protected void fire(ListenerAction<E> var1, int var2) {
      this.fire(this.getListeners(var2), var1);
   }

   protected void fire(ListenerAction<E> var1) {
      this.fire(this.getListeners(), var1);
   }

   private void fire(final List<E> var1, final ListenerAction<E> var2) {
      if (SwingUtilities.isEventDispatchThread()) {
         Iterator var3 = var1.iterator();

         while (var3.hasNext()) {
            var2.setListener(var3.next());
            var2.run();
         }
      } else {
         SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
               Iterator var1x = var1.iterator();

               while (var1x.hasNext()) {
                  var2.setListener(var1x.next());
                  var2.run();
               }
            }
         });
      }
   }

   protected class FireResult<R> {
      private R result;

      public FireResult() {
      }

      private R fire(final List<E> var1, final ListenerActionResult<E, R> var2) {
         if (SwingUtilities.isEventDispatchThread()) {
            Iterator var3 = var1.iterator();

            while (var3.hasNext()) {
               var2.setListener(var3.next());
               var2.run();
               if (this.result == null) {
                  this.result = (R)var2.getResult();
               }
            }
         } else {
            try {
               SwingUtilities.invokeAndWait(new Runnable() {
                  @Override
                  public void run() {
                     Iterator var1x = var1.iterator();

                     while (var1x.hasNext()) {
                        var2.setListener(var1x.next());
                        var2.run();
                        if (FireResult.this.result == null) {
                           FireResult.this.result = (R)var2.getResult();
                        }
                     }
                  }
               });
            } catch (InvocationTargetException var4) {
               return null;
            } catch (InterruptedException var5) {
               return null;
            }
         }

         return this.result;
      }

      public R fire(ListenerActionResult<E, R> var1, int var2) {
         return this.fire(ListenerList.this.getListeners(var2), var1);
      }

      public R fire(ListenerActionResult<E, R> var1) {
         return this.fire(ListenerList.this.getListeners(), var1);
      }
   }
}
