package nn.pp.core.impl;

import java.io.EOFException;
import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UTFDataFormatException;

public class MonitoringDataInputStream extends FilterInputStream {
   private int countC;
   private int buflen = 0;
   private int count = 0;
   private byte[] buf = null;
   private int pos = 0;

   public MonitoringDataInputStream(InputStream var1) {
      super(var1);
      this.buflen = 65536;
      this.buf = new byte[this.buflen];
   }

   private final int readAByte() throws IOException {
      return this.count - this.pos <= 0 ? this.in.read() : this.buf[this.pos++] & 0xFF;
   }

   private final int readBytes(byte[] var1, int var2, int var3) throws IOException {
      int var4 = this.count - this.pos;
      if (var4 <= 0) {
         return this.in.read(var1, var2, var3);
      } else {
         int var5 = Math.min(var3, var4);
         System.arraycopy(this.buf, this.pos, var1, var2, var5);
         this.pos += var5;
         return var5;
      }
   }

   public void stall(byte[] var1, int var2, int var3) {
      if (var3 != 0) {
         synchronized (this) {
            if (this.countC - var3 > 0) {
               this.countC -= var3;
            } else {
               this.countC = 0;
            }
         }

         int var4 = this.count - this.pos;
         if (var4 > 0) {
            if (var4 + var3 > this.buflen) {
               this.buflen = var4 + var3;
               byte[] var5 = new byte[this.buflen];
               System.arraycopy(this.buf, this.pos, var5, var3, var4);
               this.buf = var5;
            } else {
               System.arraycopy(this.buf, this.pos, this.buf, var3, var4);
            }
         }

         this.pos = 0;
         this.count = var4 + var3;
         System.arraycopy(var1, var2, this.buf, this.pos, var3);
      }
   }

   @Override
   public final int read(byte[] var1) throws IOException {
      return this.read(var1, 0, var1.length);
   }

   @Override
   public final int read(byte[] var1, int var2, int var3) throws IOException {
      int var4 = this.readBytes(var1, var2, var3);
      synchronized (this) {
         this.countC += var4;
         return var4;
      }
   }

   @Override
   public final int read() throws IOException {
      int var1 = this.readAByte();
      synchronized (this) {
         this.countC++;
         return var1;
      }
   }

   public final void readFully(byte[] var1) throws IOException {
      this.readFully(var1, 0, var1.length);
   }

   public final void readFully(byte[] var1, int var2, int var3) throws IOException {
      if (var3 < 0) {
         throw new IndexOutOfBoundsException();
      } else {
         int var4 = 0;

         while (var4 < var3) {
            int var5 = this.readBytes(var1, var2 + var4, var3 - var4);
            if (var5 < 0) {
               throw new EOFException();
            }

            var4 += var5;
         }

         synchronized (this) {
            this.countC += var3;
         }
      }
   }

   public final boolean readBoolean() throws IOException {
      int var1 = this.readAByte();
      if (var1 < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC++;
         }

         return var1 != 0;
      }
   }

   public final byte readByte() throws IOException {
      int var1 = this.readAByte();
      if (var1 < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC++;
         }

         return (byte)var1;
      }
   }

   public final int readUnsignedByte() throws IOException {
      int var1 = this.readAByte();
      if (var1 < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC++;
            return var1;
         }
      }
   }

   public final short readShort() throws IOException {
      int var1 = this.readAByte();
      int var2 = this.readAByte();
      if ((var1 | var2) < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC += 2;
         }

         return (short)((var1 << 8) + (var2 << 0));
      }
   }

   public final int readUnsignedShort() throws IOException {
      int var1 = this.readAByte();
      int var2 = this.readAByte();
      if ((var1 | var2) < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC += 2;
         }

         return (var1 << 8) + (var2 << 0);
      }
   }

   public final char readChar() throws IOException {
      int var1 = this.readAByte();
      int var2 = this.readAByte();
      if ((var1 | var2) < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC += 2;
         }

         return (char)((var1 << 8) + (var2 << 0));
      }
   }

   public final int readInt() throws IOException {
      int var1 = this.readAByte();
      int var2 = this.readAByte();
      int var3 = this.readAByte();
      int var4 = this.readAByte();
      if ((var1 | var2 | var3 | var4) < 0) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC += 4;
         }

         return (var1 << 24) + (var2 << 16) + (var3 << 8) + (var4 << 0);
      }
   }

   public final long readLong() throws IOException {
      long var1 = this.readAByte();
      long var3 = this.readAByte();
      long var5 = this.readAByte();
      long var7 = this.readAByte();
      long var9 = this.readAByte();
      long var11 = this.readAByte();
      long var13 = this.readAByte();
      long var15 = this.readAByte();
      if ((var1 | var3 | var5 | var7 | var9 | var11 | var13 | var15) < 0L) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC += 8;
         }

         return (var1 << 56) + (var3 << 48) + (var5 << 40) + (var7 << 32) + (var9 << 24) + (var11 << 16) + (var13 << 8) + (var15 << 0);
      }
   }

   public final long readUnsignedInt() throws IOException {
      long var1 = this.readAByte();
      long var3 = this.readAByte();
      long var5 = this.readAByte();
      long var7 = this.readAByte();
      if ((var1 | var3 | var5 | var7) < 0L) {
         throw new EOFException();
      } else {
         synchronized (this) {
            this.countC += 4;
         }

         return (var1 << 24) + (var3 << 16) + (var5 << 8) + (var7 << 0);
      }
   }

   public final String readUTF() throws IOException {
      int var1 = this.readUnsignedShort();
      StringBuffer var2 = new StringBuffer(var1);
      byte[] var3 = new byte[var1];
      int var7 = 0;
      this.readFully(var3, 0, var1);

      while (var7 < var1) {
         int var4 = var3[var7] & 255;
         switch (var4 >> 4) {
            case 0:
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
               var7++;
               var2.append((char)var4);
               break;
            case 8:
            case 9:
            case 10:
            case 11:
            default:
               throw new UTFDataFormatException();
            case 12:
            case 13:
               var7 += 2;
               if (var7 > var1) {
                  throw new UTFDataFormatException();
               }

               byte var8 = var3[var7 - 1];
               if ((var8 & 192) != 128) {
                  throw new UTFDataFormatException();
               }

               var2.append((char)((var4 & 31) << 6 | var8 & 63));
               break;
            case 14:
               var7 += 3;
               if (var7 > var1) {
                  throw new UTFDataFormatException();
               }

               byte var5 = var3[var7 - 2];
               byte var6 = var3[var7 - 1];
               if ((var5 & 192) != 128 || (var6 & 192) != 128) {
                  throw new UTFDataFormatException();
               }

               var2.append((char)((var4 & 15) << 12 | (var5 & 63) << 6 | (var6 & 63) << 0));
         }
      }

      return new String(var2);
   }

   public final synchronized int getAndClearIn() {
      int var1 = this.countC;
      this.countC = 0;
      return var1;
   }
}
