package nn.pp.core.impl;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.OutputStream;

public class MonitoringDataOutputStream extends DataOutputStream {
   private OutputStream out;
   private int count;

   public MonitoringDataOutputStream(OutputStream var1) {
      super(var1);
      this.out = var1;
   }

   public OutputStream getStream() {
      return this.out;
   }

   @Override
   public void write(int var1) throws IOException {
      this.out.write(var1);
      synchronized (this) {
         this.count++;
      }
   }

   @Override
   public void write(byte[] var1, int var2, int var3) throws IOException {
      if (var3 != 0) {
         this.out.write(var1, var2, var3);
         synchronized (this) {
            this.count += var3;
         }
      }
   }

   @Override
   public void write(byte[] var1) throws IOException {
      this.write(var1, 0, var1.length);
   }

   public final void writeUnsignedShort(int var1) throws IOException {
      this.write(var1 >> 8 & 0xFF);
      this.write(var1 & 0xFF);
   }

   public final void writeUnsignedShortLE(int var1) throws IOException {
      this.write(var1 & 0xFF);
      this.write(var1 >> 8 & 0xFF);
   }

   public final void writeUnsignedInt(long var1) throws IOException {
      this.write((int)(var1 >> 24 & 255L));
      this.write((int)(var1 >> 16 & 255L));
      this.write((int)(var1 >> 8 & 255L));
      this.write((int)(var1 & 255L));
   }

   public final void writeUnsignedIntLE(long var1) throws IOException {
      this.write((int)(var1 & 255L));
      this.write((int)(var1 >> 8 & 255L));
      this.write((int)(var1 >> 16 & 255L));
      this.write((int)(var1 >> 24 & 255L));
   }

   public final void writeUnsignedLong(long var1) throws IOException {
      this.write((int)(var1 >> 56 & 255L));
      this.write((int)(var1 >> 48 & 255L));
      this.write((int)(var1 >> 40 & 255L));
      this.write((int)(var1 >> 32 & 255L));
      this.write((int)(var1 >> 24 & 255L));
      this.write((int)(var1 >> 16 & 255L));
      this.write((int)(var1 >> 8 & 255L));
      this.write((int)(var1 & 255L));
   }

   public final void writeUnsignedLongLE(long var1) throws IOException {
      this.write((int)(var1 & 255L));
      this.write((int)(var1 >> 8 & 255L));
      this.write((int)(var1 >> 16 & 255L));
      this.write((int)(var1 >> 24 & 255L));
      this.write((int)(var1 >> 32 & 255L));
      this.write((int)(var1 >> 40 & 255L));
      this.write((int)(var1 >> 48 & 255L));
      this.write((int)(var1 >> 56 & 255L));
   }

   public final void write(ProtocolMessage var1) throws IOException {
      var1.writeTo(this);
      this.flush();
   }

   public synchronized int getAndClearOut() {
      int var1 = this.count;
      this.count = 0;
      return var1;
   }
}
