package nn.pp.ext.devPref;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.util.prefs.BackingStoreException;
import java.util.prefs.InvalidPreferencesFormatException;
import java.util.prefs.Preferences;
import nn.pp.rccore.RCCore;

public class DevicePrefs {
   public static final String ROOT_NODE = "/RaritanDevices";
   protected static final String FILE_NAME = System.getProperty("user.home") != null
      ? System.getProperty("user.home") + System.getProperty("file.separator") + "DeviceTree.xml"
      : "DeviceTree.xml";
   protected static final String G2_CONNECTION_SPEED_KEY = "g2ConnectionSpeed";
   protected static final String G2_COLOR_DEPTH_KEY = "g2ColorDepth";
   protected static final String G2_SMOOTHING_KEY = "g2Smoothing";
   public static final String AUTO_MOUNT_SMARTCARDREADER_NAME = "autoMountSmartCardReaderName";
   public static final String CONNECT_PLAYBACK = "connectPlaybackDevice";
   public static final String PLAYBACK_DEVICE = "playbackDevice";
   public static final String PLAYBACK_FORMAT = "playbackFormat";
   public static final String PLAYBACK_BUFSIZE = "playbackBufferSize";
   public static final String CONNECT_CAPTURE = "connectCaptureDevice";
   public static final String CAPTURE_DEVICE = "captureDevice";
   public static final String CAPTURE_FORMAT = "captureFormat";
   public static final String CAPTURE_BUFSIZE = "captureBufferSize";
   protected Preferences rootPrefs;
   protected RCCore.ColorDepth g2ColorDepth = null;
   protected RCCore.Compression g2ConnectionSpeed = null;
   protected RCCore.Smoothing g2Smoothing = null;
   private String cardReaderName;
   private static String companyNameNoSpace = "Raritan";
   private boolean isConnectPlaybackDevice = true;
   private String playbackDevice = null;
   private String playbackFormat = null;
   private int playbackBufferSize = -1;
   private boolean isConnectCaptureDevice = false;
   private String captureDevice = null;
   private String captureFormat = null;
   private int captureBufferSize = -1;

   public DevicePrefs() {
      this.rootPrefs = Preferences.userRoot().node("/" + companyNameNoSpace + "Devices");
   }

   protected static void setComapnyName(String var0) {
      companyNameNoSpace = var0;
   }

   protected static File getOrCreateXmlFile(String var0) {
      File var1 = new File(var0);
      BufferedWriter var2 = null;

      try {
         if (!var1.exists()) {
            var1.createNewFile();
            var2 = new BufferedWriter(new FileWriter(var1));
            var2.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            var2.write("\n\n");
            var2.write("<!DOCTYPE preferences SYSTEM 'http://java.sun.com/dtd/preferences.dtd'>");
            var2.write("\n\n");
            var2.write("<preferences EXTERNAL_XML_VERSION=\"1.0\">");
            var2.write("<root type=\"user\">");
            var2.write("<map /><node name=\"" + companyNameNoSpace + "Devices\"><map />");
            var2.write("</node></root></preferences>");
            var2.flush();
         }
      } catch (IOException var12) {
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var14 = null;
            } catch (IOException var11) {
            }
         }
      }

      return var1;
   }

   public void exportPreferences(String var1) {
      Preferences var2 = this.rootPrefs.node(var1);
      this.storeToPreferences(var2);
      BufferedOutputStream var3 = null;

      try {
         var3 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(FILE_NAME)));
         this.rootPrefs.exportSubtree(var3);
      } catch (FileNotFoundException var19) {
      } catch (IOException var20) {
      } catch (BackingStoreException var21) {
      } catch (Exception var22) {
         var22.printStackTrace();
      } finally {
         if (var3 != null) {
            try {
               var3.close();
               Object var24 = null;
            } catch (IOException var18) {
            }
         }
      }
   }

   protected void storeToPreferences(Preferences var1) {
      if (this.g2ConnectionSpeed == null) {
         var1.remove("g2ConnectionSpeed");
      } else {
         var1.put("g2ConnectionSpeed", this.g2ConnectionSpeed.toString());
      }

      if (this.g2Smoothing != null) {
         var1.put("g2Smoothing", this.g2Smoothing.toString());
      }

      if (this.g2ColorDepth != null) {
         var1.put("g2ColorDepth", this.g2ColorDepth.toString());
      }

      String var2 = this.getCardReaderName();
      if (var2 != null) {
         assert var2.length() < 8192;

         var1.put("autoMountSmartCardReaderName", var2);
      } else {
         var1.remove("autoMountSmartCardReaderName");
      }

      var1.putBoolean("connectPlaybackDevice", this.isConnectPlaybackDevice());
      if (this.getPlaybackDevice() != null) {
         var1.put("playbackDevice", this.getPlaybackDevice());
      } else {
         var1.remove("playbackDevice");
      }

      if (this.getPlaybackFormat() != null) {
         var1.put("playbackFormat", this.getPlaybackFormat());
      } else {
         var1.remove("playbackFormat");
      }

      var1.putInt("playbackBufferSize", this.getPlaybackBufferSize());
      var1.putBoolean("connectCaptureDevice", this.isConnectCaptureDevice());
      if (this.getCaptureDevice() != null) {
         var1.put("captureDevice", this.getCaptureDevice());
      } else {
         var1.remove("captureDevice");
      }

      if (this.getCaptureFormat() != null) {
         var1.put("captureFormat", this.getCaptureFormat());
      } else {
         var1.remove("captureFormat");
      }

      var1.putInt("captureBufferSize", this.getCaptureBufferSize());
   }

   public static void importPreferences() {
      BufferedInputStream var0 = null;

      try {
         var0 = new BufferedInputStream(new FileInputStream(getOrCreateXmlFile(FILE_NAME)));
         Preferences.importPreferences(var0);
      } catch (InvalidPreferencesFormatException var12) {
      } catch (IOException var13) {
      } finally {
         if (var0 != null) {
            try {
               var0.close();
               Object var15 = null;
            } catch (IOException var11) {
            }
         }
      }
   }

   public void importPreferences(String var1) {
      Object var2 = null;

      try {
         var2 = new BufferedInputStream(new FileInputStream(getOrCreateXmlFile(FILE_NAME)));
         this.importPreferences(var1, (InputStream)var2, this.rootPrefs);
      } catch (IOException var4) {
      } catch (Exception var5) {
      }
   }

   protected void importPreferences(String var1, InputStream var2, Preferences var3) {
      Preferences var4 = null;

      try {
         Preferences.importPreferences(var2);
         var4 = var3.node(var1);
      } catch (InvalidPreferencesFormatException var16) {
      } catch (IOException var17) {
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var19 = null;
            } catch (IOException var15) {
            }
         }
      }

      if (var4 != null) {
         this.loadValues(var4);
      }
   }

   protected void loadValues(Preferences var1) {
      Object var2 = null;
      var2 = var1.get("g2ConnectionSpeed", null);
      if (var2 != null) {
         for (RCCore.Compression var6 : RCCore.Compression.values()) {
            if (var2.equalsIgnoreCase(var6.toString())) {
               this.g2ConnectionSpeed = var6;
               break;
            }
         }
      }

      var2 = var1.get("g2ColorDepth", null);
      if (var2 != null) {
         for (RCCore.ColorDepth var16 : RCCore.ColorDepth.values()) {
            if (var2.equalsIgnoreCase(var16.toString())) {
               this.g2ColorDepth = var16;
               break;
            }
         }
      }

      var2 = var1.get("g2Smoothing", null);
      if (var2 != null) {
         for (RCCore.Smoothing var17 : RCCore.Smoothing.values()) {
            if (var2.equalsIgnoreCase(var17.toString())) {
               this.g2Smoothing = var17;
               break;
            }
         }
      }

      this.setCardReaderName(var1.get("autoMountSmartCardReaderName", null));
      this.setConnectPlaybackDevice(var1.getBoolean("connectPlaybackDevice", true));
      this.setPlaybackDevice(var1.get("playbackDevice", null));
      this.setPlaybackFormat(var1.get("playbackFormat", null));
      this.setPlaybackBufferSize(var1.getInt("playbackBufferSize", -1));
      this.setConnectCaptureDevice(var1.getBoolean("connectCaptureDevice", false));
      this.setCaptureDevice(var1.get("captureDevice", null));
      this.setCaptureFormat(var1.get("captureFormat", null));
      this.setCaptureBufferSize(var1.getInt("captureBufferSize", -1));
   }

   public static DevicePrefs getNode(String var0) {
      importPreferences();
      Preferences var1 = Preferences.userRoot().node("/" + companyNameNoSpace + "Devices");

      try {
         if (var1.nodeExists(var0)) {
            DevicePrefs var2 = new DevicePrefs();
            var2.importPreferences(var0);
            return var2;
         }
      } catch (BackingStoreException var3) {
      }

      return null;
   }

   public RCCore.ColorDepth getG2ColorDepth() {
      return this.g2ColorDepth;
   }

   public RCCore.Compression getG2ConnectionSpeed() {
      return this.g2ConnectionSpeed;
   }

   public RCCore.Smoothing getG2Smoothing() {
      return this.g2Smoothing;
   }

   public void setG2ColorDepth(RCCore.ColorDepth var1) {
      this.g2ColorDepth = var1;
   }

   public void setG2ConnectionSpeed(RCCore.Compression var1) {
      this.g2ConnectionSpeed = var1;
   }

   public void setG2Smoothing(RCCore.Smoothing var1) {
      this.g2Smoothing = var1;
   }

   public String getCardReaderName() {
      return this.cardReaderName;
   }

   public void setCardReaderName(String var1) {
      this.cardReaderName = var1;
   }

   public boolean isConnectPlaybackDevice() {
      return this.isConnectPlaybackDevice;
   }

   public void setConnectPlaybackDevice(boolean var1) {
      this.isConnectPlaybackDevice = var1;
   }

   public String getPlaybackDevice() {
      return this.playbackDevice;
   }

   public void setPlaybackDevice(String var1) {
      this.playbackDevice = var1;
   }

   public String getPlaybackFormat() {
      return this.playbackFormat;
   }

   public void setPlaybackFormat(String var1) {
      this.playbackFormat = var1;
   }

   public int getPlaybackBufferSize() {
      return this.playbackBufferSize;
   }

   public void setPlaybackBufferSize(int var1) {
      this.playbackBufferSize = var1;
   }

   public boolean isConnectCaptureDevice() {
      return this.isConnectCaptureDevice;
   }

   public void setConnectCaptureDevice(boolean var1) {
      this.isConnectCaptureDevice = var1;
   }

   public String getCaptureDevice() {
      return this.captureDevice;
   }

   public void setCaptureDevice(String var1) {
      this.captureDevice = var1;
   }

   public String getCaptureFormat() {
      return this.captureFormat;
   }

   public void setCaptureFormat(String var1) {
      this.captureFormat = var1;
   }

   public int getCaptureBufferSize() {
      return this.captureBufferSize;
   }

   public void setCaptureBufferSize(int var1) {
      this.captureBufferSize = var1;
   }
}
