package nn.pp.ext.macro;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.logging.Level;
import java.util.prefs.BackingStoreException;
import java.util.prefs.InvalidPreferencesFormatException;
import java.util.prefs.Preferences;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import nn.pp.logging.RemoteConsoleLogger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.EntityResolver;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

class KeyboardMacroParserImpl implements IMacroParser {
   private static KeyboardMacroParserImpl.DTDResolverAndErrorHandler ENTITY_RESOLVER_ERROR_HANDLER = new KeyboardMacroParserImpl.DTDResolverAndErrorHandler();
   private static final String FILE_NAME = System.getProperty("user.home") != null
      ? System.getProperty("user.home") + System.getProperty("file.separator") + "KeyboardMacros.xml"
      : "KeyboardMacros.xml";
   public static final String ROOT_NODE = "/KeyboardMacros";
   private static final String MACRO_NAME_KEY = "name";
   private static final String HOT_KEY_COMBINATION_KEY = "hotKey";
   private static final String MACRO_SEQUENCE_KEY = "macroSequence";
   private static final String CONN_SCRIPT_EDIT_SEQUENCE_KEY = "EditSequence";

   private static File getOrCreateXmlFile(String var0) throws IOException {
      File var1 = new File(var0);
      BufferedWriter var2 = null;

      try {
         if (!var1.exists()) {
            var1.createNewFile();
            var2 = new BufferedWriter(new FileWriter(var1));
            var2.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            var2.write("\n\n");
            var2.write("<!DOCTYPE preferences SYSTEM 'http://java.sun.com/dtd/preferences.dtd'>");
            var2.write("\n\n");
            var2.write("<preferences EXTERNAL_XML_VERSION=\"1.0\">");
            var2.write("<root type=\"user\">");
            var2.write("<map /><node name=\"KeyboardMacros\"><map />");
            var2.write("</node></root></preferences>");
            var2.flush();
         }
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var11 = null;
            } catch (IOException var9) {
            }
         }
      }

      return var1;
   }

   private List<IMacro> getMacroList(String var1) throws MacroException {
      BufferedInputStream var2 = null;
      List var3 = Collections.emptyList();

      try {
         try {
            var2 = new BufferedInputStream(new FileInputStream(getOrCreateXmlFile(var1)));
            Preferences.importPreferences(var2);
         } catch (FileNotFoundException var19) {
            System.out.println("Unable to load keyboard macrof from file " + var1);
            RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "Exception trying to import Keyboard Macro.", (Throwable)var19);
         }

         Preferences var4 = Preferences.userRoot().node("/KeyboardMacros");
         Object var5 = null;
         var5 = var4.childrenNames();
         var3 = new ArrayList();

         for (int var6 = 0; var6 < ((Object[])var5).length; var6++) {
            Preferences var7 = var4.node((String)((Object[])var5)[var6]);
            Macro var8 = new Macro(var7.get("name", ""), var7.get("macroSequence", ""), var7.getInt("hotKey", -1));
            var3.add(var8);
         }
      } catch (BackingStoreException var20) {
         throw new MacroException("Unable to get macros", var20);
      } catch (InvalidPreferencesFormatException var21) {
         throw new MacroException("Unable to get macros", var21);
      } catch (IOException var22) {
         throw new MacroException("Unable to get macros", var22);
      } finally {
         if (var2 != null) {
            try {
               var2.close();
               Object var24 = null;
            } catch (IOException var18) {
            }
         }
      }

      return var3;
   }

   @Override
   public IMacro getKeyboardMacro(String var1) {
      Macro var2 = null;
      if (var1 != null && !"".equals(var1)) {
         Preferences var3 = Preferences.userRoot().node("/KeyboardMacros");
         Preferences var4 = var3.node(var1);
         if (var4 != null) {
            String var5 = var4.get("name", null);
            if (var5 != null) {
               var2 = new Macro(var1, var4.get("macroSequence", ""), var4.getInt("hotKey", -1));
            }
         }
      }

      return var2;
   }

   @Override
   public List<IMacro> getKeyboardMacros() throws MacroException {
      return this.getMacroList(FILE_NAME);
   }

   @Override
   public List<IMacro> getKeyboardMacros(String var1) throws MacroException {
      return this.getMacroList(var1);
   }

   @Override
   public void createKeyboardMacro(IMacro var1) throws MacroException {
      this.updateKeyboardMacro(var1, null, true);
   }

   @Override
   public void createKeyboardMacro(IMacro var1, boolean var2) throws MacroException {
      this.updateKeyboardMacro(var1, null, var2);
   }

   @Override
   public void deleteKeyboardMacro(IMacro var1) throws MacroException {
      this.deleteKeyboardMacro(var1, true);
   }

   @Override
   public void deleteKeyboardMacro(IMacro var1, boolean var2) throws MacroException {
      Preferences var3 = Preferences.userRoot().node("/KeyboardMacros");

      try {
         var3.node(var1.getName()).removeNode();
         if (var2) {
            this.saveKeyboardMacro();
         }
      } catch (BackingStoreException var5) {
         throw new MacroException("Unable to delete macro", var5);
      }
   }

   @Override
   public void saveKeyboardMacro() throws MacroException {
      this.saveKeyboardMacro(FILE_NAME);
   }

   @Override
   public void saveKeyboardMacro(String var1) throws MacroException {
      Preferences var2 = Preferences.userRoot().node("/KeyboardMacros");
      BufferedOutputStream var3 = null;

      try {
         var3 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(var1)));
         var2.exportSubtree(var3);
      } catch (FileNotFoundException var14) {
         throw new MacroException("Unable to save macro", var14);
      } catch (IOException var15) {
         throw new MacroException("Unable to save macro", var15);
      } catch (BackingStoreException var16) {
         throw new MacroException("Unable to save macro", var16);
      } finally {
         if (var3 != null) {
            try {
               var3.close();
               Object var18 = null;
            } catch (IOException var13) {
            }
         }
      }
   }

   @Override
   public void updateKeyboardMacro(IMacro var1, String var2) throws MacroException {
      this.updateKeyboardMacro(var1, var2, true);
   }

   @Override
   public void updateKeyboardMacro(IMacro var1, String var2, boolean var3) throws MacroException {
      Preferences var4 = Preferences.userRoot().node("/KeyboardMacros");
      BufferedOutputStream var5 = null;

      try {
         if (var2 != null) {
            var4.node(var2).removeNode();
         }

         Preferences var6 = var4.node(var1.getName());
         var6.put("name", var1.getName());
         var6.putInt("hotKey", var1.getHotKey());
         var6.put("macroSequence", var1.getSequence());
         var5 = new BufferedOutputStream(new FileOutputStream(getOrCreateXmlFile(FILE_NAME)));
         var4.exportSubtree(var5);
      } catch (FileNotFoundException var16) {
         throw new MacroException("Unable to update macro", var16);
      } catch (IOException var17) {
         throw new MacroException("Unable to update macro", var17);
      } catch (BackingStoreException var18) {
         throw new MacroException("Unable to update macro", var18);
      } finally {
         if (var5 != null) {
            try {
               var5.close();
               Object var20 = null;
            } catch (IOException var15) {
            }
         }
      }
   }

   private Element getXmlElement(File var1, String var2) throws IOException, SAXException {
      Document var3 = null;
      DocumentBuilderFactory var4 = DocumentBuilderFactory.newInstance();
      var4.setValidating(true);
      DocumentBuilder var5 = null;

      try {
         var5 = var4.newDocumentBuilder();
      } catch (ParserConfigurationException var10) {
         RemoteConsoleLogger.getInstance()
            .getLogger()
            .log(
               Level.SEVERE,
               "Parser Configuration Exception attempting to parse out the Keyboard Macros from the file: " + var1.getAbsolutePath(),
               (Throwable)var10
            );
         return null;
      }

      var5.setEntityResolver(ENTITY_RESOLVER_ERROR_HANDLER);
      var5.setErrorHandler(ENTITY_RESOLVER_ERROR_HANDLER);
      var3 = var5.parse(var1);
      Element var6 = var3.getDocumentElement();
      NodeList var7 = var6.getElementsByTagName("node");
      var6 = null;
      Object var8 = null;

      for (int var9 = 0; var9 < var7.getLength(); var9++) {
         var8 = var7.item(var9);
         if (var8.getNodeType() == 1 && ((Element)var8).getAttribute("name").equals(var2)) {
            var6 = (Element)var8;
         }
      }

      return var6;
   }

   private Element getMacrosElement(File var1) throws IOException, SAXException {
      return this.getXmlElement(var1, "KeyboardMacros");
   }

   private Element getConnectionScriptsElement(File var1) throws IOException, SAXException {
      return this.getXmlElement(var1, "ConnectionScripts");
   }

   @Override
   public SortedMap<String, IMacro> getValidMacros(File var1) throws IOException, SAXException {
      TreeMap var2 = new TreeMap();
      IMacro var3 = null;
      Element var4 = this.getMacrosElement(var1);
      if (var4 == null) {
         var4 = this.getConnectionScriptsElement(var1);
      }

      if (var4 == null) {
         return var2;
      } else {
         NodeList var5 = var4.getElementsByTagName("node");
         NodeList var6 = null;

         for (int var7 = 0; var7 < var5.getLength(); var7++) {
            if (var5.item(var7).getNodeType() == 1) {
               var6 = ((Element)var5.item(var7)).getElementsByTagName("entry");
               if (var6.getLength() >= 3) {
                  var3 = new Macro();

                  for (int var8 = 0; var8 < var6.getLength(); var8++) {
                     if (var6.item(var8).getNodeType() == 1) {
                        var4 = (Element)var6.item(var8);
                        if (var4.getAttribute("key").equals("name")) {
                           var3.setName(var4.getAttribute("value"));
                        }

                        if (var4.getAttribute("key").equals("hotKey")) {
                           var3.setHotKey(Integer.parseInt(var4.getAttribute("value")));
                        }

                        if (var4.getAttribute("key").equals("macroSequence")) {
                           var3.setSequence(var4.getAttribute("value"));
                        }

                        if (var4.getAttribute("key").equals("EditSequence")) {
                           var3.setSequence(this.convertConnectionScriptSequence(var4.getAttribute("value")));
                        }
                     }
                  }

                  if (var3.getName().length() > 0 && var3.getSequence().length() > 0) {
                     var2.put(var3.getName(), var3);
                  }
               }
            }
         }

         return var2;
      }
   }

   private String convertConnectionScriptSequence(String var1) {
      String[] var2 = var1.split(";");
      String var3 = "";

      for (int var4 = 0; var4 < var2.length; var4++) {
         var3 = var3 + var2[var4].substring(0, 1) + " " + var2[var4].substring(1);
         if (var4 < var2.length - 1) {
            var3 = var3 + "&&";
         }
      }

      return var3;
   }

   @Override
   public String getBackupFilename() {
      return FILE_NAME + ".bkp";
   }

   private static class DTDResolverAndErrorHandler implements EntityResolver, ErrorHandler {
      private static final String PREFS_DTD = new String(
         "<!ELEMENT preferences (root)><!ATTLIST preferences EXTERNAL_XML_VERSION CDATA \"0.0\" ><!ELEMENT root (map, node*) ><!ATTLIST root type (system|user) #REQUIRED ><!ELEMENT node (map, node*) ><!ATTLIST node name CDATA #REQUIRED ><!ELEMENT map (entry*) ><!ELEMENT entry EMPTY ><!ATTLIST entry key   CDATA #REQUIRED value CDATA #REQUIRED >"
      );

      private DTDResolverAndErrorHandler() {
      }

      @Override
      public InputSource resolveEntity(String var1, String var2) throws SAXException, IOException {
         return "http://java.sun.com/dtd/preferences.dtd".equals(var2) ? new InputSource(new StringReader(PREFS_DTD)) : null;
      }

      @Override
      public void error(SAXParseException var1) throws SAXException {
         throw var1;
      }

      @Override
      public void fatalError(SAXParseException var1) throws SAXException {
         throw var1;
      }

      @Override
      public void warning(SAXParseException var1) throws SAXException {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.WARNING, "Warning Parsing the XML KeyboardMacro file", (Throwable)var1);
      }
   }
}
