package nn.pp.ext.pref;

import com.util.kbd.KeyboardUtil;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.util.logging.Level;
import java.util.prefs.BackingStoreException;
import java.util.prefs.InvalidPreferencesFormatException;
import java.util.prefs.Preferences;
import nn.pp.logging.RemoteConsoleLogger;

public class ApplicationPreferences implements IApplicationPreferences {
   public static final String ROOT_NODE = "/ApplicationSettings";
   public static final Object mutex = new Object();
   public static final int SORT_TYPE_CHANNEL = 0;
   public static final int SORT_TYPE_NAME = 1;
   public static final int SORT_TYPE_STATUS = 2;
   private static final String SHOW_SCROLL_BORDERS_KEY = "showScrollBorders";
   private static final String ENABLE_SMOOTHING_KEY = "smoothing";
   private static final String SMOOTHING_LEVEL_KEY = "smoothingLevel";
   private static final String AUTO_SYNC_MOUSE_KEY = "autoSyncMouse";
   private static final String SINGLE_MOUSE_INSTRUCTIONS_KEY = "singleMouseInstructions";
   private static final String DO_AUTO_COLORCAL = "autoColorCal";
   private static final String OSUI_HOT_KEY = "osuiHotKey";
   private static final String KEYBOARD_TYPE_KEY = "keyboardType";
   private static final String BROADCAST_PORT_KEY = "broadcastPort";
   private static final String DEFAULT_HTTPS_PORT_KEY = "defaultHttpsPort";
   private static final String KEYBOARD_SHORCUT_MENU_HOTKEY = "KeyboardShortcutMenuHotKey";
   private static final String SINGLE_MOUSE_EXIT_HOTKEY = "SingleMouseExitHotKey";
   private static final String CONNECTION_EXIT_HOTKEY = "ConnectionExitHotKey";
   private static final String PIN_MENU_TOOLBAR = "PinMenuToolbar";
   private static final String SCAN_DISPLAY_INTERVAL = "ScanDisplayInterval";
   private static final String PORT_SCAN_INTERVAL = "PortScanInterval";
   private static final String SCAN_THUMBNAIL_SIZE = "ScanThumbnailSize";
   private static final String SCAN_ORIENTATION = "ScanOrientation";
   private static final String VIEW_MESSAGE = "viewMessage";
   private static final String SHOW_ALL = "showAll";
   private static final String SHOW_UNASSIGNED = "showUnassigned";
   private static final String SHOW_TOOLS = "showTools";
   private static final String CHANNEL_SORT_METHOD = "sortChannelsBy";
   private static final String LOG_JAC = "LogJac";
   private static final String SHOW_GROUPS = "ShowGroups";
   private static final String ALWAYS_OPEN_FS = "AlwaysOpenFS";
   private static final String MONITOR_SETTING = "monitor";
   private static final String MONITOR_COUNT = "monitorCount";
   private static final String ALWAYS_OPEN_SMM = "AlwaysOpenSingleMouseMode";
   private static final String ALWAYS_OPEN_SCALED = "AlwaysOpenScale";
   private static final String NETWORKING_IPV6 = "IPv6_Networking";
   private boolean ipv6NetworkingEnabled = false;
   public final int SMOOTHING_HIGH = 17;
   private Preferences rootPrefs;
   private boolean showScrollBorders = true;
   private boolean enableSmoothing = false;
   private int smoothingLevel = 0;
   private boolean autoSyncMouse = true;
   private boolean singleMouseInstructions = true;
   private boolean doAutoColorCal = true;
   private int osuiHotKey = 0;
   private int keyboardType = 0;
   private String keyboardMenuHotkey = "Ctrl+Alt+M";
   private String singleMouseExitHotkey = "Ctrl+Alt+O";
   private String connectionExitHotkey = "Ctrl+Alt+Q";
   private static int broadcastPort = 5000;
   private static int defaultHttpsPort = 443;
   private String fileName;
   protected boolean enableLogging = false;
   private boolean viewMessage = false;
   private boolean showAll = true;
   private boolean showUnassigned = false;
   private boolean showTools = true;
   private int channelSortMethod = 0;
   private boolean showGroups = false;
   private static final String SHOW_CS_TOOLS = "showCSTools";
   private boolean showCSTools = true;
   private volatile boolean alwaysOpenInFS;
   private String monitorSetting = null;
   private int monitorCount = -1;
   private boolean alwaysOpenSMM = false;
   private boolean alwaysOpenScaled = false;
   private boolean pinMenuToolbar = false;
   private int scanDisplayInterval = 10;
   private int portScanInterval = 10;
   private String scanThumbnailSize = "160x120";
   private String scanOrientation = "Vertical";

   public ApplicationPreferences() {
      this.rootPrefs = Preferences.userRoot().node("/ApplicationSettings");
      this.fileName = System.getProperty("user.home") != null
         ? System.getProperty("user.home") + System.getProperty("file.separator") + "ApplicationSettings.xml"
         : "ApplicationSettings.xml";
   }

   @Override
   public void exportPreferences() {
      this.rootPrefs.putBoolean("showScrollBorders", this.showScrollBorders);
      this.rootPrefs.putBoolean("smoothing", this.enableSmoothing);
      this.rootPrefs.putInt("smoothingLevel", this.smoothingLevel);
      this.rootPrefs.putBoolean("autoSyncMouse", this.autoSyncMouse);
      this.rootPrefs.putBoolean("singleMouseInstructions", this.singleMouseInstructions);
      this.rootPrefs.putBoolean("autoColorCal", this.doAutoColorCal);
      this.rootPrefs.putInt("osuiHotKey", this.osuiHotKey);
      this.rootPrefs.putInt("keyboardType", this.keyboardType);
      this.rootPrefs.putInt("broadcastPort", broadcastPort);
      this.rootPrefs.putInt("defaultHttpsPort", defaultHttpsPort);
      this.rootPrefs.put("KeyboardShortcutMenuHotKey", this.keyboardMenuHotkey);
      this.rootPrefs.put("SingleMouseExitHotKey", this.singleMouseExitHotkey);
      this.rootPrefs.putBoolean("viewMessage", this.viewMessage);
      this.rootPrefs.putBoolean("showAll", this.showAll);
      this.rootPrefs.putBoolean("showUnassigned", this.showUnassigned);
      this.rootPrefs.putBoolean("showTools", this.getShowTools());
      this.rootPrefs.putBoolean("showCSTools", this.showCSTools);
      this.rootPrefs.putInt("sortChannelsBy", this.channelSortMethod);
      this.rootPrefs.putBoolean("ShowGroups", this.isShowGroups());
      this.rootPrefs.putBoolean("IPv6_Networking", this.isIPv6NetworkingEnabled());
      this.rootPrefs.putBoolean("AlwaysOpenFS", this.isAlwaysOpenInFS());
      if (this.getMonitorSetting() != null) {
         this.rootPrefs.put("monitor", this.getMonitorSetting());
      } else {
         this.rootPrefs.remove("monitor");
      }

      if (this.getMonitorCount() != -1) {
         this.rootPrefs.putInt("monitorCount", this.getMonitorCount());
      } else {
         this.rootPrefs.remove("monitorCount");
      }

      this.rootPrefs.putBoolean("AlwaysOpenSingleMouseMode", this.isAlwaysOpenSMM());
      this.rootPrefs.putBoolean("AlwaysOpenScale", this.isAlwaysOpenScaled());
      this.rootPrefs.put("ConnectionExitHotKey", this.getConnectionExitHotkey());
      this.rootPrefs.putBoolean("PinMenuToolbar", this.isPinMenu());
      this.rootPrefs.putInt("ScanDisplayInterval", this.getScanDisplayInterval());
      this.rootPrefs.putInt("PortScanInterval", this.getPortScanInterval());
      this.rootPrefs.put("ScanThumbnailSize", this.getScanThumbnailSize());
      this.rootPrefs.put("ScanOrientation", this.getScanOrientation());
      this.exportLoggerPreferences();
      if (this.showAll) {
         try {
            synchronized (mutex) {
               mutex.notifyAll();
            }
         } catch (Exception var18) {
         }
      }

      BufferedOutputStream var20 = null;

      try {
         var20 = new BufferedOutputStream(new FileOutputStream(this.getOrCreateXmlFile(this.fileName)));
         this.rootPrefs.exportSubtree(var20);
      } catch (IOException var15) {
      } catch (BackingStoreException var16) {
      } finally {
         if (var20 != null) {
            try {
               var20.close();
               Object var21 = null;
            } catch (IOException var14) {
            }
         }
      }
   }

   @Override
   public void exportLoggerPreferences() {
      this.rootPrefs.putBoolean("LogJac", this.enableLogging);
   }

   @Override
   public void importPreferences() {
      BufferedInputStream var1 = null;

      try {
         try {
            var1 = new BufferedInputStream(new FileInputStream(this.getOrCreateXmlFile(this.fileName)));
            Preferences.importPreferences(var1);
            var1.close();
         } catch (FileNotFoundException var17) {
            System.out.println("Cannot open application preferences file. Go ahead with Java preferences.");
         }

         this.importLoggerSettings();
         this.showScrollBorders = this.rootPrefs.getBoolean("showScrollBorders", true);
         this.enableSmoothing = this.rootPrefs.getBoolean("smoothing", false);
         this.smoothingLevel = this.rootPrefs.getInt("smoothingLevel", 17);
         this.autoSyncMouse = this.rootPrefs.getBoolean("autoSyncMouse", true);
         this.singleMouseInstructions = this.rootPrefs.getBoolean("singleMouseInstructions", true);
         this.doAutoColorCal = this.rootPrefs.getBoolean("autoColorCal", true);
         this.osuiHotKey = this.rootPrefs.getInt("osuiHotKey", 0);
         this.keyboardType = this.rootPrefs.getInt("keyboardType", 0);
         broadcastPort = this.rootPrefs.getInt("broadcastPort", broadcastPort);
         defaultHttpsPort = this.rootPrefs.getInt("defaultHttpsPort", defaultHttpsPort);
         this.keyboardMenuHotkey = this.rootPrefs.get("KeyboardShortcutMenuHotKey", "Ctrl+Alt+M");
         this.singleMouseExitHotkey = this.rootPrefs.get("SingleMouseExitHotKey", "Ctrl+Alt+O");
         this.viewMessage = this.rootPrefs.getBoolean("viewMessage", false);
         this.showAll = this.rootPrefs.getBoolean("showAll", true);
         this.showUnassigned = this.rootPrefs.getBoolean("showUnassigned", false);
         this.showTools = this.rootPrefs.getBoolean("showTools", true);
         this.showCSTools = this.rootPrefs.getBoolean("showCSTools", true);
         this.channelSortMethod = this.rootPrefs.getInt("sortChannelsBy", 0);
         this.showGroups = this.rootPrefs.getBoolean("ShowGroups", false);
         this.setIPv6NetworkingEnabled(this.rootPrefs.getBoolean("IPv6_Networking", false));
         this.setAlwaysOpenInFS(this.rootPrefs.getBoolean("AlwaysOpenFS", false));
         this.setMonitorSetting(this.rootPrefs.get("monitor", null));
         this.setMonitorCount(this.rootPrefs.getInt("monitorCount", -1));
         this.setAlwaysOpenSMM(this.rootPrefs.getBoolean("AlwaysOpenSingleMouseMode", false));
         this.setAlwaysOpenScaled(this.rootPrefs.getBoolean("AlwaysOpenScale", false));

         try {
            String var2 = this.keyboardMenuHotkey.substring(this.keyboardMenuHotkey.length() - 1);
            String var3 = this.singleMouseExitHotkey.substring(this.singleMouseExitHotkey.length() - 1);
            String var4 = this.connectionExitHotkey.substring(this.connectionExitHotkey.length() - 1);
            if (var2.equals(var4) || var3.equals(var4)) {
               if (var2.equals(var4)) {
                  var4 = this.getNextHotKey(var4);
                  if (var3.equals(var4)) {
                     var4 = this.getNextHotKey(var4);
                  }
               } else if (var3.equals(var4)) {
                  var4 = this.getNextHotKey(var4);
                  if (var2.equals(var4)) {
                     var4 = this.getNextHotKey(var4);
                  }
               }

               RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Connection Exit Hot Key Conflict Detected. Changing it to :" + var4);
            }

            this.setConnectionExitHotkey(this.rootPrefs.get("ConnectionExitHotKey", "Ctrl+Alt+" + var4));
         } catch (Exception var18) {
            RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, " Exception Occured :", (Throwable)var18);
         }

         this.setPinMenu(this.rootPrefs.getBoolean("PinMenuToolbar", false));
         this.setScanDisplayInterval(this.rootPrefs.getInt("ScanDisplayInterval", 10));
         this.setPortScanInterval(this.rootPrefs.getInt("PortScanInterval", 10));
         this.setScanThumbnailSize(this.rootPrefs.get("ScanThumbnailSize", "160x120"));
         this.setScanOrientation(this.rootPrefs.get("ScanOrientation", "Vertical"));
         this.postImportPreferences();
      } catch (InvalidPreferencesFormatException var19) {
         var19.printStackTrace();
      } catch (IOException var20) {
         var20.printStackTrace();
      } finally {
         if (var1 != null) {
            try {
               var1.close();
               Object var22 = null;
            } catch (IOException var16) {
            }
         }
      }
   }

   @Override
   public void postImportPreferences() {
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Show scroll borders: " + this.showScrollBorders);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Enable smoothing: " + this.enableSmoothing);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Smoothing level: " + this.smoothingLevel);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Auto sync mouse: " + this.autoSyncMouse);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Single mouse instructions: " + this.singleMouseInstructions);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Automatic color calibration: " + this.doAutoColorCal);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "OSUI hotkey: " + this.osuiHotKey);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Keyboard type: " + KeyboardUtil.getLocale(this.keyboardType));
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Broadcast port: " + broadcastPort);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Default HTTPS port: " + defaultHttpsPort);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Exit fullscreen hotkey: " + this.keyboardMenuHotkey);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Exit single mouse mode hotkey: " + this.singleMouseExitHotkey);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Exit single mouse mode hotkey: " + this.singleMouseExitHotkey);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "View message pane: " + this.viewMessage);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Show all: " + this.showAll);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Show unassigned channels: " + this.showUnassigned);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Show tools: " + this.showTools);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Show CS tools: " + this.showCSTools);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Channel sort method: " + this.channelSortMethod);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Show Groups: " + this.isShowGroups());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Always Open in FS: " + this.isAlwaysOpenInFS());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Monitor Setting: " + this.getMonitorSetting());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Monitor Count: " + this.getMonitorCount());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "ConnectionExitHotkey: " + this.getConnectionExitHotkey());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "PinMenuToolbar: " + this.isPinMenu());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "ScanDisplayInterval: " + this.getScanDisplayInterval());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "PortScanInterval: " + this.getPortScanInterval());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "ScanThumbnailSize: " + this.getScanThumbnailSize());
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "ScanOrientation: " + this.getScanOrientation());
   }

   @Override
   public void importLoggerSettings() {
      this.enableLogging = this.rootPrefs.getBoolean("LogJac", false);
      RemoteConsoleLogger.getInstance().enableLogging(this.enableLogging);
      RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, "Enable logging: " + this.enableLogging);
   }

   private File getOrCreateXmlFile(String var1) {
      File var2 = new File(var1);
      BufferedWriter var3 = null;

      try {
         if (!var2.exists()) {
            var2.createNewFile();
            var3 = new BufferedWriter(new FileWriter(var2));
            var3.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            var3.write("\n\n");
            var3.write("<!DOCTYPE preferences SYSTEM 'http://java.sun.com/dtd/preferences.dtd'>");
            var3.write("\n\n");
            var3.write("<preferences EXTERNAL_XML_VERSION=\"1.0\">");
            var3.write("<root type=\"user\">");
            var3.write("<map /><node name=\"ApplicationSettings\"><map />");
            var3.write("</node></root></preferences>");
            var3.flush();
         }
      } catch (IOException var13) {
      } finally {
         if (var3 != null) {
            try {
               var3.close();
               Object var15 = null;
            } catch (IOException var12) {
            }
         }
      }

      return var2;
   }

   @Override
   public boolean isAutoSyncMouse() {
      return this.autoSyncMouse;
   }

   @Override
   public int getKeyboardType() {
      return this.keyboardType;
   }

   @Override
   public int getOsuiHotKey() {
      return this.osuiHotKey;
   }

   @Override
   public boolean isShowScrollBorders() {
      return this.showScrollBorders;
   }

   @Override
   public boolean isSingleMouseInstructions() {
      return this.singleMouseInstructions;
   }

   @Override
   public boolean isEnableLogging() {
      return this.enableLogging;
   }

   @Override
   public String getkeyboardMenuHotkey() {
      return this.keyboardMenuHotkey;
   }

   @Override
   public void setAutoSyncMouse(boolean var1) {
      this.autoSyncMouse = var1;
      this.exportPreferences();
   }

   @Override
   public void setKeyboardType(int var1) {
      this.keyboardType = var1;
      this.exportPreferences();
   }

   @Override
   public void setOsuiHotKey(int var1) {
      this.osuiHotKey = var1;
      this.exportPreferences();
   }

   @Override
   public void setShowScrollBorders(boolean var1) {
      this.showScrollBorders = var1;
      this.exportPreferences();
   }

   @Override
   public void setEnableLogging(boolean var1) {
      this.enableLogging = var1;
      this.exportPreferences();
   }

   @Override
   public void setSingleMouseInstructions(boolean var1) {
      this.singleMouseInstructions = var1;
      this.exportPreferences();
   }

   @Override
   public void setKeyboardMenuHotkey(String var1) {
      this.keyboardMenuHotkey = var1;
      this.exportPreferences();
   }

   @Override
   public void setSingleMouseExitHotkey(String var1) {
      this.singleMouseExitHotkey = var1;
      this.exportPreferences();
   }

   @Override
   public void setViewMessage(boolean var1) {
      this.viewMessage = var1;
      this.exportPreferences();
   }

   @Override
   public void setShowAll(boolean var1) {
      this.showAll = var1;
      this.exportPreferences();
   }

   @Override
   public void setShowUnassigned(boolean var1) {
      this.showUnassigned = var1;
      this.exportPreferences();
   }

   @Override
   public void setShowTools(boolean var1) {
      this.showTools = var1;
      this.exportPreferences();
   }

   @Override
   public void setShowGroups(boolean var1) {
      this.showGroups = var1;
      this.exportPreferences();
   }

   @Override
   public void setChannelSortMethod(int var1) {
      this.channelSortMethod = var1;
      this.exportPreferences();
   }

   @Override
   public void setAllData(ApplicationPreferencesVO var1) {
      this.showScrollBorders = var1.showScrollBorders;
      this.autoSyncMouse = var1.autoSyncMouse;
      this.singleMouseInstructions = var1.singleCursorInstructions;
      this.osuiHotKey = var1.osuiHotKey;
      this.keyboardType = var1.keyboardType;
      broadcastPort = var1.broadcastPort;
      defaultHttpsPort = var1.defaultHttpsPort;
      this.doAutoColorCal = var1.autoColorCal;
      this.keyboardMenuHotkey = var1.keyboardMenuHotkeyValue;
      this.enableLogging = var1.enableLogging;
      this.setIPv6NetworkingEnabled(var1.ipv6NetworkingEnabled);
      this.setAlwaysOpenInFS(var1.isAlwaysOpenInFS);
      this.setMonitorSetting(var1.monitorSetting);
      this.setMonitorCount(var1.monitorCount);
      this.setAlwaysOpenSMM(var1.enableSingleMouse);
      this.setAlwaysOpenScaled(var1.enableScaling);
      this.setPinMenu(var1.pinMenu);
      this.setScanDisplayInterval(var1.scanInterval);
      this.setPortScanInterval(var1.portScanInterval);
      this.setScanThumbnailSize(var1.thumbnailSize);
      this.setScanOrientation(var1.orientation);
      this.exportPreferences();
   }

   @Override
   public boolean getViewMessage() {
      return this.viewMessage;
   }

   @Override
   public boolean getShowAll() {
      return this.showAll;
   }

   @Override
   public boolean getShowUnassigned() {
      return this.showUnassigned;
   }

   @Override
   public boolean getShowTools() {
      return this.showTools;
   }

   @Override
   public int getChannelSortMethod() {
      return this.channelSortMethod;
   }

   @Override
   public boolean isShowGroups() {
      return this.showGroups;
   }

   @Override
   public int getBroadcastPort() {
      return broadcastPort;
   }

   @Override
   public void setBroadcastPort(int var1) {
      if (broadcastPort < 0) {
         broadcastPort = var1;
      }
   }

   @Override
   public int getDefaultHttpsPort() {
      return defaultHttpsPort;
   }

   @Override
   public void setDefaultHttpsPort(int var1) {
      defaultHttpsPort = var1;
   }

   protected Preferences getRootPrefs() {
      return this.rootPrefs;
   }

   protected void setRootPrefs(Preferences var1) {
      this.rootPrefs = var1;
   }

   @Override
   public String getSingleMouseExitHotkey() {
      return this.singleMouseExitHotkey;
   }

   @Override
   public int getSmoothingLevel() {
      return this.smoothingLevel;
   }

   @Override
   public boolean isEnableSmoothing() {
      return this.enableSmoothing;
   }

   @Override
   public void setEnableSmoothing(boolean var1) {
      this.enableSmoothing = var1;
      this.exportPreferences();
   }

   @Override
   public void setSmoothingLevel(int var1) {
      this.smoothingLevel = var1;
      this.exportPreferences();
   }

   @Override
   public boolean isDoAutoColorCal() {
      return this.doAutoColorCal;
   }

   @Override
   public void setDoAutoColorCal(boolean var1) {
      this.doAutoColorCal = var1;
   }

   @Override
   public boolean isShowCSTools() {
      return this.showCSTools;
   }

   @Override
   public void setShowCSTools(boolean var1) {
      this.showCSTools = var1;
      this.exportPreferences();
   }

   @Override
   public synchronized boolean isIPv6NetworkingEnabled() {
      return this.ipv6NetworkingEnabled;
   }

   private synchronized void setIPv6NetworkingEnabled(boolean var1) {
      this.ipv6NetworkingEnabled = var1;
   }

   @Override
   public boolean isAlwaysOpenInFS() {
      return this.alwaysOpenInFS;
   }

   @Override
   public void setAlwaysOpenInFS(boolean var1) {
      this.alwaysOpenInFS = var1;
   }

   @Override
   public String getMonitorSetting() {
      return this.monitorSetting;
   }

   @Override
   public void setMonitorSetting(String var1) {
      this.monitorSetting = var1;
   }

   @Override
   public int getMonitorCount() {
      return this.monitorCount;
   }

   @Override
   public void setMonitorCount(int var1) {
      this.monitorCount = var1;
   }

   @Override
   public boolean isAlwaysOpenSMM() {
      return this.alwaysOpenSMM;
   }

   @Override
   public void setAlwaysOpenSMM(boolean var1) {
      this.alwaysOpenSMM = var1;
   }

   @Override
   public boolean isAlwaysOpenScaled() {
      return this.alwaysOpenScaled;
   }

   @Override
   public void setAlwaysOpenScaled(boolean var1) {
      this.alwaysOpenScaled = var1;
   }

   @Override
   public String getConnectionExitHotkey() {
      return this.connectionExitHotkey;
   }

   @Override
   public int getScanDisplayInterval() {
      return this.scanDisplayInterval;
   }

   @Override
   public int getPortScanInterval() {
      return this.portScanInterval;
   }

   @Override
   public String getScanThumbnailSize() {
      return this.scanThumbnailSize;
   }

   @Override
   public String getScanOrientation() {
      return this.scanOrientation;
   }

   @Override
   public boolean isPinMenu() {
      return this.pinMenuToolbar;
   }

   @Override
   public void setConnectionExitHotkey(String var1) {
      this.connectionExitHotkey = var1;
   }

   @Override
   public void setPinMenu(boolean var1) {
      this.pinMenuToolbar = var1;
   }

   @Override
   public void setScanDisplayInterval(int var1) {
      this.scanDisplayInterval = var1;
   }

   @Override
   public void setPortScanInterval(int var1) {
      this.portScanInterval = var1;
   }

   @Override
   public void setScanThumbnailSize(String var1) {
      this.scanThumbnailSize = var1;
   }

   @Override
   public void setScanOrientation(String var1) {
      this.scanOrientation = var1;
   }

   private String getNextHotKey(String var1) {
      String var2 = "";
      String var3 = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
      int var4 = var3.lastIndexOf(var1);

      try {
         var2 = var3.substring(var4 + 1, var4 + 2);
      } catch (StringIndexOutOfBoundsException var6) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, " Exception Occured :", (Throwable)var6);
         var2 = var3.substring(0, 1);
      } catch (Exception var7) {
         RemoteConsoleLogger.getInstance().getLogger().log(Level.INFO, " Exception Occured :", (Throwable)var7);
      }

      return var2;
   }
}
