package nn.pp.logging;

import java.io.IOException;
import java.util.logging.ConsoleHandler;
import java.util.logging.FileHandler;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.Logger;

public final class RemoteConsoleLogger {
   private static Logger rcLogger = null;
   private static Level logLevel = Level.INFO;
   private LogFormatter logFormatter;
   private static RemoteConsoleLogger remoteConsoleLogger = new RemoteConsoleLogger();
   private static final String LOG_FILE_NAME = "mpc";
   private static FileHandler fh;
   private static ConsoleHandler ch;
   public static final String LOGGER_NAME = RemoteConsoleLogger.class.getName();
   public static final String SMART_CARD_LOGGER_NAME = "com.raritan.smartcard";
   public static final String SCAN_PROTO_LOGGER_NAME = "nn.pp.rccore.scan";
   public static final String SCAN_LOGGER_NAME = "nn.pp.common.scan";
   public static final String DELIM = ":";
   private boolean logEnabled = false;
   private boolean consoleEnabled = false;

   private RemoteConsoleLogger() {
      rcLogger = Logger.getLogger(LOGGER_NAME);
      this.logFormatter = new LogFormatter();
      rcLogger.setUseParentHandlers(false);
      rcLogger.setLevel(Level.INFO);
      Logger var1 = Logger.getLogger("com.raritan.smartcard");
      var1.setUseParentHandlers(false);
      var1.setLevel(Level.INFO);
      var1 = Logger.getLogger("nn.pp.common.scan");
      var1.setUseParentHandlers(false);
      var1.setLevel(Level.INFO);
      var1 = Logger.getLogger("nn.pp.rccore.scan");
      var1.setUseParentHandlers(false);
      var1.setLevel(Level.INFO);
      this.removeAllHandlers();
   }

   private void createFileHandler() {
      try {
         fh = new FileHandler("%h/mpc.log", 1048576, 10, true);
         fh.setFormatter(this.logFormatter);
      } catch (IOException var2) {
         System.out.println("Cannot create log file, logging will be disabled.");
      } catch (Exception var3) {
         System.out.println("Cannot create log file, logging will be disabled. Caused by:");
         var3.printStackTrace();
      }
   }

   private void createConsoleHandler() {
      ch = new ConsoleHandler();
   }

   private void removeAllHandlers() {
      Handler[] var1 = rcLogger.getHandlers();
      if (var1 != null) {
         for (Handler var5 : var1) {
            rcLogger.removeHandler(var5);
         }
      }

      Logger var7 = Logger.getLogger("com.raritan.smartcard");

      for (Handler var6 : var7.getHandlers()) {
         var7.removeHandler(var6);
      }

      var7 = Logger.getLogger("nn.pp.common.scan");

      for (Handler var19 : var7.getHandlers()) {
         var7.removeHandler(var19);
      }

      var7 = Logger.getLogger("nn.pp.rccore.scan");

      for (Handler var20 : var7.getHandlers()) {
         var7.removeHandler(var20);
      }
   }

   public static RemoteConsoleLogger getInstance() {
      return remoteConsoleLogger;
   }

   public Logger getLogger() {
      return rcLogger;
   }

   public void enableLogging(boolean var1) {
      this.logEnabled = var1;
      rcLogger.setLevel(var1 ? logLevel : Level.OFF);
      Logger var2 = Logger.getLogger("com.raritan.smartcard");
      var2.setLevel(var1 ? logLevel : Level.OFF);
      var2 = Logger.getLogger("nn.pp.common.scan");
      var2.setLevel(var1 ? logLevel : Level.OFF);
      var2 = Logger.getLogger("nn.pp.rccore.scan");
      var2.setLevel(var1 ? logLevel : Level.OFF);
      this.removeAllHandlers();
      if (var1) {
         if (fh == null) {
            this.createFileHandler();
         }

         if (fh != null) {
            rcLogger.addHandler(fh);
            var2.addHandler(fh);
         }

         if (this.consoleEnabled) {
            if (ch == null) {
               this.createConsoleHandler();
            }

            rcLogger.addHandler(ch);
            var2.addHandler(ch);
         }
      }
   }

   public void enableConsoleLogging(boolean var1) {
      this.consoleEnabled = var1;
      this.enableLogging(this.logEnabled);
   }

   public void closeFileHandler() {
      if (fh != null) {
         fh.close();
         fh = null;
      }

      if (ch != null) {
         ch.close();
         ch = null;
      }
   }
}
