package nn.pp.rccore;

import java.text.ParseException;
import java.util.Iterator;
import java.util.StringTokenizer;
import java.util.Vector;

public class KeyboardMacro implements IKeyboardMacro {
   private String name;
   private String code;
   private KeyboardMacro.KeyCode[] keycodes;
   private boolean confirm;
   private static final String confirmPrefix = "confirm";

   public KeyboardMacro(String var1, String var2, KeyboardMacro.KeyCode[] var3, boolean var4) {
      this.name = new String(var1);
      this.code = new String(var2);
      this.copyKeycodes(var3);
      this.confirm = var4;
   }

   public KeyboardMacro(String var1, String var2, String var3) throws ParseException {
      this.name = new String(var1);
      if (var2.startsWith("confirm")) {
         this.code = new String(var2.substring("confirm".length()).trim());
         this.confirm = true;
      } else {
         this.code = new String(var2);
         this.confirm = false;
      }

      Vector var4 = new Vector();
      StringTokenizer var5 = new StringTokenizer(var3);

      while (var5.hasMoreTokens()) {
         try {
            int var6 = Integer.parseInt(var5.nextToken(), 16);
            var4.addElement(new Integer(var6));
         } catch (NumberFormatException var8) {
            throw new ParseException(var3, 0);
         }
      }

      this.keycodes = new KeyboardMacro.KeyCode[var4.size()];
      int var9 = 0;
      Iterator var7 = var4.iterator();

      while (var7.hasNext()) {
         this.keycodes[var9++] = new KeyboardMacro.KeyCode((Integer)var7.next());
      }
   }

   public KeyboardMacro(IKeyboardMacro var1) {
      this.name = new String(var1.getName());
      this.code = new String(var1.getCode());
      this.copyKeycodes(var1.getKeycodes());
      this.confirm = var1.getConfirm();
   }

   private void copyKeycodes(IKeyboardMacro.IKeyCode[] var1) {
      if (var1 != null) {
         this.keycodes = new KeyboardMacro.KeyCode[var1.length];

         for (int var2 = 0; var2 < var1.length; var2++) {
            this.keycodes[var2] = new KeyboardMacro.KeyCode(var1[var2]);
         }
      }
   }

   @Override
   public String getName() {
      return this.name;
   }

   @Override
   public String getCode() {
      return this.code;
   }

   @Override
   public String getCodeWithConfirm() {
      return this.confirm ? "confirm " + this.code : this.code;
   }

   @Override
   public String getNameOrCode() {
      return this.name != null && this.name.length() > 0 ? this.name : this.code;
   }

   @Override
   public IKeyboardMacro.IKeyCode[] getKeycodes() {
      return this.keycodes;
   }

   @Override
   public boolean getConfirm() {
      return this.confirm;
   }

   @Override
   public String getKeycodesAsString() {
      String var1 = "";

      for (int var2 = 0; this.keycodes != null && var2 < this.keycodes.length; var2++) {
         if (var1.length() > 0) {
            var1 = var1 + " ";
         }

         if (!this.keycodes[var2].isPress()) {
            return "";
         }

         var1 = var1 + Integer.toHexString(this.keycodes[var2].getCode());
      }

      return var1;
   }

   public class KeyCode implements IKeyboardMacro.IKeyCode {
      private int code;
      private boolean press;
      private boolean isDelay = false;

      public KeyCode(int var2, boolean var3) {
         this.code = var2;
         this.press = var3;
      }

      public KeyCode(int var2) {
         this(var2, true);
      }

      public KeyCode(IKeyboardMacro.IKeyCode var2) {
         this.code = var2.getCode();
         this.press = var2.isPress();
         this.isDelay = var2.isDelay();
      }

      public KeyCode(boolean var2, int var3) {
         this.code = var3;
         this.isDelay = var2;
         this.press = true;
      }

      @Override
      public int getCode() {
         return this.code;
      }

      @Override
      public boolean isPress() {
         return this.press;
      }

      @Override
      public boolean isDelay() {
         return this.isDelay;
      }
   }
}
