package nn.pp.rccore;

import java.util.ArrayList;
import java.util.List;
import nn.pp.core.T;

public class UsbProfileList implements Cloneable, IUsbProfileList {
   private UsbProfile active;
   private UsbProfile preferred;
   private List<IUsbProfile> profiles;
   private String errorMsg = "ERROR: ";

   public UsbProfileList() {
      this.profiles = new ArrayList<>();
   }

   public void addProfile(UsbProfile var1, boolean var2, boolean var3) {
      this.profiles.add(var1);
      if (var2 && this.active != null) {
         this.errorMsg = this.errorMsg + T._("Duplicate Active: " + this.active.getName() + " : " + var1.getName()) + "\n";
      } else if (var2 && this.active == null) {
         this.active = var1;
      }

      if (var3 && this.preferred != null) {
         this.errorMsg = this.errorMsg + T._("Duplicate Preferred: " + this.preferred.getName() + " : " + var1.getName()) + "\n";
      } else if (var3 && this.preferred == null) {
         this.preferred = var1;
      }
   }

   public void clear() {
      this.profiles.clear();
      this.active = null;
      this.preferred = null;
      System.runFinalization();
      System.gc();
   }

   @Override
   public List<IUsbProfile> getProfiles() {
      return this.profiles;
   }

   public void setProfiles(List<IUsbProfile> var1) {
      this.profiles = var1;
   }

   @Override
   public IUsbProfile getActive() {
      return this.active;
   }

   @Override
   public IUsbProfile getPreferred() {
      return this.preferred;
   }

   public void setActive(UsbProfile var1) {
      this.active = var1;
   }

   public void setPreferred(UsbProfile var1) {
      this.preferred = var1;
   }

   public int validate() {
      int var1 = 0;
      if (this.profiles.size() > 0) {
         if (this.active == null) {
            this.errorMsg = this.errorMsg + T._("No Active profile in message") + "\n";
         }

         if (this.preferred == null) {
            this.errorMsg = this.errorMsg + T._("No Preferred profile in message") + "\n";
         }

         for (var1 = 0; var1 < this.profiles.size(); var1++) {
            UsbProfile var2 = (UsbProfile)this.profiles.get(var1);
            if (var2.isSelected()) {
               break;
            }
         }

         if (var1 == this.profiles.size()) {
            this.errorMsg = this.errorMsg + T._("No Selected profile");
         }

         if (this.errorMsg.length() > 7) {
            this.clear();
            return -1;
         }
      }

      return 1;
   }

   public String getErrorMessage() {
      return this.errorMsg != null ? this.errorMsg : " ";
   }

   @Override
   public String toString() {
      StringBuffer var1 = new StringBuffer();
      var1.append(
         "UsbProfileList [Active: "
            + (this.active == null ? "null" : String.valueOf(this.active.getId()))
            + ", Preferred: "
            + (this.preferred == null ? "null" : String.valueOf(this.preferred.getId()))
      );

      for (IUsbProfile var3 : this.profiles) {
         var1.append(", Entry: " + var3.toString());
      }

      var1.append("]");
      return var1.toString();
   }

   @Override
   protected Object clone() throws CloneNotSupportedException {
      UsbProfileList var1 = new UsbProfileList();
      var1.setActive(this.active);
      var1.setPreferred(this.preferred);
      var1.setProfiles(this.getProfiles());
      return var1;
   }
}
