package nn.pp.rccore.impl;

import java.awt.Component;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.event.KeyEvent;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Vector;
import java.util.logging.ConsoleHandler;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.X509TrustManager;
import javax.swing.JComponent;
import javax.swing.KeyStroke;
import nn.pp.core.NotificationListener;
import nn.pp.core.T;
import nn.pp.core.impl.DeviceConnector;
import nn.pp.rccore.AudioStatusListener;
import nn.pp.rccore.ConnectionEventListener;
import nn.pp.rccore.IAudioStatusExSupport;
import nn.pp.rccore.IKeyboardMacro;
import nn.pp.rccore.IKvmPort;
import nn.pp.rccore.ILicenseSupport;
import nn.pp.rccore.IMultiMonitorTargetSupport;
import nn.pp.rccore.IUsbProfileList;
import nn.pp.rccore.IVMConfigInfo;
import nn.pp.rccore.IVMMountRequestResponse;
import nn.pp.rccore.IVideoSettings;
import nn.pp.rccore.KeyboardInfoListener;
import nn.pp.rccore.KeyboardListener;
import nn.pp.rccore.KeyboardMacro;
import nn.pp.rccore.KvmPort;
import nn.pp.rccore.MouseEventListener;
import nn.pp.rccore.MouseModeListener;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.RCException;
import nn.pp.rccore.VMMountRequestResponse;
import nn.pp.rccore.VideoEventListener;
import nn.pp.rccore.VideoSettings;
import nn.pp.rccore.VirtualMediaInfoListener;
import nn.pp.rccore.impl.keyboard.KeyboardHandler;
import nn.pp.rccore.impl.mouse.MouseHandler;
import nn.pp.rccore.impl.rfb.RfbHandler;
import nn.pp.rccore.impl.rfb.RfbRenderer;

public abstract class RCCoreImpl
   implements RCCore,
   VideoEventListener,
   AudioStatusListener,
   MouseModeListener,
   KeyboardInfoListener,
   VirtualMediaInfoListener,
   ConnectionEventListener {
   protected Logger logger;
   protected RemoteConsoleRenderer renderer;
   private boolean localKeyboardMappingPersistent = false;
   private boolean fpsEnabled = true;
   private boolean trafficSpeedEnabled = true;
   private final Map<Object, Object> clientProperties = Collections.synchronizedMap(new HashMap<>());
   protected ListenerLists listeners = new ListenerLists();
   private LicenseSupport licenseSupport = new LicenseSupport(this.listeners.licenseSupportListenerList);
   private AudioStatusExSupport audioSettingsSupport = new AudioStatusExSupport(this.listeners.audioSettingsExListenerList);
   private MultiMonitorTargetSupport multiMonitorTargetSupport = new MultiMonitorTargetSupport(this);
   private boolean encodingChangeAllowed = false;
   private boolean autoSupported = false;
   private List<RCCore.Predefine> predefines = new Vector<>();
   private List<RCCore.ColorDepth> depths = new Vector<>();
   private List<RCCore.Compression> compressions = new Vector<>();
   private boolean lossySupported = false;
   private boolean currentAuto = false;
   private RCCore.ColorDepth currentDepth = RCCore.ColorDepth.COLOR_16_BIT;
   private RCCore.Compression currentCompression = RCCore.Compression.LEVEL_5;
   private boolean currentLossy = false;
   private boolean videoSettingsSupported = false;
   private boolean videoAutoAdjustSupported = false;
   private boolean colorCalibrationSupported = false;
   private boolean videoRefreshSupported = false;
   private VideoSettings videoSettings;
   private boolean videoSettingsRequested = false;
   private Dimension resolution = new Dimension(640, 480);
   private boolean cimLangOptionsSupported = false;
   private boolean ethernetGigabitSupported = false;
   private boolean audiosupport = false;
   private boolean mouseModeChangeSupported = false;
   private List<RCCore.MouseMode> mouseModes = new Vector<>();
   private RCCore.MouseMode currentMouseMode;
   private boolean singleCursorSupported = false;
   private boolean singleCursorActive = false;
   private boolean mouseSyncSupported = false;
   private List<IKeyboardMacro> keyboardMacros = new Vector<>();
   private Locale softKeyboardLocale = null;
   private Locale localKeyboardLocale = null;
   private List<RCCore.KeyboardLed> keyboardState = new Vector<>();
   private boolean sunKeyboardSupported = false;
   private boolean virtualMediaSupported = false;
   private boolean virtualMediaReadOnly = false;
   private int virtualMediaDriveCount = 0;
   private boolean remoteIsoSupported = false;
   private List<IVMMountRequestResponse> remoteIsoList = new Vector<>();
   private IVMConfigInfo vmConfig;
   private IUsbProfileList usbProfileList;
   private List<KvmPort> kvmPortList = new Vector<>();
   private int serverSessionId = -1;
   private int connectedUsers = 0;
   private boolean monitorModeAllowed = false;
   private boolean monitorMode = false;
   private boolean exclusiveModeAllowed = false;
   private boolean exclusiveMode = false;
   private String protocolVersion = "1.0";
   private String deviceName = T._("Device");
   private int inSpeed = 0;
   private int outSpeed = 0;
   private int fps = 0;
   private X509TrustManager trustManager;
   private DeviceConnector connector;
   private RfbHandler rfbHandler;
   private String proxyConnectionId;
   private String proxyUseSSL;
   private LinkedHashMap<String, String> appletParameterMap;
   private boolean lowBandwidth = false;
   private boolean customAuto = false;
   private RCCore.Compression customCompression = null;
   private RCCore.ColorDepth customColorDepth = null;
   private RCCore.Smoothing customSmoothing = null;
   Dimension clientFrameSize;
   private Map<IMultiMonitorTargetSupport.ClientSessionInitProperties, String> clientSessionInitProps = Collections.emptyMap();

   protected abstract void loadRenderer();

   public RCCoreImpl(Logger var1) {
      if (var1 == null) {
         var1 = Logger.getLogger("Remote Console");
         var1.setUseParentHandlers(false);
         var1.addHandler(new ConsoleHandler());
         var1.setLevel(Level.SEVERE);
      }

      this.logger = var1;
      this.addVideoEventListener(this, 127);
      this.addAudioStatusListener(this);
      this.addMouseModeListener(this, 7);
      this.addKeyboardInfoListener(this, 23);
      this.addVirtualMediaInfoListener(this, 7);
      this.addConnectionEventListener(this, 8191);
   }

   public void init() {
      this.loadRenderer();
   }

   @Override
   public void encodingChangeAllowed(boolean var1) {
      this.encodingChangeAllowed = var1;
   }

   @Override
   public boolean isEncodingChangeSupported() {
      return this.encodingChangeAllowed;
   }

   @Override
   public void encodingAutoSupportedChanged(boolean var1) {
      this.autoSupported = var1;
   }

   @Override
   public boolean isEncodingAutoSupported() {
      return this.autoSupported;
   }

   @Override
   public void supportedEncodingPredefinesChanged(List<RCCore.Predefine> var1) {
      this.predefines = new Vector<>(var1);
   }

   @Override
   public List<RCCore.Predefine> getSupportedEncodingPredefines() {
      return this.predefines;
   }

   @Override
   public void supportedEncodingColorDepthsChanged(List<RCCore.ColorDepth> var1) {
      this.depths = new Vector<>(var1);
   }

   @Override
   public List<RCCore.ColorDepth> getSupportedEncodingColorDepths() {
      return this.depths;
   }

   @Override
   public void supportedEncodingCompressionsChanged(List<RCCore.Compression> var1) {
      this.compressions = new Vector<>(var1);
   }

   @Override
   public List<RCCore.Compression> getSupportedEncodingCompressions() {
      return this.compressions;
   }

   @Override
   public void encodingLossySupportedChanged(boolean var1) {
      this.lossySupported = var1;
   }

   @Override
   public boolean isEncodingLossySupported() {
      return this.lossySupported;
   }

   @Override
   public void encodingAutoChanged(boolean var1) {
      this.currentAuto = var1;
   }

   @Override
   public boolean isEncodingAuto() {
      return this.currentAuto;
   }

   @Override
   public void encodingColorDepthChanged(RCCore.ColorDepth var1) {
      this.currentDepth = var1;
   }

   @Override
   public RCCore.ColorDepth getEncodingColorDepth() {
      return this.currentDepth;
   }

   @Override
   public void encodingCompressionChanged(RCCore.Compression var1) {
      this.currentCompression = var1;
   }

   @Override
   public RCCore.Compression getEncodingCompression() {
      return this.currentCompression;
   }

   @Override
   public void encodingLossyChanged(boolean var1) {
      this.currentLossy = var1;
   }

   @Override
   public boolean isEncodingLossy() {
      return this.currentLossy;
   }

   @Override
   public void videoSettingsSupportChanged(boolean var1) {
      this.videoSettingsSupported = var1;
   }

   @Override
   public boolean isVideoSettingsSupported() {
      return this.videoSettingsSupported;
   }

   @Override
   public void videoAutoAdjustSupportChanged(boolean var1) {
      this.videoAutoAdjustSupported = var1;
   }

   @Override
   public boolean isVideoAutoAdjustSupported() {
      return this.videoAutoAdjustSupported;
   }

   @Override
   public void colorCalibrationSupportChanged(boolean var1) {
      this.colorCalibrationSupported = var1;
   }

   @Override
   public boolean isColorCalibrationSupported() {
      return this.colorCalibrationSupported;
   }

   @Override
   public void videoRefreshSupportChanged(boolean var1) {
      this.videoRefreshSupported = var1;
   }

   @Override
   public boolean isVideoRefreshSupported() {
      return this.videoRefreshSupported;
   }

   @Override
   public void videoSettingsUpdated(IVideoSettings var1) {
      this.videoSettings = new VideoSettings(var1);
   }

   public VideoSettings getVideoSettings() {
      return this.videoSettingsRequested ? this.videoSettings : null;
   }

   @Override
   public void resolutionChanged(Dimension var1) {
      Dimension var2 = new Dimension(var1);
      this.resolution = var2;
   }

   @Override
   public Dimension getResolution() {
      return this.resolution;
   }

   @Override
   public void osdMessageReceived(String var1, boolean var2) {
   }

   @Override
   public void cimLanguageOptionsSupported(boolean var1) {
      this.cimLangOptionsSupported = var1;
   }

   public boolean isCimLanguageOptionsSupported() {
      return this.cimLangOptionsSupported;
   }

   @Override
   public boolean isEthernetGigabitSupported() {
      return this.ethernetGigabitSupported;
   }

   @Override
   public void ethernetGigabitSupported(boolean var1) {
      this.ethernetGigabitSupported = var1;
   }

   @Override
   public void videoDataUpdated(Rectangle var1) {
   }

   @Override
   public void audioSupportChanged(boolean var1) {
      this.audiosupport = var1;
   }

   @Override
   public boolean isAudioStatusSupportEnabled() {
      return this.audiosupport;
   }

   @Override
   public void mouseModeChangeSupportChanged(boolean var1) {
      this.mouseModeChangeSupported = var1;
   }

   @Override
   public boolean isMouseModeChangeSupported() {
      return this.mouseModeChangeSupported;
   }

   @Override
   public void supportedMouseModesChanged(List<RCCore.MouseMode> var1) {
      this.mouseModes = new Vector<>(var1);
   }

   @Override
   public List<RCCore.MouseMode> getSupportedMouseModes() {
      return this.mouseModes;
   }

   @Override
   public void mouseModeChanged(RCCore.MouseMode var1) {
      this.currentMouseMode = var1;
   }

   @Override
   public RCCore.MouseMode getMouseMode() {
      return this.currentMouseMode;
   }

   @Override
   public void singleCursorModeSupportChanged(boolean var1) {
      this.singleCursorSupported = var1;
   }

   @Override
   public boolean isSingleCursorModeSupported() {
      return this.singleCursorSupported;
   }

   @Override
   public void singleCursorModeChanged(boolean var1) {
      this.singleCursorActive = var1;
   }

   @Override
   public boolean isSingleCursorMode() {
      return this.singleCursorActive;
   }

   @Override
   public void mouseSyncSupportChanged(boolean var1) {
      this.mouseSyncSupported = var1;
   }

   @Override
   public boolean isMouseSyncSupported() {
      return this.mouseSyncSupported;
   }

   @Override
   public void keyboardMacroListChanged(List<IKeyboardMacro> var1) {
      Vector var2 = new Vector(var1.size());

      for (IKeyboardMacro var4 : var1) {
         var2.add(new KeyboardMacro(var4));
      }

      this.keyboardMacros = var2;
   }

   @Override
   public List<IKeyboardMacro> getKeyboardMacroList() {
      return this.keyboardMacros;
   }

   @Override
   public void softKeyboardMappingChanged(Locale var1) {
      Locale var2 = new Locale(var1.getLanguage(), var1.getCountry(), var1.getVariant());
      this.softKeyboardLocale = var2;
   }

   @Override
   public Locale getSoftKeyboardMapping() {
      return this.softKeyboardLocale;
   }

   @Override
   public void localKeyboardMappingChanged(Locale var1) {
      Locale var2 = new Locale(var1.getLanguage(), var1.getCountry(), var1.getVariant());
      this.localKeyboardLocale = var2;
   }

   @Override
   public Locale getLocalKeyboardMapping() {
      return this.localKeyboardLocale;
   }

   @Override
   public void keyboardLedStateChanged(List<RCCore.KeyboardLed> var1) {
      this.keyboardState = new Vector<>(var1);
   }

   @Override
   public List<RCCore.KeyboardLed> getKeyboardLedState() {
      return this.keyboardState;
   }

   @Override
   public void sunKeyboardSupported(boolean var1) {
      this.sunKeyboardSupported = var1;
   }

   public boolean isSunKeyboardSupported() {
      return this.sunKeyboardSupported;
   }

   @Override
   public void virtualMediaSupportChanged(boolean var1) {
      this.virtualMediaSupported = var1;
   }

   @Override
   public boolean isVirtualMediaSupported() {
      return this.virtualMediaSupported;
   }

   @Override
   public void virtualMediaReadOnlyChanged(boolean var1) {
      this.virtualMediaReadOnly = var1;
   }

   @Override
   public boolean isVirtualMediaReadOnly() {
      return this.virtualMediaReadOnly;
   }

   @Override
   public void virtualMediaDriveCountChanged(int var1) {
      this.virtualMediaDriveCount = var1;
   }

   @Override
   public int getVirtualMediaDriveCount() {
      return this.virtualMediaDriveCount;
   }

   @Override
   public void remoteIsoSupportChanged(boolean var1) {
      this.remoteIsoSupported = var1;
   }

   @Override
   public boolean isVirtualMediaRemoteIsoSupported() {
      return this.remoteIsoSupported;
   }

   @Override
   public void remoteIsoListChanged(List<IVMMountRequestResponse> var1) {
      Vector var2 = new Vector(var1);

      for (IVMMountRequestResponse var4 : var1) {
         var2.add(new VMMountRequestResponse(var4));
      }

      this.remoteIsoList = var2;
   }

   @Override
   public List<IVMMountRequestResponse> getVirtualMediaRemoteIsoList() {
      return this.remoteIsoList;
   }

   @Override
   public void remoteIsoMountFinished(IVMMountRequestResponse var1) {
   }

   @Override
   public void virtualMediaConfigChanged(IVMConfigInfo var1) {
      this.vmConfig = var1;
   }

   public IVMConfigInfo getVMConfigInfo() {
      return this.vmConfig;
   }

   @Override
   public void UsbProfileListChanged(IUsbProfileList var1) {
      this.usbProfileList = var1;
   }

   @Override
   public IUsbProfileList getUsbProfileList() {
      return this.usbProfileList;
   }

   @Override
   public void requestUsbProfileChange(int var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.changeUsbProfile(var1);
      }
   }

   @Override
   public void disconnected(Exception var1) {
   }

   @Override
   public void connected() {
   }

   @Override
   public void languageChanged(Locale var1) {
   }

   @Override
   public void chatWelcomeChanged(String var1) {
   }

   @Override
   public void newChatMessage(String var1) {
   }

   @Override
   public String portListChanged(List<? extends IKvmPort> var1) {
      Vector var2 = new Vector();

      for (IKvmPort var4 : var1) {
         var2.add(new KvmPort(var4));
      }

      this.kvmPortList = var2;
      return null;
   }

   @Override
   public List<KvmPort> getPortList() {
      return this.kvmPortList;
   }

   @Override
   public void serverSessionIdChanged(int var1) {
      this.serverSessionId = var1;
   }

   @Override
   public int getServerSessionId() {
      return this.serverSessionId;
   }

   @Override
   public void connectedUsersChanged(int var1) {
      this.connectedUsers = var1;
   }

   @Override
   public int getConnectedUsers() {
      return this.connectedUsers;
   }

   @Override
   public void monitorModePermissionChanged(boolean var1) {
      this.monitorModeAllowed = var1;
   }

   @Override
   public boolean hasMonitorModePermission() {
      return this.monitorModeAllowed;
   }

   @Override
   public void monitorModeChanged(boolean var1) {
      this.monitorMode = var1;
   }

   @Override
   public boolean isMonitorMode() {
      return this.monitorMode;
   }

   @Override
   public void exclusiveModePermissionChanged(boolean var1) {
      this.exclusiveModeAllowed = var1;
   }

   @Override
   public boolean hasExclusiveModePermission() {
      return this.exclusiveModeAllowed;
   }

   @Override
   public void exclusiveModeChanged(boolean var1) {
      this.exclusiveMode = var1;
   }

   @Override
   public boolean isExclusiveMode() {
      return this.exclusiveMode;
   }

   @Override
   public void protocolVersionChanged(String var1) {
      String var2 = new String(var1);
      this.protocolVersion = var2;
   }

   @Override
   public String getProtocolVersion() {
      return this.protocolVersion;
   }

   @Override
   public void deviceNameChanged(String var1) {
      String var2 = new String(var1);
      this.deviceName = var2;
   }

   @Override
   public String getDeviceName() {
      return this.deviceName;
   }

   @Override
   public void incomingTrafficSpeed(int var1) {
      this.inSpeed = var1;
   }

   @Override
   public int getIncomingTrafficSpeed() {
      return this.inSpeed;
   }

   @Override
   public void outgoingTrafficSpeed(int var1) {
      this.outSpeed = var1;
   }

   @Override
   public int getOutgoingTrafficSpeed() {
      return this.outSpeed;
   }

   @Override
   public void framesPerSecond(int var1) {
      this.fps = var1;
   }

   @Override
   public int getFramesPerSecond() {
      return this.fps;
   }

   @Override
   public boolean isLocalKeyboardMappingPersistent() {
      return this.localKeyboardMappingPersistent;
   }

   @Override
   public void setLocalKeyboardMappingPersistent(boolean var1) {
      this.localKeyboardMappingPersistent = var1;
      if (this.rfbHandler != null) {
         this.rfbHandler.setLocalKeyboardMappingPersistent(this.localKeyboardMappingPersistent);
      }
   }

   @Override
   public JComponent getRCJComponent() {
      return this.renderer.getRCJComponent();
   }

   @Override
   public BufferedImage getSnapshot(Rectangle var1) {
      return this.renderer.getSnapshot(var1);
   }

   @Override
   public BufferedImage getSnapshot() {
      return this.renderer.getSnapshot();
   }

   @Override
   public double getScalingX() {
      return this.renderer.getScalingX();
   }

   @Override
   public double getScalingY() {
      return this.renderer.getScalingY();
   }

   @Override
   public boolean isScaleToFit() {
      return this.renderer.isScaleToFit();
   }

   @Override
   public boolean isScaleToFitKeepAr() {
      return this.renderer.isScaleToFitKeepAr();
   }

   @Override
   public void setScaling(double var1, double var3) throws IllegalArgumentException, UnsupportedOperationException {
      this.renderer.setScaling(var1, var3);
   }

   @Override
   public void setScaleToFit(boolean var1, boolean var2, Dimension var3) throws UnsupportedOperationException {
      this.renderer.setScaleToFit(var1, var2, var3);
   }

   @Override
   public RCCore.Interpolation getInterpolation() {
      return this.renderer.getInterpolation();
   }

   @Override
   public void setInterpolation(RCCore.Interpolation var1) {
      this.renderer.setInterpolation(var1);
   }

   @Override
   public void syncMouse(RCCore.MouseSyncType var1) {
      MouseHandler var2 = getMouseHandler(this.renderer);
      if (var2 != null) {
         var2.doMouseSync(var1);
      } else {
         this.rfbHandler.handleMouseSync(var1);
      }
   }

   @Override
   public void setSingleCursorMode(boolean var1) {
      this.renderer.setSingleCursorMode(var1);
   }

   @Override
   public void setCaptureRightAway(boolean var1) {
      this.renderer.setCaptureRightAway(var1);
   }

   @Override
   public void enforceSMMHotKeyCheck(boolean var1) {
      if (this.renderer != null) {
         this.renderer.setEnforceSmmHotkeyCheck(var1);
      }
   }

   @Override
   public void setMouseSyncHotkey(String var1, KeyStroke var2) {
      KeyboardHandler var3 = getKeyboardHandler(this.renderer);
      if (var3 != null) {
         var3.setMouseSyncHotkey(var1, var2);
      }
   }

   @Override
   public void setHotkeys(Map<Integer, KeyStroke> var1) {
      KeyboardHandler var2 = null;
      if (this.renderer != null) {
         var2 = getKeyboardHandler(this.renderer);
      }

      if (var2 != null) {
         var2.setHotkeys(var1);
      }
   }

   @Override
   public List<Locale> getSupportedLocalKeyboardMappings() {
      KeyboardHandler var1 = getKeyboardHandler(this.renderer);
      return var1 != null ? var1.getLocalKeyboardMappings() : null;
   }

   @Override
   public void setLocalKeyboardMapping(Locale var1) throws IOException {
      KeyboardHandler var2 = getKeyboardHandler(this.renderer);
      if (var2 != null) {
         var2.setLocalKeyboardMapping(var1);
      }

      if (this.localKeyboardMappingPersistent) {
         this.setLocalKeyboardMappingToRfb(var1);
      }
   }

   @Override
   public void sendKeyboardMacro(IKeyboardMacro var1, boolean var2) {
      if (this.renderer != null) {
         KeyboardHandler var3 = getKeyboardHandler(this.renderer);
         if (var3 != null) {
            var3.sendKeyboardMacro(var1, var2);
         }
      }
   }

   @Override
   public void setOSD(String var1, int var2, boolean var3) {
      this.renderer.setOSD(var1, var2, var3);
   }

   @Override
   public Cursor getCursor() {
      return this.renderer != null && this.renderer instanceof Component ? ((Component)this.renderer).getCursor() : null;
   }

   @Override
   public void setCursor(Cursor var1) {
      if (this.renderer != null && this.renderer instanceof Component) {
         ((Component)this.renderer).setCursor(var1);
      }
   }

   @Override
   public void setMonitorMode(boolean var1) {
      this.monitorMode = var1;
      if (this.rfbHandler != null) {
         this.rfbHandler.setMonitorOnly(var1);
      }
   }

   @Override
   public RCCore.Smoothing getSmoothing() {
      return this.rfbHandler != null ? this.rfbHandler.getRfbRenderer().getSmoothing() : RfbRenderer.defaultSmoothing;
   }

   @Override
   public void setSmoothing(RCCore.Smoothing var1) {
      if (this.rfbHandler != null) {
         this.rfbHandler.getRfbRenderer().setSmoothing(var1);
      }
   }

   @Override
   public void setEncodingToAuto() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setEncodingToAuto(true);
      }
   }

   @Override
   public void setEncodingPredefine(RCCore.Predefine var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setEncodingPredefine(var1);
      }
   }

   @Override
   public void setEncodingColorDepth(RCCore.ColorDepth var1, boolean var2) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setEncodingColorDepth(var1, var2);
      }
   }

   @Override
   public void setEncodingCompression(RCCore.Compression var1, boolean var2) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setEncodingCompression(var1, var2);
      }
   }

   @Override
   public void setEncodingLossy(boolean var1, boolean var2) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setEncodingLossy(var1, var2);
      }
   }

   @Override
   public void sendKeyboardEvent(int var1, boolean var2) {
      if (this.rfbHandler != null) {
         this.rfbHandler.consumeKeyboardEvent(var1, var2);
      }
   }

   @Override
   public void setExclusiveMode(boolean var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.sendPropertyChange("exclusive", var1 ? "on" : "off");
      }
   }

   @Override
   public void setKeyboardMacroList(List<IKeyboardMacro> var1) throws IOException {
      if (this.rfbHandler != null) {
         int var2 = 0;

         for (IKeyboardMacro var4 : var1) {
            this.rfbHandler.sendPropertyChange("HOTKEY_" + var2, var4.getCodeWithConfirm());
            String var5;
            if ((var5 = var4.getName()) != null) {
               this.rfbHandler.sendPropertyChange("HOTKEYNAME_" + var2, var5);
            }

            this.rfbHandler.sendPropertyChange("HOTKEYCODE_" + var2, var4.getKeycodesAsString());
            var2++;
         }
      }
   }

   @Override
   public void setSoftKeyboardMapping(Locale var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.sendPropertyChange("softkbd_mapping", var1.toString());
      }
   }

   private void setLocalKeyboardMappingToRfb(Locale var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.sendPropertyChange("localkbd_mapping", var1.toString());
      }
   }

   @Override
   public void sendChatMessage(String var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.sendChatMessage(var1);
      }
   }

   @Override
   public void switchKvmPort(int var1, String var2) throws IOException, RCException {
      if (this.rfbHandler != null) {
         this.rfbHandler.switchKvmPort(var1, var2);
      }
   }

   @Override
   public void requestVideoSettingsUpdates() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.requestVideoSettingsUpdates();
      }

      this.videoSettingsRequested = true;
   }

   @Override
   public void stopVideoSettingsUpdates() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.stopVideoSettingsUpdates();
      }

      this.videoSettingsRequested = false;
   }

   @Override
   public void setVideoSettings(IVideoSettings var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setVideoSettings(var1);
      }
   }

   @Override
   public void requestVideoAutoSense() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.requestVideoAutoSense();
      }
   }

   @Override
   public void requestVideoColorCalibration() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.requestVideoColorCalibration();
      }
   }

   @Override
   public void requestVideoRefresh() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.requestVideoRefresh();
      }
   }

   @Override
   public void saveVideoSettings() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.saveVideoSettings();
      }
   }

   @Override
   public void cancelVideoSettings() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.cancelVideoSettings();
      }
   }

   @Override
   public void resetVideoSettingsAllModes() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.resetVideoSettingsAllModes();
      }
   }

   @Override
   public void resetVideoSettingsThisMode() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.resetVideoSettingsThisMode();
      }
   }

   @Override
   public void resetVideoSettingsThisPort() throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.resetVideoSettingsThisPort();
      }
   }

   @Override
   public void mountOrUnmountRemoteIso(IVMMountRequestResponse var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.mountOrUnmountRemoteIso(var1);
      }
   }

   @Override
   public void setMouseMode(RCCore.MouseMode var1) throws IOException {
      if (this.rfbHandler != null) {
         this.rfbHandler.setMouseMode(var1);
      }
   }

   @Override
   public List<RCCore.ColorDepth> getSupportedColorDepthsForCompression(RCCore.Compression var1) {
      return this.rfbHandler != null ? this.rfbHandler.getSupportedColorDepthsForCompression(var1) : null;
   }

   @Override
   public List<RCCore.Compression> getSupportedCompressionsForColorDepth(RCCore.ColorDepth var1) {
      return this.rfbHandler != null ? this.rfbHandler.getSupportedCompressionsForColorDepth(var1) : null;
   }

   @Override
   public RCCore.ColorDepth getEncodingColorDepthForPredefine(RCCore.Predefine var1) {
      return this.rfbHandler != null ? this.rfbHandler.getColorDepthForPredefine(var1) : null;
   }

   @Override
   public RCCore.Compression getEncodingCompressionForPredefine(RCCore.Predefine var1) {
      return this.rfbHandler != null ? this.rfbHandler.getCompressionForPredefine(var1) : null;
   }

   @Override
   public boolean getEncodingLossyForPredefine(RCCore.Predefine var1) {
      return this.rfbHandler != null ? this.rfbHandler.getLossyForPredefine(var1) : false;
   }

   @Override
   public void setX509TrustManager(X509TrustManager var1) {
      this.trustManager = var1;
   }

   @Override
   public void connectRCWithRdmSession(String var1, int var2, boolean var3, String var4, String var5, String var6, String var7) throws IOException, RCException {
      this.renderer.init();
      this.connectToHost(var1, var2, var3, var4, null, null, null, var5, var6, var7);
   }

   @Override
   public void connectRCWithEricKey(String var1, int var2, boolean var3, String var4, String var5) throws IOException, RCException {
      this.renderer.init();
      this.connectToHost(var1, var2, var3, var4, null, null, var5, null);
   }

   @Override
   public void connectRCWithUserLogin(String var1, int var2, boolean var3, String var4, String var5, String var6) throws IOException, RCException {
      this.renderer.init();
      this.connectToHost(var1, var2, var3, var4, var5, var6, null, null);
   }

   private void connectToHost(String var1, int var2, boolean var3, String var4, String var5, String var6, String var7, String var8, String var9, String var10) throws IOException, RCException {
      this.proxyConnectionId = var9;
      this.proxyUseSSL = var10;
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8);
   }

   private void connectToHost(String var1, int var2, boolean var3, String var4, String var5, String var6, String var7, String var8) throws IOException, RCException {
      this.listeners.notificationListenerList.fireTextNotification(MessageFormat.format(T._("Connecting to {0}..."), var1));
      if (this.trafficSpeedEnabled) {
         this.connector = new MonitoringDeviceConnector(this.logger, this.trustManager, this.listeners.connectionEventListenerList);
      } else {
         this.connector = new DeviceConnector(this.logger, this.trustManager);
      }

      this.connector.connect(var1, var2, var3);
      if (this.proxyConnectionId != null && this.connector.getOutputStream() != null) {
         this.connector.writeCCSGproxyModePrefix(this.proxyConnectionId);
      }

      if (!var3 && this.proxyConnectionId != null && this.proxyUseSSL != null) {
         if (this.proxyUseSSL.equals("yes")) {
            System.out.println("CC-Proxy[KVM] mode: SSL enabled .. \n");
            this.connector.connectSSLWithSocket(var1, var2);
         } else {
            System.out.println("CC-Proxy[KVM] mode: plaintext .. \n");
         }
      }

      try {
         this.rfbHandler = RfbHandler.loadRfbHandler(this.connector, this.logger, this.listeners, this.renderer);
         this.rfbHandler.setClientSessionInitProps(this.clientSessionInitProps);
         this.rfbHandler.setLocalKeyboardMappingPersistent(this.localKeyboardMappingPersistent);
         this.rfbHandler.setLowBandwidth(this.lowBandwidth);
         this.rfbHandler.setFPS(this.fpsEnabled);
         if (this.customAuto) {
            this.rfbHandler.setEncodingToAuto(false);
         } else {
            RCCore.ColorDepth var9 = this.rfbHandler.setCustomColorDepth(this.customColorDepth);
            if (this.customColorDepth != null && var9 != null) {
               this.customColorDepth = var9;
            }

            if (this.customCompression != null) {
               RCCore.Compression var10 = this.rfbHandler.setCustomCompression(this.customCompression);
               if (var10 != null) {
                  this.customCompression = var10;
               }
            }
         }

         RCCore.Smoothing var13 = this.rfbHandler.setCustomSmoothing(this.customSmoothing);
         if (var13 != null) {
            this.customSmoothing = var13;
         }

         this.rfbHandler.setAppletParmeterMap(this.appletParameterMap);
         this.rfbHandler.connect(var4, var5, var6, var7, var8);
         if (this.monitorMode) {
            this.rfbHandler.setMonitorOnly(true);
         }
      } catch (IOException var11) {
         this.connector.disconnect();
         throw var11;
      } catch (RCException var12) {
         this.connector.disconnect();
         throw var12;
      }
   }

   @Override
   public void disconnect() {
      if (this.renderer != null) {
         this.renderer.dispose();
      }

      if (this.connector != null) {
         this.connector.disconnect();
      }

      if (this.rfbHandler != null) {
         this.rfbHandler.close();
         this.rfbHandler.dispose();
         this.rfbHandler = null;
      }

      this.dispose();
   }

   @Override
   public void dispose() {
      this.removeVideoEventListener(this);
      this.removeAudioStatusListener(this);
      this.removeMouseModeListener(this);
      this.removeKeyboardInfoListener(this);
      this.removeVirtualMediaInfoListener(this);
      if (this.renderer != null) {
         this.renderer = null;
      }

      if (this.connector != null) {
         this.connector = null;
      }

      if (this.trustManager != null) {
         this.trustManager = null;
      }

      if (this.listeners != null) {
         this.listeners = null;
      }

      if (this.predefines != null) {
         this.predefines = null;
      }

      if (this.depths != null) {
         this.depths = null;
      }

      if (this.compressions != null) {
         this.compressions = null;
      }

      if (this.currentDepth != null) {
         this.currentDepth = null;
      }

      if (this.currentCompression != null) {
         this.currentCompression = null;
      }

      if (this.videoSettings != null) {
         this.videoSettings = null;
      }

      if (this.mouseModes != null) {
         this.mouseModes = null;
      }

      if (this.currentMouseMode != null) {
         this.currentMouseMode = null;
      }

      if (this.keyboardMacros != null) {
         this.keyboardMacros = null;
      }

      if (this.keyboardState != null) {
         this.keyboardState = null;
      }

      if (this.remoteIsoList != null) {
         this.remoteIsoList = null;
      }

      if (this.vmConfig != null) {
         this.vmConfig = null;
      }

      if (this.usbProfileList != null) {
         this.usbProfileList = null;
      }

      if (this.kvmPortList != null) {
         this.kvmPortList = null;
      }

      if (this.appletParameterMap != null) {
         this.appletParameterMap = null;
      }
   }

   @Override
   public void addVideoEventListener(VideoEventListener var1, int var2) {
      if (this.listeners != null) {
         this.listeners.videoEventListenerList.addListener(var1, var2);
      }
   }

   @Override
   public void removeVideoEventListener(VideoEventListener var1) {
      if (this.listeners != null) {
         this.listeners.videoEventListenerList.removeListener(var1);
      }
   }

   @Override
   public void addNotificationListener(NotificationListener var1) {
      if (this.listeners != null) {
         this.listeners.notificationListenerList.addListener(var1);
      }
   }

   @Override
   public void removeNotificationListener(NotificationListener var1) {
      if (this.listeners != null) {
         this.listeners.notificationListenerList.removeListener(var1);
      }
   }

   @Override
   public void addConnectionEventListener(ConnectionEventListener var1, int var2) {
      if (this.listeners != null) {
         this.listeners.connectionEventListenerList.addListener(var1, var2);
      }
   }

   @Override
   public void removeConnectionEventListener(ConnectionEventListener var1) {
      if (this.listeners != null) {
         this.listeners.connectionEventListenerList.removeListener(var1);
      }
   }

   @Override
   public void addAudioStatusListener(AudioStatusListener var1) {
      if (this.listeners != null) {
         this.listeners.audioStatusListenerList.addListener(var1);
      }
   }

   @Override
   public void removeAudioStatusListener(AudioStatusListener var1) {
      if (this.listeners != null) {
         this.listeners.audioStatusListenerList.removeListener(var1);
      }
   }

   @Override
   public void addMouseModeListener(MouseModeListener var1, int var2) {
      if (this.listeners != null) {
         this.listeners.mouseModeListenerList.addListener(var1, var2);
      }
   }

   @Override
   public void removeMouseModeListener(MouseModeListener var1) {
      if (this.listeners != null) {
         this.listeners.mouseModeListenerList.removeListener(var1);
      }
   }

   @Override
   public void addKeyboardInfoListener(KeyboardInfoListener var1, int var2) {
      if (this.listeners != null) {
         this.listeners.keyboardInfoListenerList.addListener(var1, var2);
      }
   }

   @Override
   public void removeKeyboardInfoListener(KeyboardInfoListener var1) {
      if (this.listeners != null) {
         this.listeners.keyboardInfoListenerList.removeListener(var1);
      }
   }

   @Override
   public void addVirtualMediaInfoListener(VirtualMediaInfoListener var1, int var2) {
      if (this.listeners != null) {
         this.listeners.virtualMediaInfoListenerList.addListener(var1, var2);
      }
   }

   @Override
   public void removeVirtualMediaInfoListener(VirtualMediaInfoListener var1) {
      if (this.listeners != null) {
         this.listeners.virtualMediaInfoListenerList.removeListener(var1);
      }
   }

   @Override
   public void addKeyboardListener(KeyboardListener var1) {
      if (this.listeners != null) {
         this.listeners.keyboardListenerList.addListener(var1);
      }
   }

   @Override
   public void removeKeyboardListener(KeyboardListener var1) {
      if (this.listeners != null) {
         this.listeners.keyboardListenerList.removeListener(var1);
      }
   }

   @Override
   public void addMouseEventListener(MouseEventListener var1, int var2) {
      if (this.listeners != null) {
         this.listeners.mouseEventListenerList.addListener(var1, var2);
      }
   }

   @Override
   public void removeMouseEventListener(MouseEventListener var1) {
      if (this.listeners != null) {
         this.listeners.mouseEventListenerList.removeListener(var1);
      }
   }

   @Override
   public int getKeyCode(int var1, char var2, int var3) {
      KeyboardHandler var4;
      return (var4 = getKeyboardHandler(this.renderer)) != null ? var4.translateKeyEvent(var1, var2, var3) : -1;
   }

   @Override
   public void setAppletParameterMap(LinkedHashMap<String, String> var1) {
      this.appletParameterMap = var1;
   }

   @Override
   public void setLowBandwidth(boolean var1) {
      this.lowBandwidth = var1;
   }

   @Override
   public void setConnectionProperties(boolean var1, RCCore.Compression var2, RCCore.ColorDepth var3, RCCore.Smoothing var4) {
      this.customAuto = var1;
      this.customCompression = var2;
      this.customColorDepth = var3;
      this.customSmoothing = var4;
   }

   @Override
   public void sendKeyboardEvent(KeyEvent var1) throws RCException {
      if (var1 != null) {
         KeyboardHandler var2 = null;
         if (this.renderer != null) {
            var2 = getKeyboardHandler(this.renderer);
         }

         if (var2 != null) {
            if (var1.getID() == 401) {
               var2.keyPressed(var1);
            } else if (var1.getID() == 402) {
               var2.keyReleased(var1);
            } else {
               if (var1.getID() != 400) {
                  throw new RCException("Invalid Keyboard Event Specified");
               }

               var2.keyTyped(var1);
            }
         }
      }
   }

   @Override
   public void sendMouseEvent(boolean var1, int var2, int var3, int var4) {
      if (var1) {
         this.rfbHandler.consumeRelativeMouseEvent(var2, var3, var4);
      } else {
         this.rfbHandler.consumeAbsoluteMouseEvent(var2, var3, var4);
      }
   }

   @Override
   public void setClientFrameSizeChanged(Dimension var1) {
      this.clientFrameSize = var1;
      this.renderer.setFrameSize(var1);
   }

   @Override
   public void setClientSessionInitProperties(Map<RCCore.ClientSessionInitProperties, String> var1) {
      HashMap var2 = new HashMap();

      for (RCCore.ClientSessionInitProperties var4 : var1.keySet()) {
         var2.put(IMultiMonitorTargetSupport.ClientSessionInitProperties.valueOf(var4.name()), var1.get(var4));
      }

      this.setClientSessionInitProperties2(var2);
   }

   public void setClientSessionInitProperties2(Map<IMultiMonitorTargetSupport.ClientSessionInitProperties, String> var1) {
      this.clientSessionInitProps = Collections.unmodifiableMap(var1);
   }

   private static KeyboardHandler getKeyboardHandler(RemoteConsoleRenderer var0) {
      return var0 instanceof ISupportsKeyboardHandling ? ((ISupportsKeyboardHandling)var0).getKeyboardHandler() : null;
   }

   private static MouseHandler getMouseHandler(RemoteConsoleRenderer var0) {
      return var0 instanceof ISupportsMouseHandling ? ((ISupportsMouseHandling)var0).getMouseHandler() : null;
   }

   @Override
   public <CT> CT getCapablity(Class<CT> var1) {
      if (var1 == ILicenseSupport.class) {
         return (CT)this.licenseSupport;
      } else if (var1 == IAudioStatusExSupport.class) {
         return (CT)this.audioSettingsSupport;
      } else {
         return (CT)(var1 == IMultiMonitorTargetSupport.class ? this.multiMonitorTargetSupport : null);
      }
   }

   @Override
   public boolean isOsdDisabled() {
      return this.renderer != null ? this.renderer.isOsdDisabled() : false;
   }

   @Override
   public void setOsdDisabled(boolean var1) {
      if (this.renderer != null) {
         this.renderer.setOsdDisabled(var1);
      }
   }

   @Override
   public boolean isFPS() {
      return this.fpsEnabled;
   }

   @Override
   public boolean isTrafficSpeed() {
      return this.trafficSpeedEnabled;
   }

   @Override
   public void setFPS(boolean var1) {
      this.fpsEnabled = var1;
   }

   @Override
   public void setTrafficSpeed(boolean var1) {
      this.trafficSpeedEnabled = var1;
   }

   @Override
   public int getVideoUpdateDelay() {
      RfbHandler var1 = this.rfbHandler;
      return var1 != null ? var1.getVideoUpdateDelay() : 0;
   }

   @Override
   public void setVideoUpdateDelay(int var1) {
      RfbHandler var2 = this.rfbHandler;
      if (var2 != null) {
         var2.setVideoUpdateDelay(var1);
      }
   }

   @Override
   public Object getClientProperty(Object var1) {
      return this.clientProperties.get(var1);
   }

   @Override
   public void putClientProperty(Object var1, Object var2) {
      this.clientProperties.put(var1, var2);
   }
}
