package nn.pp.rccore.impl;

import java.awt.AlphaComposite;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.font.LineMetrics;
import java.awt.geom.Rectangle2D;
import java.awt.image.BufferedImage;
import java.util.HashMap;
import java.util.Timer;
import java.util.TimerTask;
import javax.swing.JComponent;

public class RemoteConsoleOsd {
   private JComponent owner;
   private Color osdBgColor = Color.yellow;
   private Color osdFgColor = Color.blue;
   private int osdAlpha = 50;
   private RemoteConsoleOsd.Position osdPosition = RemoteConsoleOsd.Position.CENTER;
   private Font osdFont;
   private final int defaultOsdHeight = 20;
   private final int defaultOsdMargin = 20;
   private boolean osdBlank = false;
   private String osdMessage;
   private boolean osdShow;
   private int osdWidth;
   private int osdHeight;
   private Timer osdTimer;
   private Image osdImage;
   private Graphics osdGraphics;
   HashMap<String, RemoteConsoleOsd.Position> positionMap;

   public RemoteConsoleOsd(JComponent var1) {
      this.owner = var1;
      this.osdFont = new Font("Monospaced", 1, 20);
      this.osdImage = new BufferedImage(10, 10, 1);
      this.osdGraphics = this.osdImage.getGraphics();
      this.positionMap = new HashMap<>();
      this.positionMap.put("TOP", RemoteConsoleOsd.Position.TOP);
      this.positionMap.put("CENTER", RemoteConsoleOsd.Position.CENTER);
      this.positionMap.put("BOTTOM", RemoteConsoleOsd.Position.BOTTOM);
   }

   public void setBgColor(Color var1) {
      this.osdBgColor = new Color(var1.getRGB());
   }

   public void setFgColor(Color var1) {
      this.osdFgColor = new Color(var1.getRGB());
   }

   public void setAlpha(int var1) {
      if (var1 >= 0 && var1 <= 100) {
         this.osdAlpha = var1;
      }
   }

   public void setPosition(RemoteConsoleOsd.Position var1) {
      this.osdPosition = var1;
   }

   public void setPosition(String var1) {
      RemoteConsoleOsd.Position var2 = this.positionMap.get(var1.toUpperCase());
      if (var2 != null) {
         this.setPosition(var2);
      }
   }

   public boolean osdBlank() {
      return this.osdBlank;
   }

   public boolean osdShow() {
      return this.osdShow;
   }

   public void renderOsd(Graphics var1, Dimension var2) {
      if (this.osdShow) {
         if (this.osdPosition != RemoteConsoleOsd.Position.CENTER && var2.width != this.osdImage.getWidth(null)) {
            this.generateOsdImage(var2.width);
         }

         int var3 = Math.max((var2.width - this.osdWidth) / 2, 0);
         int var4 = 0;
         if (this.osdPosition == RemoteConsoleOsd.Position.CENTER) {
            var4 = Math.max((var2.height - this.osdHeight) / 2, 0);
         } else if (this.osdPosition == RemoteConsoleOsd.Position.BOTTOM) {
            var4 = var2.height - this.osdHeight;
         } else {
            var4 = 0;
         }

         Graphics2D var5 = (Graphics2D)var1;
         AlphaComposite var6 = AlphaComposite.getInstance(3, this.osdAlpha / 100.0F);
         var5.setComposite(var6);
         var1.drawImage(this.osdImage, var3, var4, null);
      }
   }

   public void setOsd(String var1, int var2, boolean var3, int var4) {
      this.osdBlank = var3;
      this.osdMessage = var1;
      this.generateOsdImage(var4);
      if (this.osdTimer != null) {
         this.osdTimer.cancel();
         this.osdTimer = null;
      }

      if (var2 > 0 && this.osdShow) {
         this.osdTimer = new Timer("OSD");
         this.osdTimer.schedule(new TimerTask() {
            @Override
            public void run() {
               RemoteConsoleOsd.this.osdShow = false;
               RemoteConsoleOsd.this.osdTimer.cancel();
               RemoteConsoleOsd.this.osdTimer = null;
               RemoteConsoleOsd.this.owner.repaint();
            }
         }, var2);
      }
   }

   private void generateOsdImage(int var1) {
      if (this.osdMessage != null && this.osdMessage.length() > 0) {
         Graphics2D var4 = (Graphics2D)this.osdGraphics;
         Rectangle2D var5 = this.osdFont.getStringBounds(this.osdMessage, var4.getFontRenderContext());
         LineMetrics var6 = this.osdFont.getLineMetrics(this.osdMessage, var4.getFontRenderContext());
         int var2 = (int)var5.getWidth();
         int var3 = (int)var5.getHeight();
         if (this.osdPosition == RemoteConsoleOsd.Position.CENTER) {
            this.osdWidth = var2 + 20;
            this.osdHeight = 40;
         } else {
            this.osdWidth = var1;
            this.osdHeight = 20;
         }

         this.osdImage = new BufferedImage(this.osdWidth, this.osdHeight, 3);
         this.osdGraphics = this.osdImage.getGraphics();
         this.osdGraphics.setColor(this.osdBgColor);
         this.osdGraphics.fillRect(0, 0, this.osdWidth, this.osdHeight);
         this.osdGraphics.setColor(this.osdFgColor);
         this.osdGraphics.setFont(this.osdFont);
         this.osdGraphics.drawString(this.osdMessage, (this.osdWidth - var2) / 2, (int)(this.osdHeight - (this.osdHeight - var3) / 2 - var6.getDescent()));
         this.osdShow = true;
      } else {
         this.osdShow = false;
      }
   }

   public static enum Position {
      TOP,
      CENTER,
      BOTTOM;
   }
}
