package nn.pp.rccore.impl;

import java.awt.AlphaComposite;
import java.awt.Color;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Image;
import java.awt.Insets;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Toolkit;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.image.BufferedImage;
import java.awt.image.ImagingOpException;
import java.net.URL;
import java.text.ParseException;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JComponent;
import javax.swing.JPanel;
import nn.pp.core.T;
import nn.pp.core.Util;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.impl.keyboard.KeyboardEventConsumer;
import nn.pp.rccore.impl.keyboard.KeyboardHandler;
import nn.pp.rccore.impl.mouse.MouseEventConsumer;
import nn.pp.rccore.impl.mouse.MouseHandler;
import nn.pp.rccore.impl.mouse.MouseHandlerAbsolute;
import nn.pp.rccore.impl.mouse.MouseHandlerRelative;

public class RemoteConsoleRendererGraphical extends JComponent implements RemoteConsoleRenderer, ISupportsMouseHandling, ISupportsKeyboardHandling {
   private Logger logger;
   private ListenerLists listeners;
   private double scaleX = 1.0;
   private double scaleY = 1.0;
   private boolean scaleToFit = false;
   private boolean scaleToFitKeepAr = false;
   private Object sizeMtx;
   protected Dimension dimension;
   protected Dimension scaledDimension;
   protected Image image;
   protected Graphics graphics;
   protected FramebufferRenewer renewer;
   private RemoteConsoleOsd osd;
   private boolean osdDisabled = false;
   private MouseEventConsumer mouseConsumer;
   private boolean singleCursor = false;
   private MouseHandlerAbsolute mouseHandlerAbsolute;
   private MouseHandlerRelative mouseHandlerRelative;
   private MouseHandler mouseHandler;
   private Cursor oldCursor = null;
   private Cursor transparentCursor = null;
   private boolean enforceSmmHotkeyCheck = false;
   private KeyboardHandler keyboardHandler;
   private KeyboardEventConsumer keyboardConsumer;
   private static RenderingHints interpolNearestNeighbor = new RenderingHints(
      RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR
   );
   private static RenderingHints interpolBilinear = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BILINEAR);
   private static RenderingHints interpolBicubic = new RenderingHints(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
   private static RenderingHints antialiasOn = new RenderingHints(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
   private RenderingHints renderingHints;
   private RCCore.Interpolation interpolation = RCCore.Interpolation.GOOD;
   private boolean interpolationPossible = true;
   private Dimension frameSize;
   private RemoteConsoleRendererGraphical.ContainerPanel container;

   RemoteConsoleRendererGraphical(Logger var1, ListenerLists var2) {
      this.logger = var1;
      this.listeners = var2;
      this.renderingHints = new RenderingHints(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_DEFAULT);
      this.osd = new RemoteConsoleOsd(this);
      this.sizeMtx = new Object();
      this.dimension = new Dimension(640, 480);
      this.scaledDimension = new Dimension(640, 480);
      this.mouseHandlerAbsolute = new MouseHandlerAbsolute(this, var2.mouseEventListenerList);
      this.mouseHandlerRelative = new MouseHandlerRelative(this, var2.mouseEventListenerList, var2.notificationListenerList);
      this.setFocusTraversalKeysEnabled(false);
      this.keyboardHandler = new KeyboardHandler(var1, var2.keyboardListenerList, var2.keyboardInfoListenerList, this);
      this.addKeyListener(this.keyboardHandler);
      this.addFocusListener(this.keyboardHandler);
      this.transparentCursor = this.loadCursor("cur_trans.gif", "transparent");
      this.setSingleCursorMode(this.singleCursor);
      this.setInterpolation(this.interpolation);
      this.container = new RemoteConsoleRendererGraphical.ContainerPanel(this);
   }

   @Override
   public String toString() {
      return T._("Renderer without acceleration");
   }

   @Override
   public void setRenewer(FramebufferRenewer var1) {
      this.renewer = var1;
   }

   @Override
   public RCCore.Interpolation getInterpolation() {
      return this.interpolation;
   }

   @Override
   public void setInterpolation(RCCore.Interpolation var1) {
      this.renderingHints.clear();
      if (var1 == RCCore.Interpolation.FAST) {
         this.renderingHints.add(interpolNearestNeighbor);
      } else if (var1 == RCCore.Interpolation.GOOD) {
         this.renderingHints.add(interpolBilinear);
      } else if (var1 == RCCore.Interpolation.BEST) {
         this.renderingHints.add(interpolBicubic);
         this.renderingHints.add(antialiasOn);
      }

      this.repaint();
   }

   private Cursor loadCursor(String var1, String var2) {
      String var3 = "/" + this.getClass().getPackage().getName().replace('.', '/');
      URL var4 = this.getClass().getResource(var3.substring(0, var3.lastIndexOf(47) + 1) + "cursors/" + var1);
      if (var4 != null) {
         Image var5 = Toolkit.getDefaultToolkit().getImage(var4);
         if (var5 != null) {
            return Toolkit.getDefaultToolkit().createCustomCursor(var5, new Point(0, 0), var2);
         }
      }

      this.logger
         .log(
            Level.WARNING,
            "Failed to load cursor.. name: " + var2 + "  imageName: " + var1 + " from:\n\t" + var3.substring(0, var3.lastIndexOf(47) + 1) + "cursors/" + var1
         );
      return null;
   }

   @Override
   public void setMouseEventConsumer(MouseEventConsumer var1) {
      this.mouseConsumer = var1;
   }

   public MouseEventConsumer getMouseEventConsumer() {
      return this.mouseConsumer;
   }

   @Override
   public void setKeyboardEventConsumer(KeyboardEventConsumer var1) {
      this.keyboardConsumer = var1;
   }

   public KeyboardEventConsumer getKeyboardEventConsumer() {
      return this.keyboardConsumer;
   }

   private void setMouseHandler(MouseHandler var1) {
      if (this.mouseHandler != null) {
         this.removeMouseListener(this.mouseHandler);
         this.removeMouseMotionListener(this.mouseHandler);
         this.removeMouseWheelListener(this.mouseHandler);
      }

      this.mouseHandler = var1;
      this.addMouseListener(this.mouseHandler);
      this.addMouseMotionListener(this.mouseHandler);
      this.addMouseWheelListener(this.mouseHandler);
   }

   @Override
   public MouseHandler getMouseHandler() {
      return this.mouseHandler;
   }

   @Override
   public void setCursor(Cursor var1) {
      if (this.getCursor() == this.transparentCursor) {
         this.oldCursor = var1;
      } else {
         this.doSetCursor(var1);
      }
   }

   protected void doSetCursor(Cursor var1) {
      super.setCursor(var1);
   }

   @Override
   public void setSingleCursorMode(boolean var1) {
      if (var1) {
         if (this.getEnforceSmmHotkeyCheck()) {
            if (!this.keyboardHandler.haveMouseSyncHotkey()) {
               this.listeners.notificationListenerList.fireTextNotification(T._("Single Cursor Mode not possible, no hotkey is set!"));
               this.listeners.mouseModeListenerList.fireSingleCursorModeChanged(false);
               var1 = false;
            } else {
               this.setMouseHandler(this.mouseHandlerRelative);
               this.setTransparentCursor();
            }
         } else {
            this.setMouseHandler(this.mouseHandlerRelative);
            this.setTransparentCursor();
         }
      } else {
         this.setMouseHandler(this.mouseHandlerAbsolute);
         this.listeners.notificationListenerList.fireTextNotification(T._("Double Mouse Mode"));
         this.mouseHandlerRelative.relativeMouseModeLeft();
         this.oldCursor = Cursor.getDefaultCursor();
         this.restoreCursor();
      }

      this.singleCursor = var1;
   }

   public void setTransparentCursor() {
      if (this.getCursor() != this.transparentCursor) {
         this.oldCursor = this.getCursor();
         this.doSetCursor(this.transparentCursor);
      }
   }

   public void restoreCursor() {
      this.doSetCursor(this.oldCursor);
   }

   public boolean isSingleCursorMode() {
      return this.singleCursor;
   }

   @Override
   public void setMouseSyncString(String var1) {
      this.mouseHandlerRelative.setSynckey(var1);
   }

   @Override
   public void setMouseSyncKeys(String var1, String var2) throws ParseException {
      this.keyboardHandler.setMouseSyncHotkey(var1, var2);
   }

   @Override
   public KeyboardHandler getKeyboardHandler() {
      return this.keyboardHandler;
   }

   @Override
   public void setOsdBgColor(Color var1) {
      this.osd.setBgColor(var1);
   }

   @Override
   public void setOsdFgColor(Color var1) {
      this.osd.setFgColor(var1);
   }

   @Override
   public void setOsdAlpha(int var1) {
      this.osd.setAlpha(var1);
   }

   @Override
   public void setOsdPosition(String var1) {
      this.osd.setPosition(var1);
   }

   @Override
   public void setOsdDisabled(boolean var1) {
      this.osdDisabled = var1;
   }

   @Override
   public boolean isOsdDisabled() {
      return this.osdDisabled;
   }

   @Override
   protected void paintComponent(Graphics var1) {
      if (this.image != null) {
         this.paintContentInterpolated(var1, this.getPreferredSize());
      }
   }

   protected void paintContentInterpolated(Graphics var1, Dimension var2) {
      if (!var2.equals(this.dimension)) {
         if (this.interpolationPossible && this.interpolation != RCCore.Interpolation.NONE) {
            Graphics2D var3 = (Graphics2D)var1;
            var3.setRenderingHints(this.renderingHints);
         }

         try {
            this.paintContent(var1, var2);
         } catch (ImagingOpException var4) {
            this.interpolationPossible = false;
         }
      } else {
         this.paintContent(var1, var2);
      }
   }

   private void paintContent(Graphics var1, Dimension var2) {
      boolean var3 = this.osd.osdShow();
      if (var3) {
         Graphics2D var4 = (Graphics2D)var1;
         AlphaComposite var5 = AlphaComposite.getInstance(2, 1.0F);
         var4.setComposite(var5);
      }

      if (this.osd.osdBlank()) {
         var1.setColor(Color.black);
         var1.fillRect(0, 0, var2.width, var2.height);
      } else {
         int var7 = 0;
         int var8 = 0;
         if (this.isScaleToFit()) {
            Dimension var6 = this.getSize();
            if (var2.width < var6.width) {
               var7 = (var6.width - var2.width) / 2;
            }

            if (var2.height < var6.height) {
               var8 = (var6.height - var2.height) / 2;
            }
         }

         var1.drawImage(this.image, var7, var8, var2.width, var2.height, null);
      }

      if (var3) {
         this.osd.renderOsd(var1, var2);
      }
   }

   private Dimension getScaledDimension(Dimension var1) {
      Dimension var2;
      synchronized (this.sizeMtx) {
         var2 = new Dimension(this.dimension);
      }

      return Util.getScaledDimension(var1, var2);
   }

   @Override
   public Dimension getPreferredSize() {
      Dimension var1;
      if (this.scaleToFit) {
         synchronized (this.sizeMtx) {
            var1 = this.container.getSize();
            if (this.scaleToFitKeepAr) {
               var1 = this.getScaledDimension(var1);
            }
         }
      } else {
         var1 = this.scaledDimension;
      }

      return var1;
   }

   @Override
   public Dimension getMinimumSize() {
      return this.getPreferredSize();
   }

   @Override
   public Dimension getMaximumSize() {
      return this.getPreferredSize();
   }

   private Dimension getResolution() {
      return this.dimension;
   }

   @Override
   public JComponent getRCJComponent() {
      return this.container;
   }

   @Override
   public BufferedImage getSnapshot() {
      return this.getSnapshot(null);
   }

   @Override
   public BufferedImage getSnapshot(Rectangle var1) {
      boolean var2 = false;
      synchronized (this.sizeMtx) {
         if (var1 == null) {
            var1 = new Rectangle(0, 0, this.dimension.width, this.dimension.height);
            var2 = true;
         } else if (var1.x < 0
            || var1.y < 0
            || var1.width < 0
            || var1.height < 0
            || var1.x + var1.width > this.dimension.width
            || var1.y + var1.height > this.dimension.height) {
            throw new IllegalArgumentException();
         }
      }

      BufferedImage var6 = new BufferedImage(var1.width, var1.height, 1);
      Graphics var4 = var6.getGraphics();
      if (this.osd.osdBlank()) {
         var4.setColor(Color.black);
         var4.fillRect(0, 0, var1.width, var1.height);
      } else {
         var4.drawImage(this.image, 0, 0, var1.width, var1.height, var1.x, var1.y, var1.x + var1.width, var1.y + var1.height, null);
      }

      if (var2 && this.osd.osdShow()) {
         this.osd.renderOsd(var4, new Dimension(var1.width, var1.height));
      }

      return var6;
   }

   @Override
   public void drawRemoteConsoleData(Image var1, int var2, int var3, int var4, int var5) {
      this.graphics.setClip(var2, var3, var4, var5);
      this.graphics.drawImage(var1, 0, 0, null);
      if (this.dimension != null) {
         this.graphics.setClip(0, 0, this.dimension.width, this.dimension.height);
      }

      if (this.scaleToFit) {
         this.repaint();
      } else {
         int var6 = Math.max(0, (int)(var2 * this.scaleX) - 1);
         int var7 = Math.max(0, (int)(var3 * this.scaleY) - 1);
         int var8 = (int)((var2 + var4) * this.scaleX) + 1;
         int var9 = (int)((var3 + var5) * this.scaleY) + 1;
         this.repaint(new Rectangle(var6, var7, var8 - var6, var9 - var7));
      }
   }

   protected void createImage() {
      if (this.image != null) {
         this.image.flush();
      }

      if (this.graphics != null) {
         this.graphics.dispose();
      }

      this.image = this.createImage(this.dimension.width, this.dimension.height);
      this.graphics = this.image.getGraphics();
   }

   @Override
   public void screenResolutionChanged(Dimension var1) {
      synchronized (this.sizeMtx) {
         this.dimension = new Dimension(var1.width, var1.height);
         this.scaledDimension = new Dimension((int)(var1.width * this.scaleX), (int)(var1.height * this.scaleY));
      }

      this.createImage();
      this.revalidate();
   }

   @Override
   public void setOSD(String var1, int var2, boolean var3) {
      int var4;
      synchronized (this.sizeMtx) {
         var4 = this.dimension.width;
      }

      this.osd.setOsd(this.osdDisabled ? null : var1, var2, var3, var4);
      this.repaint();
   }

   @Override
   public void init() {
      this.listeners.videoEventListenerList.fireResolutionChanged(this.getResolution());
   }

   @Override
   public void dispose() {
      if (this.mouseHandlerAbsolute != null) {
         this.mouseHandlerAbsolute.dispose();
         this.mouseHandlerAbsolute = null;
      }

      if (this.mouseHandlerRelative != null) {
         this.mouseHandlerRelative.dispose();
         this.mouseHandlerRelative = null;
      }

      if (this.keyboardHandler != null) {
         this.keyboardHandler.dispose();
         this.keyboardHandler = null;
      }

      if (this.listeners != null) {
         this.listeners = null;
      }

      if (this.image != null) {
         this.image = null;
      }

      if (this.graphics != null) {
         this.graphics = null;
      }

      if (this.renewer != null) {
         this.renewer = null;
      }

      if (this.osd != null) {
         this.osd = null;
      }
   }

   @Override
   public double getScalingX() {
      synchronized (this.sizeMtx) {
         return this.scaleX;
      }
   }

   @Override
   public double getScalingY() {
      synchronized (this.sizeMtx) {
         return this.scaleY;
      }
   }

   @Override
   public boolean isScaleToFit() {
      synchronized (this.sizeMtx) {
         return this.scaleToFit;
      }
   }

   @Override
   public boolean isScaleToFitKeepAr() {
      synchronized (this.sizeMtx) {
         return this.scaleToFitKeepAr;
      }
   }

   @Override
   public void setScaling(double var1, double var3) throws IllegalArgumentException {
      if (var1 <= 0.0) {
         throw new IllegalArgumentException(T._("X scaling parameter out of range"));
      } else if (var3 <= 0.0) {
         throw new IllegalArgumentException(T._("X scaling parameter out of range"));
      } else {
         synchronized (this.sizeMtx) {
            this.scaleX = var1;
            this.scaleY = var3;
            this.scaledDimension = new Dimension((int)(this.dimension.width * this.scaleX), (int)(this.dimension.height * this.scaleY));
         }
      }
   }

   @Override
   public void setScaleToFit(boolean var1, boolean var2, Dimension var3) {
      synchronized (this.sizeMtx) {
         this.scaleToFit = var1;
         this.scaleToFitKeepAr = var2;
         this.container.setSize(var3);
      }
   }

   public void descalePoint(Point var1) {
      double var2 = var1.getX();
      double var4 = var1.getY();
      synchronized (this.sizeMtx) {
         double var7 = this.scaleX;
         double var9 = this.scaleY;
         if (this.scaleToFit) {
            Dimension var11 = this.getPreferredSize();
            var7 = var11.getWidth() / this.dimension.getWidth();
            var9 = var11.getHeight() / this.dimension.getHeight();
         }

         var1.setLocation(
            Math.max(0.0, Math.min((double)(this.dimension.width - 1), var2 / var7)), Math.max(0.0, Math.min((double)(this.dimension.height - 1), var4 / var9))
         );
      }
   }

   @Override
   public void setCaptureRightAway(boolean var1) {
      this.getMouseHandler().setCaptureRightAway(var1);
   }

   public boolean getEnforceSmmHotkeyCheck() {
      return this.enforceSmmHotkeyCheck;
   }

   @Override
   public void setEnforceSmmHotkeyCheck(boolean var1) {
      this.enforceSmmHotkeyCheck = var1;
   }

   @Override
   public void setFrameSize(Dimension var1) {
      this.frameSize = var1;
   }

   public Dimension getFrameSize() {
      return this.frameSize;
   }

   @Override
   public <CT> CT getCapablity(Class<CT> var1) {
      return null;
   }

   @Override
   public ReadWriteLock getLock() {
      return null;
   }

   @Override
   public void setImageProvider(ImageProvider var1) {
   }

   private class ContainerPanel extends JPanel {
      private JComponent comp;

      public ContainerPanel(JComponent var2) {
         this.comp = var2;
         this.setLayout(new GridBagLayout());
         this.add(this.comp, new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
         var2.enableInputMethods(false);
      }

      @Override
      public void requestFocus() {
         this.comp.requestFocus();
      }

      @Override
      public boolean requestFocusInWindow() {
         return this.comp.requestFocusInWindow();
      }

      @Override
      public synchronized void addMouseMotionListener(MouseMotionListener var1) {
         super.addMouseMotionListener(var1);
         this.comp.addMouseMotionListener(var1);
      }

      @Override
      public synchronized void removeMouseMotionListener(MouseMotionListener var1) {
         super.removeMouseMotionListener(var1);
         this.comp.removeMouseMotionListener(var1);
      }

      @Override
      public synchronized void addMouseListener(MouseListener var1) {
         super.addMouseListener(var1);
         this.comp.addMouseListener(var1);
      }

      @Override
      public synchronized void removeMouseListener(MouseListener var1) {
         super.removeMouseListener(var1);
         this.comp.removeMouseListener(var1);
      }
   }
}
