package nn.pp.rccore.impl.keyboard;

import java.awt.event.KeyEvent;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Vector;

public abstract class CharTranslator extends KeyTranslator implements CharTranslatorConstants {
   private boolean isLeftShiftDown = false;
   private boolean isRightShiftDown = false;
   private boolean isAltGrDown = false;
   protected KeyTranslator targetLanguage = null;
   protected Hashtable<Character, Vector<Integer>> charMappings = new Hashtable<>();
   protected HashSet<Integer> ctrlModifiedKeys = new HashSet<>();

   protected CharTranslator() {
      this.setTargetTranslator();
      this.addCharsToTranslate();
   }

   protected void setTargetTranslator() {
      this.targetLanguage = new KeyTranslator_en_US();
   }

   @Override
   protected void addKeys() {
      this.addKeyMappingByCode(8, 1, 13);
      this.addKeyMappingByCode(20, 1, 28);
      this.addKeyMappingByCode(27, 1, 59);
      this.addKeyMappingByCode(112, 1, 60);
      this.addKeyMappingByCode(113, 1, 61);
      this.addKeyMappingByCode(114, 1, 62);
      this.addKeyMappingByCode(115, 1, 63);
      this.addKeyMappingByCode(116, 1, 64);
      this.addKeyMappingByCode(117, 1, 65);
      this.addKeyMappingByCode(118, 1, 66);
      this.addKeyMappingByCode(119, 1, 67);
      this.addKeyMappingByCode(120, 1, 68);
      this.addKeyMappingByCode(121, 1, 69);
      this.addKeyMappingByCode(122, 1, 70);
      this.addKeyMappingByCode(123, 1, 71);
      this.addKeyMappingByCode(154, 1, 72);
      this.addKeyMappingByCode(145, 1, 73);
      this.addKeyMappingByCode(19, 1, 74);
      this.addKeyMappingByCode(155, 1, 75);
      this.addKeyMappingByCode(36, 1, 76);
      this.addKeyMappingByCode(33, 1, 77);
      this.addKeyMappingByCode(127, 1, 78);
      this.addKeyMappingByCode(35, 1, 79);
      this.addKeyMappingByCode(34, 1, 80);
      this.addKeyMappingByCode(38, 1, 81);
      this.addKeyMappingByCode(37, 1, 82);
      this.addKeyMappingByCode(40, 1, 83);
      this.addKeyMappingByCode(39, 1, 84);
      this.addKeyMappingByCode(525, 1, 106);
   }

   protected abstract void addCharsToTranslate();

   @Override
   public abstract Locale getLocale();

   protected boolean anyShiftDown() {
      return this.isLeftShiftDown | this.isRightShiftDown;
   }

   protected void addCharMappings(char var1, int[] var2) {
      Vector var3 = new Vector(var2.length);

      for (int var7 : var2) {
         var3.add(var7);
      }

      this.charMappings.put(var1, var3);
   }

   private Vector<Integer> restoreShiftStates(boolean var1, boolean var2) {
      Vector var3 = new Vector();
      if (var1 != this.isLeftShiftDown) {
         var3.add((this.isLeftShiftDown ? 65536 : 0) | this.translateTargetKeyEvent(16, '\u0000', 2));
         this.isLeftShiftDown = var1;
      }

      if (var2 != this.isRightShiftDown) {
         var3.add((this.isRightShiftDown ? 65536 : 0) | this.translateTargetKeyEvent(16, '\u0000', 3));
         this.isRightShiftDown = var2;
      }

      return var3;
   }

   private Vector<Integer> restoreAltGrState(boolean var1) {
      Vector var2 = new Vector();
      if (!this.allowAltGr()) {
         return var2;
      } else {
         if (var1 != this.isAltGrDown) {
            var2.add((this.isAltGrDown ? 65536 : 0) | this.translateTargetKeyEvent(65406, '\u0000', 3));
            this.isAltGrDown = var1;
         }

         return var2;
      }
   }

   private void interpretKeyList(Vector<Integer> var1, boolean var2, boolean var3, boolean var4) {
      for (int var7 = 0; var7 < var1.size(); var7++) {
         int var5 = (Integer)var1.get(var7);
         switch (var5) {
            case 131072:
               if (this.anyShiftDown()) {
                  var1.remove(var7);
                  var7--;
               } else {
                  var1.set(var7, this.translateTargetKeyEvent(16, '\u0000', 2));
                  this.isLeftShiftDown = true;
               }
               break;
            case 262144:
               if (this.isLeftShiftDown) {
                  var1.insertElementAt(65536 | this.translateTargetKeyEvent(16, '\u0000', 2), var7);
                  this.isLeftShiftDown = false;
                  var7++;
               }

               if (this.isRightShiftDown) {
                  var1.insertElementAt(65536 | this.translateTargetKeyEvent(16, '\u0000', 3), var7);
                  this.isRightShiftDown = false;
                  var7++;
               }

               var1.remove(var7);
               var7--;
               break;
            case 393216:
               int var11 = var1.size();
               var1.remove(var7);
               var1.addAll(var7, this.restoreShiftStates(var2, var3));
               var7 = var7 + var1.size() - var11;
               break;
            case 524288:
               if (!this.isAltGrDown && this.allowAltGr()) {
                  var1.set(var7, this.translateTargetKeyEvent(65406, '\u0000', 3));
                  this.isAltGrDown = true;
               } else {
                  var1.remove(var7);
                  var7--;
               }
               break;
            case 1048576:
               if (this.isAltGrDown && this.allowAltGr()) {
                  var1.set(var7, 65536 | this.translateTargetKeyEvent(65406, '\u0000', 3));
                  this.isAltGrDown = false;
               } else {
                  var1.remove(var7);
                  var7--;
               }
               break;
            case 1572864:
               int var10 = var1.size();
               var1.remove(var7);
               var1.addAll(var7, this.restoreAltGrState(var4));
               var7 = var7 + var1.size() - var10;
               break;
            case 1966080:
               int var6 = var1.size();
               var1.remove(var7);
               var1.addAll(var7, this.restoreShiftStates(var2, var3));
               var1.addAll(var7 + var1.size() - var6 + 1, this.restoreAltGrState(var4));
               var7 = var7 + var1.size() - var6;
               break;
            default:
               int var8 = var5 & 65536;
               var5 = (var5 | 65536) ^ 65536;
               var1.set(var7, var8 | this.translateTargetKeyEvent(var5, '\u0000', 1));
         }
      }
   }

   public Vector<Integer> translateChar(KeyEvent var1) {
      char var2 = var1.getKeyChar();
      Vector var3 = this.charMappings.get(var2) == null ? null : new Vector<>(this.charMappings.get(var2));
      if (var3 != null) {
         boolean var4 = this.isLeftShiftDown;
         boolean var5 = this.isRightShiftDown;
         boolean var6 = this.isAltGrDown;
         this.interpretKeyList(var3, var4, var5, var6);
         var3.addAll(this.restoreShiftStates(var4, var5));
         var3.addAll(this.restoreAltGrState(var6));
      }

      return var3;
   }

   @Override
   public int translateKeyEvent(KeyEvent var1) {
      int var2 = var1.getKeyLocation();
      int var3 = var1.getKeyCode();
      int var4 = var1.getID();
      int var5 = var1.getModifiersEx();
      if ((var5 & 128) > 0 && var3 != 17 && (var5 & 512) == 0 && var4 == 401) {
         this.ctrlModifiedKeys.add(var3);
         return this.targetLanguage.translateKeyEvent(var1);
      } else if (this.ctrlModifiedKeys.contains(var3) && var4 == 402) {
         this.ctrlModifiedKeys.remove(var3);
         return this.targetLanguage.translateKeyEvent(var1);
      } else {
         if (var3 == 16) {
            if (var2 == 2) {
               this.isLeftShiftDown = var4 == 401;
            } else if (var2 == 3) {
               this.isRightShiftDown = var4 == 401;
            }
         } else if (var3 == 65406) {
            this.isAltGrDown = var4 == 401;
         } else if (var3 == 18 && var2 == 3) {
            this.isAltGrDown = var4 == 401;
         }

         if (var2 != 1) {
            return this.targetLanguage.translateKeyEvent(var1);
         } else {
            Integer var6 = this.getByCode(var3, var2);
            return var6 == null ? -1 : var6;
         }
      }
   }

   public int translateTargetKeyEvent(int var1, char var2, int var3) {
      return this.targetLanguage.translateKeyEvent(var1, var2, var3);
   }

   @Override
   public int translateKeyEvent(int var1, char var2, int var3) {
      return this.translateTargetKeyEvent(var1, var2, var3);
   }
}
