package nn.pp.rccore.impl.keyboard;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.io.IOException;
import java.text.MessageFormat;
import java.text.ParseException;
import java.util.EmptyStackException;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Stack;
import java.util.StringTokenizer;
import java.util.Timer;
import java.util.TimerTask;
import java.util.Vector;
import java.util.Map.Entry;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.KeyStroke;
import nn.pp.core.Platform;
import nn.pp.core.T;
import nn.pp.rccore.IKeyboardMacro;
import nn.pp.rccore.impl.KeyboardInfoListenerList;
import nn.pp.rccore.impl.KeyboardListenerList;
import nn.pp.rccore.impl.RemoteConsoleRendererGraphical;
import nn.pp.rccore.impl.mouse.MouseHandler;

public class KeyboardHandler implements KeyListener, FocusListener {
   private static final int CAPS = 28;
   private static final int LEFT_SHIFT = 41;
   private static final int RIGHT_SHIFT = 53;
   private static final int LEFT_CTRL = 54;
   private static final int ALT = 55;
   private static final int ALTGR = 57;
   private static final int RIGHT_CTRL = 58;
   private static final int NUMLOCK = 85;
   private static final int LEFT_WIN = 105;
   private static final int RIGHT_WIN = 107;
   private static final int ESCAPE = 59;
   private static final int ENTER = 27;
   private static final int NUMPAD_ENTER = 98;
   private static final int KANJI = 0;
   private static final int JP_CONVERT = 109;
   private static final int JP_NO_CONVERT = 108;
   private static final int JP_CAPS_LOCK = 28;
   private static final int JP_KANA = 110;
   private Logger logger;
   private KeyboardListenerList listenerList;
   private KeyboardInfoListenerList infoListenerList;
   private RemoteConsoleRendererGraphical renderer;
   private KeyStroke mouseSyncKeyStroke = null;
   private HashMap<Integer, KeyStroke> hotkeyKeyStrokes = null;
   private Hashtable<Integer, Boolean> hashMouseSync = null;
   private boolean mouseSyncCombo = false;
   private boolean altGrDown = false;
   private Object lock = new Object();
   private Vector<Integer> pressedKeys = new Vector<>();
   private Timer altGrPressTimer = null;
   private boolean ctrlPressPending = false;
   private boolean ctrlDown = false;
   private boolean leftAltPressed = false;
   private boolean leftAltReleased = false;
   private boolean leftCtrlReleased = false;
   private boolean altGraphDown = false;
   private boolean hotKeyDetected = false;
   private int[] modifiers = new int[]{41, 53, 54, 55, 57, 58, 105, 107};
   private int[] permanentModifiers = new int[]{28, 85};
   private KeyTranslator[] keyTranslatorList = new KeyTranslator[]{
      new KeyTranslator_en_US(),
      new KeyTranslator_da_DK(),
      new KeyTranslator_de_CH(),
      new KeyTranslator_de_DE(),
      new KeyTranslator_en_GB(),
      new KeyTranslator_es_ES(),
      new KeyTranslator_fr_CH(),
      new KeyTranslator_fr_FR_Impl(),
      new KeyTranslator_hu_HU(),
      new KeyTranslator_it_IT(),
      new KeyTranslator_ja_JP_Impl(),
      new KeyTranslator_ko_KR(),
      new KeyTranslator_fr_BE(),
      new KeyTranslator_no_NO(),
      new KeyTranslator_pt_PT(),
      new KeyTranslator_sl_SL(),
      new KeyTranslator_sv_SE(),
      new CharTranslator_fr_to_en(),
      new CharTranslator_fr_to_en_intl()
   };
   private KeyTranslator keyTranslator;
   private boolean ignoreNextNumpadKeyTyped = false;
   private boolean holdLCtrl = false;
   private long LCtrlTime;
   private int heldNumpadKeyNo;
   private boolean holdNumpadPress = false;
   private boolean macroJustSent = false;

   public KeyboardHandler(Logger var1, KeyboardListenerList var2, KeyboardInfoListenerList var3, RemoteConsoleRendererGraphical var4) {
      this.logger = var1;
      this.listenerList = var2;
      this.infoListenerList = var3;
      this.renderer = var4;
      this.loadKeyTranslator();
   }

   public void dispose() {
      this.releaseAllKeys();
      if (this.keyTranslatorList != null) {
         this.keyTranslatorList = null;
      }

      if (this.keyTranslator != null) {
         this.keyTranslator.dispose();
         this.keyTranslator = null;
      }
   }

   public void setMouseSyncHotkey(String var1, KeyStroke var2) {
      this.mouseSyncKeyStroke = var2;
      this.renderer.setMouseSyncString(var1);
   }

   public void setMouseSyncHotkey(String var1, String var2) throws ParseException {
      if (this.mouseSyncKeyStroke == null) {
         this.mouseSyncCombo = true;
         this.hashMouseSync = new Hashtable<>();
         if (var2 != null) {
            StringTokenizer var3 = new StringTokenizer(var2);

            while (var3.hasMoreTokens()) {
               try {
                  int var4 = Integer.parseInt(var3.nextToken(), 16);
                  this.logger.log(Level.FINER, "Sync: parsed keyNo: " + var4);
                  this.hashMouseSync.put(new Integer(var4), new Boolean(false));
               } catch (NumberFormatException var5) {
                  throw new ParseException(var2, 0);
               }
            }

            this.renderer.setMouseSyncString(var1);
         }
      }
   }

   public boolean haveMouseSyncHotkey() {
      return this.mouseSyncKeyStroke != null || this.hashMouseSync != null;
   }

   public void setHotkeys(Map<Integer, KeyStroke> var1) {
      this.hotkeyKeyStrokes = new HashMap<>();

      for (Entry var3 : var1.entrySet()) {
         this.hotkeyKeyStrokes.put((Integer)var3.getKey(), (KeyStroke)var3.getValue());
      }
   }

   private boolean isJapaneseKey(int var1) {
      return this.keyTranslator.getLocale().getLanguage().equals("ja") && (var1 >= 108 && var1 <= 110 || var1 == 0 || var1 == 28 || var1 >= 243 && var1 <= 245);
   }

   @Override
   public void keyPressed(KeyEvent var1) {
      if (!this.handleHotkeys(var1)) {
         int var2 = this.translateKeyEvent(var1);
         if (Platform.isMac() && var2 == 28) {
            this.processKeyPressed(var2);
            this.processKeyReleased(var2);
            this.logger.log(Level.INFO, T._("Key Pressed: Mac : Sending Press/Release for CAPS LOCK."));
         } else if (Platform.isSun() && this.isPermanentModifier(var2)) {
            this.processKeyPressed(var2);
            this.processKeyReleased(var2);
            this.logger.log(Level.INFO, T._("Key Pressed: Solaris : Sending Press/Release for CAPS/NUM LOCK."));
         } else if (var2 != 0 && var2 != 108 && var2 != 109 && var2 != 110 && var2 != 28 || !this.keyTranslator.getLocale().getLanguage().equals("ja")) {
            if (!this.keyTranslator.allowAltGr()) {
               if (Platform.isWindows()) {
                  if (this.holdLCtrl) {
                     if (var1.getWhen() == this.LCtrlTime && var2 == 57) {
                        this.holdLCtrl = false;
                        return;
                     }

                     this.holdLCtrl = false;
                     this.processKeyPressed(54);
                  }

                  if (var2 == 54) {
                     this.holdLCtrl = true;
                     this.LCtrlTime = var1.getWhen();
                     return;
                  }
               }

               if (var2 == 57) {
                  return;
               }
            }

            this.setLeftAltDownFlag(var1);
            this.setAltGraphDownFlag(var1);
            this.processCtrlAltKeys(var1);
            if (!(this.keyTranslator instanceof CharTranslator)) {
               var1.consume();
            }

            if (var1.getKeyLocation() == 4 && !this.holdNumpadPress) {
               switch (var1.getKeyCode()) {
                  case 10:
                  case 96:
                  case 97:
                  case 98:
                  case 99:
                  case 100:
                  case 101:
                  case 102:
                  case 103:
                  case 104:
                  case 105:
                  case 106:
                  case 107:
                  case 108:
                  case 109:
                  case 110:
                  case 111:
                     this.ignoreNextNumpadKeyTyped = true;
                     if (this.keyTranslator instanceof CharTranslator) {
                        this.holdNumpadPress = true;
                        this.heldNumpadKeyNo = var2;
                        return;
                     }
               }
            }

            if (var2 < 0) {
               this.logger.log(Level.INFO, T._("No key translation found for key pressed event"));
            } else {
               boolean var3 = false;
               if (var1.isAltGraphDown() && var2 != 57 && !this.altGrDown) {
                  this.logger.log(Level.FINER, " !!! Using virtual AltGr-Press !!!");
                  this.processKeyPressed(57);
                  var3 = true;
               }

               this.handleKeyPressed(var2);
               this.handleMouseSyncKey(var2, false);
               if (var3) {
                  this.processKeyReleased(57);
               }
            }
         }
      }
   }

   @Override
   public void keyTyped(KeyEvent var1) {
      if (this.holdLCtrl) {
         this.processKeyPressed(54);
         this.holdLCtrl = false;
      }

      this.handleHotkeys(var1);
      this.handleMouseSyncKey(var1);
      if (this.ignoreNextNumpadKeyTyped) {
         switch (var1.getKeyChar()) {
            case '\n':
            case '*':
            case '+':
            case ',':
            case '-':
            case '.':
            case '/':
            case '0':
            case '1':
            case '2':
            case '3':
            case '4':
            case '5':
            case '6':
            case '7':
            case '8':
            case '9':
               this.ignoreNextNumpadKeyTyped = false;
               if (this.holdNumpadPress) {
                  this.holdNumpadPress = false;
                  this.processKeyPressed(this.heldNumpadKeyNo);
               }

               return;
            case '\u000b':
            case '\f':
            case '\r':
            case '\u000e':
            case '\u000f':
            case '\u0010':
            case '\u0011':
            case '\u0012':
            case '\u0013':
            case '\u0014':
            case '\u0015':
            case '\u0016':
            case '\u0017':
            case '\u0018':
            case '\u0019':
            case '\u001a':
            case '\u001b':
            case '\u001c':
            case '\u001d':
            case '\u001e':
            case '\u001f':
            case ' ':
            case '!':
            case '"':
            case '#':
            case '$':
            case '%':
            case '&':
            case '\'':
            case '(':
            case ')':
         }
      }

      int var2 = this.translateKeyEvent(var1);
      var1.consume();
      if (var2 < 0) {
         if (!(this.keyTranslator instanceof CharTranslator)) {
            this.logger.log(Level.FINEST, T._("No key translation found for key typed event"));
            return;
         }

         this.handleCharTranslation(var1);
      } else {
         this.handleKeyTyped(var2);
      }
   }

   @Override
   public void keyReleased(KeyEvent var1) {
      if (this.holdLCtrl) {
         this.processKeyPressed(54);
         this.holdLCtrl = false;
      }

      this.setLeftAltDownFlag(var1);
      this.setAltGraphDownFlag(var1);
      this.processCtrlAltKeys(var1);
      int var2 = this.translateKeyEvent(var1);
      if (!(this.keyTranslator instanceof CharTranslator)) {
         var1.consume();
      }

      if (var2 < 0) {
         this.logger.log(Level.INFO, T._("No key translation found for key released event"));
      } else {
         this.handleMouseSyncKey(var2, true);
         if (Platform.isMac() && var2 == 28) {
            this.processKeyPressed(var2);
            this.processKeyReleased(var2);
            this.logger.log(Level.INFO, T._("Key Released: Mac : Sending Press/Release for CAPS LOCK."));
         } else if (Platform.isSun() && this.isPermanentModifier(var2)) {
            this.processKeyPressed(var2);
            this.processKeyReleased(var2);
            this.logger.log(Level.INFO, T._("Key Released: Solaris : Sending Press/Release for CAPS/NUM LOCK."));
         } else {
            if (this.isJapaneseKey(var2)) {
               this.handleKeyTyped(var2);
            } else {
               this.handleKeyReleased(var2);
            }
         }
      }
   }

   private void loadKeyTranslator() {
      this.setKeyTranslator(Locale.getDefault(), true);
      this.infoListenerList.fireLocalKeyboardMappingChanged(this.keyTranslator.getLocale());
   }

   public List<Locale> getLocalKeyboardMappings() {
      Vector var1 = new Vector();

      for (int var2 = 0; var2 < this.keyTranslatorList.length; var2++) {
         var1.add(this.keyTranslatorList[var2].getLocale());
      }

      return var1;
   }

   public void setLocalKeyboardMapping(Locale var1) throws IllegalArgumentException {
      this.setKeyTranslator(var1, false);
   }

   private void setKeyTranslator(Locale var1, boolean var2) throws IllegalArgumentException {
      KeyTranslator var3 = null;

      for (int var7 = 0; var7 < this.keyTranslatorList.length; var7++) {
         var3 = this.keyTranslatorList[var7];
         Locale var8 = var3.getLocale();
         String var4;
         String var5;
         String var6;
         if ((var4 = var8.getLanguage()).equals(var1.getLanguage())
            && (var5 = var8.getCountry()).equals(var1.getCountry())
            && (var6 = var8.getVariant()).equals(var1.getVariant())) {
            this.keyTranslator = var3;
            this.logger.log(Level.INFO, MessageFormat.format(T._("Found keyboard translator for language {0}, country {1}, variant {2}"), var4, var5, var6));
            return;
         }
      }

      if (!var2) {
         String var19 = MessageFormat.format(T._("No keyboard translator for Locale {0} found!"), var1);
         this.logger.log(Level.SEVERE, var19);
         throw new IllegalArgumentException(var19);
      } else {
         for (int var15 = 0; var15 < this.keyTranslatorList.length; var15++) {
            var3 = this.keyTranslatorList[var15];
            Locale var17 = var3.getLocale();
            String var12;
            String var14;
            if ((var12 = var17.getLanguage()).equals(var1.getLanguage()) && (var14 = var17.getCountry()).equals(var1.getCountry())) {
               this.keyTranslator = var3;
               this.logger.log(Level.INFO, MessageFormat.format(T._("Found keyboard translator for language {0}, country {1}"), var12, var14));
               return;
            }
         }

         for (int var16 = 0; var16 < this.keyTranslatorList.length; var16++) {
            var3 = this.keyTranslatorList[var16];
            Locale var18 = var3.getLocale();
            String var13;
            if ((var13 = var18.getLanguage()).equals(var1.getLanguage())) {
               this.keyTranslator = var3;
               this.logger.log(Level.INFO, MessageFormat.format(T._("Found keyboard translator for language {0}"), var13));
               return;
            }
         }

         this.keyTranslator = this.keyTranslatorList[0];
         this.logger
            .log(
               Level.WARNING,
               MessageFormat.format(T._("No keyboard translator for Locale {0} found, using default one for {1}"), var1, this.keyTranslator.getLocale())
            );
      }
   }

   private int translateKeyEvent(KeyEvent var1) {
      return this.keyTranslator.translateKeyEvent(var1);
   }

   public int translateKeyEvent(int var1, char var2, int var3) {
      return this.keyTranslator.translateKeyEvent(var1, var2, var3);
   }

   private void handleKeyPressed(int var1) {
      synchronized (this.lock) {
         if (!this.pressedKeys.contains(var1)) {
            this.pressedKeys.addElement(var1);
            this.processKeyPressed(var1);
         } else if (!this.isModifier(var1) && !this.isPermanentModifier(var1)) {
            this.processKeyPressed(var1);
         }
      }
   }

   private void handleKeyTyped(int var1) {
      synchronized (this.lock) {
         if (!this.pressedKeys.contains(var1)) {
            this.processKeyPressed(var1);
            this.processKeyReleased(var1);
         }
      }
   }

   private void handleKeyReleased(int var1) {
      synchronized (this.lock) {
         int var3;
         if ((var3 = this.pressedKeys.indexOf(var1)) >= 0) {
            this.pressedKeys.removeElementAt(var3);
         } else if (Platform.isLinux() || this.keyTranslator.getLocale().getLanguage().equals("ja")) {
            switch (var1) {
               case 27:
               case 59:
               case 98:
                  break;
               default:
                  if (this.macroJustSent) {
                     this.macroJustSent = false;
                  } else {
                     this.processKeyPressed(var1);
                  }
            }
         }

         this.processKeyReleased(var1);
      }
   }

   private void handleCharTranslation(KeyEvent var1) {
      Vector var2 = ((CharTranslator)this.keyTranslator).translateChar(var1);
      if (var2 != null) {
         for (int var4 : var2) {
            if ((var4 & 65536) != 0) {
               synchronized (this.lock) {
                  this.processKeyReleased(var4 ^ 65536);
               }
            } else {
               synchronized (this.lock) {
                  this.processKeyPressed(var4);
               }
            }
         }
      } else {
         this.logger.log(Level.INFO, T._("No character translation sequence found for key typed event"));
      }
   }

   private void processKeyPressed(int var1) {
      if (var1 == 54 && this.altGrPressTimer == null && this.keyTranslator.allowAltGr()) {
         this.startAltGrPressTimer();
      } else {
         if (var1 == 57 && this.keyTranslator.allowAltGr()) {
            if (this.ctrlPressPending) {
               this.ctrlPressPending = false;
               if (this.altGrPressTimer != null) {
                  this.altGrPressTimer.cancel();
                  this.altGrPressTimer = null;
               }

               this.altGrDown = true;
            } else if (this.altGrDown) {
               return;
            }
         }

         if (var1 != 57 || this.keyTranslator.allowAltGr()) {
            this.processKeyPressedInternal(var1);
         }
      }
   }

   private void processKeyPressedInternal(int var1) {
      KeyboardEventConsumer var2 = this.renderer.getKeyboardEventConsumer();
      if (var2 != null) {
         var2.consumeKeyboardEvent(var1, false);
      }

      this.listenerList.fireKeyboardEvent(var1, false);
   }

   private void processKeyReleased(int var1) {
      if (var1 == 54) {
         if (this.altGrDown && !this.ctrlDown) {
            return;
         }

         this.ctrlDown = false;
         if (this.ctrlPressPending) {
            if (this.altGrPressTimer != null) {
               this.altGrPressTimer.cancel();
               this.altGrPressTimer = null;
            }

            this.processKeyPressedInternal(var1);
         }
      } else if (var1 == 57 && this.keyTranslator instanceof CharTranslator) {
         this.altGrDown = false;
      }

      this.processKeyReleasedInternal(var1);
   }

   private void processKeyReleasedInternal(int var1) {
      KeyboardEventConsumer var2 = this.renderer.getKeyboardEventConsumer();
      if (var2 != null) {
         var2.consumeKeyboardEvent(var1, true);
      }

      this.listenerList.fireKeyboardEvent(var1, true);
   }

   private void startAltGrPressTimer() {
      this.altGrPressTimer = new Timer("AltGrPress");
      this.altGrPressTimer.schedule(new TimerTask() {
         @Override
         public void run() {
            synchronized (KeyboardHandler.this.lock) {
               if (KeyboardHandler.this.ctrlPressPending) {
                  KeyboardHandler.this.processKeyPressedInternal(54);
                  KeyboardHandler.this.ctrlPressPending = false;
                  KeyboardHandler.this.ctrlDown = true;
                  KeyboardHandler.this.altGrPressTimer = null;
               }
            }
         }
      }, 30L);
      this.ctrlPressPending = true;
   }

   private boolean isModifier(int var1) {
      for (int var2 = 0; var2 < this.modifiers.length; var2++) {
         if (var1 == this.modifiers[var2]) {
            return true;
         }
      }

      return false;
   }

   private boolean isPermanentModifier(int var1) {
      for (int var2 = 0; var2 < this.permanentModifiers.length; var2++) {
         if (var1 == this.permanentModifiers[var2]) {
            return true;
         }
      }

      return false;
   }

   private void handleMouseSyncKey(int var1, boolean var2) {
      if (this.mouseSyncKeyStroke == null) {
         if (this.hashMouseSync != null && !this.hashMouseSync.isEmpty()) {
            if (var2) {
               if (this.hashMouseSync.containsKey(var1)) {
                  this.hashMouseSync.put(var1, new Boolean(false));
               }
            } else if (this.hashMouseSync.containsKey(var1)) {
               this.hashMouseSync.put(var1, new Boolean(true));
            }

            if (!this.hashMouseSync.contains(new Boolean(false))) {
               this.logger.log(Level.FINER, "Sync: all keys pressed");
               if (this.mouseSyncCombo) {
                  MouseHandler var3 = this.renderer.getMouseHandler();
                  if (var3 != null) {
                     var3.handleMouseSyncHotkey();
                  }

                  this.mouseSyncCombo = false;
               }
            }

            if (!this.hashMouseSync.contains(new Boolean(true))) {
               this.mouseSyncCombo = true;
            }
         }
      }
   }

   private void handleMouseSyncKey(KeyEvent var1) {
      if (this.mouseSyncKeyStroke != null) {
         if (KeyStroke.getKeyStrokeForEvent(var1).equals(this.mouseSyncKeyStroke)) {
            MouseHandler var2 = this.renderer.getMouseHandler();
            if (var2 != null) {
               var2.handleMouseSyncHotkey();
            }
         }
      }
   }

   private boolean handleHotkeys(KeyEvent var1) {
      if (this.hotkeyKeyStrokes == null) {
         return false;
      } else {
         if (!(this.keyTranslator instanceof CharTranslator)) {
            var1.consume();
         }

         this.hotKeyDetected = false;

         for (Entry var3 : this.hotkeyKeyStrokes.entrySet()) {
            KeyStroke var4 = (KeyStroke)var3.getValue();
            if (KeyStroke.getKeyStrokeForEvent(var1).equals(var4) && this.leftAltPressed) {
               this.listenerList.fireHotkeyDetected((Integer)var3.getKey());
               this.hotKeyDetected = true;
               this.leftAltPressed = false;
               return true;
            }
         }

         return false;
      }
   }

   @Override
   public void focusLost(FocusEvent var1) {
      this.releaseAllKeys();
   }

   @Override
   public void focusGained(FocusEvent var1) {
      this.releaseAllKeys();
   }

   private void releaseAllKeys() {
      synchronized (this.lock) {
         this.altGrDown = false;
         this.ctrlDown = false;

         for (int var3 : this.pressedKeys) {
            this.logger.log(Level.FINER, "Releasing key " + var3);
            this.processKeyReleasedInternal(var3);
         }

         this.pressedKeys.clear();
         this.ctrlPressPending = false;
      }
   }

   public synchronized void doKeyboardMacro(IKeyboardMacro var1, boolean var2) throws IOException {
      Stack var3 = new Stack();
      IKeyboardMacro.IKeyCode[] var4 = var1.getKeycodes();
      if (var2) {
         this.processKeyReleasedInternal(55);
         this.processKeyReleasedInternal(54);
         this.processKeyReleasedInternal(55);
         this.processKeyReleasedInternal(58);
         this.processKeyReleasedInternal(55);
      }

      for (int var5 = 0; var5 < var4.length; var5++) {
         IKeyboardMacro.IKeyCode var6 = var4[var5];
         int var7 = var6.getCode();
         if (var6.isDelay()) {
            try {
               Thread.sleep(var7);
            } catch (Exception var10) {
            }
         } else {
            this.logger.log(Level.FINER, "ButtonKey: keyNo: " + var7);
            switch (var7) {
               case 240:
                  break;
               case 241:
                  this.releaseStackKeys(var3);
                  break;
               case 242:
                  try {
                     Thread.sleep(100L);
                  } catch (Exception var11) {
                  }
                  break;
               case 243:
                  this.releaseLastStackKey(var3);
                  break;
               default:
                  Integer var8 = new Integer(var7);
                  if (var6.isPress()) {
                     var3.push(var8);
                     this.processKeyPressedInternal(var8);
                  } else {
                     int var9;
                     if ((var9 = var3.lastIndexOf(var8)) != -1) {
                        var3.removeElementAt(var9);
                     }

                     this.processKeyReleasedInternal(var8);
                  }
            }
         }
      }

      this.releaseStackKeys(var3);
   }

   public void sendKeyboardMacro(final IKeyboardMacro var1, final boolean var2) {
      Thread var5 = new Thread(new Runnable() {
         @Override
         public void run() {
            try {
               KeyboardHandler.this.doKeyboardMacro(var1, var2);
            } catch (IOException var2x) {
               KeyboardHandler.this.logger.log(Level.WARNING, "Unable to send keyboard macro");
            }
         }
      });
      var5.start();
      this.macroJustSent = true;
   }

   private void releaseStackKeys(Stack<Integer> var1) {
      try {
         while (true) {
            Integer var2 = (Integer)var1.pop();
            this.processKeyReleasedInternal(var2);
         }
      } catch (EmptyStackException var3) {
      }
   }

   private void releaseLastStackKey(Stack<Integer> var1) {
      try {
         Integer var2 = (Integer)var1.pop();
         this.processKeyReleasedInternal(var2);
      } catch (EmptyStackException var3) {
      }
   }

   private void setLeftAltDownFlag(KeyEvent var1) {
      if (var1.getKeyCode() == 18 && !this.altGraphDown && var1.getKeyLocation() == 2 && var1.getID() == 401) {
         this.leftAltPressed = true;
      }
   }

   private void setAltGraphDownFlag(KeyEvent var1) {
      if (var1.isControlDown() && var1.isAltDown() && var1.getKeyLocation() == 3 && var1.getID() == 401) {
         this.altGraphDown = true;
      } else if (var1.getKeyLocation() == 3 && this.altGraphDown && var1.getID() == 402) {
         this.altGraphDown = false;
      }
   }

   private void processCtrlAltKeys(KeyEvent var1) {
      if (this.leftAltPressed && var1.getKeyCode() == 18 && var1.getID() == 402 && var1.getKeyLocation() == 2) {
         this.leftAltReleased = true;
         this.leftAltPressed = false;
      } else if (this.leftCtrlReleased) {
         this.leftCtrlReleased = false;
         this.leftAltReleased = false;
      } else if (var1.getKeyCode() == 17 && var1.getID() == 402) {
         this.leftCtrlReleased = true;
      } else if (this.leftAltReleased) {
         this.leftCtrlReleased = false;
         this.leftAltReleased = false;
      }

      if (this.leftAltReleased && this.leftCtrlReleased) {
         if (!this.hotKeyDetected) {
            this.listenerList.fireCtrlAltReleaseDetected(true);
         }

         this.leftAltReleased = false;
         this.leftCtrlReleased = false;
      }
   }
}
