package nn.pp.rccore.impl.mouse;

import java.awt.Dimension;
import java.awt.Point;
import java.awt.Robot;
import java.awt.event.MouseEvent;
import java.text.MessageFormat;
import java.util.Timer;
import java.util.TimerTask;
import nn.pp.core.T;
import nn.pp.core.impl.NotificationListenerList;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.impl.MouseEventListenerList;
import nn.pp.rccore.impl.RemoteConsoleRendererGraphical;

public class MouseHandlerRelative extends MouseHandler {
   private NotificationListenerList notificationListenerList;
   private Object mousemtx = new Object();
   private static Robot robot = null;
   private Timer timer;
   private boolean handleMouse = false;
   private int dx;
   private int dy;
   private int oldPointerMask = 0;
   private String synckey = "";
   private boolean toldUser = false;
   private Point oldPosScaled = new Point(0, 0);
   private boolean captureRightAway = false;

   public MouseHandlerRelative(RemoteConsoleRendererGraphical var1, MouseEventListenerList var2, NotificationListenerList var3) {
      super(var1, var2);
      this.notificationListenerList = var3;
      if (robot == null) {
         try {
            robot = new Robot();
         } catch (Exception var5) {
         }
      }

      this.timer = new Timer("RelMouse");
      this.timer.schedule(new TimerTask() {
         @Override
         public void run() {
            MouseHandlerRelative.this.writeMouseRelative();
         }
      }, 10L, 10L);
   }

   public void setSynckey(String var1) {
      this.synckey = var1;
   }

   public void relativeMouseModeLeft() {
      this.toldUser = false;
   }

   @Override
   public void dispose() {
      this.timer.cancel();
   }

   private void writeMouseRelative() {
      MouseEventConsumer var1 = this.renderer.getMouseEventConsumer();
      synchronized (this.mousemtx) {
         if ((this.dx != 0 || this.dy != 0) && var1 != null) {
            var1.consumeRelativeMouseEvent(this.dx, this.dy, this.oldPointerMask);
            this.mouseListenerList.fireRelativeMouseEvent(this.dx, this.dy, this.oldPointerMask);
            this.dx = this.dy = 0;
         }
      }
   }

   @Override
   public void doMouseSync(RCCore.MouseSyncType var1) {
   }

   @Override
   public void handleMouseSyncHotkey() {
      this.temporarilyLeaveSingleMouseMode();
   }

   private void temporarilyLeaveSingleMouseMode() {
      this.handleMouse = false;
      this.renderer.restoreCursor();
   }

   @Override
   protected int getPointerMask() {
      return this.oldPointerMask;
   }

   @Override
   public void mouseEntered(MouseEvent var1) {
      if (this.handleMouse || this.captureRightAway) {
         this.clearPointerMask();
         this.renderer.setTransparentCursor();
      } else if (!this.toldUser) {
         this.tellUser();
      }
   }

   @Override
   public void mouseExited(MouseEvent var1) {
      this.clearPointerMask();
      if (var1.getModifiersEx() == 1024) {
         MouseEvent var2 = new MouseEvent(this.renderer, 502, var1.getWhen(), var1.getModifiers(), var1.getX(), var1.getY(), 1, false);
         this.handlePressRelease(var2);
      }

      this.temporarilyLeaveSingleMouseMode();
   }

   @Override
   public void mousePressed(MouseEvent var1) {
      this.renderer.requestFocusInWindow();
      if (this.handleMouse || this.captureRightAway) {
         this.handlePressRelease(var1);
      } else if (!this.toldUser) {
         this.tellUser();
      }
   }

   @Override
   public void mouseReleased(MouseEvent var1) {
      if (!this.handleMouse && !this.captureRightAway) {
         this.handleMouse = true;
         this.notificationListenerList.fireTextNotification(MessageFormat.format(T._("Single mouse mode entered, press {0} to leave"), this.synckey));
         this.moveRobot();
      } else {
         this.handlePressRelease(var1);
      }
   }

   @Override
   public void mouseMoved(MouseEvent var1) {
      if (!this.renderer.isFocusOwner() || !this.handleMouse && !this.captureRightAway) {
         if (!this.toldUser) {
            this.tellUser();
         }
      } else {
         this.handleMouseMove(var1);
      }
   }

   @Override
   public void mouseDragged(MouseEvent var1) {
      if (!this.renderer.isFocusOwner() || !this.handleMouse && !this.captureRightAway) {
         if (!this.toldUser) {
            this.tellUser();
         }
      } else {
         this.handleMouseMove(var1);
      }
   }

   private void tellUser() {
      this.toldUser = true;
   }

   private void moveRobot() {
      int var1;
      int var2;
      if (this.renderer.getFrameSize().width >= this.renderer.getSize().width && this.renderer.getFrameSize().height >= this.renderer.getSize().height) {
         var2 = this.renderer.getSize().width;
         var1 = this.renderer.getSize().height;
      } else {
         var2 = this.renderer.getFrameSize().width;
         var1 = this.renderer.getFrameSize().height;
      }

      Dimension var3 = new Dimension(var2, var1);
      int var4 = var3.width / 2;
      int var5 = var3.height / 2;
      Point var6 = this.renderer.getLocationOnScreen();
      int var7 = (int)var6.getX() + var4;
      int var8 = (int)var6.getY() + var5;
      robot.mouseMove(var7, var8);
   }

   private void handlePressRelease(MouseEvent var1) {
      this.writeMouseRelative();
      this.oldPointerMask = this.getPointerMask(var1);
      MouseEventConsumer var2 = this.renderer.getMouseEventConsumer();
      if (var2 != null) {
         var2.consumeRelativeMouseEvent(0, 0, this.oldPointerMask);
      }

      this.mouseListenerList.fireRelativeMouseEvent(0, 0, this.oldPointerMask);
   }

   private void handleMouseMove(MouseEvent var1) {
      int var2;
      int var3;
      if (this.renderer.getFrameSize().width >= this.renderer.getSize().width && this.renderer.getFrameSize().height >= this.renderer.getSize().height) {
         var3 = this.renderer.getSize().width;
         var2 = this.renderer.getSize().height;
      } else {
         var3 = this.renderer.getFrameSize().width;
         var2 = this.renderer.getFrameSize().height;
      }

      Dimension var4 = new Dimension(var3, var2);
      int var5 = var4.width / 2;
      int var6 = var4.height / 2;
      this.currentPos.setLocation(var1.getX(), var1.getY());
      this.oldPosScaled.setLocation(this.oldPos);
      if (var1.getX() != var5 || var1.getY() != var6) {
         synchronized (this.mousemtx) {
            this.dx = (int)(this.dx + (this.currentPos.getX() - this.oldPosScaled.getX()));
            this.dy = (int)(this.dy + (this.currentPos.getY() - this.oldPosScaled.getY()));
         }

         this.moveRobot();
      }

      this.oldPos.setLocation(var1.getPoint());
   }

   public boolean isCaptureRightAway() {
      return this.captureRightAway;
   }

   @Override
   public void setCaptureRightAway(boolean var1) {
      this.captureRightAway = var1;
   }
}
