package nn.pp.rccore.impl.rfb;

import java.io.IOException;
import java.text.MessageFormat;
import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.rccore.RCException;

public class ImageDecoderHextile extends ImageDecoderRaw {
   public ImageDecoderHextile(Logger var1, RfbHandler var2) {
      super(var1, var2);
   }

   @Override
   public void decodeImage(
      MonitoringDataInputStream var1,
      int[] var2,
      int var3,
      int var4,
      int var5,
      int var6,
      int var7,
      int var8,
      int var9,
      int var10,
      int var11,
      RfbPixelFormat var12
   ) throws IOException, RCException {
      if (var12.bitsPerPixel == 8) {
         this.drawHextileRect8(var1, var2, var8, var9, var10, var11, var3, var12);
      } else {
         if (var12.bitsPerPixel != 16) {
            throw new RCException(MessageFormat.format(T._("Hextile Encoding for {0} bits color depth not supported"), var12.bitsPerPixel));
         }

         this.drawHextileRect16(var1, var2, var8, var9, var10, var11, var3, var12);
      }
   }

   protected final void drawHextileRect8(MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, RfbPixelFormat var8) throws IOException, RCException {
      int var9 = 0;
      int var10 = 0;

      for (int var16 = var4; var16 < var4 + var6; var16 += 16) {
         for (int var15 = var3; var15 < var3 + var5; var15 += 16) {
            int var17 = 16;
            int var18 = 16;
            if (var3 + var5 - var15 < 16) {
               var17 = var3 + var5 - var15;
            }

            if (var4 + var6 - var16 < 16) {
               var18 = var4 + var6 - var16;
            }

            int var19 = this.readBufferedByte(var1);
            if ((var19 & 1) != 0) {
               this.finishBufferedReading(var1);
               this.drawRawRect8(var1, var2, var15, var16, var17, var18, var7, var8);
            } else {
               if ((var19 & 2) != 0) {
                  var9 = this.readBufferedByte(var1);
               }

               this.fillRect8(var2, var9, var15, var16, var17, var18, var7);
               if ((var19 & 4) != 0) {
                  var10 = this.readBufferedByte(var1);
               }

               if ((var19 & 8) != 0) {
                  int var20 = this.readBufferedByte(var1);
                  if ((var19 & 16) != 0) {
                     for (int var30 = 0; var30 < var20; var30++) {
                        var10 = this.readBufferedByte(var1);
                        int var28 = this.readBufferedByte(var1);
                        int var29 = this.readBufferedByte(var1);
                        int var24 = var28 >> 4;
                        int var25 = var28 & 15;
                        int var26 = (var29 >> 4) + 1;
                        int var27 = (var29 & 15) + 1;
                        this.fillRect8(var2, var10, var24 + var15, var25 + var16, var26, var27, var7);
                     }
                  } else {
                     for (int var23 = 0; var23 < var20; var23++) {
                        int var21 = this.readBufferedByte(var1);
                        int var22 = this.readBufferedByte(var1);
                        int var11 = var21 >> 4;
                        int var12 = var21 & 15;
                        int var13 = (var22 >> 4) + 1;
                        int var14 = (var22 & 15) + 1;
                        this.fillRect8(var2, var10, var11 + var15, var12 + var16, var13, var14, var7);
                     }
                  }
               }
            }
         }
      }

      this.finishBufferedReading(var1);
   }

   protected final void drawHextileRect16(MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, RfbPixelFormat var8) throws IOException, RCException {
      int[] var9 = new int[2];
      int[] var10 = new int[2];

      for (int var16 = var4; var16 < var4 + var6; var16 += 16) {
         for (int var15 = var3; var15 < var3 + var5; var15 += 16) {
            int var17 = 16;
            int var18 = 16;
            if (var3 + var5 - var15 < 16) {
               var17 = var3 + var5 - var15;
            }

            if (var4 + var6 - var16 < 16) {
               var18 = var4 + var6 - var16;
            }

            int var19 = this.readBufferedByte(var1);
            if ((var19 & 1) != 0) {
               this.finishBufferedReading(var1);
               this.drawRawRect16(var1, var2, var15, var16, var17, var18, var7, var8);
            } else {
               if ((var19 & 2) != 0) {
                  var9[0] = this.readBufferedByte(var1);
                  var9[1] = this.readBufferedByte(var1);
               }

               this.fillRect16(var2, var9, var15, var16, var17, var18, var7, var8.bigEndian);
               if ((var19 & 4) != 0) {
                  var10[0] = this.readBufferedByte(var1);
                  var10[1] = this.readBufferedByte(var1);
               }

               if ((var19 & 8) != 0) {
                  int var20 = this.readBufferedByte(var1);
                  if ((var19 & 16) != 0) {
                     for (int var30 = 0; var30 < var20; var30++) {
                        var10[0] = this.readBufferedByte(var1);
                        var10[1] = this.readBufferedByte(var1);
                        int var28 = this.readBufferedByte(var1);
                        int var29 = this.readBufferedByte(var1);
                        int var24 = var28 >> 4;
                        int var25 = var28 & 15;
                        int var26 = (var29 >> 4) + 1;
                        int var27 = (var29 & 15) + 1;
                        this.fillRect16(var2, var10, var24 + var15, var25 + var16, var26, var27, var7, var8.bigEndian);
                     }
                  } else {
                     for (int var23 = 0; var23 < var20; var23++) {
                        int var21 = this.readBufferedByte(var1);
                        int var22 = this.readBufferedByte(var1);
                        int var11 = var21 >> 4;
                        int var12 = var21 & 15;
                        int var13 = (var22 >> 4) + 1;
                        int var14 = (var22 & 15) + 1;
                        this.fillRect16(var2, var10, var11 + var15, var12 + var16, var13, var14, var7, var8.bigEndian);
                     }
                  }
               }
            }
         }
      }

      this.finishBufferedReading(var1);
   }
}
