package nn.pp.rccore.impl.rfb;

import java.io.IOException;
import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.core.impl.MonitoringDataInputStream;

public class ImageDecoderLrle extends ImageDecoder {
   private ImageDecoderLrle.LRLEColorDecoder lrle_dec;
   private int lrle_subenc = -1;
   private int[] prevLine;
   private boolean lrle_debug = false;

   public ImageDecoderLrle(Logger var1, RfbHandler var2) {
      super(var1, var2);
   }

   private void drawLRLEMap(MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, int var8, int var9) throws IOException {
      int var10 = 8 / this.lrle_dec.conf.grey_depth;
      int var17 = (1 << this.lrle_dec.conf.grey_depth) - 1;
      int var14 = var8 / var10;
      int var15 = var8 % var10;

      for (int var11 = 0; var11 < var9; var11++) {
         for (int var12 = 0; var12 < var14; var12++) {
            int var16 = this.readBufferedByte(var1);

            for (int var13 = var10 - 1; var13 >= 0; var13--) {
               var2[var3 + var11 * var4 + var12 * var10 + var13] = this.lrle_dec.greys[var16 & var17];
               var16 >>= this.lrle_dec.conf.grey_depth;
            }
         }

         if (var15 != 0) {
            int var19 = this.readBufferedByte(var1);

            for (int var18 = var15 - 1; var18 >= 0; var18--) {
               var2[var3 + var11 * var4 + var14 * var10 + var18] = this.lrle_dec.greys[var19 & var17];
               var19 >>= this.lrle_dec.conf.grey_depth;
            }
         }
      }
   }

   @Override
   public void decodeImage(
      MonitoringDataInputStream var1,
      int[] var2,
      int var3,
      int var4,
      int var5,
      int var6,
      int var7,
      int var8,
      int var9,
      int var10,
      int var11,
      RfbPixelFormat var12
   ) throws IOException {
      if (this.prevLine == null || this.prevLine.length < var3) {
         this.prevLine = new int[var3];
      }

      Arrays.fill(this.prevLine, 0);
      int var22 = 0;
      boolean var23 = false;
      int var25 = -16777216;
      if (this.lrle_subenc == -1 || this.lrle_subenc != var7) {
         this.lrle_subenc = var7;
         this.lrle_dec = new ImageDecoderLrle.LRLEColorDecoder(this.lrle_subenc);
      }

      for (int var14 = var9; var14 < var9 + var11; var14 += 16) {
         for (int var13 = var8; var13 < var8 + var10; var13 += 16) {
            int var26 = var14 * var3 + var13;
            int var15 = 16;
            int var16 = 16;
            if (var8 + var10 - var13 < 16) {
               var15 = var8 + var10 - var13;
            }

            if (var9 + var11 - var14 < 16) {
               var16 = var9 + var11 - var14;
            }

            if (this.lrle_dec.conf.is_map) {
               this.drawLRLEMap(var1, var2, var26, var4, var5, var13, var14, var15, var16);
            } else {
               int var18 = 0;
               int var17 = 0;
               byte var20 = 0;
               byte var19 = 0;
               if (this.lrle_debug) {
                  this.logger.log(Level.FINER, "Tile (" + var13 + "," + var14 + ")");
               }

               while (true) {
                  if (this.lrle_debug) {
                     System.out.print("(" + var17 + "," + var18 + ")");
                  }

                  if (var17 == 0 && var20 + var18 == var16) {
                     if (this.lrle_debug) {
                        this.logger.log(Level.FINER, " >>END OF TILE");
                     }
                     break;
                  }

                  int var21 = this.readBufferedByte(var1);
                  if (this.lrle_debug) {
                     System.out.print(" Code=0x" + Integer.toHexString(var21) + " -> ");
                  }

                  if ((var21 & 224) == 224) {
                     var23 = true;
                     var22 = var21 == 255 ? this.readBufferedByte(var1) : var21 & 31;
                     if (this.lrle_debug) {
                        this.logger.log(Level.FINER, "COPY " + (var22 + 1));
                     }
                  } else if (this.lrle_dec.conf.is_compact) {
                     var23 = false;
                     if (this.lrle_dec.conf.depth <= 3) {
                        var25 = this.lrle_dec.colors[var21 & 7];
                        var22 = var21 >> 3;
                        if (this.lrle_debug) {
                           this.logger
                              .log(Level.FINER, "PIXEL=0x" + Integer.toHexString(var21 & 7) + " (RUN=" + (var22 + 1) + ") -> 0x" + Integer.toHexString(var25));
                        }
                     } else {
                        var25 = this.lrle_dec.colors[var21 & 15];
                        var22 = var21 >> 4;
                        if (this.lrle_debug) {
                           this.logger
                              .log(Level.FINER, "PIXEL=0x" + Integer.toHexString(var21 & 15) + " (RUN=" + (var22 + 1) + ") -> 0x" + Integer.toHexString(var25));
                        }
                     }
                  } else {
                     switch ((var21 & 192) >> 6) {
                        case 0:
                        case 1:
                           if (this.lrle_dec.conf.depth > 7) {
                              var21 = var21 << 8 | this.readBufferedByte(var1);
                           }

                           var25 = this.lrle_dec.colors[var21];
                           if (this.lrle_debug) {
                              this.logger.log(Level.FINER, "PIXEL=0x" + Integer.toHexString(var21) + " -> 0x" + Integer.toHexString(var25));
                           }

                           var22 = 0;
                           var23 = false;
                           break;
                        case 2:
                           var25 = this.lrle_dec.greys[var21 & 63];
                           if (this.lrle_debug) {
                              this.logger.log(Level.FINER, "GREY=0x" + Integer.toHexString(var21) + " -> 0x" + Integer.toHexString(var25));
                           }

                           var22 = 0;
                           var23 = false;
                           break;
                        case 3:
                           var22 = var21 & 31;
                     }
                  }

                  for (int var24 = 0; var24 <= var22; var24++) {
                     if (!var23) {
                        this.prevLine[var17] = var25;
                     }

                     var2[var26 + (var20 + var18) * var3 + var19 + var17] = this.prevLine[var17];
                     if (var19 + ++var17 == var15) {
                        var17 = 0;
                        var18++;
                     }
                  }
               }
            }
         }
      }

      this.finishBufferedReading(var1);
   }

   private class LRLEColorDecoder {
      public int subenc;
      public int[] colors;
      public int[] greys;
      public ImageDecoderLrle.LRLEColorDecoderConf conf;
      private ImageDecoderLrle.LRLEColorDecoderConf[] configs = new ImageDecoderLrle.LRLEColorDecoderConf[]{
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, false, false, 15, 6),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, false, false, 15, 6),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, false, false, 7, 4),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, false, false, 7, 4),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, true, false, 4, 4),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, true, false, 4, 4),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, true, true, 4, 4),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, true, true, 4, 4),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, true, true, 3, 3),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(false, true, true, 3, 3),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(true, false, true, 2, 2),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(true, false, true, 2, 2),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(true, false, true, 1, 1),
         ImageDecoderLrle.this.new LRLEColorDecoderConf(true, false, true, 1, 1)
      };

      public LRLEColorDecoder(int var2) {
         this.subenc = var2;
         ImageDecoderLrle.this.logger.log(Level.INFO, T._("new LRLE color decoder type") + " " + this.subenc);
         this.createLRLEData();
         this.createLRLEColorTables();
      }

      private void createLRLEData() {
         if (this.subenc < this.configs.length) {
            this.conf = this.configs[this.subenc];
            ImageDecoderLrle.this.logger.log(Level.INFO, this.conf.toString());
         } else {
            ImageDecoderLrle.this.logger.log(Level.SEVERE, T._("ERROR: unsupported color decoder type"));
         }
      }

      private void createLRLEColorTables() {
         this.greys = new int[1 << this.conf.grey_depth];
         if (this.conf.is_grey) {
            this.colors = new int[1 << this.conf.grey_depth];
         }

         for (int var1 = 0; var1 < 1 << this.conf.grey_depth; var1++) {
            this.greys[var1] = -16777216;
            switch (this.conf.grey_depth) {
               case 1:
                  this.greys[var1] = this.greys[var1] | var1 * 255 << 16 | var1 * 255 << 8 | var1 * 255;
                  break;
               case 2:
                  this.greys[var1] = this.greys[var1] | var1 * 85 << 16 | var1 * 85 << 8 | var1 * 85;
                  break;
               case 3:
                  this.greys[var1] = this.greys[var1] | var1 * 73 / 2 << 16 | var1 * 73 / 2 << 8 | var1 * 73 / 2;
                  break;
               case 4:
                  this.greys[var1] = this.greys[var1] | var1 * 17 << 16 | var1 * 17 << 8 | var1 * 17;
                  break;
               case 5:
                  this.greys[var1] = this.greys[var1] | var1 * 33 / 4 << 16 | var1 * 33 / 4 << 8 | var1 * 33 / 4;
                  break;
               case 6:
                  this.greys[var1] = this.greys[var1] | var1 * 65 / 16 << 16 | var1 * 65 / 16 << 8 | var1 * 65 / 16;
                  break;
               default:
                  this.greys[var1] = this.greys[var1] | 16711935;
            }

            if (this.conf.is_grey) {
               this.colors[var1] = this.greys[var1];
            }
         }

         if (!this.conf.is_grey) {
            this.colors = new int[1 << this.conf.depth];
            switch (this.conf.depth) {
               case 4:
                  this.colors[0] = -16777216;
                  this.colors[1] = -8454144;
                  this.colors[2] = -16744704;
                  this.colors[3] = -8421632;
                  this.colors[4] = -16777089;
                  this.colors[5] = -8454017;
                  this.colors[6] = -16744577;
                  this.colors[7] = -8421505;
                  this.colors[8] = -4144960;
                  this.colors[9] = -65536;
                  this.colors[10] = -16711936;
                  this.colors[11] = -256;
                  this.colors[12] = -16776961;
                  this.colors[13] = -65281;
                  this.colors[14] = -16711681;
                  this.colors[15] = -1;
                  break;
               case 7:
                  int[] var2 = new int[]{0, 64, 128, 192, 255};

                  for (int var4 = 0; var4 < 125; var4++) {
                     this.colors[var4] = 0xFF000000 | var2[var4 / 25] << 16 | var2[var4 / 5 % 5] << 8 | var2[var4 % 5];
                  }

                  for (int var5 = 125; var5 < 128; var5++) {
                     this.colors[var5] = -65536;
                  }
                  break;
               case 15:
                  for (int var3 = 0; var3 < 1 << this.conf.depth; var3++) {
                     this.colors[var3] = 0xFF000000 | ((var3 & 31744) >> 10) * 33 / 4 << 16 | ((var3 & 992) >> 5) * 33 / 4 << 8 | (var3 & 31) * 33 / 4;
                  }
            }
         }
      }
   }

   private class LRLEColorDecoderConf {
      public boolean is_compact;
      public boolean is_grey;
      public boolean is_map;
      public int depth;
      public int grey_depth;

      public LRLEColorDecoderConf(boolean var2, boolean var3, boolean var4, int var5, int var6) {
         this.is_map = var2;
         this.is_compact = var3;
         this.is_grey = var4;
         this.depth = var5;
         this.grey_depth = var6;
      }

      @Override
      public String toString() {
         return new String("Compact=" + this.is_compact + ",Grey=" + this.is_grey + ",Depth=" + this.depth + ",GreyDepth=" + this.grey_depth);
      }
   }
}
