package nn.pp.rccore.impl.rfb;

import java.io.IOException;
import java.text.MessageFormat;
import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.rccore.RCException;

public class ImageDecoderRawVsc extends ImageDecoderRaw {
   private byte[] rawTmpBuf;

   public ImageDecoderRawVsc(Logger var1, RfbHandler var2) {
      super(var1, var2);
   }

   @Override
   public void decodeImage(
      MonitoringDataInputStream var1,
      int[] var2,
      int var3,
      int var4,
      int var5,
      int var6,
      int var7,
      int var8,
      int var9,
      int var10,
      int var11,
      RfbPixelFormat var12
   ) throws IOException, RCException {
      if (var12.bitsPerPixel == 8) {
         this.drawRawVscRect8(var1, var2, var8, var9, var10, var11, var4, var5, var3, var12);
      } else {
         if (var12.bitsPerPixel != 16) {
            throw new RCException(MessageFormat.format(T._("Raw Encoding for {0} bits color depth not supported"), var12.bitsPerPixel));
         }

         this.drawRawVscRect16(var1, var2, var8, var9, var10, var11, var4, var5, var3, var12);
      }
   }

   protected final void checkRawTmpBufSize(int var1) {
      if (this.rawTmpBuf == null || this.rawTmpBuf.length < var1) {
         this.rawTmpBuf = new byte[var1];
      }
   }

   private final void drawRawVscRect8(
      MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, int var8, int var9, RfbPixelFormat var10
   ) throws IOException, RCException {
      byte var11 = var1.readByte();
      if ((var11 & 1) == 0) {
         this.drawRawRect8(var1, var2, var3, var4, var5, var6, var9, var10);
      } else {
         int var12 = var5 * var6;
         this.checkRawTmpBufSize(var12);
         var1.readFully(this.rawTmpBuf, 0, var12);
         var5 = Math.min(var5, var7 - var3);
         var6 = Math.min(var6, var8 - var4);
         var12 = var5 * var6;
         this.checkRawBufSize(var12);
         int var13 = 0;
         int var14 = 0;
         int var15 = 0;
         int var16 = 0;
         int var17 = 0;

         for (int var18 = 0; var18 < var6; var18++) {
            int var19 = 0;

            for (int var20 = 0; var20 < var5; var20++) {
               this.rawBuf[var14] = this.rawTmpBuf[var13];
               var14++;
               var13++;
               if (++var19 == 16) {
                  var13 += 240;
                  var19 = 0;
               }
            }

            var13 = var15 + ++var16 * 16;
            if (var16 == 16) {
               var15 = ++var17 * 16 * var5;
               var13 = var15;
               var16 = 0;
            }
         }

         this.colorDecode8(var2, this.rawBuf, var4 * var9 + var3, var5, var6, var9);
      }
   }

   private final void drawRawVscRect16(
      MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, int var8, int var9, RfbPixelFormat var10
   ) throws IOException, RCException {
      byte var11 = var1.readByte();
      if ((var11 & 1) == 0) {
         this.drawRawRect16(var1, var2, var3, var4, var5, var6, var9, var10);
      } else {
         int var12 = 2 * var5 * var6;
         this.checkRawTmpBufSize(var12);
         var1.readFully(this.rawTmpBuf, 0, var12);
         var5 = Math.min(var5, var7 - var3);
         var6 = Math.min(var6, var8 - var4);
         var12 = 2 * var5 * var6;
         this.checkRawBufSize(var12);
         int var13 = 0;
         int var14 = 0;
         int var15 = 0;
         int var16 = 0;
         int var17 = 0;

         for (int var18 = 0; var18 < var6; var18++) {
            int var19 = 0;

            for (int var20 = 0; var20 < var5; var20++) {
               this.rawBuf[var14++] = this.rawTmpBuf[var13++];
               this.rawBuf[var14++] = this.rawTmpBuf[var13++];
               if (++var19 == 16) {
                  var13 += 480;
                  var19 = 0;
               }
            }

            var13 = var15 + ++var16 * 16 * 2;
            if (var16 == 16) {
               var15 = ++var17 * 16 * var5 * 2;
               var13 = var15;
               var16 = 0;
            }
         }

         this.colorDecode16(var2, this.rawBuf, var4 * var9 + var3, var5, var6, var9, (var11 & 4) == 4);
      }
   }
}
