package nn.pp.rccore.impl.rfb;

import java.awt.image.DirectColorModel;
import java.io.IOException;
import java.util.logging.Logger;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.rccore.RCException;

public abstract class ImageDecoderSoftware extends ImageDecoder {
   private static DirectColorModel colormodel8 = new DirectColorModel(8, 7, 56, 192);
   protected static int[] intcolors8;
   private static DirectColorModel colormodel16 = new DirectColorModel(16, 63488, 2016, 31);
   private static int[] intcolors16;
   private static boolean initialized = false;

   public ImageDecoderSoftware(Logger var1, RfbHandler var2) {
      super(var1, var2);
      if (!initialized) {
         intcolors8 = new int[256];

         for (int var3 = 0; var3 < 256; var3++) {
            intcolors8[var3] = colormodel8.getRGB(var3);
         }

         intcolors16 = new int[65536];

         for (int var4 = 0; var4 < 65536; var4++) {
            intcolors16[var4] = colormodel16.getRGB(var4);
         }

         initialized = true;
      }
   }

   @Override
   public abstract void decodeImage(
      MonitoringDataInputStream var1,
      int[] var2,
      int var3,
      int var4,
      int var5,
      int var6,
      int var7,
      int var8,
      int var9,
      int var10,
      int var11,
      RfbPixelFormat var12
   ) throws IOException, RCException;

   protected final void colorDecode8(int[] var1, byte[] var2, int var3, int var4, int var5, int var6) {
      int var7 = 0;
      int var8 = var3;

      for (int var9 = 0; var9 < var5; var9++) {
         for (int var10 = 0; var10 < var4; var10++) {
            int var11 = intcolors8[255 & var2[var7++]];
            var1[var8++] = var11;
         }

         var8 += var6 - var4;
      }
   }

   protected final void colorDecode16(int[] var1, byte[] var2, int var3, int var4, int var5, int var6, boolean var7) {
      byte var8 = 0;
      int var9 = var3;

      for (int var10 = 0; var10 < var5; var10++) {
         for (int var11 = 0; var11 < var4; var11++) {
            int var12;
            if (var7) {
               var12 = (var2[var8 + 0] & 255) << 8 | var2[var8 + 1] & 255;
            } else {
               var12 = (var2[var8 + 1] & 255) << 8 | var2[var8 + 0] & 255;
            }

            var8 += 2;
            var1[var9++] = intcolors16[var12];
         }

         var9 += var6 - var4;
      }
   }

   protected final void fillRect(int[] var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      for (int var8 = var4; var8 < var4 + var6; var8++) {
         int var9 = var8 * var7;

         for (int var10 = var3; var10 < var3 + var5; var10++) {
            var1[var9 + var10] = var2;
         }
      }
   }

   protected final void fillRect8(int[] var1, int var2, int var3, int var4, int var5, int var6, int var7) {
      this.fillRect(var1, intcolors8[var2 & 0xFF], var3, var4, var5, var6, var7);
   }

   protected final void fillRect16(int[] var1, int[] var2, int var3, int var4, int var5, int var6, int var7, boolean var8) {
      int var9;
      if (var8) {
         var9 = (var2[0] & 0xFF) << 8 | var2[1] & 0xFF;
      } else {
         var9 = (var2[1] & 0xFF) << 8 | var2[0] & 0xFF;
      }

      this.fillRect(var1, intcolors16[var9], var3, var4, var5, var6, var7);
   }
}
