package nn.pp.rccore.impl.rfb;

import java.awt.Color;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.logging.Logger;
import java.util.zip.DataFormatException;
import java.util.zip.Inflater;
import nn.pp.core.T;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.rccore.RCException;

public class ImageDecoderTight extends ImageDecoderSoftware {
   private static int[] tightLUT1BitFullColorBlackWhite;
   private static int[] tightLUT2BitFullColorGrayscale;
   private static int[] tightLUT4BitFullColorGrayscale;
   private static int[] tightLUT4BitFullColor16Colors;
   private static int[] tightLUT8BitFullColor256Colors;
   private static boolean initialized = false;
   private Inflater[] tightInflaters;
   private byte[] monoBuf;
   private byte[] zlibBuf;
   private byte[] tmpBuf;
   private byte[] tmpCacheBuf;
   private int lastFbWidth = -1;
   private int lastFbHeight = -1;
   private TightCacheTile[] tightCacheTiles;

   protected final void checkMonoBufSize(int var1) {
      if (this.monoBuf == null || this.monoBuf.length < var1) {
         this.monoBuf = new byte[var1];
      }
   }

   protected final void checkZlibBufSize(int var1) {
      if (this.zlibBuf == null || this.zlibBuf.length < var1) {
         this.zlibBuf = new byte[var1];
      }
   }

   public ImageDecoderTight(Logger var1, RfbHandler var2) {
      super(var1, var2);
      this.tightInflaters = new Inflater[4];
      this.tmpBuf = new byte[65536];
      this.tmpCacheBuf = new byte[65536];
      if (!initialized) {
         tightLUT1BitFullColorBlackWhite = new int[2];
         tightLUT2BitFullColorGrayscale = new int[4];
         tightLUT4BitFullColorGrayscale = new int[16];
         tightLUT4BitFullColor16Colors = new int[16];
         tightLUT8BitFullColor256Colors = intcolors8;
         tightLUT1BitFullColorBlackWhite[0] = new Color(0, 0, 0).getRGB();
         tightLUT1BitFullColorBlackWhite[1] = new Color(255, 255, 255).getRGB();
         tightLUT2BitFullColorGrayscale[0] = new Color(0, 0, 0).getRGB();
         tightLUT2BitFullColorGrayscale[1] = new Color(128, 128, 128).getRGB();
         tightLUT2BitFullColorGrayscale[2] = new Color(192, 192, 192).getRGB();
         tightLUT2BitFullColorGrayscale[3] = new Color(255, 255, 255).getRGB();
         tightLUT4BitFullColorGrayscale[0] = new Color(0, 0, 0).getRGB();
         tightLUT4BitFullColorGrayscale[1] = new Color(33, 33, 33).getRGB();
         tightLUT4BitFullColorGrayscale[2] = new Color(50, 50, 50).getRGB();
         tightLUT4BitFullColorGrayscale[3] = new Color(67, 67, 67).getRGB();
         tightLUT4BitFullColorGrayscale[4] = new Color(92, 92, 92).getRGB();
         tightLUT4BitFullColorGrayscale[5] = new Color(105, 105, 105).getRGB();
         tightLUT4BitFullColorGrayscale[6] = new Color(117, 117, 117).getRGB();
         tightLUT4BitFullColorGrayscale[7] = new Color(134, 134, 134).getRGB();
         tightLUT4BitFullColorGrayscale[8] = new Color(151, 151, 151).getRGB();
         tightLUT4BitFullColorGrayscale[9] = new Color(163, 163, 163).getRGB();
         tightLUT4BitFullColorGrayscale[10] = new Color(178, 178, 178).getRGB();
         tightLUT4BitFullColorGrayscale[11] = new Color(193, 193, 193).getRGB();
         tightLUT4BitFullColorGrayscale[12] = new Color(209, 209, 209).getRGB();
         tightLUT4BitFullColorGrayscale[13] = new Color(226, 226, 226).getRGB();
         tightLUT4BitFullColorGrayscale[14] = new Color(79, 79, 79).getRGB();
         tightLUT4BitFullColorGrayscale[15] = new Color(255, 255, 255).getRGB();
         tightLUT4BitFullColor16Colors[0] = new Color(0, 0, 0).getRGB();
         tightLUT4BitFullColor16Colors[1] = new Color(128, 0, 0).getRGB();
         tightLUT4BitFullColor16Colors[2] = new Color(255, 0, 0).getRGB();
         tightLUT4BitFullColor16Colors[3] = new Color(0, 128, 0).getRGB();
         tightLUT4BitFullColor16Colors[4] = new Color(128, 128, 0).getRGB();
         tightLUT4BitFullColor16Colors[5] = new Color(255, 255, 0).getRGB();
         tightLUT4BitFullColor16Colors[6] = new Color(0, 255, 0).getRGB();
         tightLUT4BitFullColor16Colors[7] = new Color(0, 0, 128).getRGB();
         tightLUT4BitFullColor16Colors[8] = new Color(128, 0, 128).getRGB();
         tightLUT4BitFullColor16Colors[9] = new Color(0, 128, 128).getRGB();
         tightLUT4BitFullColor16Colors[10] = new Color(128, 128, 128).getRGB();
         tightLUT4BitFullColor16Colors[11] = new Color(192, 192, 192).getRGB();
         tightLUT4BitFullColor16Colors[12] = new Color(255, 0, 255).getRGB();
         tightLUT4BitFullColor16Colors[13] = new Color(0, 255, 255).getRGB();
         tightLUT4BitFullColor16Colors[14] = new Color(255, 255, 255).getRGB();
         tightLUT4BitFullColor16Colors[15] = new Color(0, 0, 255).getRGB();
         initialized = true;
      }
   }

   @Override
   public void decodeImage(
      MonitoringDataInputStream var1,
      int[] var2,
      int var3,
      int var4,
      int var5,
      int var6,
      int var7,
      int var8,
      int var9,
      int var10,
      int var11,
      RfbPixelFormat var12
   ) throws IOException, RCException {
      if (var12.bitsPerPixel != 8) {
         throw new RCException(MessageFormat.format(T._("Tight Encoding for {0} bits color depth not supported"), var12.bitsPerPixel));
      } else {
         if (var4 != this.lastFbWidth || var5 != this.lastFbHeight) {
            this.setNewTightCacheSize(var4, var5);
            this.lastFbWidth = var4;
            this.lastFbHeight = var5;
         }

         if (var6 == 7) {
            this.drawTightRect8(var1, var2, var8, var9, var10, var11, var3, var4, var12);
         } else if (var6 == 9) {
            this.drawTightCacheRect8(var1, var2, var8, var9, var10, var11, var3, var4, var12);
         }
      }
   }

   private void setNewTightCacheSize(int var1, int var2) {
      if (this.tightCacheTiles != null) {
         this.deinitTightCache();
         System.gc();
      }

      this.initTightCache(var1, var2);
   }

   public void initTightCache(int var1, int var2) {
      int var3 = var1;
      int var4 = var2;
      if (var1 % 16 != 0) {
         var3 = (var1 / 16 + 1) * 16;
      }

      if (var2 % 16 != 0) {
         var4 = (var2 / 16 + 1) * 16;
      }

      int var5 = var3 / 16 * (var4 / 16);
      this.tightCacheTiles = new TightCacheTile[var5];

      for (int var6 = 0; var6 < var5; var6++) {
         this.tightCacheTiles[var6] = new TightCacheTile(8, 256);
      }
   }

   public void deinitTightCache() {
      this.tightCacheTiles = null;
   }

   protected final void drawTightRect8(
      MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, int var8, RfbPixelFormat var9
   ) throws IOException, RCException {
      this.drawTightRect0(var1, var2, var3, var4, var5, var6, var7, var8, var9, null, 0, 0, 0);
   }

   protected final void drawTightCacheRect8(
      MonitoringDataInputStream var1, int[] var2, int var3, int var4, int var5, int var6, int var7, int var8, RfbPixelFormat var9
   ) throws IOException, RCException {
      int var10 = var1.read();
      int var11 = var10 >> 4 & 3;
      int var12 = var10 >> 4 & 12;
      int var13 = var10 & 15;
      byte var14 = 16;
      byte var17;
      byte var19;
      switch (var13) {
         case 1:
            var17 = 8;
            var19 = 10;
            break;
         case 2:
            var17 = 4;
            var19 = 11;
            break;
         case 3:
            var17 = 2;
            var19 = 12;
            break;
         case 4:
            var17 = 2;
            var19 = 13;
            break;
         case 5:
         case 6:
         case 7:
         default:
            return;
         case 8:
            var17 = 1;
            var19 = 0;
      }

      int var18;
      if ((var4 + var6) % var14 != 0) {
         var18 = (var4 + var6) / var14 * var14 - var4;
      } else {
         var18 = var6;
      }

      int var15 = var5 / var14 * (var18 / var14);
      byte[] var16 = new byte[var15];
      if (var15 < 12) {
         var1.readFully(var16, 0, var15);
      } else {
         int var20 = this.rfbHandler.readCompactLen();
         this.checkZlibBufSize(var20);
         var1.readFully(this.zlibBuf, 0, var20);
         if (this.tightInflaters[var11] == null) {
            this.tightInflaters[var11] = new Inflater();
         }

         Inflater var21 = this.tightInflaters[var11];
         var21.setInput(this.zlibBuf, 0, var20);

         try {
            var21.inflate(var16, 0, var15);
         } catch (DataFormatException var23) {
            throw new IOException(var23.toString());
         }
      }

      if (var12 == 0) {
         this.readCacheMetaRect(var3, var4, var5, var6, var8, var16, var12, var14, var17);
         this.drawXBitFullColor(var2, var3, var4, var5, var6, var7, this.tmpBuf, var19);
      } else {
         this.drawTightRect0(var1, var2, var3, var4, var5, var6, var7, var8, var9, var16, var12, var14, var17);
      }
   }

   private final void drawTightRect0(
      MonitoringDataInputStream var1,
      int[] var2,
      int var3,
      int var4,
      int var5,
      int var6,
      int var7,
      int var8,
      RfbPixelFormat var9,
      byte[] var10,
      int var11,
      int var12,
      int var13
   ) throws IOException, RCException {
      int var14 = var1.read();

      for (int var15 = 0; var15 < 4; var15++) {
         if ((var14 & 1) != 0 && this.tightInflaters[var15] != null) {
            this.tightInflaters[var15] = null;
         }

         var14 >>= 1;
      }

      if (var14 > 15) {
         throw new RCException(MessageFormat.format(T._("Incorrect tight subencoding: {0}"), var14));
      } else if (var14 != 8 && var14 != 15) {
         int var25 = 0;
         int var16 = var5;
         int[] var17 = new int[2];
         if ((var14 | 3) == 7) {
            int var18 = var1.read();
            int var19 = var18 & 15;
            int var20 = var18 >> 4 & 15;
            if (var19 == 1) {
               var25 = var1.read() + 1;
               if (var25 != 2) {
                  throw new IOException(T._("Incorrect tight palette size:") + " " + var25);
               }

               switch (var20) {
                  case 1:
                     var18 = var1.read();
                     var17[0] = tightLUT1BitFullColorBlackWhite[var18 >> 1];
                     var17[1] = tightLUT1BitFullColorBlackWhite[var18 & 1];
                     break;
                  case 2:
                     var18 = var1.read();
                     var17[0] = tightLUT2BitFullColorGrayscale[var18 >> 2];
                     var17[1] = tightLUT2BitFullColorGrayscale[var18 & 3];
                     break;
                  case 3:
                     var18 = var1.read();
                     var17[0] = tightLUT4BitFullColorGrayscale[var18 >> 4];
                     var17[1] = tightLUT4BitFullColorGrayscale[var18 & 15];
                     break;
                  case 4:
                     var18 = var1.read();
                     var17[0] = tightLUT4BitFullColor16Colors[var18 >> 4];
                     var17[1] = tightLUT4BitFullColor16Colors[var18 & 15];
                     break;
                  default:
                     var17[0] = tightLUT8BitFullColor256Colors[var1.read()];
                     var17[1] = tightLUT8BitFullColor256Colors[var1.read()];
               }

               var16 = (var5 + 7) / 8;
            } else if (var19 != 0) {
               throw new IOException(T._("Incorrect tight filter id:") + " " + var19);
            }
         } else {
            switch (var14) {
               case 10:
                  var16 = (var5 + 7) / 8;
                  break;
               case 11:
                  var16 = (var5 + 3) / 4;
                  break;
               case 12:
               case 13:
                  var16 = (var5 + 1) / 2;
            }
         }

         int var30 = var6 * var16;
         if (var30 < 12) {
            if (var25 == 2) {
               this.checkMonoBufSize(var30);
               var1.readFully(this.monoBuf, 0, var30);
               this.drawMonoData(var2, var3, var4, var5, var6, var7, this.monoBuf, var17);
            } else {
               var1.readFully(this.tmpBuf, 0, var30);
               this.drawXBitFullColor(var2, var3, var4, var5, var6, var7, this.tmpBuf, var14);
            }
         } else {
            int var31 = this.rfbHandler.readCompactLen();
            this.checkZlibBufSize(var31);
            var1.readFully(this.zlibBuf, 0, var31);
            int var32;
            if ((var14 & 8) != 0) {
               var32 = 0;
            } else {
               var32 = var14 & 3;
            }

            if (this.tightInflaters[var32] == null) {
               this.tightInflaters[var32] = new Inflater();
            }

            Inflater var21 = this.tightInflaters[var32];
            var21.setInput(this.zlibBuf, 0, var31);

            try {
               if (var25 == 2) {
                  this.checkMonoBufSize(var30);
                  var21.inflate(this.monoBuf, 0, var30);
                  this.drawMonoData(var2, var3, var4, var5, var6, var7, this.monoBuf, var17);
               } else {
                  var21.inflate(this.tmpBuf, 0, var30);
                  if (var10 != null) {
                     this.readCacheMetaRect(var3, var4, var5, var6, var8, var10, var11, var12, var13);
                  }

                  this.drawXBitFullColor(var2, var3, var4, var5, var6, var7, this.tmpBuf, var14);
               }
            } catch (DataFormatException var23) {
               throw new IOException(var23.toString());
            }
         }
      } else {
         if (var14 == 8) {
            this.fillRect8(var2, var1.read(), var3, var4, var5, var6, var7);
         } else {
            int var24 = 0;
            switch (var1.read()) {
               case 1:
                  var24 = tightLUT1BitFullColorBlackWhite[var1.read()];
                  break;
               case 2:
                  var24 = tightLUT2BitFullColorGrayscale[var1.read()];
                  break;
               case 3:
                  var24 = tightLUT4BitFullColorGrayscale[var1.read()];
                  break;
               case 4:
                  var24 = tightLUT4BitFullColor16Colors[var1.read()];
            }

            this.fillRect(var2, var24, var3, var4, var5, var6, var7);
         }
      }
   }

   private final void drawMonoData(int[] var1, int var2, int var3, int var4, int var5, int var6, byte[] var7, int[] var8) {
      int[] var13 = var1;
      int var14 = var3 * var6 + var2;
      int var15 = 0;
      int var16 = (var4 + 7) / 8;

      for (int var10 = 0; var10 < var5; var10++) {
         var15 = var10 * var16;

         int var9;
         for (var9 = 0; var9 < var4 / 8; var9++) {
            int var12 = var7[var15 + var9] & 255;

            for (int var11 = 7; var11 >= 0; var11--) {
               var13[var14++] = var8[var12 >> var11 & 1];
            }
         }

         for (int var17 = 7; var17 >= 8 - var4 % 8; var17--) {
            int var18 = var7[var15 + var9] & 255;
            var13[var14++] = var8[var18 >> var17 & 1];
         }

         var14 += var6 - var4;
      }
   }

   private final void drawXBitFullColor(int[] var1, int var2, int var3, int var4, int var5, int var6, byte[] var7, int var8) {
      int var9 = var6;
      int var10 = var3 * var6 + var2;
      int var11 = 0;
      byte[] var12 = var7;
      int[] var13 = var1;
      switch (var8) {
         case 10:
            int[] var24 = tightLUT1BitFullColorBlackWhite;
            int var35 = var4 / 8;
            int var37 = var4 % 8;

            for (int var30 = 0; var30 < var5; var30++) {
               for (int var27 = 0; var27 < var35; var27++) {
                  byte var40 = var12[var11++];

                  for (int var32 = 7; var32 >= 0; var32--) {
                     var13[var10++] = var24[var40 >> var32 & 1];
                  }
               }

               if (var37 != 0) {
                  byte var41 = var12[var11++];

                  for (int var33 = var37; var33 > 0; var33--) {
                     var13[var10++] = var24[var41 >> var33 & 1];
                  }
               }

               var10 += var9 - var4;
            }
            break;
         case 11:
            int[] var23 = tightLUT2BitFullColorGrayscale;
            int var34 = var4 / 4;
            int var36 = var4 % 4;

            for (int var29 = 0; var29 < var5; var29++) {
               for (int var26 = 0; var26 < var34; var26++) {
                  byte var38 = var12[var11++];

                  for (byte var17 = 6; var17 >= 0; var17 -= 2) {
                     var13[var10++] = var23[var38 >> var17 & 3];
                  }
               }

               if (var36 != 0) {
                  byte var39 = var12[var11++];

                  for (int var31 = var36; var31 > 0; var31--) {
                     var13[var10++] = var23[var39 >> 2 * var31 & 3];
                  }
               }

               var10 += var9 - var4;
            }
            break;
         case 12:
         case 13:
            int[] var22;
            if (var8 == 13) {
               var22 = tightLUT4BitFullColor16Colors;
            } else {
               var22 = tightLUT4BitFullColorGrayscale;
            }

            int var18 = var4 / 2;
            int var19 = var4 % 2;

            for (int var28 = 0; var28 < var5; var28++) {
               for (int var25 = 0; var25 < var18; var25++) {
                  byte var20 = var12[var11++];
                  var13[var10++] = var22[var20 >> 4 & 15];
                  var13[var10++] = var22[var20 & 15];
               }

               if (var19 != 0) {
                  var13[var10++] = var22[var12[var11++] >> 4 & 15];
               }

               var10 += var9 - var4;
            }
            break;
         default:
            int[] var14 = tightLUT8BitFullColor256Colors;

            for (int var16 = 0; var16 < var5; var16++) {
               for (int var15 = 0; var15 < var4; var15++) {
                  var13[var10++] = var14[var12[var11++] & 255];
               }

               var10 += var9 - var4;
            }
      }
   }

   private void readCacheMetaRect(int var1, int var2, int var3, int var4, int var5, byte[] var6, int var7, int var8, int var9) {
      int var14 = 0;
      int var16;
      if (var2 % var8 != 0) {
         var16 = (var2 / var8 + 1) * var8 - var2;
      } else {
         var16 = 0;
      }

      int var17;
      if ((var2 + var4) % var8 != 0) {
         var17 = (var2 + var4) / var8 * var8 - var2;
      } else {
         var17 = var4;
      }

      if (var7 == 8) {
         byte[] var18 = this.tmpBuf;
         byte[] var19 = this.tmpCacheBuf;
         if (var16 != 0) {
            System.arraycopy(var18, 0, var19, 0, var16 * var3 / var9);
            var14 += var16 * var3 / var9;
         }

         int var11;
         for (var11 = var16; var11 < var17; var11 += var8) {
            for (int var12 = 0; var12 < var8; var12++) {
               for (int var10 = 0; var10 < var3; var10 += var8) {
                  byte var13 = var6[var11 / var8 * (var3 / var8) + var10 / var8];
                  int var15 = var13 & 127;
                  if ((var13 & 128) == 0) {
                     this.tightCacheTiles[(var2 + var11) / var8 * (var5 / var8) + (var1 + var10) / var8]
                        .saveDataStream(var15, var12 * (var8 / var9), var8 / var9, var18, var14);
                     var14 += var8 / var9;
                  }

                  this.tightCacheTiles[(var2 + var11) / var8 * (var5 / var8) + (var1 + var10) / var8]
                     .restoreDataStream(var15, var12 * (var8 / var9), var8 / var9, var19, ((var11 + var12) * var3 + var10) / var9);
               }
            }
         }

         if (var17 != var4) {
            System.arraycopy(var18, var14, var19, var11 * var3 / var9, (var4 - var17) * var3 / var9);
            var14 += (var4 - var17) * var3 / var9;
         }

         System.arraycopy(var19, 0, var18, 0, var3 * var4 / var9);
      } else if (var7 == 4) {
         byte[] var29 = this.tmpBuf;

         for (int var22 = var16; var22 < var17; var22 += var8) {
            for (int var20 = 0; var20 < var3; var20 += var8) {
               int var27 = var6[var22 / var8 * (var3 / var8) + var20 / var8] & 127;

               for (int var24 = 0; var24 < var8; var24++) {
                  this.tightCacheTiles[(var2 + var22) / var8 * (var5 / var8) + (var1 + var20) / var8]
                     .saveDataStream(var27, var24 * (var8 / var9), var8 / var9, var29, ((var22 + var24) * var3 + var20) / var9);
               }
            }
         }
      } else {
         byte[] var30 = this.tmpBuf;

         for (int var23 = 0; var23 < var4; var23 += var8) {
            for (int var21 = 0; var21 < var3; var21 += var8) {
               int var28 = var6[var23 / var8 * (var3 / var8) + var21 / var8] & 127;

               for (int var25 = 0; var25 < var8; var25++) {
                  this.tightCacheTiles[(var2 + var23) / var8 * (var5 / var8) + (var1 + var21) / var8]
                     .restoreDataStream(var28, var25 * (var8 / var9), var8 / var9, var30, ((var23 + var25) * var3 + var21) / var9);
               }
            }
         }
      }
   }
}
