package nn.pp.rccore.impl.rfb;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.io.IOException;
import java.lang.reflect.Array;
import java.text.MessageFormat;
import java.text.ParseException;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Timer;
import java.util.TimerTask;
import java.util.Vector;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.NotificationEvent;
import nn.pp.core.T;
import nn.pp.core.impl.DeviceConnector;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.core.impl.ProtocolHandler;
import nn.pp.rccore.IAudioStatusExSupport;
import nn.pp.rccore.IMultiMonitorTargetSupport;
import nn.pp.rccore.IVMMountRequestResponse;
import nn.pp.rccore.IVideoSettings;
import nn.pp.rccore.KeyboardMacro;
import nn.pp.rccore.KvmPort;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.RCException;
import nn.pp.rccore.UsbProfile;
import nn.pp.rccore.UsbProfileList;
import nn.pp.rccore.VMConfigInfo;
import nn.pp.rccore.VMMountRequestResponse;
import nn.pp.rccore.VideoSettings;
import nn.pp.rccore.impl.FramebufferRenewer;
import nn.pp.rccore.impl.ISupportsKeyboardHandling;
import nn.pp.rccore.impl.ISupportsMouseHandling;
import nn.pp.rccore.impl.KeyValuePair;
import nn.pp.rccore.impl.ListenerLists;
import nn.pp.rccore.impl.RemoteConsoleRenderer;
import nn.pp.rccore.impl.StringLocale;
import nn.pp.rccore.impl.keyboard.KeyboardEventConsumer;
import nn.pp.rccore.impl.mouse.MouseEventConsumer;

public abstract class RfbHandler extends ProtocolHandler<RCException> implements FramebufferRenewer, MouseEventConsumer, KeyboardEventConsumer {
   protected ListenerLists listeners;
   protected RemoteConsoleRenderer renderer;
   protected RfbEncoding encoding;
   protected RfbVideoSettingsHandler videoSettingsHandler;
   protected UsbProfileList usbProfileList;
   protected VMConfigInfo vmConfig;
   private boolean monitorOnly = false;
   protected boolean lowBandwidth = false;
   private boolean fpsEnabled;
   private int fps = 0;
   private TimerTask pingTimerTask;
   private Timer fpsTimer;
   private byte[] framebufferUpdateRectBuffer = null;
   private ZlibEncodingInflater inflater;
   protected String osdText;
   protected int osdTimeout;
   protected boolean osdBlank;
   protected int framebufferWidth;
   protected int framebufferHeight;
   protected int framebufferWidthPadded;
   protected int framebufferHeightPadded;
   protected String serverCommandName;
   protected String serverCommandValue;
   protected int noFramebufferUpdateRects;
   protected int framebufferUpdateSize;
   protected int framebufferUpdateFlags;
   protected int framebufferUpdateRectX;
   protected int framebufferUpdateRectY;
   protected int framebufferUpdateRectW;
   protected int framebufferUpdateRectH;
   protected int framebufferUpdateRectEncoding;
   protected int framebufferUpdateRectSize;
   private int hotkeyHighestIndex = 0;
   private String[] hotkeyKeyCodes;
   private String[] hotkeyReadableCodes;
   private String[] hotkeyNames;
   protected boolean videoSettingsAvailable = false;
   protected boolean videoRefreshAvailable = false;
   protected boolean videoSettingsOffsetOnly = false;
   protected boolean videoSettingsPermStandard = false;
   protected boolean videoSettingsPermFull = false;
   protected boolean colorCalibration = false;
   private String mouseSyncKeyCode;
   private String mouseSyncReadableCode;
   private boolean localKeyboardMappingPersistent = false;
   protected List<KvmPort> portList;
   protected RfbPixelFormat currentRfbPixelFormat = RfbPixelFormat.rfbPixelFormat16Bit;
   private List<RCCore.MouseMode> supportedMouseModes = new Vector<>();
   private List<RCCore.KeyboardLed> keyboardLeds = new Vector<>();
   protected LinkedHashMap<String, String> appletParameterMap;
   protected UsbProfile selectedUsbProfile;
   protected List<UsbProfile> usbProfiles;
   protected MonitoringDataInputStream isFbUpd;
   protected MonitoringDataInputStream isFbUpdRect;
   private ImageDecoder imageDecoderLrle;
   private ImageDecoder imageDecoderRaw;
   private ImageDecoder imageDecoderRawVsc;
   private ImageDecoder imageDecoderHextile;
   private ImageDecoder imageDecoderTight;
   private RfbRenderer rfbRenderer;
   RCCore.MouseMode currentMouseMode;
   private RCCore.ColorDepth customColorDepth = null;
   private RCCore.Compression customCompression = null;
   private RCCore.Smoothing customSmoothing = null;
   private int videoUpdateDelay;
   private Map<IMultiMonitorTargetSupport.ClientSessionInitProperties, String> clientSessionInitProps;

   public static RfbHandler loadRfbHandler(DeviceConnector var0, Logger var1, ListenerLists var2, RemoteConsoleRenderer var3) throws IOException, RCException {
      RfbVersionNegotiator var4 = new RfbVersionNegotiator();
      var4.init(var0, var1, var2, null);
      var4.negotiateProtocolVersion();
      RfbHandler var5 = loadRfbHandler(var0, var1, var2, var3, var4.versionMajor, var4.versionMinor);
      var5.versionMajor = var4.versionMajor;
      var5.versionMinor = var4.versionMinor;
      return var5;
   }

   public static RfbHandler loadRfbHandler(DeviceConnector var0, Logger var1, ListenerLists var2, RemoteConsoleRenderer var3, int var4, int var5) throws IOException, RCException {
      RfbHandler var6;
      try {
         String var7 = getVersionString(var4, var5, '_');
         String var10 = "nn.pp.rccore.impl.rfb.V" + var7 + ".RfbHandlerV" + var7;
         var1.log(Level.FINE, T._("Trying to load protocol handler:") + " " + var10);
         var6 = (RfbHandler)Class.forName(var10).newInstance();
      } catch (Throwable var9) {
         String var8 = T._("Unable to load protocol handler!");
         var1.log(Level.SEVERE, var8, var9);
         throw new RCException(var8);
      }

      var6.init(var0, var1, var2, var3);
      return var6;
   }

   public void setAppletParmeterMap(LinkedHashMap<String, String> var1) {
   }

   protected Map<String, String> getCapabilityMap() {
      return null;
   }

   @Override
   protected String getProtocolName() {
      return "RFB";
   }

   protected RCException loadException(String var1) {
      return new RCException(var1);
   }

   public RfbRenderer getRfbRenderer() {
      return this.rfbRenderer;
   }

   @Override
   protected void disconnected(Exception var1) {
      if (this.listeners != null) {
         this.listeners.connectionEventListenerList.fireDisconnected(var1);
      }
   }

   public void init(DeviceConnector var1, Logger var2, ListenerLists var3, RemoteConsoleRenderer var4) throws IOException {
      this.listeners = var3;
      this.renderer = var4;
      super.init(var1, var2);
      if (var4 != null) {
         var4.setRenewer(this);
         if (var4 instanceof ISupportsMouseHandling) {
            ((ISupportsMouseHandling)var4).setMouseEventConsumer(this);
         }

         if (var4 instanceof ISupportsKeyboardHandling) {
            ((ISupportsKeyboardHandling)var4).setKeyboardEventConsumer(this);
         }

         this.inflater = new ZlibEncodingInflater(var2);
         this.rfbRenderer = new RfbRenderer(var4, var2);
         var4.setImageProvider(this.rfbRenderer);
      }
   }

   @Override
   public void dispose() {
      if (this.pingTimerTask != null) {
         this.pingTimerTask.cancel();
      }

      if (this.fpsTimer != null) {
         this.fpsTimer.cancel();
      }

      if (this.encoding != null) {
         this.encoding = null;
      }

      if (this.renderer != null) {
         this.renderer.dispose();
         this.renderer = null;
      }

      if (this.rfbRenderer != null) {
         this.rfbRenderer.dispose();
         this.rfbRenderer = null;
      }

      if (this.listeners != null) {
         this.listeners = null;
      }

      if (this.videoSettingsHandler != null) {
         this.videoSettingsHandler = null;
      }

      if (this.usbProfileList != null) {
         this.usbProfileList = null;
      }

      if (this.vmConfig != null) {
         this.vmConfig = null;
      }

      if (this.framebufferUpdateRectBuffer != null) {
         this.framebufferUpdateRectBuffer = null;
      }

      if (this.inflater != null) {
         this.inflater = null;
      }

      if (this.portList != null) {
         this.portList = null;
      }

      if (this.currentRfbPixelFormat != null) {
         this.currentRfbPixelFormat = null;
      }

      if (this.supportedMouseModes != null) {
         this.supportedMouseModes = null;
      }

      if (this.keyboardLeds != null) {
         this.keyboardLeds = null;
      }

      if (this.appletParameterMap != null) {
         this.appletParameterMap = null;
      }

      if (this.selectedUsbProfile != null) {
         this.selectedUsbProfile = null;
      }

      if (this.usbProfiles != null) {
         this.usbProfiles = null;
      }

      if (this.isFbUpd != null) {
         this.isFbUpd = null;
      }

      if (this.isFbUpdRect != null) {
         this.isFbUpdRect = null;
      }

      if (this.imageDecoderLrle != null) {
         this.imageDecoderLrle = null;
      }

      if (this.imageDecoderRaw != null) {
         this.imageDecoderRaw = null;
      }

      if (this.imageDecoderRawVsc != null) {
         this.imageDecoderRawVsc = null;
      }

      if (this.imageDecoderHextile != null) {
         this.imageDecoderHextile = null;
      }

      if (this.imageDecoderTight != null) {
         this.imageDecoderTight = null;
      }

      if (this.isFbUpd != null) {
         this.isFbUpd = null;
      }

      System.gc();
      System.runFinalization();
      super.dispose();
   }

   protected void sendIncrementalFramebufferUpdateRequest() throws IOException {
      this.writeFramebufferUpdateRequest(0, 0, this.framebufferWidth, this.framebufferHeight, true);
   }

   protected void sendFullFramebufferUpdateRequest() throws IOException {
      this.writeFramebufferUpdateRequest(0, 0, this.framebufferWidth, this.framebufferHeight, false);
   }

   @Override
   protected void initialHandshakeFinished() throws IOException {
      super.initialHandshakeFinished();
      this.pingTimerTask = new TimerTask() {
         int serial = 0;

         @Override
         public void run() {
            try {
               RfbHandler.this.writePingRequest(this.serial++);
            } catch (IOException var2) {
               RfbHandler.this.logger.log(Level.WARNING, T._("Could not write ping request"), (Throwable)var2);
            }
         }
      };
      PingTimer.schedule(this.pingTimerTask);
      if (this.fpsEnabled) {
         this.fpsTimer = new Timer("FPS");
         this.fpsTimer.schedule(new TimerTask() {
            @Override
            public void run() {
               int var1 = RfbHandler.this.getAndClearFps();
               RfbHandler.this.listeners.connectionEventListenerList.fireFramesPerSecond(var1);
            }
         }, 1000L, 1000L);
      }

      this.listeners.connectionEventListenerList.fireProtocolVersionChanged(getVersionString(this.versionMajor, this.versionMinor, '.'));
      this.listeners.connectionEventListenerList.fireConnected();
      this.listeners.notificationListenerList.fireTextNotification(MessageFormat.format(T._("Successfully connected to {0}"), this.host));
   }

   private synchronized void increaseFps() {
      this.fps++;
   }

   private synchronized int getAndClearFps() {
      int var1 = this.fps;
      this.fps = 0;
      return var1;
   }

   public int readCompactLen() throws IOException {
      int var1 = this.is.readUnsignedByte();
      int var2 = var1 & 127;
      if ((var1 & 128) != 0) {
         var1 = this.is.readUnsignedByte();
         var2 |= (var1 & 127) << 7;
         if ((var1 & 128) != 0) {
            var1 = this.is.readUnsignedByte();
            var2 |= (var1 & 0xFF) << 14;
         }
      }

      return var2;
   }

   public void setMonitorOnly(boolean var1) {
      this.monitorOnly = var1;
   }

   public void setEncodingToAuto(boolean var1) throws IOException {
      this.encoding.setEncodingToAuto();
      if (var1) {
         this.writeSetEncodingsMsg(this.encoding.getRfbEncodings());
         this.writeSetPixelFormatMsg(this.encoding.getRfbPixelFormat());
         this.sendFullFramebufferUpdateRequest();
      }
   }

   public void setEncodingPredefine(RCCore.Predefine var1) throws IOException {
      this.encoding.setPredefine(var1);
      this.writeSetEncodingsMsg(this.encoding.getRfbEncodings());
      this.writeSetPixelFormatMsg(this.encoding.getRfbPixelFormat());
      this.sendFullFramebufferUpdateRequest();
   }

   public void setEncodingColorDepth(RCCore.ColorDepth var1, boolean var2) throws IOException {
      this.encoding.setColorDepth(var1);
      if (var2) {
         this.writeSetEncodingsMsg(this.encoding.getRfbEncodings());
         this.writeSetPixelFormatMsg(this.encoding.getRfbPixelFormat());
         this.sendFullFramebufferUpdateRequest();
      }
   }

   public void setEncodingCompression(RCCore.Compression var1, boolean var2) throws IOException {
      this.encoding.setCompression(var1);
      if (var2) {
         this.writeSetEncodingsMsg(this.encoding.getRfbEncodings());
         this.writeSetPixelFormatMsg(this.encoding.getRfbPixelFormat());
         this.sendFullFramebufferUpdateRequest();
      }
   }

   public void setEncodingLossy(boolean var1, boolean var2) throws IOException {
      this.encoding.setLossy(var1);
      if (var2) {
         this.writeSetEncodingsMsg(this.encoding.getRfbEncodings());
         this.writeSetPixelFormatMsg(this.encoding.getRfbPixelFormat());
         this.sendFullFramebufferUpdateRequest();
      }
   }

   public void sendPropertyChange(String var1, String var2) throws IOException {
      this.writeUserPropChangeEvent(var1, var2);
   }

   public void setLocalKeyboardMappingPersistent(boolean var1) {
      this.localKeyboardMappingPersistent = var1;
   }

   public void requestVideoSettingsUpdates() throws IOException {
      this.videoSettingsHandler.requestVideoSettingsUpdates();
   }

   public void stopVideoSettingsUpdates() throws IOException {
      this.videoSettingsHandler.stopVideoSettingsUpdates();
   }

   public void setVideoSettings(IVideoSettings var1) throws IOException {
      this.videoSettingsHandler.setVideoSettings(var1);
   }

   public void requestVideoAutoSense() throws IOException {
      this.videoSettingsHandler.requestVideoAutoSense();
   }

   public void requestVideoColorCalibration() throws IOException {
      this.videoSettingsHandler.requestVideoColorCalibration();
   }

   public void requestVideoRefresh() throws IOException {
      this.writeVideoRefreshMsg();
   }

   public void saveVideoSettings() throws IOException {
      this.videoSettingsHandler.saveVideoSettings();
   }

   public void cancelVideoSettings() throws IOException {
      this.videoSettingsHandler.cancelVideoSettings();
   }

   public void resetVideoSettingsAllModes() throws IOException {
      this.videoSettingsHandler.resetVideoSettingsAllModes();
   }

   public void resetVideoSettingsThisMode() throws IOException {
      this.videoSettingsHandler.resetVideoSettingsThisMode();
   }

   public void resetVideoSettingsThisPort() throws IOException {
      this.videoSettingsHandler.resetVideoSettingsThisPort();
   }

   public void sendChatMessage(String var1) throws IOException {
      this.writeUtf8StringMsg(var1);
   }

   public void switchKvmPort(int var1, String var2) throws IOException, RCException {
      this.writeKvmSwitchEventMsg(var1, var2);
   }

   public List<RCCore.ColorDepth> getSupportedColorDepthsForCompression(RCCore.Compression var1) {
      return this.encoding.getSupportedColorDepthsForCompression(var1);
   }

   public List<RCCore.Compression> getSupportedCompressionsForColorDepth(RCCore.ColorDepth var1) {
      return this.encoding.getSupportedCompressionsForColorDepth(var1);
   }

   public RCCore.ColorDepth getColorDepthForPredefine(RCCore.Predefine var1) {
      return this.encoding.getColorDepthForPredefine(var1);
   }

   public RCCore.Compression getCompressionForPredefine(RCCore.Predefine var1) {
      return this.encoding.getCompressionForPredefine(var1);
   }

   public boolean getLossyForPredefine(RCCore.Predefine var1) {
      return this.encoding.getLossyForPredefine(var1);
   }

   public void mountOrUnmountRemoteIso(IVMMountRequestResponse var1) throws IOException {
      this.writeVmMountsRequest(var1);
   }

   public void setMouseMode(RCCore.MouseMode var1) throws IOException {
      String var2;
      if (var1 == RCCore.MouseMode.ABSOLUTE) {
         var2 = "absolute";
      } else if (var1 == RCCore.MouseMode.AUTOMATIC) {
         var2 = "auto";
      } else {
         if (var1 != RCCore.MouseMode.STANDARD) {
            return;
         }

         var2 = "direct";
      }

      this.writeSetConnectionParameterMsg("current_mouse_mode", var2);
   }

   public void changeUsbProfile(int var1) throws IOException {
      this.writeUsbProfileSelect(var1);
   }

   @Override
   public void renewFramebuffer() {
      if (this.connected && !this.inInitialHandshake) {
         try {
            this.sendFullFramebufferUpdateRequest();
         } catch (IOException var2) {
         }
      }
   }

   @Override
   public void consumeAbsoluteMouseEvent(int var1, int var2, int var3) {
      if (this.connected && !this.inInitialHandshake && !this.monitorOnly) {
         try {
            this.writePointerEvent(false, var1, var2, 0, var3);
         } catch (IOException var5) {
            this.logger.log(Level.SEVERE, T._("Could not write mouse event!"), (Throwable)var5);
         }
      }
   }

   @Override
   public void consumeRelativeMouseEvent(int var1, int var2, int var3) {
      if (this.connected && !this.inInitialHandshake && !this.monitorOnly) {
         try {
            this.writePointerEvent(true, var1, var2, 0, var3);
         } catch (IOException var5) {
            this.logger.log(Level.SEVERE, T._("Could not write mouse event!"), (Throwable)var5);
         }
      }
   }

   @Override
   public void consumeMouseWheelEvent(int var1, int var2) {
      if (this.connected && !this.inInitialHandshake && !this.monitorOnly) {
         try {
            if (this.currentMouseMode == RCCore.MouseMode.ABSOLUTE) {
               this.writePointerEvent(false, 0, 0, var1, var2);
            } else {
               this.writePointerEvent(true, 0, 0, var1, var2);
            }
         } catch (IOException var4) {
            this.logger.log(Level.SEVERE, T._("Could not write mouse event!"), (Throwable)var4);
         }
      }
   }

   @Override
   public void handleMouseSync(RCCore.MouseSyncType var1) {
      if (this.connected && !this.inInitialHandshake && !this.monitorOnly) {
         byte var2;
         if (var1 == RCCore.MouseSyncType.FAST) {
            var2 = 2;
         } else if (var1 == RCCore.MouseSyncType.HARD) {
            var2 = 1;
         } else {
            var2 = 0;
         }

         try {
            this.writeMouseSyncEvent(var2);
         } catch (IOException var4) {
            this.logger.log(Level.SEVERE, T._("Could not write mouse sync event!"), (Throwable)var4);
         }
      }
   }

   @Override
   public void consumeKeyboardEvent(int var1, boolean var2) {
      if (this.connected && !this.inInitialHandshake && !this.monitorOnly) {
         try {
            this.writeKeyboardEvent(var1, var2);
         } catch (IOException var4) {
            this.logger.log(Level.SEVERE, T._("Could not write keyboard event!"), (Throwable)var4);
         }
      }
   }

   public void hotkeyDetected(int var1) {
   }

   protected boolean notificationIsQuit() {
      return false;
   }

   private static String getQuitReasonMsg(int var0) {
      switch (var0) {
         case 1:
            return T._("No Permission");
         case 2:
            return T._("Exclusive Access Active");
         case 3:
            return T._("Manually Rejected");
         case 4:
            return T._("Server Password Disabled");
         case 5:
            return T._("Loopback Connection is Senseless");
         case 6:
            return T._("Authentication Failed");
         case 7:
            return T._("Access to this KVM Port Denied");
         case 8:
            return T._("Too Many Clients Active Simultaneously");
         case 9:
         case 10:
         case 11:
         case 12:
         case 13:
         case 14:
         case 15:
         default:
            return T._("Unknown Reason");
         case 16:
            return T._("Unexpected Server Error");
         case 17:
            return T._("Bad Protocol Version");
         case 18:
            return T._("Protocol Error");
         case 19:
            return T._("Internal Server Error");
         case 20:
            return T._("Wrong Replay Parameters");
         case 21:
            return T._("Unable to Establish SSL Connection");
      }
   }

   private static String[] resizeArray(String[] var0, int var1) {
      int var2 = Array.getLength(var0);
      Object var3 = Array.newInstance(var0.getClass().getComponentType(), var1);
      int var4 = Math.min(var2, var1);
      if (var4 > 0) {
         System.arraycopy(var0, 0, var3, 0, var4);
      }

      return (String[])var3;
   }

   private boolean portListContains(String var1) {
      if (this.portList != null) {
         for (KvmPort var3 : this.portList) {
            if (var3.equals(var1)) {
               return true;
            }
         }
      }

      return false;
   }

   protected void processConnectionParameter(List<KeyValuePair<String, String>> var1) throws RCException {
      for (KeyValuePair var3 : var1) {
         String var4 = (String)var3.getKey();
         String var5 = (String)var3.getValue();
         this.processConnectionParameter(var4, var5);
      }
   }

   protected boolean processConnectionParameter(String var1, String var2) throws RCException {
      if (var2.equals("")) {
         return false;
      } else if (var1.equalsIgnoreCase("hwenc") || var1.equalsIgnoreCase("hw_enc")) {
         boolean var14 = var2.equalsIgnoreCase("yes");
         this.listeners.videoEventListenerList.fireEncodingLossySupportedChanged(var14);
         this.listeners.videoEventListenerList.fireEncodingAutoSupportedChanged(true);
         this.listeners.videoEventListenerList.fireSupportedEncodingPredefinesChanged(this.encoding.getSupportedPredefines());
         this.listeners.videoEventListenerList.fireSupportedEncodingColorDepthsChanged(this.encoding.getSupportedColorDepths());
         this.listeners.videoEventListenerList.fireSupportedEncodingCompressionsChanged(this.encoding.getSupportedCompressions());
         if (this.encoding != null) {
            this.encoding.hwEncSupported(var14);
         }

         return true;
      } else if (var1.equalsIgnoreCase("selenc")) {
         if (this.lowBandwidth) {
            this.encoding.setEncodingTypeFromRfb("preconf");
         } else {
            this.encoding.setEncodingTypeFromRfb(var2);
         }

         return true;
      } else if (var1.equalsIgnoreCase("fixenc")) {
         if (this.lowBandwidth) {
            this.encoding.setEncodingPredefineFromRfb("modem_4bit");
         } else {
            this.encoding.setEncodingPredefineFromRfb(var2);
         }

         return true;
      } else if (var1.equalsIgnoreCase("AdvEncCR")) {
         this.encoding.setEncodingCompressionFromRfb(var2);
         return true;
      } else if (var1.equalsIgnoreCase("AdvEncCD")) {
         this.encoding.setEncodingColorDepthFromRfb(var2);
         return true;
      } else if (var1.equalsIgnoreCase("BOARD_NAME")) {
         this.listeners.connectionEventListenerList.fireDeviceNameChanged(var2);
         return true;
      } else if (var1.equalsIgnoreCase("vs_enc")) {
         this.listeners.videoEventListenerList.fireEncodingChangeAllowed(var2.equalsIgnoreCase("yes"));
         return true;
      } else if (var1.equalsIgnoreCase("drive_redirection_no_drives")) {
         int var13 = Integer.parseInt(var2);
         this.listeners.virtualMediaInfoListenerList.fireVirtualMediaSupportChanged(var13 != 0);
         this.listeners.virtualMediaInfoListenerList.fireVirtualMediaDriveCountChanged(var13);
         return true;
      } else if (var1.equalsIgnoreCase("drive_redirection_read_only")) {
         this.listeners.virtualMediaInfoListenerList.fireVirtualMediaReadOnlyChanged(var2.equalsIgnoreCase("yes"));
         return true;
      } else {
         if (var1.equalsIgnoreCase("audio_support")) {
            this.listeners.audioStatusListenerList.fireAudioSupportChanged(var2.equalsIgnoreCase("yes"));
         }

         if (var1.equalsIgnoreCase("osd_bgcolor")) {
            Color var12 = new Color(Integer.valueOf(var2.substring(1), 16));
            this.renderer.setOsdBgColor(var12);
            return true;
         } else if (var1.equalsIgnoreCase("osd_fgcolor")) {
            Color var11 = new Color(Integer.valueOf(var2.substring(1), 16));
            this.renderer.setOsdFgColor(var11);
            return true;
         } else if (var1.equalsIgnoreCase("osd_alpha")) {
            int var10 = Integer.valueOf(var2, 10);
            this.renderer.setOsdAlpha(var10);
            return true;
         } else if (var1.equalsIgnoreCase("osd_position")) {
            this.renderer.setOsdPosition(var2);
            return true;
         } else if (var1.toLowerCase().startsWith("hotkey_")) {
            if (this.hotkeyReadableCodes == null) {
               this.hotkeyReadableCodes = new String[1];
            }

            String var9 = var1.substring("hotkey_".length());
            int var16 = Integer.valueOf(var9, 10);
            if (this.hotkeyHighestIndex < var16) {
               this.hotkeyHighestIndex = var16;
            }

            this.hotkeyReadableCodes = resizeArray(this.hotkeyReadableCodes, var16 + 1);
            this.hotkeyReadableCodes[var16] = new String(var2);
            return true;
         } else if (var1.toLowerCase().startsWith("hotkeycode_")) {
            if (this.hotkeyKeyCodes == null) {
               this.hotkeyKeyCodes = new String[1];
            }

            String var8 = var1.substring("hotkeycode_".length());
            int var15 = Integer.valueOf(var8, 10);
            this.hotkeyKeyCodes = resizeArray(this.hotkeyKeyCodes, var15 + 1);
            this.hotkeyKeyCodes[var15] = new String(var2);
            return true;
         } else if (var1.toLowerCase().startsWith("hotkeyname_")) {
            if (this.hotkeyNames == null) {
               this.hotkeyNames = new String[1];
            }

            String var7 = var1.substring("hotkeyname_".length());
            int var4 = Integer.valueOf(var7, 10);
            this.hotkeyNames = resizeArray(this.hotkeyNames, var4 + 1);
            this.hotkeyNames[var4] = new String(var2);
            return true;
         } else if (var1.equalsIgnoreCase("localkbd_mapping")) {
            if (this.localKeyboardMappingPersistent && var2.length() > 0) {
               Locale var6 = StringLocale.loadLocale(var2);
               this.listeners.keyboardInfoListenerList.fireLocalKeyboardMappingChanged(var6);
            }

            return true;
         } else if (var1.equalsIgnoreCase("softkbd_mapping")) {
            if (var2.length() > 0) {
               Locale var5 = StringLocale.loadLocale(var2);
               this.listeners.keyboardInfoListenerList.fireSoftKeyboardMappingChanged(var5);
            }

            return true;
         } else if (var1.equalsIgnoreCase("video_settings")) {
            this.videoSettingsAvailable = var2.equalsIgnoreCase("yes");
            return true;
         } else if (var1.equalsIgnoreCase("refresh_video")) {
            this.videoRefreshAvailable = var2.equalsIgnoreCase("yes");
            return true;
         } else if (var1.equalsIgnoreCase("vs_type")) {
            this.videoSettingsOffsetOnly = var2.equalsIgnoreCase("offset");
            return true;
         } else if (var1.equalsIgnoreCase("vs_perm_std")) {
            this.videoSettingsPermStandard = var2.equalsIgnoreCase("yes");
            return true;
         } else if (var1.equalsIgnoreCase("vs_perm_adv")) {
            this.videoSettingsPermFull = var2.equalsIgnoreCase("yes");
            return true;
         } else if (var1.equalsIgnoreCase("color_calibration")) {
            this.colorCalibration = var2.equalsIgnoreCase("yes");
            return true;
         } else if (var1.equalsIgnoreCase("eth_gigabit")) {
            this.listeners.connectionEventListenerList.fireEthernetGigabitSupported(var2.equalsIgnoreCase("yes"));
            return true;
         } else if (var1.equalsIgnoreCase("mousesync_key")) {
            this.mouseSyncReadableCode = var2;
            return true;
         } else if (var1.equalsIgnoreCase("mousesync_keycode")) {
            this.mouseSyncKeyCode = var2;
            return true;
         } else if (var1.equalsIgnoreCase("use_iip")) {
            this.listeners.mouseModeListenerList.fireMouseSyncSupportChanged(var2.equalsIgnoreCase("yes"));
            this.listeners.mouseModeListenerList.fireSingleCursorModeSupportChanged(var2.equalsIgnoreCase("yes"));
            return true;
         } else {
            if (var1.equalsIgnoreCase("EXCLUSIVE_MOUSE")) {
               this.listeners.mouseModeListenerList.fireSingleCursorModeChanged(var2.equalsIgnoreCase("yes"));
            }

            if (var1.equalsIgnoreCase("monitor_mode")) {
               if (var2.equalsIgnoreCase("yes")) {
                  this.listeners.connectionEventListenerList.fireMonitorModeChanged(true);
                  this.listeners.connectionEventListenerList.fireMonitorModePermissionChanged(true);
               } else if (var2.equalsIgnoreCase("sticky")) {
                  this.listeners.connectionEventListenerList.fireMonitorModeChanged(true);
                  this.listeners.connectionEventListenerList.fireMonitorModePermissionChanged(false);
               } else {
                  this.listeners.connectionEventListenerList.fireMonitorModeChanged(false);
                  this.listeners.connectionEventListenerList.fireMonitorModePermissionChanged(true);
               }

               return true;
            } else if (var1.equalsIgnoreCase("exclusive_perm")) {
               if (var2.equalsIgnoreCase("on")) {
                  this.listeners.connectionEventListenerList.fireExclusiveModeChanged(true);
                  this.listeners.connectionEventListenerList.fireExclusiveModePermissionChanged(true);
               } else if (var2.equalsIgnoreCase("off")) {
                  this.listeners.connectionEventListenerList.fireExclusiveModeChanged(false);
                  this.listeners.connectionEventListenerList.fireExclusiveModePermissionChanged(true);
               } else if (var2.equalsIgnoreCase("sticky")) {
                  this.listeners.connectionEventListenerList.fireExclusiveModeChanged(true);
                  this.listeners.connectionEventListenerList.fireExclusiveModePermissionChanged(false);
               } else if (var2.equalsIgnoreCase("no")) {
                  this.listeners.connectionEventListenerList.fireExclusiveModeChanged(false);
                  this.listeners.connectionEventListenerList.fireExclusiveModePermissionChanged(false);
               }

               return true;
            } else if (var1.equalsIgnoreCase("mouse_caps")) {
               this.listeners.mouseModeListenerList.fireMouseModeChangeSupportChanged(var2.equalsIgnoreCase("yes"));
               return true;
            } else if (var1.equalsIgnoreCase("vmmount_caps")) {
               this.listeners.virtualMediaInfoListenerList.fireRemoteIsoSupportChanged(var2.equalsIgnoreCase("yes"));
               return true;
            } else {
               if (var1.toLowerCase().startsWith("license_")) {
                  String[] var3 = var1.split("_");
                  if (var3.length == 2) {
                     this.listeners.licenseSupportListenerList.fireLicenseFeatureSupportChanged(var3[1], var2.equalsIgnoreCase("yes"));
                  }
               }

               if (var1.equalsIgnoreCase("charset")) {
                  if (var2.length() > 0) {
                     T.setCharset(var2);
                  }

                  return true;
               } else if (var1.equalsIgnoreCase("cim_lang_option")) {
                  this.listeners.connectionEventListenerList.fireCimLanguageOptionsSupported(var2.equalsIgnoreCase("yes"));
                  return true;
               } else if (var1.equalsIgnoreCase("devicename")) {
                  this.listeners.connectionEventListenerList.fireDeviceNameChanged(var2);
                  return true;
               } else {
                  return false;
               }
            }
         }
      }
   }

   protected boolean processServerCommand(String var1, String var2) throws RCException {
      if (var1.equalsIgnoreCase("rc_users")) {
         int var15 = Integer.parseInt(var2);
         this.listeners.connectionEventListenerList.fireConnectedUsersChanged(var15);
         return true;
      } else if (var1.equalsIgnoreCase("charset")) {
         T.setCharset(var2);
         return true;
      } else if (var1.equalsIgnoreCase("exclusive_mode")) {
         boolean var14 = var2.equalsIgnoreCase("active");
         this.listeners.connectionEventListenerList.fireExclusiveModeChanged(var14);
         return true;
      } else if (var1.equalsIgnoreCase("support_mouse_absolute")) {
         if (var2.equalsIgnoreCase("yes")) {
            if (!this.supportedMouseModes.contains(RCCore.MouseMode.ABSOLUTE)) {
               this.supportedMouseModes.add(RCCore.MouseMode.ABSOLUTE);
            }
         } else if (this.supportedMouseModes.contains(RCCore.MouseMode.ABSOLUTE)) {
            this.supportedMouseModes.remove(RCCore.MouseMode.ABSOLUTE);
         }

         this.listeners.mouseModeListenerList.fireSupportedMouseModesChanged(this.supportedMouseModes);
         return true;
      } else if (var1.equalsIgnoreCase("support_mouse_auto")) {
         if (var2.equalsIgnoreCase("yes")) {
            if (!this.supportedMouseModes.contains(RCCore.MouseMode.AUTOMATIC)) {
               this.supportedMouseModes.add(RCCore.MouseMode.AUTOMATIC);
            }
         } else if (this.supportedMouseModes.contains(RCCore.MouseMode.AUTOMATIC)) {
            this.supportedMouseModes.remove(RCCore.MouseMode.AUTOMATIC);
         }

         this.listeners.mouseModeListenerList.fireSupportedMouseModesChanged(this.supportedMouseModes);
         return true;
      } else if (var1.equalsIgnoreCase("support_mouse_direct")) {
         if (var2.equalsIgnoreCase("yes")) {
            if (!this.supportedMouseModes.contains(RCCore.MouseMode.STANDARD)) {
               this.supportedMouseModes.add(RCCore.MouseMode.STANDARD);
            }
         } else if (this.supportedMouseModes.contains(RCCore.MouseMode.STANDARD)) {
            this.supportedMouseModes.remove(RCCore.MouseMode.STANDARD);
         }

         this.listeners.mouseModeListenerList.fireSupportedMouseModesChanged(this.supportedMouseModes);
         return true;
      } else if (var1.equalsIgnoreCase("current_mouse_mode")) {
         RCCore.MouseMode var13;
         if (var2.equalsIgnoreCase("absolute")) {
            var13 = RCCore.MouseMode.ABSOLUTE;
         } else if (var2.equalsIgnoreCase("auto")) {
            var13 = RCCore.MouseMode.AUTOMATIC;
         } else {
            if (!var2.equalsIgnoreCase("direct")) {
               return true;
            }

            var13 = RCCore.MouseMode.STANDARD;
         }

         this.listeners.mouseModeListenerList.fireMouseModeChanged(var13);
         return true;
      } else if (var1.equalsIgnoreCase("capslockled")) {
         if (var2.equalsIgnoreCase("on")) {
            if (!this.keyboardLeds.contains(RCCore.KeyboardLed.LED_CAPSLOCK)) {
               this.keyboardLeds.add(RCCore.KeyboardLed.LED_CAPSLOCK);
            }
         } else if (this.keyboardLeds.contains(RCCore.KeyboardLed.LED_CAPSLOCK)) {
            this.keyboardLeds.remove(RCCore.KeyboardLed.LED_CAPSLOCK);
         }

         this.listeners.keyboardInfoListenerList.fireKeyboardLedStateChanged(this.keyboardLeds);
         return true;
      } else if (var1.equalsIgnoreCase("numlockled")) {
         if (var2.equalsIgnoreCase("on")) {
            if (!this.keyboardLeds.contains(RCCore.KeyboardLed.LED_NUMLOCK)) {
               this.keyboardLeds.add(RCCore.KeyboardLed.LED_NUMLOCK);
            }
         } else if (this.keyboardLeds.contains(RCCore.KeyboardLed.LED_NUMLOCK)) {
            this.keyboardLeds.remove(RCCore.KeyboardLed.LED_NUMLOCK);
         }

         this.listeners.keyboardInfoListenerList.fireKeyboardLedStateChanged(this.keyboardLeds);
         return true;
      } else if (var1.equalsIgnoreCase("scrolllockled")) {
         if (var2.equalsIgnoreCase("on")) {
            if (!this.keyboardLeds.contains(RCCore.KeyboardLed.LED_SCROLLLOCK)) {
               this.keyboardLeds.add(RCCore.KeyboardLed.LED_SCROLLLOCK);
            }
         } else if (this.keyboardLeds.contains(RCCore.KeyboardLed.LED_SCROLLLOCK)) {
            this.keyboardLeds.remove(RCCore.KeyboardLed.LED_SCROLLLOCK);
         }

         this.listeners.keyboardInfoListenerList.fireKeyboardLedStateChanged(this.keyboardLeds);
         return true;
      } else if (var1.equalsIgnoreCase("devicename")) {
         this.listeners.connectionEventListenerList.fireDeviceNameChanged(var2);
         return true;
      } else {
         if (var1.equalsIgnoreCase("audio")) {
            boolean var3 = false;
            boolean var4 = false;
            String var5 = null;
            String var6 = null;
            String[] var7 = var2.split(";");

            for (String var11 : var7) {
               String[] var12 = var11.split("=");
               if (var12.length == 2) {
                  if (var12[0].equalsIgnoreCase("spk")) {
                     var3 = var12[1].equalsIgnoreCase("true");
                  } else if (var12[0].equalsIgnoreCase("spkformat")) {
                     var5 = var12[1];
                  } else if (var12[0].equalsIgnoreCase("mic")) {
                     var4 = var12[1].equalsIgnoreCase("true");
                  } else if (var12[0].equalsIgnoreCase("micformat")) {
                     var6 = var12[1];
                  }
               }
            }

            this.listeners
               .audioSettingsExListenerList
               .fireAudioSettingsChanged(new IAudioStatusExSupport.AudioStatus(var3, var5), new IAudioStatusExSupport.AudioStatus(var4, var6));
         }

         return false;
      }
   }

   protected int readServerId() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected List<KvmPort> readPortListMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readAuthCaps() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   public void writeLogin(String var1, int var2, int var3) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readSessionChallenge() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   public void writeChallengeResponse(String var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readAuthSuccessfulMsg() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   protected int readQuitMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected NotificationEvent readUserNotificationMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected String readUtf8StringMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeUtf8StringMsg(String var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected List<KeyValuePair<String, String>> readConnectionParameterMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected String readServerRCMessageMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readOSDStateMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeClientInitMsg(String var1) throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   protected void writeKvmSwitchEventMsg(int var1, String var2) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected String readKeyboardLayout() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readServerFBFormat() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readServerCommand() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected int readPingRequest() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writePingRequest(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected int readPingReply() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writePingReply(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected RfbPixelFormat readAckPixelFormatMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readBandwidthRequestMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeBandwidthReplyMsg(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeSetEncodingsMsg(int[] var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeSetPixelFormatMsg(RfbPixelFormat var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeFramebufferUpdateRequest(int var1, int var2, int var3, int var4, boolean var5) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readFramebufferUpdate() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readFramebufferUpdateRect() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writePointerEvent(boolean var1, int var2, int var3, int var4, int var5) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeMouseSyncEvent(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeKeyboardEvent(int var1, boolean var2) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeUserPropChangeEvent(String var1, String var2) throws IOException {
      throw new UnsupportedOperationException();
   }

   public void writeVideoSettingsRequest(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   public void writeVideoSettingsEvent(int var1, int var2) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeVideoRefreshMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readVideoQualityMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected VideoSettings readVideoSettingsMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected List<VMMountRequestResponse> readVmShareList() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected VMMountRequestResponse readVmMountsResponse() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeVmMountsRequest(IVMMountRequestResponse var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeSetConnectionParameterMsg(String var1, String var2) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected UsbProfileList readUsbProfileList() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   protected void writeUsbProfileSelect(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected VMConfigInfo readVirtualMediaConfig() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   protected void readCapabilityTableMessage() throws IOException {
   }

   protected void writeAssociatedTagMsg(String var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   public void setLowBandwidth(boolean var1) {
   }

   public RCCore.ColorDepth setCustomColorDepth(RCCore.ColorDepth var1) {
      RCCore.ColorDepth var2 = null;
      List var3 = this.encoding.getSupportedColorDepths();
      if (var3.contains(var1)) {
         var2 = var1;
      }

      this.customColorDepth = var2;
      return var2;
   }

   public RCCore.Compression setCustomCompression(RCCore.Compression var1) {
      RCCore.Compression var2 = null;
      List var3 = this.encoding.getSupportedCompressions();
      if (var3.contains(var1)) {
         var2 = var1;
      }

      this.customCompression = var2;
      return var2;
   }

   public RCCore.Smoothing setCustomSmoothing(RCCore.Smoothing var1) {
      RCCore.Smoothing var2 = null;
      List var3 = this.encoding.getSupportedSmoothingValues();
      if (var3.contains(var1)) {
         var2 = var1;
      }

      this.customSmoothing = var2;
      return var2;
   }

   protected Map<IMultiMonitorTargetSupport.ClientSessionInitProperties, String> getClientSessionInitProps() {
      return this.clientSessionInitProps;
   }

   public void setClientSessionInitProps(Map<IMultiMonitorTargetSupport.ClientSessionInitProperties, String> var1) {
      this.clientSessionInitProps = var1;
   }

   @Override
   protected void negotiateProtocolVersion() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   protected void processServerInit() throws IOException {
      int var1 = this.readServerId();
      this.listeners.connectionEventListenerList.fireServerSessionIdChanged(var1);
   }

   protected void processPortList() throws IOException {
      List var1 = this.readPortListMsg();
      String var2 = this.listeners.connectionEventListenerList.firePortListChanged(var1);
      this.portList = var1;
      if (var2 != null) {
         this.portID = var2;
      }
   }

   protected void processFramebufferUpdate() throws IOException, RCException {
      int var1 = this.videoUpdateDelay;
      if (var1 == 0) {
         this.sendIncrementalFramebufferUpdateRequest();
      }

      this.increaseFps();
      this.readFramebufferUpdate();
      this.isFbUpd = this.inflater.getUncompressedDataStream(this.is, this, this.updateIsZlib(), false, this.framebufferUpdateSize);
      Rectangle var2 = new Rectangle();

      for (int var3 = 0; var3 < this.noFramebufferUpdateRects; var3++) {
         this.readFramebufferUpdateRect();
         if (this.framebufferUpdateRectX + this.framebufferUpdateRectW > this.framebufferWidthPadded
            || this.framebufferUpdateRectY + this.framebufferUpdateRectH > this.framebufferHeightPadded) {
            throw new RCException(
               MessageFormat.format(
                  T._("Framebuffer update rectangle too large: {0}x{1} at ({2},{3}"),
                  new Integer(this.framebufferUpdateRectW),
                  new Integer(this.framebufferUpdateRectH),
                  new Integer(this.framebufferUpdateRectX),
                  new Integer(this.framebufferUpdateRectY)
               )
            );
         }

         Rectangle var4 = this.processFramebufferUpdateRect();
         var2 = var2.union(var4);
      }

      if (var2.x + var2.width > this.framebufferWidth) {
         var2.width = this.framebufferWidth - var2.x;
      }

      if (var2.y + var2.height > this.framebufferHeight) {
         var2.height = this.framebufferHeight - var2.y;
      }

      this.rfbRenderer.render(var2.x, var2.y, var2.width, var2.height);
      if (var1 != 0) {
         try {
            Thread.sleep(var1);
            this.sendIncrementalFramebufferUpdateRequest();
         } catch (InterruptedException var5) {
            Thread.currentThread().interrupt();
            return;
         }
      }
   }

   protected void processUserNotification() throws IOException, RCException {
      if (this.notificationIsQuit()) {
         int var2 = this.readQuitMsg();
         throw new RCException(getQuitReasonMsg(var2));
      } else {
         NotificationEvent var1 = this.readUserNotificationMsg();
         this.listeners.notificationListenerList.fireNotification(var1);
         if (var1.isQuit()) {
            throw new RCException(var1.getErrorCode(), var1.getMessage());
         }
      }
   }

   protected void processUtf8String() throws IOException, RCException {
      String var1 = this.readUtf8StringMsg();
      if (this.inInitialHandshake) {
         this.listeners.connectionEventListenerList.fireChatWelcomeChanged(var1);
      } else {
         this.listeners.connectionEventListenerList.fireNewChatMessage(var1);
      }
   }

   protected void processKeyboardLayout() throws IOException, RCException {
      String var1 = this.readKeyboardLayout();
      this.listeners.keyboardInfoListenerList.fireSunKeyboardSupported(var1.equalsIgnoreCase("sun"));
   }

   protected void processOSDState() throws IOException, RCException {
      this.readOSDStateMsg();
      this.logger
         .log(
            Level.FINER,
            MessageFormat.format(
               T._("Got OSD message, message: \"{0}\", timeout: {1}, blank: {2}"),
               this.osdText,
               new Integer(this.osdTimeout),
               this.osdBlank ? T._("true") : T._("false")
            )
         );
      this.renderer.setOSD(this.osdText, this.osdTimeout, this.osdBlank);
      this.listeners.videoEventListenerList.fireOsdMessageReceived(this.osdText, this.osdBlank);
   }

   protected void processVideoQuality() throws IOException, RCException {
      this.readVideoQualityMsg();
   }

   protected void processVideoSettings() throws IOException, RCException {
      VideoSettings var1 = this.readVideoSettingsMsg();
      this.videoSettingsHandler.setLastVideoSettings(var1);
      this.listeners.videoEventListenerList.fireVideoSettingsUpdated(var1);
   }

   private boolean isCustomConnectionProperties() {
      return this.customColorDepth != null || this.customCompression != null || this.customSmoothing != null;
   }

   protected void processConnectionParameterList() throws IOException, RCException {
      this.hotkeyHighestIndex = 0;
      List var1 = this.readConnectionParameterMsg();
      Object var2 = null;
      String var3 = "";
      String var4 = "";
      if (this.getCapabilityMap() != null && this.getCapabilityMap().size() > 0) {
         for (String var15 : this.appletParameterMap.keySet()) {
            var4 = this.appletParameterMap.get(var15);
            KeyValuePair var6 = new KeyValuePair<>(var15, var4);
            var1.add(var6);
         }
      }

      if (this.isCustomConnectionProperties()) {
         for (KeyValuePair var19 : var1) {
            if ("selenc".equalsIgnoreCase((String)var19.getKey())) {
               var1.remove(var19);
               break;
            }
         }

         var1.add(0, new KeyValuePair<>("selenc", "manual"));
      }

      this.processConnectionParameter(var1);
      if (this.isCustomConnectionProperties()) {
         if (this.customColorDepth != null) {
            this.encoding.setEncodingColorDepth(this.customColorDepth);
         }

         if (this.customCompression != null) {
            this.encoding.setEncodingCompression(this.customCompression);
         }

         if (this.customSmoothing != null) {
            this.rfbRenderer.setSmoothing(this.customSmoothing);
         }
      }

      int var18 = 0;
      if (this.hotkeyKeyCodes != null) {
         var18 = Math.min(this.hotkeyKeyCodes.length, this.hotkeyHighestIndex + 1);
      }

      if (var18 > 0) {
         Vector var20 = new Vector();

         for (int var7 = 0; var7 < var18; var7++) {
            String var8 = this.hotkeyKeyCodes != null && var7 + 1 <= this.hotkeyKeyCodes.length && this.hotkeyKeyCodes[var7] != null
               ? this.hotkeyKeyCodes[var7]
               : "";
            String var9 = this.hotkeyReadableCodes != null && var7 + 1 <= this.hotkeyReadableCodes.length && this.hotkeyReadableCodes[var7] != null
               ? this.hotkeyReadableCodes[var7]
               : "";
            String var10 = this.hotkeyNames != null && var7 + 1 <= this.hotkeyNames.length && this.hotkeyNames[var7] != null ? this.hotkeyNames[var7] : "";

            try {
               var20.add(new KeyboardMacro(var10, var9, var8));
            } catch (ParseException var13) {
               this.logger.log(Level.WARNING, T._("Could not parse keyboard hotkey"), (Throwable)var13);
            }
         }

         this.listeners.keyboardInfoListenerList.fireKeyboardMacroListChanged(var20);
      }

      this.listeners
         .videoEventListenerList
         .fireVideoSettingsSupportChanged(this.videoSettingsAvailable && (this.videoSettingsPermStandard || this.videoSettingsPermFull));
      this.listeners.videoEventListenerList.fireVideoAutoAdjustSupportChanged(this.videoSettingsAvailable && !this.videoSettingsOffsetOnly);
      this.listeners
         .videoEventListenerList
         .fireColorCalibrationSupportChanged(this.videoSettingsAvailable && !this.videoSettingsOffsetOnly && this.colorCalibration);
      this.listeners.videoEventListenerList.fireVideoRefreshSupportChanged(this.videoRefreshAvailable);
      if (this.mouseSyncKeyCode != null && this.mouseSyncKeyCode.length() > 0 && this.mouseSyncReadableCode != null && this.mouseSyncReadableCode.length() > 0) {
         try {
            this.renderer.setMouseSyncKeys(this.mouseSyncReadableCode, this.mouseSyncKeyCode);
         } catch (ParseException var12) {
            this.logger.log(Level.WARNING, T._("Could not parse Mouse Sync hotkey, single mouse mode not possible"), (Throwable)var12);
         }
      }
   }

   protected void processAckPixelFormat() throws IOException, RCException {
      RfbPixelFormat var1 = this.readAckPixelFormatMsg();
      if (var1 == null) {
         throw new RCException(T._("Invalid Pixel Format received"));
      } else {
         this.currentRfbPixelFormat = var1;
      }
   }

   protected void processAuthCaps() throws IOException, RCException {
      this.readAuthCaps();
   }

   protected void processSessionChallenge() throws IOException, RCException {
      this.readSessionChallenge();
   }

   protected void processAuthSuccessful() throws IOException, RCException {
      this.readAuthSuccessfulMsg();
      this.logger.log(Level.INFO, T._("Successfully logged in."));
   }

   protected void processServerFBFormat() throws IOException, RCException {
      this.readServerFBFormat();
      this.framebufferWidthPadded = this.framebufferWidth;
      this.framebufferHeightPadded = this.framebufferHeight;
      if (this.framebufferWidthPadded % 16 != 0) {
         this.framebufferWidthPadded = (this.framebufferWidthPadded / 16 + 1) * 16;
      }

      if (this.framebufferHeightPadded % 16 != 0) {
         this.framebufferHeightPadded = (this.framebufferHeightPadded / 16 + 1) * 16;
      }

      this.logger
         .log(Level.INFO, MessageFormat.format(T._("New resolution: {0} x {1}"), new Integer(this.framebufferWidth), new Integer(this.framebufferHeight)));
      Dimension var1 = new Dimension(this.framebufferWidth, this.framebufferHeight);
      this.rfbRenderer.setResolution(this.framebufferWidth, this.framebufferHeight);
      this.renderer.screenResolutionChanged(var1);
      this.listeners.videoEventListenerList.fireResolutionChanged(var1);
      if (!this.inInitialHandshake) {
         this.sendFullFramebufferUpdateRequest();
      }
   }

   protected void processServerRCMessage() throws IOException, RCException {
      String var1 = this.readServerRCMessageMsg();
      this.logger.log(Level.FINER, MessageFormat.format(T._("Got RC message: \"{0}\""), var1));
      this.listeners.notificationListenerList.fireTextNotification(var1);
   }

   protected void processServerCommand() throws IOException, RCException {
      this.readServerCommand();
      this.logger.log(Level.FINER, MessageFormat.format(T._("Got Server command: \"{0}\" - \"{1}\""), this.serverCommandName, this.serverCommandValue));
      this.processServerCommand(this.serverCommandName, this.serverCommandValue);
   }

   protected void processPingRequest() throws IOException, RCException {
      int var1 = this.readPingRequest();
      this.writePingReply(var1);
   }

   protected void processPingReply() throws IOException, RCException {
      this.readPingReply();
   }

   protected void processBandwidthRequest() throws IOException, RCException {
      this.writeBandwidthReplyMsg(1);
      this.readBandwidthRequestMsg();
      this.writeBandwidthReplyMsg(2);
      this.logger.log(Level.INFO, T._("Bandwidth measurement done."));
   }

   protected void processMouseCapsResponse() throws IOException, RCException {
      throw new UnsupportedOperationException();
   }

   protected void processVmMountsResponse() throws IOException, RCException {
      VMMountRequestResponse var1 = this.readVmMountsResponse();
      this.listeners.virtualMediaInfoListenerList.fireRemoteIsoMountFinished(var1);
   }

   protected void processVmShareTable() throws IOException {
      List var1 = this.readVmShareList();
      this.listeners.virtualMediaInfoListenerList.fireRemoteIsoListChanged(var1);
   }

   protected void processUsbProfileList() throws IOException, RCException {
      this.readUsbProfileList();
      this.listeners.virtualMediaInfoListenerList.fireUsbProfileListChanged(this.usbProfileList);
   }

   protected void processVirtualMediaConfig() throws IOException, RCException {
      VMConfigInfo var1 = this.readVirtualMediaConfig();
      this.listeners.virtualMediaInfoListenerList.fireVirtualMediaConfigChanged(var1);
   }

   @Override
   protected void processProtocol() throws IOException, RCException {
      while (this.shouldRun) {
         int var1 = this.readServerMessageType();
         switch (var1) {
            case 0:
               this.processFramebufferUpdate();
               break;
            case 3:
               this.processUserNotification();
               break;
            case 4:
               this.processPortList();
               break;
            case 5:
               this.processServerInit();
               break;
            case 7:
               this.processUtf8String();
               break;
            case 8:
               this.processVideoSettings();
               break;
            case 9:
               this.processKeyboardLayout();
               break;
            case 16:
               this.processOSDState();
               break;
            case 17:
               this.processVideoQuality();
               break;
            case 18:
               this.processConnectionParameterList();
               break;
            case 19:
               this.processAckPixelFormat();
               break;
            case 32:
               this.processAuthCaps();
               break;
            case 33:
               this.processSessionChallenge();
               break;
            case 34:
               this.processAuthSuccessful();
               break;
            case 128:
               this.processServerFBFormat();
               break;
            case 131:
               this.processServerRCMessage();
               break;
            case 132:
               this.processServerCommand();
               break;
            case 148:
               this.processPingRequest();
               break;
            case 149:
               this.processPingReply();
               break;
            case 150:
               this.processBandwidthRequest();
               break;
            case 165:
               this.processMouseCapsResponse();
               break;
            case 166:
               this.processVmMountsResponse();
               break;
            case 167:
               this.processVmShareTable();
               break;
            case 168:
               this.processVirtualMediaConfig();
               break;
            case 170:
               this.processUsbProfileList();
               break;
            default:
               this.logger.log(Level.SEVERE, T._("Unknown Protocol message received:") + " " + var1);
               throw new RCException(T._("Protocol Error: Unknown Protocol message received"));
         }

         if (this.inInitialHandshake) {
            this.processInitialHandshake(var1);
         }
      }
   }

   protected abstract boolean updateIsZlib();

   protected abstract boolean updateRectIsZlibStreamed();

   protected abstract boolean updateRectIsZlibCompress();

   protected boolean updateRectIsZlib() {
      return this.updateRectIsZlibStreamed() || this.updateRectIsZlibCompress();
   }

   protected abstract int getUpdateRectEncoding();

   protected abstract int getUpdateRectSubencoding();

   protected int readHardwareEncodingSize() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readHardwareEncodingPadding() throws IOException {
      throw new UnsupportedOperationException();
   }

   private void ensureFramebufferUpdateRectBuffer(int var1) {
      if (this.framebufferUpdateRectBuffer == null || this.framebufferUpdateRectBuffer.length < var1) {
         this.framebufferUpdateRectBuffer = new byte[var1];
      }
   }

   private void processLrleEncoding() throws IOException, RCException {
      if (this.imageDecoderLrle == null) {
         this.imageDecoderLrle = new ImageDecoderLrle(this.logger, this);
      }

      if (this.framebufferUpdateRectSize <= 0) {
         this.framebufferUpdateRectSize = this.readHardwareEncodingSize();
      }

      ReadWriteLock var1 = this.renderer.getLock();

      assert !(var1 instanceof ReentrantReadWriteLock) || ((ReentrantReadWriteLock)var1).isWriteLockedByCurrentThread();

      this.imageDecoderLrle
         .decodeImage(
            this.isFbUpdRect,
            this.rfbRenderer.getFramebufferImageMemory(),
            this.rfbRenderer.getFramebufferImageMemoryWidth(),
            this.framebufferWidth,
            this.framebufferHeight,
            this.getUpdateRectEncoding(),
            this.getUpdateRectSubencoding(),
            this.framebufferUpdateRectX,
            this.framebufferUpdateRectY,
            this.framebufferUpdateRectW,
            this.framebufferUpdateRectH,
            this.currentRfbPixelFormat
         );
      if (!this.updateRectIsZlib()) {
         this.readHardwareEncodingPadding();
      }
   }

   private void processRawEncoding() throws IOException, RCException {
      this.logger.log(Level.FINE, T._("Decoding RAW encoded rect."));
      if (this.imageDecoderRaw == null) {
         this.imageDecoderRaw = new ImageDecoderRaw(this.logger, this);
      }

      ReadWriteLock var1 = this.renderer.getLock();

      assert !(var1 instanceof ReentrantReadWriteLock) || ((ReentrantReadWriteLock)var1).isWriteLockedByCurrentThread();

      this.imageDecoderRaw
         .decodeImage(
            this.isFbUpdRect,
            this.rfbRenderer.getFramebufferImageMemory(),
            this.rfbRenderer.getFramebufferImageMemoryWidth(),
            this.framebufferWidth,
            this.framebufferHeight,
            this.getUpdateRectEncoding(),
            this.getUpdateRectSubencoding(),
            this.framebufferUpdateRectX,
            this.framebufferUpdateRectY,
            this.framebufferUpdateRectW,
            this.framebufferUpdateRectH,
            this.currentRfbPixelFormat
         );
   }

   private void processRawVscEncoding() throws IOException, RCException {
      this.logger.log(Level.FINE, T._("Decoding RAW VSC encoded rect."));
      if (this.imageDecoderRawVsc == null) {
         this.imageDecoderRawVsc = new ImageDecoderRawVsc(this.logger, this);
      }

      ReadWriteLock var1 = this.renderer.getLock();

      assert !(var1 instanceof ReentrantReadWriteLock) || ((ReentrantReadWriteLock)var1).isWriteLockedByCurrentThread();

      this.imageDecoderRawVsc
         .decodeImage(
            this.isFbUpdRect,
            this.rfbRenderer.getFramebufferImageMemory(),
            this.rfbRenderer.getFramebufferImageMemoryWidth(),
            this.framebufferWidth,
            this.framebufferHeight,
            this.getUpdateRectEncoding(),
            this.getUpdateRectSubencoding(),
            this.framebufferUpdateRectX,
            this.framebufferUpdateRectY,
            this.framebufferUpdateRectW,
            this.framebufferUpdateRectH,
            this.currentRfbPixelFormat
         );
   }

   private void processHextileEncoding() throws IOException, RCException {
      this.logger.log(Level.FINE, T._("Decoding Hextile encoded rect."));
      if (this.imageDecoderHextile == null) {
         this.imageDecoderHextile = new ImageDecoderHextile(this.logger, this);
      }

      ReadWriteLock var1 = this.renderer.getLock();

      assert !(var1 instanceof ReentrantReadWriteLock) || ((ReentrantReadWriteLock)var1).isWriteLockedByCurrentThread();

      this.imageDecoderHextile
         .decodeImage(
            this.isFbUpdRect,
            this.rfbRenderer.getFramebufferImageMemory(),
            this.rfbRenderer.getFramebufferImageMemoryWidth(),
            this.framebufferWidth,
            this.framebufferHeight,
            this.getUpdateRectEncoding(),
            this.getUpdateRectSubencoding(),
            this.framebufferUpdateRectX,
            this.framebufferUpdateRectY,
            this.framebufferUpdateRectW,
            this.framebufferUpdateRectH,
            this.currentRfbPixelFormat
         );
   }

   private void processTightEncoding() throws IOException, RCException {
      this.logger.log(Level.FINE, T._("Decoding Tight encoded rect."));
      if (this.imageDecoderTight == null) {
         this.imageDecoderTight = new ImageDecoderTight(this.logger, this);
      }

      ReadWriteLock var1 = this.renderer.getLock();

      assert !(var1 instanceof ReentrantReadWriteLock) || ((ReentrantReadWriteLock)var1).isWriteLockedByCurrentThread();

      this.imageDecoderTight
         .decodeImage(
            this.isFbUpdRect,
            this.rfbRenderer.getFramebufferImageMemory(),
            this.rfbRenderer.getFramebufferImageMemoryWidth(),
            this.framebufferWidth,
            this.framebufferHeight,
            this.getUpdateRectEncoding(),
            this.getUpdateRectSubencoding(),
            this.framebufferUpdateRectX,
            this.framebufferUpdateRectY,
            this.framebufferUpdateRectW,
            this.framebufferUpdateRectH,
            this.currentRfbPixelFormat
         );
   }

   private void processUnknownEncoding() throws IOException, RCException {
      String var1 = MessageFormat.format(T._("Unknown rectangle encoding {0} found"), "0x" + Integer.toHexString(this.framebufferUpdateRectEncoding));
      if (this.framebufferUpdateRectSize >= 0) {
         this.logger.log(Level.WARNING, var1);
         this.ensureFramebufferUpdateRectBuffer(this.framebufferUpdateRectSize);
         this.isFbUpdRect.readFully(this.framebufferUpdateRectBuffer, 0, this.framebufferUpdateRectSize);
      } else {
         throw new RCException(var1);
      }
   }

   private Rectangle processFramebufferUpdateRect() throws IOException, RCException {
      this.isFbUpdRect = this.inflater
         .getUncompressedDataStream(
            this.isFbUpd,
            this,
            this.isFbUpd == this.is ? this.updateRectIsZlibStreamed() : false,
            this.isFbUpd == this.is ? this.updateRectIsZlibCompress() : false,
            this.framebufferUpdateRectSize
         );
      this.framebufferUpdateRectSize = this.inflater.getUncompressedSize();
      ReadWriteLock var1 = this.renderer.getLock();
      if (var1 != null) {
         var1.writeLock().lock();
      }

      Rectangle var3;
      try {
         switch (this.getUpdateRectEncoding()) {
            case 0:
               this.processRawEncoding();
               break;
            case 5:
               this.processHextileEncoding();
               break;
            case 7:
            case 9:
               this.processTightEncoding();
               break;
            case 10:
               this.processRawVscEncoding();
               break;
            case 11:
            case 128:
               this.processLrleEncoding();
               break;
            default:
               this.processUnknownEncoding();
         }

         Rectangle var2 = new Rectangle(this.framebufferUpdateRectX, this.framebufferUpdateRectY, this.framebufferUpdateRectW, this.framebufferUpdateRectH);
         var2 = this.rfbRenderer.updatePixel(var2);
         var3 = var2;
      } finally {
         if (var1 != null) {
            var1.writeLock().unlock();
         }
      }

      return var3;
   }

   public boolean isFPS() {
      return this.fpsEnabled;
   }

   public void setFPS(boolean var1) {
      this.fpsEnabled = var1;
   }

   public int getVideoUpdateDelay() {
      return this.videoUpdateDelay;
   }

   public void setVideoUpdateDelay(int var1) {
      this.videoUpdateDelay = var1;
   }
}
