package nn.pp.rccore.impl.rfb;

import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import java.awt.image.DataBufferInt;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.logging.Logger;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.impl.ImageProvider;
import nn.pp.rccore.impl.RemoteConsoleRenderer;

public class RfbRenderer implements ImageProvider {
   public static final RCCore.Smoothing defaultSmoothing = RCCore.Smoothing.LOW;
   private int framebufferImageWidth;
   private int framebufferImageHeight;
   private BufferedImage framebufferImage;
   private static BufferedImage initialImage = new BufferedImage(800, 600, 3);
   private RCCore.Smoothing smoothing = RCCore.Smoothing.LOW;
   private Logger logger;
   private RemoteConsoleRenderer renderer;
   private static final int BLKSIZE = 4;
   private static final int PIXPERBLK = 16;
   private int MAXBLKCOLS;
   private int MAXBLKROWS;
   private final int CENTER_WEIGHT = 2;
   private final int ADJACENT_WEIGHT = 1;
   private final int R_LUM_COEFF = 3;
   private final int G_LUM_COEFF = 6;
   private final int B_LUM_COEFF = 1;
   private int[] blk_ravg;
   private int[] blk_gavg;
   private int[] blk_bavg;
   private int[] blk_rnew;
   private int[] blk_gnew;
   private int[] blk_bnew;
   private boolean[][] blk_smoothFlag;

   public RfbRenderer(RemoteConsoleRenderer var1, Logger var2) {
      this.renderer = var1;
      this.logger = var2;
      ReadWriteLock var3 = var1.getLock();
      if (var3 != null) {
         var3.writeLock().lock();
      }

      try {
         this.framebufferImage = initialImage;
      } finally {
         if (var3 != null) {
            var3.writeLock().unlock();
         }
      }

      this.setSmoothing(defaultSmoothing);
   }

   public synchronized void setSmoothing(RCCore.Smoothing var1) {
      this.smoothing = var1;
   }

   public synchronized RCCore.Smoothing getSmoothing() {
      return this.smoothing;
   }

   public synchronized void setResolution(int var1, int var2) {
      this.framebufferImageWidth = var1;
      this.framebufferImageHeight = var2;
      if (this.framebufferImageWidth % 16 != 0) {
         this.framebufferImageWidth = (this.framebufferImageWidth / 16 + 1) * 16;
      }

      if (this.framebufferImageHeight % 16 != 0) {
         this.framebufferImageHeight = (this.framebufferImageHeight / 16 + 1) * 16;
      }

      ReadWriteLock var3 = this.renderer.getLock();
      if (var3 != null) {
         var3.writeLock().lock();
      }

      try {
         if (this.framebufferImage != null) {
            this.framebufferImage.flush();
         }

         this.framebufferImage = new BufferedImage(this.framebufferImageWidth, this.framebufferImageHeight, 3);
      } finally {
         if (var3 != null) {
            var3.writeLock().unlock();
         }
      }

      this.CreateSmoothBuffers(this.framebufferImageWidth, this.framebufferImageHeight);
   }

   public int[] getFramebufferImageMemory() {
      return ((DataBufferInt)this.framebufferImage.getRaster().getDataBuffer()).getData();
   }

   public int getFramebufferImageMemoryWidth() {
      return this.framebufferImageWidth;
   }

   public int getFramebufferImageMemoryHeight() {
      return this.framebufferImageHeight;
   }

   public synchronized void render(int var1, int var2, int var3, int var4) {
      this.renderer.drawRemoteConsoleData(this.framebufferImage, var1, var2, var3, var4);
   }

   public synchronized Rectangle updatePixel(Rectangle var1) {
      if (this.smoothing != RCCore.Smoothing.NONE) {
         this.smooth(var1.x, var1.y, var1.width, var1.height);
      }

      if (var1.x >= 4) {
         var1.x -= 4;
         var1.width += 4;
      }

      if (var1.x + var1.width < this.framebufferImageWidth - 4) {
         var1.width += 4;
      }

      if (var1.y >= 4) {
         var1.y -= 4;
         var1.height += 4;
      }

      if (var1.y + var1.height < this.framebufferImageHeight - 4) {
         var1.height += 4;
      }

      return var1;
   }

   private int getSmoothMargin() {
      if (this.smoothing == RCCore.Smoothing.LOW) {
         return 18;
      } else {
         return this.smoothing == RCCore.Smoothing.HIGH ? 27 : 0;
      }
   }

   private void CreateSmoothBuffers(int var1, int var2) {
      this.MAXBLKCOLS = var1 / 4;
      this.MAXBLKROWS = var2 / 4;
      this.blk_ravg = new int[this.MAXBLKCOLS * 3];
      this.blk_gavg = new int[this.MAXBLKCOLS * 3];
      this.blk_bavg = new int[this.MAXBLKCOLS * 3];
      this.blk_rnew = new int[this.MAXBLKCOLS * 3];
      this.blk_gnew = new int[this.MAXBLKCOLS * 3];
      this.blk_bnew = new int[this.MAXBLKCOLS * 3];
      this.blk_smoothFlag = new boolean[this.MAXBLKROWS][this.MAXBLKCOLS];
   }

   private int getMergeMargin() {
      if (this.smoothing == RCCore.Smoothing.LOW) {
         return 7;
      } else {
         return this.smoothing == RCCore.Smoothing.HIGH ? 9 : 0;
      }
   }

   private int getBlendMargin() {
      return this.getSmoothMargin();
   }

   private void smooth(int var1, int var2, int var3, int var4) {
      int var5 = this.getSmoothMargin();
      int var6 = this.getMergeMargin();
      int var7 = this.getBlendMargin();
      int var8 = var7 * 6;
      int var9;
      int var13 = var9 = var2 / 4;
      if (var9 > 0) {
         var9--;
      }

      int var10;
      int var14 = var10 = (var2 + var4 - 4) / 4;
      if (var10 < (this.framebufferImageHeight - 4) / 4) {
         var10++;
      }

      int var11;
      int var15 = var11 = var1 / 4;
      if (var11 > 0) {
         var11--;
      }

      int var12;
      int var16 = var12 = (var1 + var3 - 4) / 4;
      if (var12 < (this.framebufferImageWidth - 4) / 4) {
         var12++;
      }

      int var22 = -1;
      int var21 = -1;
      int var23 = 0;
      int var39 = 0;
      int var43 = 0;
      int var35 = 0;
      ReadWriteLock var48 = this.renderer.getLock();

      assert !(var48 instanceof ReentrantReadWriteLock) || ((ReentrantReadWriteLock)var48).isWriteLockedByCurrentThread();

      int[] var49 = this.getFramebufferImageMemory();

      for (int var28 = var9 - 1; var28 <= var10; var28++) {
         if (var28 + 1 <= var10) {
            boolean var17 = var28 + 1 < var13;
            boolean var19 = var28 + 1 > var14;

            for (int var29 = var11; var29 <= var12; var29++) {
               int var24 = var23 + var29;
               boolean var18 = var29 < var15;
               boolean var20 = var29 > var16;
               int var33 = (var28 + 1) * 4 * this.framebufferImageWidth + var29 * 4;
               if (!var17 && !var19 && !var18 && !var20) {
                  boolean var34 = true;
                  int var46 = 0;
                  int var42 = 0;
                  int var38 = 0;
                  int var44 = 255;
                  int var40 = 255;
                  int var36 = 255;
                  int var45 = 0;
                  int var41 = 0;
                  int var37 = 0;
                  int var27 = 0;

                  label281:
                  for (int var30 = 0; var34 && var30 < 4; var33 += this.framebufferImageWidth) {
                     int var67 = var33;
                     int var31 = 0;

                     while (var31 < 4) {
                        label276: {
                           int var56 = var49[var67];
                           if (var56 != var27) {
                              var27 = var56;
                              var39 = var56 >> 8 & 0xFF;
                              if (var39 < var40 || var39 > var41) {
                                 if (var39 < var40) {
                                    var40 = var39;
                                 }

                                 if (var39 > var41) {
                                    var41 = var39;
                                 }

                                 var34 = var41 - var40 <= var5;
                                 if (!var34) {
                                    break label276;
                                 }
                              }

                              var43 = var56 & 0xFF;
                              if (var43 < var44 || var43 > var45) {
                                 if (var43 < var44) {
                                    var44 = var43;
                                 }

                                 if (var43 > var45) {
                                    var45 = var43;
                                 }

                                 var34 = var45 - var44 <= var5;
                                 if (!var34) {
                                    break label276;
                                 }
                              }

                              var35 = var56 >> 16 & 0xFF;
                              if (var35 < var36 || var35 > var37) {
                                 if (var35 < var36) {
                                    var36 = var35;
                                 }

                                 if (var35 > var37) {
                                    var37 = var35;
                                 }

                                 var34 = var37 - var36 <= var5;
                                 if (!var34) {
                                    break label276;
                                 }
                              }
                           }

                           var38 += var35;
                           var42 += var39;
                           var46 += var43;
                           var31++;
                           var67++;
                           continue;
                        }

                        var30++;
                        continue label281;
                     }
                     break;
                  }

                  this.blk_smoothFlag[var28 + 1][var29] = var34;
                  if (var34) {
                     this.blk_ravg[var24] = (var38 + 8) / 16;
                     this.blk_gavg[var24] = (var42 + 8) / 16;
                     this.blk_bavg[var24] = (var46 + 8) / 16;
                  }
               } else if (this.blk_smoothFlag[var28 + 1][var29] && (!var17 && !var19 || !var18 && !var20)) {
                  int var26 = var49[var33 + 1 + this.framebufferImageWidth];
                  this.blk_rnew[var24] = this.blk_ravg[var24] = var26 >> 16 & 0xFF;
                  this.blk_gnew[var24] = this.blk_gavg[var24] = var26 >> 8 & 0xFF;
                  this.blk_bnew[var24] = this.blk_bavg[var24] = var26 & 0xFF;
                  if (var19) {
                     int var32 = var33 + (var28 + 1 & 1);
                     var49[var32] = var49[var32 + 2] = var26;
                  } else if (var20) {
                     int var64 = var33 + (var29 & 1) * this.framebufferImageWidth;
                     var49[var64] = var49[var64 + 2 * this.framebufferImageWidth] = var26;
                  } else if (var17) {
                     int var65 = var33 + 3 * this.framebufferImageWidth + (var28 & 1);
                     var49[var65] = var49[var65 + 2] = var26;
                  } else if (var18) {
                     int var66 = var33 + 3 + (var29 + 1 & 1) * this.framebufferImageWidth;
                     var49[var66] = var49[var66 + 2 * this.framebufferImageWidth] = var26;
                  }
               }
            }
         }

         if (var28 >= var13) {
            boolean var50 = var28 > var14;

            for (int var60 = var15; var60 <= var12; var60++) {
               int var52 = var22 + var60;
               if (this.blk_smoothFlag[var28][var60]) {
                  int var71 = var28 * 4 * this.framebufferImageWidth + var60 * 4;
                  boolean var51 = var60 > var16;
                  int var57;
                  if (!var50 && !var51) {
                     int var47 = 2;
                     int var72 = 2 * this.blk_ravg[var52];
                     int var75 = 2 * this.blk_gavg[var52];
                     int var78 = 2 * this.blk_bavg[var52];

                     for (int var61 = var28 - 1; var61 <= var28 + 1; var61 += 2) {
                        if (var61 >= var9 && var61 <= var10 && this.blk_smoothFlag[var61][var60]) {
                           int var25 = (var61 < var28 ? var21 : var23) + var60;
                           if (Math.abs(this.blk_ravg[var52] - this.blk_ravg[var25]) <= var6
                              && Math.abs(this.blk_gavg[var52] - this.blk_gavg[var25]) <= var6
                              && Math.abs(this.blk_bavg[var52] - this.blk_bavg[var25]) <= var6) {
                              var47++;
                              var72 += this.blk_ravg[var25] * 1;
                              var75 += this.blk_gavg[var25] * 1;
                              var78 += this.blk_bavg[var25] * 1;
                           }
                        }
                     }

                     for (int var63 = var60 - 1; var63 <= var60 + 1; var63 += 2) {
                        if (var63 >= var11 && var63 <= var12 && this.blk_smoothFlag[var28][var63]) {
                           int var53 = var22 + var63;
                           if (Math.abs(this.blk_ravg[var52] - this.blk_ravg[var53]) <= var6
                              && Math.abs(this.blk_gavg[var52] - this.blk_gavg[var53]) <= var6
                              && Math.abs(this.blk_bavg[var52] - this.blk_bavg[var53]) <= var6) {
                              var47++;
                              var72 += this.blk_ravg[var53] * 1;
                              var75 += this.blk_gavg[var53] * 1;
                              var78 += this.blk_bavg[var53] * 1;
                           }
                        }
                     }

                     var35 = this.blk_rnew[var52] = (var72 + var47 / 2) / var47;
                     var39 = this.blk_gnew[var52] = (var75 + var47 / 2) / var47;
                     var43 = this.blk_bnew[var52] = (var78 + var47 / 2) / var47;
                     var57 = 0xFF000000 | var35 << 16 | var39 << 8 | var43;
                     int var62 = 0;

                     for (int var68 = var71; var62 < 4; var68 += this.framebufferImageWidth) {
                        var49[var68] = var49[var68 + 1] = var49[var68 + 2] = var49[var68 + 3] = var57;
                        var62++;
                     }
                  } else {
                     var57 = var49[var71 + 1 + this.framebufferImageWidth];
                     var35 = this.blk_rnew[var52];
                     var39 = this.blk_gnew[var52];
                     var43 = this.blk_bnew[var52];
                  }

                  if (var7 > 0) {
                     if (var60 > var11 && !var50) {
                        int var54 = var52 - 1;
                        int var73 = this.blk_rnew[var54] - var35;
                        int var76 = this.blk_gnew[var54] - var39;
                        int var79 = this.blk_bnew[var54] - var43;
                        if (this.blk_smoothFlag[var28][var60 - 1]
                           && Math.abs(var73) <= var7
                           && Math.abs(var76) <= var7
                           && Math.abs(var79) <= var7
                           && Math.abs(var73 * 3 + var76 * 6 + var79 * 1) <= var8) {
                           int var58 = var49[var71 - 2 + this.framebufferImageWidth];
                           if (var58 != var57) {
                              int var69 = var71 + (var60 & 1) * this.framebufferImageWidth;
                              var49[var69 - 1] = var49[var69 - 1 + 2 * this.framebufferImageWidth] = var57;
                              var49[var69] = var49[var69 + 2 * this.framebufferImageWidth] = var58;
                           }
                        }
                     }

                     if (var28 > var9 && !var51) {
                        int var55 = var21 + var60;
                        int var74 = this.blk_rnew[var55] - var35;
                        int var77 = this.blk_gnew[var55] - var39;
                        int var80 = this.blk_bnew[var55] - var43;
                        if (this.blk_smoothFlag[var28 - 1][var60]
                           && Math.abs(var74) <= var7
                           && Math.abs(var77) <= var7
                           && Math.abs(var80) <= var7
                           && Math.abs(var74 * 3 + var77 * 6 + var80 * 1) <= var8) {
                           int var59 = var49[var71 + 1 - 2 * this.framebufferImageWidth];
                           if (var59 != var57) {
                              int var70 = var71 + (var28 & 1);
                              var49[var70 - this.framebufferImageWidth] = var49[var70 + 2 - this.framebufferImageWidth] = var57;
                              var49[var70] = var49[var70 + 2] = var59;
                           }
                        }
                     }
                  }
               }
            }
         }

         var21 = var22;
         var22 = var23;
         var23 += this.MAXBLKCOLS;
         if (var23 >= this.MAXBLKCOLS * 3) {
            var23 = 0;
         }
      }
   }

   public void dispose() {
      ReadWriteLock var1 = this.renderer.getLock();
      if (var1 != null) {
         var1.writeLock().lock();
      }

      try {
         if (this.framebufferImage != null) {
            this.framebufferImage.flush();
            this.framebufferImage = null;
            this.framebufferImage = initialImage;
         }
      } finally {
         if (var1 != null) {
            var1.writeLock().unlock();
         }
      }
   }

   @Override
   public BufferedImage getImage() {
      return this.framebufferImage;
   }

   public ReadWriteLock getLock() {
      return this.renderer.getLock();
   }
}
