package nn.pp.rccore.impl.rfb.V01_21;

import java.io.IOException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.rccore.RCException;
import nn.pp.rccore.impl.rfb.RfbHandler;

public class RfbAuthenticatorV01_21 {
   private RfbHandler rfbHandler;
   private Logger logger;
   protected String username;
   protected String password;
   protected String httpSessionID;
   protected String rdmSessionID;
   private MessageDigest digest;
   private static final int AUTH_TYPE_UNKNOWN = -1;
   private static final int AUTH_TYPE_PLAIN = 0;
   private static final int AUTH_TYPE_MD5 = 1;
   private static final int AUTH_TYPE_HTTP_SESSION_ID = 2;
   private static final int AUTH_TYPE_RDM_SESSION_ID = 3;
   private int authCaps = 0;
   private int authMethod = -1;

   public RfbAuthenticatorV01_21(RfbHandler var1, Logger var2) {
      this.rfbHandler = var1;
      this.logger = var2;
   }

   public void setAuthParameters(int var1, String var2, String var3, String var4, String var5) {
      this.authCaps = var1;
      this.username = var2;
      this.password = var3;
      this.httpSessionID = var4;
      this.rdmSessionID = var5;
   }

   public void negotiateAuthentication() throws IOException, RCException {
      if ((this.authCaps & 4) != 0 && this.username != null && this.password != null) {
         this.logger.log(Level.FINE, T._("Using MD5 authentication"));
         this.authMethod = 1;

         try {
            this.digest = MessageDigest.getInstance("MD5");
         } catch (NoSuchAlgorithmException var2) {
            this.logger.log(Level.WARNING, T._("MD5 not available, using plain authentication."));
            this.authMethod = 0;
         }
      } else if ((this.authCaps & 2) != 0 && this.username != null && this.password != null) {
         this.logger.log(Level.FINE, T._("Using Plain authentication"));
         this.authMethod = 0;
      } else if ((this.authCaps & 16) != 0 && this.rdmSessionID != null) {
         this.logger.log(Level.FINE, T._("Using RDM Session ID authentication"));
         this.authMethod = 3;
      } else if ((this.authCaps & 1) != 0 && this.httpSessionID != null) {
         this.logger.log(Level.FINE, T._("Using HTTP Session ID authentication"));
         this.authMethod = 2;
      }

      switch (this.authMethod) {
         case 0:
            this.rfbHandler.writeLogin(this.username, 2, 0);
            break;
         case 1:
            this.rfbHandler.writeLogin(this.username, 4, 0);
            break;
         case 2:
            this.rfbHandler.writeLogin("", 1, 0);
            break;
         case 3:
            this.rfbHandler.writeLogin("super", 16, 0);
            break;
         default:
            throw new RCException(T._("No proper authentication scheme found"));
      }
   }

   public void processChallenge(byte[] var1) throws IOException, RCException {
      switch (this.authMethod) {
         case 0:
            if (var1 != null) {
               throw new RCException(T._("Protocol error: bad challenge size"));
            }

            this.rfbHandler.writeChallengeResponse(this.password);
            break;
         case 1:
            if (var1 != null) {
               this.digest.update(var1);
            }

            this.digest.update(this.password.getBytes("ISO-8859-1"));
            byte[] var2 = this.digest.digest();
            String var3 = this.rfbHandler.binToHex(var2);
            this.rfbHandler.writeChallengeResponse(var3);
            break;
         case 2:
            if (var1 == null || var1.length != 65) {
               throw new RCException(T._("Protocol error: bad challenge size"));
            }

            byte[] var4 = new byte[64];
            System.arraycopy(var1, 0, var4, 0, 64);
            String var5 = this.rfbHandler.getChallengeResponse(var4, "MD5");
            this.rfbHandler.writeChallengeResponse(var5 + '\u0000');
            break;
         case 3:
            if (var1 != null) {
               throw new RCException(T._("Protocol error: bad challenge size"));
            }

            this.rfbHandler.writeChallengeResponse(this.rdmSessionID + '\u0000');
            break;
         default:
            throw new RCException(T._("No proper authentication scheme found"));
      }
   }
}
