package nn.pp.rccore.impl.rfb.V01_21;

import java.text.MessageFormat;
import java.util.List;
import java.util.Vector;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.rccore.RCCore;
import nn.pp.rccore.impl.VideoEventListenerList;
import nn.pp.rccore.impl.rfb.RfbEncoding;
import nn.pp.rccore.impl.rfb.RfbPixelFormat;

public class RfbEncodingV01_21 extends RfbEncoding {
   private static Object converterLock = new Object();
   private static Converter converter = null;
   private static final int ENCODING_TYPE_NOT_SET = 0;
   private static final int ENCODING_TYPE_AUTO = 1;
   private static final int ENCODING_TYPE_PREDEFINED = 2;
   private static final int ENCODING_TYPE_ADVANCED = 3;
   private int encodingType = 0;
   private RCCore.ColorDepth colorDepth = RCCore.ColorDepth.COLOR_16_BIT;
   private RCCore.Compression compression = RCCore.Compression.UNCOMPRESSED;
   private boolean lossy = false;
   private List<RfbEncodingV01_21.Predefine> predefinesHw;
   private List<RfbEncodingV01_21.Predefine> predefinesSw;
   private List<RfbEncodingV01_21.Compression> compressionsHw;
   private List<RfbEncodingV01_21.Compression> compressionsSw;
   private List<RfbEncodingV01_21.ColorDepth> colorDepthsHw;
   private List<RfbEncodingV01_21.ColorDepth> colorDepthsSw;
   private List<RCCore.Smoothing> smoothingValues;

   private static void loadConverter() {
      synchronized (converterLock) {
         if (converter == null) {
            converter = new Converter();
         }
      }
   }

   private static RCCore.ColorDepth getColorDepthFromString(String var0) {
      loadConverter();
      return converter.getColorDepthFromString(var0);
   }

   private static RCCore.Compression getCompressionFromString(String var0) {
      loadConverter();
      return converter.getCompressionFromString(var0);
   }

   private static RCCore.Predefine getPredefineFromString(String var0) {
      loadConverter();
      return converter.getPredefineFromString(var0);
   }

   public RfbEncodingV01_21(Logger var1, VideoEventListenerList var2) {
      super(var1, var2);
      this.addHardwareEncodings();
      this.addSoftwareEncodings();
      this.smoothingValues = new Vector<>();

      for (RCCore.Smoothing var6 : RCCore.Smoothing.values()) {
         this.smoothingValues.add(var6);
      }
   }

   private void addHardwareEncodings() {
      this.predefinesHw = new Vector<>();
      this.predefinesHw
         .add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.LAN_HICOLOR, RCCore.Compression.UNCOMPRESSED, RCCore.ColorDepth.COLOR_16_BIT, false));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.LAN, RCCore.Compression.UNCOMPRESSED, RCCore.ColorDepth.COLOR_8_BIT, false));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.DSL, RCCore.Compression.LEVEL_2, RCCore.ColorDepth.COLOR_8_BIT, false));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.UMTS, RCCore.Compression.LEVEL_4, RCCore.ColorDepth.COLOR_8_BIT, true));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.ISDN, RCCore.Compression.LEVEL_6, RCCore.ColorDepth.COLOR_4_BIT, true));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.MODEM, RCCore.Compression.LEVEL_7, RCCore.ColorDepth.GREY_2_BIT, true));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.MODEM_4BIT, RCCore.Compression.LEVEL_8, RCCore.ColorDepth.GREY_4_BIT, true));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.GPRS, RCCore.Compression.LEVEL_8, RCCore.ColorDepth.GREY_2_BIT, true));
      this.predefinesHw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.GSM, RCCore.Compression.LEVEL_9, RCCore.ColorDepth.BW_1_BIT, true));
      Vector var1 = new Vector();
      var1.add(RCCore.ColorDepth.COLOR_16_BIT);
      var1.add(RCCore.ColorDepth.COLOR_8_BIT);
      var1.add(RCCore.ColorDepth.COLOR_4_BIT);
      var1.add(RCCore.ColorDepth.GREY_4_BIT);
      var1.add(RCCore.ColorDepth.GREY_2_BIT);
      var1.add(RCCore.ColorDepth.BW_1_BIT);
      this.compressionsHw = new Vector<>();
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.UNCOMPRESSED, var1, 128, 0));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_1, var1, 128, 1));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_2, var1, 128, 2));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_3, var1, 128, 3));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_4, var1, 128, 4));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_5, var1, 128, 5));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_6, var1, 128, 6));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_7, var1, 128, 7));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_8, var1, 128, 8));
      this.compressionsHw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_9, var1, 128, 9));
      Vector var2 = new Vector();
      var2.add(RCCore.Compression.UNCOMPRESSED);
      var2.add(RCCore.Compression.LEVEL_1);
      var2.add(RCCore.Compression.LEVEL_2);
      var2.add(RCCore.Compression.LEVEL_3);
      var2.add(RCCore.Compression.LEVEL_4);
      var2.add(RCCore.Compression.LEVEL_5);
      var2.add(RCCore.Compression.LEVEL_6);
      var2.add(RCCore.Compression.LEVEL_7);
      var2.add(RCCore.Compression.LEVEL_8);
      var2.add(RCCore.Compression.LEVEL_9);
      this.colorDepthsHw = new Vector<>();
      this.colorDepthsHw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.COLOR_16_BIT, var2, 0, 0, 1, RfbPixelFormat.rfbPixelFormat16Bit));
      this.colorDepthsHw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.COLOR_8_BIT, var2, 8, 2, 3, RfbPixelFormat.rfbPixelFormat16Bit));
      this.colorDepthsHw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.COLOR_4_BIT, var2, 4, 5, 5, RfbPixelFormat.rfbPixelFormat16Bit));
      this.colorDepthsHw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.GREY_4_BIT, var2, 3, 6, 7, RfbPixelFormat.rfbPixelFormat16Bit));
      this.colorDepthsHw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.GREY_2_BIT, var2, 2, 10, 11, RfbPixelFormat.rfbPixelFormat16Bit));
      this.colorDepthsHw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.BW_1_BIT, var2, 1, 12, 13, RfbPixelFormat.rfbPixelFormat16Bit));
   }

   private void addSoftwareEncodings() {
      this.predefinesSw = new Vector<>();
      this.predefinesSw
         .add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.VIDEO_HICOLOR, RCCore.Compression.VIDEO_OPTIMIZED, RCCore.ColorDepth.COLOR_16_BIT, false));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.VIDEO, RCCore.Compression.VIDEO_OPTIMIZED, RCCore.ColorDepth.COLOR_8_BIT, false));
      this.predefinesSw
         .add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.LAN_HICOLOR, RCCore.Compression.UNCOMPRESSED, RCCore.ColorDepth.COLOR_16_BIT, false));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.LAN, RCCore.Compression.UNCOMPRESSED, RCCore.ColorDepth.COLOR_8_BIT, false));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.DSL, RCCore.Compression.LEVEL_2, RCCore.ColorDepth.COLOR_8_BIT, false));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.UMTS, RCCore.Compression.LEVEL_4, RCCore.ColorDepth.COLOR_8_BIT, true));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.ISDN, RCCore.Compression.LEVEL_6, RCCore.ColorDepth.COLOR_4_BIT, true));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.MODEM, RCCore.Compression.LEVEL_7, RCCore.ColorDepth.GREY_2_BIT, true));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.GPRS, RCCore.Compression.LEVEL_8, RCCore.ColorDepth.GREY_2_BIT, true));
      this.predefinesSw.add(new RfbEncodingV01_21.Predefine(RCCore.Predefine.GSM, RCCore.Compression.LEVEL_9, RCCore.ColorDepth.BW_1_BIT, true));
      Vector var1 = new Vector();
      var1.add(RCCore.ColorDepth.COLOR_8_BIT);
      var1.add(RCCore.ColorDepth.COLOR_4_BIT);
      var1.add(RCCore.ColorDepth.GREY_4_BIT);
      var1.add(RCCore.ColorDepth.GREY_2_BIT);
      var1.add(RCCore.ColorDepth.BW_1_BIT);
      Vector var2 = new Vector();
      var2.add(RCCore.ColorDepth.COLOR_16_BIT);
      var2.add(RCCore.ColorDepth.COLOR_8_BIT);
      this.compressionsSw = new Vector<>();
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.VIDEO_OPTIMIZED, var2, 10, 0, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.UNCOMPRESSED, var2, 5, 0, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_1, var1, 7, 1, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_2, var1, 7, 2, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_3, var1, 7, 3, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_4, var1, 7, 4, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_5, var1, 7, 5, false));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_6, var1, 7, 6, true));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_7, var1, 7, 7, true));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_8, var1, 7, 8, true));
      this.compressionsSw.add(new RfbEncodingV01_21.Compression(RCCore.Compression.LEVEL_9, var1, 7, 9, true));
      Vector var3 = new Vector();
      var3.add(RCCore.Compression.VIDEO_OPTIMIZED);
      var3.add(RCCore.Compression.UNCOMPRESSED);
      var3.add(RCCore.Compression.LEVEL_1);
      var3.add(RCCore.Compression.LEVEL_2);
      var3.add(RCCore.Compression.LEVEL_3);
      var3.add(RCCore.Compression.LEVEL_4);
      var3.add(RCCore.Compression.LEVEL_5);
      var3.add(RCCore.Compression.LEVEL_6);
      var3.add(RCCore.Compression.LEVEL_7);
      var3.add(RCCore.Compression.LEVEL_8);
      var3.add(RCCore.Compression.LEVEL_9);
      Vector var4 = new Vector();
      var4.add(RCCore.Compression.VIDEO_OPTIMIZED);
      var4.add(RCCore.Compression.UNCOMPRESSED);
      Vector var5 = new Vector();
      var5.add(RCCore.Compression.LEVEL_1);
      var5.add(RCCore.Compression.LEVEL_2);
      var5.add(RCCore.Compression.LEVEL_3);
      var5.add(RCCore.Compression.LEVEL_4);
      var5.add(RCCore.Compression.LEVEL_5);
      var5.add(RCCore.Compression.LEVEL_6);
      var5.add(RCCore.Compression.LEVEL_7);
      var5.add(RCCore.Compression.LEVEL_8);
      var5.add(RCCore.Compression.LEVEL_9);
      this.colorDepthsSw = new Vector<>();
      this.colorDepthsSw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.COLOR_16_BIT, var4, 0, 0, 0, RfbPixelFormat.rfbPixelFormat16Bit));
      this.colorDepthsSw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.COLOR_8_BIT, var3, 8, 0, 0, RfbPixelFormat.rfbPixelFormat8Bit));
      this.colorDepthsSw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.COLOR_4_BIT, var5, 4, 0, 0, RfbPixelFormat.rfbPixelFormat8Bit));
      this.colorDepthsSw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.GREY_4_BIT, var5, 3, 0, 0, RfbPixelFormat.rfbPixelFormat8Bit));
      this.colorDepthsSw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.GREY_2_BIT, var5, 2, 0, 0, RfbPixelFormat.rfbPixelFormat8Bit));
      this.colorDepthsSw.add(new RfbEncodingV01_21.ColorDepth(RCCore.ColorDepth.BW_1_BIT, var5, 1, 0, 0, RfbPixelFormat.rfbPixelFormat8Bit));
   }

   @Override
   public List<RCCore.Predefine> getSupportedPredefines() {
      Vector var1 = new Vector();

      for (RfbEncodingV01_21.Predefine var4 : this.supportHwEnc ? this.predefinesHw : this.predefinesSw) {
         var1.add(var4.predefine);
      }

      return var1;
   }

   @Override
   public List<RCCore.ColorDepth> getSupportedColorDepths() {
      Vector var1 = new Vector();

      for (RfbEncodingV01_21.ColorDepth var4 : this.supportHwEnc ? this.colorDepthsHw : this.colorDepthsSw) {
         var1.add(var4.depth);
      }

      return var1;
   }

   @Override
   public List<RCCore.Compression> getSupportedCompressions() {
      Vector var1 = new Vector();

      for (RfbEncodingV01_21.Compression var4 : this.supportHwEnc ? this.compressionsHw : this.compressionsSw) {
         var1.add(var4.comp);
      }

      return var1;
   }

   @Override
   public List<RCCore.Smoothing> getSupportedSmoothingValues() {
      Vector var1 = new Vector();

      for (RCCore.Smoothing var3 : this.smoothingValues) {
         var1.add(var3);
      }

      return var1;
   }

   @Override
   public List<RCCore.ColorDepth> getSupportedColorDepthsForCompression(RCCore.Compression var1) {
      RfbEncodingV01_21.Compression var2 = this.lookupCompression(var1);
      return var2.possibleColorDepths;
   }

   @Override
   public List<RCCore.Compression> getSupportedCompressionsForColorDepth(RCCore.ColorDepth var1) {
      RfbEncodingV01_21.ColorDepth var2 = this.lookupColorDepth(var1);
      return var2.possibleCompressions;
   }

   @Override
   public RCCore.ColorDepth getColorDepthForPredefine(RCCore.Predefine var1) {
      RfbEncodingV01_21.Predefine var2 = this.lookupPredefine(var1);
      return var2.colorDepth;
   }

   @Override
   public RCCore.Compression getCompressionForPredefine(RCCore.Predefine var1) {
      RfbEncodingV01_21.Predefine var2 = this.lookupPredefine(var1);
      return var2.compression;
   }

   @Override
   public boolean getLossyForPredefine(RCCore.Predefine var1) {
      RfbEncodingV01_21.Predefine var2 = this.lookupPredefine(var1);
      return var2.lossy;
   }

   @Override
   public void setPredefine(RCCore.Predefine var1) throws IllegalArgumentException {
      RfbEncodingV01_21.Predefine var2 = this.lookupPredefine(var1);
      this.encodingType = 2;
      this.colorDepth = var2.colorDepth;
      this.compression = var2.compression;
      this.lossy = var2.lossy;
   }

   @Override
   public void setEncodingToAuto() {
      this.encodingType = 1;
   }

   @Override
   public void setColorDepth(RCCore.ColorDepth var1) {
      this.encodingType = 3;
      this.colorDepth = var1;
   }

   @Override
   public void setLossy(boolean var1) {
      this.lossy = var1;
   }

   @Override
   public void setCompression(RCCore.Compression var1) {
      this.encodingType = 3;
      this.compression = var1;
   }

   private RfbEncodingV01_21.Predefine lookupPredefine(RCCore.Predefine var1) {
      for (RfbEncodingV01_21.Predefine var4 : this.supportHwEnc ? this.predefinesHw : this.predefinesSw) {
         if (var4.predefine == var1) {
            return var4;
         }
      }

      throw new IllegalArgumentException(T._("Predefined encoding not found"));
   }

   private RfbEncodingV01_21.Compression lookupCompression(RCCore.Compression var1) {
      for (RfbEncodingV01_21.Compression var4 : this.supportHwEnc ? this.compressionsHw : this.compressionsSw) {
         if (var4.comp == var1) {
            return var4;
         }
      }

      throw new IllegalArgumentException();
   }

   private RfbEncodingV01_21.ColorDepth lookupColorDepth(RCCore.ColorDepth var1) {
      for (RfbEncodingV01_21.ColorDepth var4 : this.supportHwEnc ? this.colorDepthsHw : this.colorDepthsSw) {
         if (var4.depth == var1) {
            return var4;
         }
      }

      throw new IllegalArgumentException();
   }

   @Override
   public void setEncodingTypeFromRfb(String var1) {
      this.logger.log(Level.FINE, "Using encoding type " + var1);
      if (var1.equalsIgnoreCase("auto")) {
         this.encodingType = 1;
      } else if (var1.equalsIgnoreCase("preconf")) {
         this.encodingType = 2;
      } else if (var1.equalsIgnoreCase("manual")) {
         this.encodingType = 3;
      } else {
         this.logger.log(Level.WARNING, MessageFormat.format(T._("Unknown RFB encoding type received: {0}, using Auto"), var1));
         this.encodingType = 1;
      }

      this.listeners.fireEncodingAutoChanged(this.encodingType == 1);
   }

   @Override
   public void setEncodingPredefineFromRfb(String var1) {
      if (this.encodingType == 2) {
         this.logger.log(Level.FINE, "Using predefined encoding " + var1);
         this.setPredefine(getPredefineFromString(var1));
         this.listeners.fireEncodingColorDepthChanged(this.colorDepth);
         this.listeners.fireEncodingCompressionChanged(this.compression);
         this.listeners.fireEncodingLossyChanged(this.lossy);
      }
   }

   @Override
   public void setEncodingCompressionFromRfb(String var1) {
      this.setEncodingCompression(getCompressionFromString(var1));
   }

   @Override
   public void setEncodingCompression(RCCore.Compression var1) {
      if (this.encodingType == 3) {
         this.logger.log(Level.FINE, "Using compression " + var1);
         this.setCompression(var1);
         this.listeners.fireEncodingCompressionChanged(this.compression);
      }
   }

   @Override
   public void setEncodingColorDepthFromRfb(String var1) {
      this.setEncodingColorDepth(getColorDepthFromString(var1));
   }

   @Override
   public void setEncodingColorDepth(RCCore.ColorDepth var1) {
      if (this.encodingType == 3) {
         this.logger.log(Level.FINE, "Using color depth " + var1);
         this.setColorDepth(var1);
         this.listeners.fireEncodingColorDepthChanged(this.colorDepth);
      }
   }

   @Override
   public int[] getRfbEncodings() {
      int[] var1 = new int[4];
      int var2 = 0;
      RfbEncodingV01_21.Compression var3 = this.lookupCompression(this.compression);
      RfbEncodingV01_21.ColorDepth var4 = this.lookupColorDepth(this.colorDepth);
      if (this.encodingType == 1) {
         RfbEncodingV01_21.Compression var5 = this.lookupCompression(RCCore.Compression.LEVEL_5);
         int var19;
         if (this.supportHwEnc) {
            int var6 = 128;
            var6 |= var4.getRfbLrleSubencLossless() << 12;
            var19 = var6 | var5.rfbCompressionLevel << 8;
            var1[var2++] = 255;
         } else {
            var19 = var5.rfbEncoding;
            var19 |= var4.getSubformat() << 12;
            var19 |= var5.rfbCompressionLevel << 8;
            var1[var2++] = 127;
         }

         var1[var2++] = var19;
      } else if (this.supportHwEnc) {
         int var12 = 128;
         if (this.lossy) {
            var12 |= var4.getRfbLrleSubencLossy() << 12;
         } else {
            var12 |= var4.getRfbLrleSubencLossless() << 12;
         }

         var12 |= var3.rfbCompressionLevel << 8;
         var1[var2++] = var12;
      } else {
         int var15 = var3.rfbEncoding;
         var15 |= var4.getSubformat() << 12;
         var15 |= var3.rfbCompressionLevel << 8;
         if (var3.getComp() == RCCore.Compression.VIDEO_OPTIMIZED) {
            var15 |= 131072;
         }

         var1[var2++] = var15;
         if (var3.isCacheUsed()) {
            var1[var2++] = 9;
         }
      }

      return var1;
   }

   @Override
   public RfbPixelFormat getRfbPixelFormat() {
      if (this.encodingType == 1) {
         RfbEncodingV01_21.ColorDepth var2 = this.lookupColorDepth(RCCore.ColorDepth.COLOR_8_BIT);
         return var2.rfbPixelFormat;
      } else {
         RfbEncodingV01_21.ColorDepth var1 = this.lookupColorDepth(this.colorDepth);
         return var1.rfbPixelFormat;
      }
   }

   class ColorDepth {
      RCCore.ColorDepth depth;
      int rfbSubencSw;
      int rfbLrleSubencLossy;
      int rfbLrleSubencLossless;
      RfbPixelFormat rfbPixelFormat;
      List<RCCore.Compression> possibleCompressions;

      ColorDepth(RCCore.ColorDepth var2, List<RCCore.Compression> var3, int var4, int var5, int var6, RfbPixelFormat var7) {
         this.depth = var2;
         this.possibleCompressions = var3;
         this.rfbSubencSw = var4;
         this.rfbLrleSubencLossy = var5;
         this.rfbLrleSubencLossless = var6;
         this.rfbPixelFormat = var7;
      }

      public int getRfbLrleSubencLossless() {
         return this.rfbLrleSubencLossless;
      }

      public int getRfbLrleSubencLossy() {
         return this.rfbLrleSubencLossy;
      }

      public int getSubformat() {
         return this.rfbSubencSw;
      }
   }

   class Compression {
      RCCore.Compression comp;
      int rfbEncoding;
      int rfbCompressionLevel;
      boolean useCache = false;
      List<RCCore.ColorDepth> possibleColorDepths;

      Compression(RCCore.Compression var2, List<RCCore.ColorDepth> var3, int var4, int var5) {
         this.comp = var2;
         this.possibleColorDepths = var3;
         this.rfbEncoding = var4;
         this.rfbCompressionLevel = var5;
      }

      Compression(RCCore.Compression var2, List<RCCore.ColorDepth> var3, int var4, int var5, boolean var6) {
         this(var2, var3, var4, var5);
         this.useCache = var6;
      }

      public RCCore.Compression getComp() {
         return this.comp;
      }

      public boolean isCacheUsed() {
         return this.useCache;
      }
   }

   class Predefine {
      RCCore.Predefine predefine;
      RCCore.Compression compression;
      RCCore.ColorDepth colorDepth;
      boolean lossy;

      Predefine(RCCore.Predefine var2, RCCore.Compression var3, RCCore.ColorDepth var4, boolean var5) {
         this.predefine = var2;
         this.compression = var3;
         this.colorDepth = var4;
         this.lossy = var5;
      }
   }
}
