package nn.pp.rccore.scan.impl;

import java.io.IOException;
import java.util.concurrent.atomic.AtomicReference;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.INotificationEvent;
import nn.pp.core.NotificationListener;
import nn.pp.core.impl.DeviceConnector;
import nn.pp.core.impl.NotificationListenerList;
import nn.pp.rccore.scan.ScanCoreException;
import nn.pp.rccore.scan.ScanSession;
import nn.pp.rccore.scan.ScanSessionEventsListener;
import nn.pp.rccore.scan.impl.commands.QuitMessageFromClient;
import nn.pp.rccore.scan.impl.commands.ScanSessionRequest;
import nn.pp.rccore.scan.impl.rsp.RSPHandler;

public class ScanSessionImpl implements ScanSession {
   private final String host;
   private final int port;
   private final boolean sslMode;
   private final String rdmSessionID;
   private final String ericKey;
   private final String userName;
   private final String password;
   private final String proxyConnectionId;
   private final String proxyUseSSL;
   private final AtomicReference<Object> handleRef = new AtomicReference<>();
   private final AtomicReference<Enum<ScanSessionImpl.State>> state = new AtomicReference<>(ScanSessionImpl.State.NOT_STARTED);
   private static final Logger LOGGER = Logger.getLogger(ScanSessionImpl.class.getName());
   private volatile DeviceConnector deviceConnector;
   private final RSPHandler protoHandler = new RSPHandler();
   private final NotificationListenerList notificationListenerList = new NotificationListenerList();
   private final ScanSessionEventsListenerList scanSessionEventsListenerList = new ScanSessionEventsListenerList();

   public ScanSessionImpl(String var1, int var2, boolean var3, String var4, String var5, String var6, String var7, String var8, String var9) {
      this.host = var1;
      this.port = var2;
      this.sslMode = var3;
      this.rdmSessionID = var4;
      this.ericKey = var5;
      this.userName = var6;
      this.password = var7;
      this.proxyConnectionId = var8;
      this.proxyUseSSL = var9;
   }

   @Override
   public void removeNotificationListener(NotificationListener var1) {
      this.notificationListenerList.removeListener(var1);
   }

   @Override
   public void start(String[] var1, ScanSessionEventsListener var2, NotificationListener var3) throws ScanCoreException, IOException {
      if (this.state.compareAndSet(ScanSessionImpl.State.NOT_STARTED, ScanSessionImpl.State.START_CALLED)) {
         DeviceConnector var4 = new DeviceConnector(Logger.getLogger("nn.pp.rccore.scan"), null);

         try {
            var4.connect(this.host, this.port, this.sslMode);
            if (this.proxyConnectionId != null) {
               var4.writeCCSGproxyModePrefix(this.proxyConnectionId);
               if ("yes".equalsIgnoreCase(this.proxyUseSSL)) {
                  var4.connectSSLWithSocket(this.host, this.port);
               }
            }
         } catch (IOException var9) {
            throw var9;
         }

         this.deviceConnector = var4;

         try {
            this.protoHandler.init(var4, Logger.getLogger("nn.pp.rccore.scan"));
         } catch (IOException var8) {
            var4.disconnect();
            throw var8;
         }

         this.protoHandler.addListener(ScanSessionEventsListener.class, new ScanSessionImpl.Ssel());
         this.protoHandler.addListener(NotificationListener.class, new ScanSessionImpl.Nl());
         if (var3 != null) {
            this.notificationListenerList.addListener(var3);
         }

         if (var2 != null) {
            this.scanSessionEventsListenerList.addListener(var2);
         }

         try {
            this.protoHandler.connect(null, this.userName, this.password, this.ericKey, this.rdmSessionID);
         } catch (IOException var6) {
            var4.disconnect();
            throw var6;
         } catch (ScanCoreException var7) {
            var4.disconnect();
            throw var7;
         }

         this.protoHandler.executeClientCommands(new ScanSessionRequest(var1));
         if (!this.handleRef.compareAndSet(null, new Object())) {
            LOGGER.log(Level.INFO, "Cleaning up");
            this.protoHandler.executeClientCommands(new QuitMessageFromClient());
         }
      }
   }

   @Override
   public void removeScanSessionEventsListener(ScanSessionEventsListener var1) {
      this.scanSessionEventsListenerList.removeListener(var1);
   }

   @Override
   public void close() {
      Enum var1 = this.state.getAndSet(ScanSessionImpl.State.CLOSE_CALLED);
      if (var1 == ScanSessionImpl.State.START_CALLED) {
         Object var2 = this.handleRef.get();
         if (var2 != null || !this.handleRef.compareAndSet(null, Boolean.TRUE)) {
            this.protoHandler.executeClientCommands(new QuitMessageFromClient());
         }
      }
   }

   private class Nl implements NotificationListener {
      private Nl() {
      }

      @Override
      public void receivedNotification(INotificationEvent var1) {
         if (var1.isQuit() || var1.isError()) {
            ScanSessionImpl.LOGGER.log(Level.INFO, "Trace of Quit", (Throwable)(new Exception("TRACE FOR DEBUG")));
            ScanSessionImpl.LOGGER.log(Level.INFO, "Reason for Quit - " + var1.getMessage());
            ScanSessionImpl.this.protoHandler.close();
            ScanSessionImpl.this.deviceConnector.disconnect();
         }

         ScanSessionImpl.this.notificationListenerList.fireNotification(var1);
      }

      @Override
      public void textNotification(String var1) {
      }
   }

   private class Ssel implements ScanSessionEventsListener {
      private Ssel() {
      }

      @Override
      public void scanSessionCreated(int var1) {
         ScanSessionImpl.this.scanSessionEventsListenerList.firescanSessionCreated(var1);
      }

      @Override
      public void disconnected(Exception var1) {
         ScanSessionImpl.LOGGER.log(Level.INFO, "disconnect received", (Throwable)var1);
         ScanSessionImpl.this.protoHandler.close();
         ScanSessionImpl.this.deviceConnector.disconnect();
         ScanSessionImpl.this.scanSessionEventsListenerList.fireDisconnected(var1);
      }
   }

   private static enum State {
      NOT_STARTED,
      START_CALLED,
      CLOSE_CALLED;
   }
}
