package nn.pp.rccore.scan.impl.rsp.V01_00;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.NoSuchAlgorithmException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.Util;
import nn.pp.core.impl.MonitoringDataOutputStream;
import nn.pp.rccore.scan.ScanCoreException;
import nn.pp.rccore.scan.impl.commands.AuthHttpIDChallResponse;
import nn.pp.rccore.scan.impl.commands.AuthHttpIDGetChallenge;
import nn.pp.rccore.scan.impl.commands.AuthNamePassRequest;
import nn.pp.rccore.scan.impl.commands.AuthRDMRequest;
import nn.pp.rccore.scan.impl.commands.CommandVisitorV01_00;
import nn.pp.rccore.scan.impl.commands.PongResponse;
import nn.pp.rccore.scan.impl.commands.QuitMessageFromClient;
import nn.pp.rccore.scan.impl.commands.ScanSessionRequest;

public class CommandToMessageWriterVisitor implements CommandVisitorV01_00 {
   private MonitoringDataOutputStream mos;
   private static final Logger LOGGER = Logger.getLogger(CommandToMessageWriterVisitor.class.getName());

   @Override
   public void handleAuthNamePassRequest(AuthNamePassRequest var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(0);
      var2.write(0);

      byte[] var3;
      byte[] var4;
      try {
         var3 = var1.getUserName().getBytes("ISO-8859-1");
         var4 = var1.getPassword().getBytes("ISO-8859-1");
      } catch (UnsupportedEncodingException var6) {
         throw new ScanCoreException(var6);
      }

      var2.writeShort(var3.length);
      var2.writeShort(var4.length);
      var2.write(var3);
      var2.write(var4);
      var2.flush();
      Object var7 = null;
   }

   @Override
   public void handleAuthRDMRequest(AuthRDMRequest var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(7);
      String var3 = var1.getRdmID() + '\u0000';

      byte[] var4;
      try {
         var4 = var3.getBytes("ISO-8859-1");
      } catch (UnsupportedEncodingException var6) {
         throw new ScanCoreException(var6);
      }

      var2.write((byte)var4.length);
      var2.write(var4);
      var2.flush();
      Object var7 = null;
   }

   @Override
   public void handleHttpIDChallengeResponse(AuthHttpIDChallResponse var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();

      byte[] var3;
      try {
         var3 = Util.getHash(var1.getChallenge(), var1.getHttpSessionID().getBytes("ISO-8859-1"));
      } catch (NoSuchAlgorithmException var6) {
         throw new ScanCoreException(var6);
      }

      byte[] var4 = Util.binToHex(var3).getBytes("ISO-8859-1");
      if (var4.length != 64 && var4.length != 32) {
         throw new ScanCoreException("Response has invalid length");
      } else {
         byte[] var5 = new byte[var4.length + 9];
         System.arraycopy("RSP RESP=".getBytes("ISO-8859-1"), 0, var5, 0, 9);
         System.arraycopy(var4, 0, var5, 9, var4.length);
         var2.write(var5);
         var2.flush();
         Object var7 = null;
      }
   }

   @Override
   public void handleHttpIDGetChallenge(AuthHttpIDGetChallenge var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(6);
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handleScanSessionRequest(ScanSessionRequest var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(1);
      String[] var3 = var1.getPortIds();
      var2.write((byte)var3.length);
      byte[][] var4 = new byte[var3.length][];

      for (int var5 = 0; var5 < var3.length; var5++) {
         String var6 = var3[var5];

         try {
            var4[var5] = var6.getBytes("ISO-8859-1");
         } catch (UnsupportedEncodingException var9) {
            throw new ScanCoreException(var9);
         }

         var2.write((byte)var4[var5].length);
      }

      for (byte[] var8 : var4) {
         var2.write(var8);
      }

      var2.flush();
      Object var10 = null;
   }

   @Override
   public void handlePongResponse(PongResponse var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(5);
      var2.flush();
      Object var3 = null;
   }

   @Override
   public void handleQuitMessageFromClient(QuitMessageFromClient var1) throws IOException, ScanCoreException {
      LOGGER.log(Level.INFO, "Writing command on Socket " + var1);
      MonitoringDataOutputStream var2 = this.getMos();
      var2.write(3);
      var2.write(0);
      var2.writeShort(0);
      var2.writeInt(var1.getReason());
      var2.flush();
      Object var3 = null;
   }

   synchronized void setOs(MonitoringDataOutputStream var1) {
      this.mos = var1;
   }

   private synchronized MonitoringDataOutputStream getMos() {
      return this.mos;
   }
}
