package nn.pp.rccore.scan.impl.rsp.V01_00;

import java.util.EnumMap;
import java.util.EnumSet;

public class ProtoStateMachine {
   private static final EnumMap<ProtoStates, EnumSet<ProtoMessages>> table = new EnumMap<>(ProtoStates.class);
   private static final EnumMap<ProtoStateMachine.PingPongState, EnumSet<ProtoMessages>> pingPongTable = new EnumMap<>(ProtoStateMachine.PingPongState.class);
   private static final EnumMap<ProtoStateMachine.AuthState, EnumSet<ProtoMessages>> authTable = new EnumMap<>(ProtoStateMachine.AuthState.class);
   private ProtoStates state = ProtoStates.UNKNOWN;
   private ProtoStateMachine.PingPongState pingPongState = ProtoStateMachine.PingPongState.PONG_SENT;
   private ProtoStateMachine.AuthState authState = ProtoStateMachine.AuthState.AUTH_NOT_SENT;

   public synchronized void transitionOnMessage(ProtoMessages var1) {
      if (this.isValidMessage(var1)) {
         switch (var1) {
            case PING:
               this.pingPongState = ProtoStateMachine.PingPongState.PING_RECEIVED;
               break;
            case PONG:
               this.pingPongState = ProtoStateMachine.PingPongState.PONG_SENT;
               break;
            case AUTH_REQUEST:
               this.authState = ProtoStateMachine.AuthState.AUTH_REQ;
               break;
            case AUTH_RESPONSE:
               this.authState = ProtoStateMachine.AuthState.AUTH_RESP;
         }

         if (var1.isTransition()) {
            this.state = var1.getToState();
         }

         this.notifyAll();
      }
   }

   public synchronized void waitOnState(ProtoStates var1) throws InterruptedException {
      if (this.state != var1) {
         while (this.state != var1 && this.state != ProtoStates.TERMINATED) {
            this.wait();
         }
      }
   }

   public synchronized boolean isValidMessage(ProtoMessages var1) {
      if (table.get(this.state).contains(var1)) {
         switch (var1) {
            case PING:
            case PONG:
               return pingPongTable.get(this.pingPongState).contains(var1);
            case AUTH_REQUEST:
            case AUTH_RESPONSE:
               return authTable.get(this.authState).contains(var1);
            default:
               return true;
         }
      } else {
         return false;
      }
   }

   public synchronized ProtoStates getState() {
      return this.state;
   }

   static {
      table.put(ProtoStates.UNKNOWN, EnumSet.of(ProtoMessages.AUTH_REQUEST, ProtoMessages.AUTH_RESPONSE, ProtoMessages.QUIT_RESP));
      table.put(
         ProtoStates.AUTHENTICATED,
         EnumSet.of(
            ProtoMessages.SCAN_REQUEST, ProtoMessages.SCAN_RESPONSE, ProtoMessages.PING, ProtoMessages.PONG, ProtoMessages.QUIT_REQ, ProtoMessages.QUIT_RESP
         )
      );
      table.put(ProtoStates.SCAN_SESSION_CREATED, EnumSet.of(ProtoMessages.PING, ProtoMessages.PONG, ProtoMessages.QUIT_REQ, ProtoMessages.QUIT_RESP));
      table.put(ProtoStates.TERMINATED, EnumSet.noneOf(ProtoMessages.class));
      pingPongTable.put(ProtoStateMachine.PingPongState.PING_RECEIVED, EnumSet.of(ProtoMessages.PING, ProtoMessages.PONG));
      pingPongTable.put(ProtoStateMachine.PingPongState.PONG_SENT, EnumSet.of(ProtoMessages.PING));
      authTable.put(ProtoStateMachine.AuthState.AUTH_NOT_SENT, EnumSet.of(ProtoMessages.AUTH_REQUEST));
      authTable.put(ProtoStateMachine.AuthState.AUTH_REQ, EnumSet.of(ProtoMessages.AUTH_REQUEST, ProtoMessages.AUTH_RESPONSE));
      authTable.put(ProtoStateMachine.AuthState.AUTH_RESP, EnumSet.noneOf(ProtoMessages.class));
   }

   private static enum AuthState {
      AUTH_NOT_SENT,
      AUTH_REQ,
      AUTH_RESP;
   }

   private static enum PingPongState {
      PING_RECEIVED,
      PONG_SENT;
   }
}
