package nn.pp.rccore.scan.impl.rsp.V01_00;

import java.io.IOException;
import nn.pp.core.NotificationListener;
import nn.pp.core.impl.MonitoringDataInputStream;
import nn.pp.core.impl.MonitoringDataOutputStream;
import nn.pp.rccore.scan.ScanCoreException;
import nn.pp.rccore.scan.ScanSessionEventsListener;
import nn.pp.rccore.scan.impl.commands.AuthHttpIDChallResponse;
import nn.pp.rccore.scan.impl.commands.AuthHttpIDGetChallenge;
import nn.pp.rccore.scan.impl.commands.AuthNamePassRequest;
import nn.pp.rccore.scan.impl.commands.AuthRDMRequest;
import nn.pp.rccore.scan.impl.commands.CommandVisitorV01_00;
import nn.pp.rccore.scan.impl.commands.PongResponse;
import nn.pp.rccore.scan.impl.commands.QuitMessageFromClient;
import nn.pp.rccore.scan.impl.commands.ScanSessionRequest;
import nn.pp.rccore.scan.impl.rsp.ClientCommandsExecutor;
import nn.pp.rccore.scan.impl.rsp.EventsListenerManager;
import nn.pp.rccore.scan.impl.rsp.ScanCoreNotificationEvent;
import nn.pp.rccore.scan.impl.rsp.SupportsVisitor;

public class RSPMessageHandlerV01_00Impl implements RSPMessageHandlerV01_00, CommandVisitorV01_00 {
   private volatile ClientCommandsExecutor clientCommandsExecutor;
   private volatile EventsListenerManager eventsListenerManager;
   private volatile MonitoringDataOutputStream os;
   private volatile MonitoringDataInputStream is;
   private final CommandToMessageWriterVisitor messageWriter = new CommandToMessageWriterVisitor();
   private final ProtoStateMachine stateMachine = new ProtoStateMachine();

   @Override
   public void handleAuthResponse(AuthResponse var1) {
      if (this.handleMessageReading(ProtoMessages.AUTH_RESPONSE, var1.getAck() != 0) && var1.getAck() == 0) {
         this.setQuitState();

         for (NotificationListener var3 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var3.receivedNotification(new ScanCoreNotificationEvent(var1.getReason()));
         }
      }
   }

   @Override
   public void handleScanSessionResponse(ScanSessionResponse var1) {
      if (this.handleMessageReading(ProtoMessages.SCAN_RESPONSE, var1.getAck() != 0)) {
         if (var1.getAck() == 0) {
            this.setQuitState();

            for (NotificationListener var3 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
               var3.receivedNotification(new ScanCoreNotificationEvent(var1.getReason()));
            }
         } else {
            for (ScanSessionEventsListener var5 : this.eventsListenerManager.getListeners(ScanSessionEventsListener.class)) {
               var5.scanSessionCreated(var1.getScanReferralId());
            }
         }
      }
   }

   @Override
   public void handlePingRequest(PingRequest var1) {
      if (this.handleMessageReading(ProtoMessages.PING, true)) {
         this.clientCommandsExecutor.executeClientCommands(new PongResponse());
      }
   }

   @Override
   public void handleQuitRequestFromServer(QuitRequestFromServer var1) {
      if (this.handleMessageReading(ProtoMessages.QUIT_RESP, true)) {
         for (NotificationListener var3 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var3.receivedNotification(new ScanCoreNotificationEvent(1, var1.getReason()));
         }
      }
   }

   @Override
   public void handleAuthNamePassRequest(AuthNamePassRequest var1) throws IOException, ScanCoreException {
      this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST);
   }

   @Override
   public void handleAuthRDMRequest(AuthRDMRequest var1) throws IOException, ScanCoreException {
      this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST);
   }

   @Override
   public void handleHttpIDChallengeResponse(AuthHttpIDChallResponse var1) throws IOException, ScanCoreException {
      this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST);
   }

   @Override
   public void handleHttpIDGetChallenge(AuthHttpIDGetChallenge var1) throws IOException, ScanCoreException {
      if (this.handleMessageWriting(var1, ProtoMessages.AUTH_REQUEST)) {
         AuthHttpIDChallenge var2 = new AuthHttpIDChallenge().readMessage(this.is);
         byte[] var3 = var2.getChallenge();
         this.clientCommandsExecutor.executeClientCommands(new AuthHttpIDChallResponse(var3, var1.getHttpSessionID()));
      }
   }

   @Override
   public void handleScanSessionRequest(ScanSessionRequest var1) throws IOException, ScanCoreException {
      this.handleWritingWithWait(var1, ProtoMessages.SCAN_REQUEST, ProtoStates.UNKNOWN, ProtoStates.AUTHENTICATED);
   }

   @Override
   public void handlePongResponse(PongResponse var1) throws IOException, ScanCoreException {
      this.handleMessageWriting(var1, ProtoMessages.PONG);
   }

   @Override
   public void handleQuitMessageFromClient(QuitMessageFromClient var1) throws IOException, ScanCoreException {
      if (this.handleMessageWriting(var1, ProtoMessages.QUIT_REQ)) {
         for (ScanSessionEventsListener var3 : this.eventsListenerManager.getListeners(ScanSessionEventsListener.class)) {
            var3.disconnected(null);
         }
      }
   }

   void setEventsListenerManager(EventsListenerManager var1) {
      this.eventsListenerManager = var1;
   }

   void setClientCommandsExecutor(ClientCommandsExecutor var1) {
      this.clientCommandsExecutor = var1;
   }

   void setOs(MonitoringDataOutputStream var1) {
      this.os = var1;
   }

   void setIs(MonitoringDataInputStream var1) {
      this.is = var1;
   }

   private boolean handleMessageReading(ProtoMessages var1, boolean var2) {
      boolean var3 = false;
      ProtoStates var4;
      synchronized (this.stateMachine) {
         var4 = this.stateMachine.getState();
         if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
            return false;
         }

         if (this.stateMachine.isValidMessage(var1)) {
            if (var2) {
               this.stateMachine.transitionOnMessage(var1);
            }

            return true;
         }

         this.setQuitState();
         var3 = true;
      }

      if (var3) {
         for (NotificationListener var6 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var6.receivedNotification(new ScanCoreNotificationEvent(1, 10001, true, "Current State was " + var4));
         }
      }

      return false;
   }

   private boolean handleMessageWriting(SupportsVisitor<CommandVisitorV01_00> var1, ProtoMessages var2) throws IOException, ScanCoreException {
      boolean var3 = false;
      ProtoStates var4;
      synchronized (this.stateMachine) {
         var4 = this.stateMachine.getState();
         if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
            return false;
         }

         if (this.stateMachine.isValidMessage(var2)) {
            this.messageWriter.setOs(this.os);

            try {
               var1.accept(this.messageWriter);
            } catch (IOException var8) {
               this.setQuitState();
               throw var8;
            } catch (ScanCoreException var9) {
               this.setQuitState();
               throw var9;
            }

            this.stateMachine.transitionOnMessage(var2);
            return true;
         }

         this.setQuitState();
         var3 = true;
      }

      if (var3) {
         for (NotificationListener var6 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var6.receivedNotification(new ScanCoreNotificationEvent(1, 10001, true, "Current State was " + var4));
         }
      }

      return false;
   }

   private void handleWritingWithWait(SupportsVisitor<CommandVisitorV01_00> var1, ProtoMessages var2, ProtoStates var3, ProtoStates var4) throws IOException, ScanCoreException {
      boolean var5 = false;
      ProtoStates var6;
      synchronized (this.stateMachine) {
         var6 = this.stateMachine.getState();
         if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
            return;
         }

         boolean var8;
         while (true) {
            try {
               var8 = this.waitForRequiredState(var2, var3, var4);
               break;
            } catch (InterruptedException var13) {
            }
         }

         if (var8) {
            if (this.stateMachine.getState() == ProtoStates.TERMINATED) {
               return;
            }

            this.messageWriter.setOs(this.os);

            try {
               var1.accept(this.messageWriter);
            } catch (IOException var11) {
               this.setQuitState();
               throw var11;
            } catch (ScanCoreException var12) {
               this.setQuitState();
               throw var12;
            }

            this.stateMachine.transitionOnMessage(var2);
         } else {
            this.setQuitState();
            var5 = true;
         }
      }

      if (var5) {
         for (NotificationListener var16 : this.eventsListenerManager.getListeners(NotificationListener.class)) {
            var16.receivedNotification(new ScanCoreNotificationEvent(1, 10001, true, "Current State was " + var6));
         }
      }
   }

   private boolean waitForRequiredState(ProtoMessages var1, ProtoStates var2, ProtoStates var3) throws InterruptedException {
      if (!this.stateMachine.isValidMessage(var1)) {
         if (this.stateMachine.getState() != var2) {
            return false;
         }

         this.stateMachine.waitOnState(var3);
      }

      return true;
   }

   private void setQuitState() {
      synchronized (this.stateMachine) {
         this.stateMachine.transitionOnMessage(ProtoMessages.QUIT_RESP);
      }
   }

   public void handleDisconnection() {
      synchronized (this.stateMachine) {
         this.stateMachine.transitionOnMessage(ProtoMessages.QUIT_RESP);
      }
   }
}
