package nn.pp.vmcore;

import java.io.File;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.List;
import java.util.logging.Logger;
import nn.pp.core.Platform;
import nn.pp.core.T;
import nn.pp.vmcore.impl.DriveEnumeratorDefault;
import nn.pp.vmcore.impl.DriveEnumeratorLinux;
import nn.pp.vmcore.impl.DriveEnumeratorMacOsX;
import nn.pp.vmcore.impl.DriveEnumeratorWindows;
import nn.pp.vmcore.impl.Folder;
import nn.pp.vmcore.impl.IsoImage;

public abstract class RedirectableObject {
   public static List<RedirectableObject> getAvailableDrives(Logger var0) {
      Object var1;
      if (Platform.isWindows()) {
         var1 = new DriveEnumeratorWindows();
      } else if (Platform.isLinux()) {
         var1 = new DriveEnumeratorLinux();
      } else if (Platform.isMacOsX()) {
         var1 = new DriveEnumeratorMacOsX();
      } else {
         var1 = new DriveEnumeratorDefault();
      }

      return ((DriveEnumerator)var1).getAvailableDrives(var0);
   }

   public static RedirectableObject getIsoImage(File var0) {
      return new IsoImage(var0);
   }

   public static RedirectableObject getRedirectedFolder(File var0) {
      return new Folder(var0);
   }

   public abstract String getShortName();

   public abstract String getLongName();

   public abstract String getRedirectionType();

   public abstract VMCore.DriveType getDriveType(Logger var1) throws IOException, VMException;

   @Override
   public String toString() {
      return MessageFormat.format(T._("{0} - {1}"), this.getRedirectionType(), this.getShortName());
   }
}
