package nn.pp.vmcore.impl;

import java.io.File;
import java.io.FileOutputStream;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.util.Calendar;
import nn.pp.core.T;
import nn.pp.vmcore.VMException;

public class NativeLibraryDownloader {
   private static final String libraryName = "DrvRedirNative2";
   private static final String libraryName_x64 = "DrvRedirNative2_x64";
   private static final String localLibraryName = "DrvRedir2";
   private static final int libraryMajor = 1;
   private static final int libraryMinor = 1;

   public void loadNativeLibrary() throws VMException, IOException {
      this.deleteOldLibraryFiles();
      URL var1 = NativeLibraryDownloader.class.getClassLoader().getResource(this.buildSourceFileName());
      URLConnection var2 = var1.openConnection();
      var2.connect();
      InputStream var3 = var2.getInputStream();
      File var4 = this.downloadToLocal(var3);

      try {
         System.load(var4.getCanonicalPath().trim());
      } catch (Throwable var7) {
         throw new VMException(var7.getMessage());
      }

      int var5 = this.getVersionMajor();
      int var6 = this.getVersionMinor();
      if (var5 != 1 || var6 != 1) {
         throw new VMException(T._("Native library version mismatch"));
      } else if (!this.isSupportedByOSVersion()) {
         throw new VMException(T._("Native implementation not supported by Operation System."));
      }
   }

   private static void debug(String var0) {
   }

   private String getFileSuffix() throws VMException {
      if (System.getProperty("os.name").startsWith("Windows")) {
         return ".dll";
      } else {
         throw new VMException(T._("Not supported by Operating System"));
      }
   }

   private String buildSourceFileName() throws VMException {
      return "amd64".equals(System.getProperty("os.arch")) ? "DrvRedirNative2_x64" + this.getFileSuffix() : "DrvRedirNative2" + this.getFileSuffix();
   }

   private String getTimeString() {
      Calendar var1 = Calendar.getInstance();
      int var2 = var1.get(1);
      int var3 = var1.get(2);
      int var4 = var1.get(5);
      int var5 = var1.get(11);
      int var6 = var1.get(12);
      int var7 = var1.get(13);
      String var8 = new String("");
      var8 = var8 + var2;
      if (var3 < 10) {
         var8 = var8 + "0";
      }

      var8 = var8 + var3;
      if (var4 < 10) {
         var8 = var8 + "0";
      }

      var8 = var8 + var4;
      var8 = var8 + "-";
      if (var5 < 10) {
         var8 = var8 + "0";
      }

      var8 = var8 + var5;
      if (var6 < 10) {
         var8 = var8 + "0";
      }

      var8 = var8 + var6;
      if (var7 < 10) {
         var8 = var8 + "0";
      }

      return var8 + var7;
   }

   private File downloadToLocal(InputStream var1) throws IOException, VMException {
      File var2 = null;
      var2 = File.createTempFile("DrvRedir2-" + this.getTimeString() + "-", this.getFileSuffix());
      var2.deleteOnExit();
      FileOutputStream var3 = new FileOutputStream(var2);
      byte[] var4 = new byte[4096];
      int var6 = 0;

      int var5;
      while ((var5 = var1.read(var4)) != -1) {
         var3.write(var4, 0, var5);
         var6 += var5;
      }

      var3.close();
      var1.close();
      debug("Downloaded " + var6 + " bytes of native code to " + var2.getCanonicalPath() + ".");
      return var2;
   }

   private void deleteOldLibraryFiles() {
      String var1 = System.getProperty("java.io.tmpdir");
      File var2 = new File(var1);
      if (var2 != null) {
         File[] var3 = var2.listFiles(new FilenameFilter() {
            @Override
            public boolean accept(File var1, String var2x) {
               try {
                  return var2x.startsWith("DrvRedir2") && var2x.endsWith(NativeLibraryDownloader.this.getFileSuffix());
               } catch (VMException var4) {
                  return false;
               }
            }
         });

         for (int var4 = 0; var4 < var3.length; var4++) {
            var3[var4].delete();
         }
      }
   }

   private native int getVersionMajor();

   private native int getVersionMinor();

   private native boolean isSupportedByOSVersion();
}
