package nn.pp.vmcore.impl;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.logging.Logger;
import nn.pp.core.T;

public abstract class RedirectedDriveDev extends RedirectedImageWithPartitionTable {
   private boolean mediumChanging = false;

   public RedirectedDriveDev(File var1, boolean var2, Logger var3) {
      super(var1, var2, var3);
   }

   @Override
   public synchronized void open() throws IOException {
      this.file = new RedirectedDriveDev.BlockDevice(this.imageFile, this.readOnly ? "r" : "rw");
      if (this.file == null) {
         throw new IOException(T._("Could not open file"));
      } else {
         this.mediumChanging = false;
      }
   }

   @Override
   protected synchronized boolean isRemovable(RandomAccessFile var1) throws IOException {
      boolean var2 = super.isRemovable(var1) || super.isFixed(var1);
      return !var2 ? var2 : !this.devNameIndicatesHarddisk();
   }

   @Override
   protected synchronized boolean isFixed(RandomAccessFile var1) throws IOException {
      boolean var2 = super.isRemovable(var1) || super.isFixed(var1);
      return !var2 ? var2 : this.devNameIndicatesHarddisk();
   }

   protected abstract boolean devNameIndicatesHarddisk();

   @Override
   public synchronized RedirectedObject.MediumChangeState getMediumChangeState() {
      try {
         RandomAccessFile var1 = new RandomAccessFile(this.imageFile, "r");
         if (this.mediumChanging) {
            return RedirectedObject.MediumChangeState.CHANGED;
         } else {
            long var2 = var1.length();
            long var4 = var2 / this.sectorSize;
            var1.close();
            return var2 != 0L && var4 != this.sectorCount ? RedirectedObject.MediumChangeState.CHANGED : RedirectedObject.MediumChangeState.NO_CHANGE;
         }
      } catch (IOException var6) {
         return this.mediumChanging ? RedirectedObject.MediumChangeState.NO_CHANGE : RedirectedObject.MediumChangeState.REMOVED;
      }
   }

   @Override
   public synchronized void mediumRemovedForChange() throws Exception {
      this.mediumChanging = true;
   }

   @Override
   public synchronized void mediumInsertedAfterChange() throws Exception {
      this.mediumChanging = false;
   }

   private class BlockDevice extends RandomAccessFile {
      long length = 0L;
      private int hops = 0;
      private static final int MatchSectorSize = 512;
      private static final int Match = 0;
      private static final int Before = 1;
      private static final int After = 2;

      public BlockDevice(File var2, String var3) throws FileNotFoundException {
         super(var2, var3);
      }

      public BlockDevice(String var2, String var3) throws FileNotFoundException {
         super(var2, var3);
      }

      @Override
      public long length() throws IOException {
         if (this.length != 0L) {
            return this.length;
         } else {
            this.length = super.length();
            if (this.length != 0L) {
               return this.length;
            } else {
               this.length = this.detectLength();
               return this.length;
            }
         }
      }

      private int match(long var1) throws IOException {
         long var3 = var1 * 512L;
         byte[] var5 = new byte[512];
         this.hops++;
         this.seek(var3);

         try {
            this.readFully(var5);
         } catch (Exception var8) {
            return 2;
         }

         try {
            this.readFully(var5);
            return 1;
         } catch (Exception var7) {
            return 0;
         }
      }

      private long findStartSearchSector() throws IOException {
         long var1 = 1024L;

         while (this.match(var1) != 2) {
            var1 *= 8L;
         }

         return var1;
      }

      private long findLengthSector(long var1, long var3) throws IOException {
         if (var1 > var3) {
            return -1L;
         } else {
            long var5 = var1 + (var3 - var1) / 2L;
            int var7 = this.match(var5);
            if (var7 == 1) {
               return this.findLengthSector(var5 + 1L, var3);
            } else {
               return var7 == 2 ? this.findLengthSector(var1, var5 - 1L) : var5;
            }
         }
      }

      private long detectLength() throws IOException {
         long var1 = this.findLengthSector(0L, this.findStartSearchSector());
         if (var1 < 0L) {
            throw new IOException(T._("Could not detect block device length"));
         } else {
            return (var1 + 1L) * 512L;
         }
      }
   }
}
