package nn.pp.vmcore.impl;

import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.vmcore.VMException;

public class RedirectedDriveNative extends RedirectedObject {
   private DriveNative nativeDrive;
   private long redirectedNative = 0L;

   private native long loadNative(long var1);

   private native void freeNative(long var1);

   private native int openNative(long var1);

   private native int closeNative(long var1);

   private native int lockAccessNative(long var1, boolean var3);

   private native int getDriveGeometryNative(long var1);

   private native long getSectorSizeNative(long var1);

   private native long getLastSectorNoNative(long var1);

   private native int readSectorsNative(long var1, long var3, long var5, byte[] var7);

   private native int writeSectorsNative(long var1, long var3, long var5, byte[] var7);

   private native RedirectedObject.MediumChangeState getMediumChangeStateNative(long var1);

   private native void mediumRemovedForChangeNative(long var1);

   private native void mediumInsertedAfterChangeNative(long var1);

   public RedirectedDriveNative(DriveNative var1, boolean var2, Logger var3) {
      super(var2, var3);
      this.nativeDrive = var1;
      this.driveType = var1.getDriveType();
   }

   @Override
   public synchronized void open() throws VMException {
      if (this.redirectedNative != 0L) {
         this.freeNative(this.redirectedNative);
      }

      this.redirectedNative = this.loadNative(this.nativeDrive.getNativePointer());
      if (this.redirectedNative == 0L) {
         throw new VMException(T._("Could not open redirected drive object."));
      } else {
         int var1 = this.openNative(this.redirectedNative);
         if (var1 != 0) {
            throw new VMException(var1, T._("Could not open drive:") + " " + this.getErrorString(var1));
         }
      }
   }

   @Override
   public synchronized void close() {
      if (this.redirectedNative != 0L) {
         this.closeNative(this.redirectedNative);
         this.freeNative(this.redirectedNative);
         this.redirectedNative = 0L;
      }
   }

   @Override
   public synchronized void determineGeometry() throws VMException {
      if (this.redirectedNative != 0L) {
         int var1 = this.getDriveGeometryNative(this.redirectedNative);
         if (var1 != 0) {
            throw new VMException(var1, T._("Could not query drive geometry:") + " " + this.getErrorString(var1));
         }
      }
   }

   @Override
   public synchronized long getLastSectorNo() {
      return this.redirectedNative != 0L ? this.getLastSectorNoNative(this.redirectedNative) : 1L;
   }

   @Override
   public synchronized int getSectorSize() {
      return this.redirectedNative != 0L ? (int)this.getSectorSizeNative(this.redirectedNative) : 1;
   }

   @Override
   protected synchronized void lockAccess(boolean var1) throws VMException {
      if (this.redirectedNative != 0L) {
         int var2 = this.lockAccessNative(this.redirectedNative, var1);
         if (!var1 && var2 != 0) {
            throw new VMException(var2, T._("Could not lock drive access:") + " " + this.getErrorString(var2));
         }

         DriveEnumeratorImpl.driveLocked(this.nativeDrive, !var1);
      }
   }

   @Override
   public synchronized void readSectors(long var1, long var3, byte[] var5) throws VMException {
      if (this.redirectedNative != 0L) {
         int var6 = this.readSectorsNative(this.redirectedNative, var1, var3, var5);
         if (var6 != 0) {
            throw new VMException(var6, T._("Could not read from drive:") + " " + this.getErrorString(var6));
         }
      }
   }

   @Override
   public synchronized void writeSectors(long var1, long var3, byte[] var5) throws VMException {
      if (this.readOnly) {
         throw new VMException(T._("Writing not supported"));
      } else {
         if (this.redirectedNative != 0L) {
            int var6 = this.writeSectorsNative(this.redirectedNative, var1, var3, var5);
            if (var6 != 0) {
               throw new VMException(var6, T._("Could not read from drive:") + " " + this.getErrorString(var6));
            }
         }
      }
   }

   @Override
   public synchronized RedirectedObject.MediumChangeState getMediumChangeState() {
      return this.redirectedNative != 0L ? this.getMediumChangeStateNative(this.redirectedNative) : RedirectedObject.MediumChangeState.NO_CHANGE;
   }

   @Override
   public synchronized void mediumRemovedForChange() throws Exception {
      if (this.redirectedNative != 0L) {
         this.mediumRemovedForChangeNative(this.redirectedNative);
      }
   }

   @Override
   public synchronized void mediumInsertedAfterChange() throws Exception {
      if (this.redirectedNative != 0L) {
         this.mediumInsertedAfterChangeNative(this.redirectedNative);
      }
   }

   private String getErrorString(int var1) {
      switch (var1) {
         case 0:
         case 1644167168:
            return T._("No error");
         case 1610612738:
            return T._("Cannot open drive, probably an access rights problem");
         case 1610612739:
            return T._("No Medium inserted or drive access error");
         case 1610612740:
            return T._("I/O error while accessing the drive");
         case 1610612741:
            return T._("This drive type does not support Drive Redirection");
         case 1610612742:
            return T._("Locking drive failed");
         case 1627389959:
            return T._("Medium changing in progress");
         default:
            return T._("Unknown error");
      }
   }
}
