package nn.pp.vmcore.impl;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.channels.FileLock;
import java.nio.channels.NonWritableChannelException;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Date;
import java.util.Vector;
import java.util.logging.Logger;
import javax.swing.JOptionPane;
import nn.pp.core.T;
import nn.pp.vmcore.VMCore;
import nn.pp.vmcore.VMException;

public class RedirectedFolder extends RedirectedObject {
   private static boolean doDebug = true;
   private File folder;
   private static final int REMOVABLE_SECTOR_SIZE = 512;
   String m_folder = null;
   int sectorSize = 512;
   static RandomAccessFile log_file;
   RedirectedFolder.BDRVVVFATState m_vvfat;
   int MODE_UNDEFINED = 0;
   int MODE_NORMAL = 1;
   int MODE_MODIFIED = 2;
   int MODE_DIRECTORY = 4;
   int MODE_FAKED = 8;
   int MODE_DELETED = 16;
   int MODE_RENAMED = 32;
   Object[] dlg_options_lock = new Object[]{"Retry", "Ignore", "Abort"};
   Object[] dlg_options_memory = new Object[]{"Ignore", "Abort"};
   Object[] dlg_options_large_file = this.dlg_options_memory;
   boolean file_not_found_except = false;
   int mem_low_counter = 0;
   boolean urgent_warning = false;
   int direntry_size = 32;
   Vector<RedirectedFolder.commit_t> all_commits = new Vector<>();

   public RedirectedFolder(File var1, boolean var2, Logger var3) {
      super(var2, var3);
      this.folder = var1;
      this.readOnly = var2;
   }

   @Override
   public void open() throws IOException, VMException {
      try {
         this.build_vvfat(this.readOnly);
      } catch (IOException var2) {
         this.close();
         throw var2;
      } catch (VMException var3) {
         this.close();
         throw var3;
      }
   }

   @Override
   public void close() {
      try {
         this.ReleaseLocks(true);
      } catch (Exception var2) {
         var2.printStackTrace();
      }
   }

   @Override
   public void determineGeometry() throws IOException, VMException {
      this.driveType = VMCore.DriveType.REMOVABLE;
      this.sectorSize = 512;
   }

   @Override
   public int getSectorSize() {
      return this.sectorSize;
   }

   @Override
   public long getLastSectorNo() {
      return this.m_vvfat.total_sectors - 1L;
   }

   @Override
   protected void lockAccess(boolean var1) throws VMException {
   }

   @Override
   public void readSectors(long var1, long var3, byte[] var5) throws IOException, VMException {
      this.ReadSectors_VFat(var1, var3, var5);
   }

   @Override
   public void writeSectors(long var1, long var3, byte[] var5) throws IOException, VMException {
      this.WriteSectors_VFat(var1, var3, var5);
   }

   private void ReleaseLocks(boolean var1) {
      RedirectedFolder.mapping_t var2 = null;
      if (this.m_vvfat != null) {
         if (this.m_vvfat.mapping != null) {
            if (this.m_vvfat.dummy_file_name.exists()) {
               this.m_vvfat.dummy_file_name.delete();
            }

            for (int var3 = 0; var3 < this.m_vvfat.mapping.size(); var3++) {
               var2 = this.m_vvfat.mapping.get(var3).mapping;
               if (var2.lock != null) {
                  try {
                     var2.lock.release();
                     var2.lock = null;
                  } catch (Exception var6) {
                     var6.printStackTrace();
                  }
               }

               if (var2.file != null) {
                  try {
                     var2.file.close();
                  } catch (IOException var7) {
                  }

                  var2.file = null;
               }
            }

            if (var1) {
               this.m_vvfat.fat.clear();
               this.m_vvfat.directory.clear();
               this.m_vvfat.mapping.clear();
               if (this.m_vvfat.image != null) {
                  try {
                     this.m_vvfat.image.close();
                  } catch (IOException var5) {
                  }

                  this.m_vvfat.image_name.delete();
               }
            }
         }
      }
   }

   static void debug(String var0, boolean var1, boolean var2) {
      if (doDebug) {
         if (var2) {
            System.out.println(var0);
         }

         if (var1) {
            try {
               log_file.writeBytes(var0);
            } catch (IOException var4) {
            }
         }
      }
   }

   public RedirectedFolder.direntry_t getDirEntry(byte[] var1) throws IOException {
      RedirectedFolder.direntry_t var2 = new RedirectedFolder.direntry_t();

      int var3;
      for (var3 = 0; var3 < 8; var3++) {
         var2.name[var3] = (char)var1[var3];
      }

      for (int var4 = 0; var3 < 11; var4++) {
         var2.extension[var4] = (char)var1[var3];
         var3++;
      }

      var2.attributes = var1[var3];
      var2.reserved[0] = var1[++var3];
      var2.reserved[1] = var1[++var3];
      var2.ctime = var1[++var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.cdate = var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.adate = var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.begin_hi = var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.mtime = var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.mdate = var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.begin = var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      var3 += 2;
      var2.size = var1[var3 + 3] << 24 & 0xFF000000 | var1[var3 + 2] << 16 & 0xFF0000 | var1[var3 + 1] << 8 & 0xFF00 | var1[var3] & 255;
      return var2;
   }

   public void fn_init(RedirectedFolder.file_name var1) {
      var1.sequence_number = var1.len = 0;
      var1.checksum = 256;
   }

   public void build_vvfat(boolean var1) throws IOException, VMException {
      boolean var2 = false;
      boolean var3 = false;
      byte var4 = 0;
      this.m_vvfat = new RedirectedFolder.BDRVVVFATState();
      this.m_folder = this.folder.getAbsolutePath();
      File var5 = new File("log.txt");
      if (var5.exists()) {
         var5.delete();
      }

      log_file = new RandomAccessFile(var5, "rw");
      debug("Build VVFAT\n", var2, var3);
      this.m_vvfat.fat_type = 32;
      this.m_vvfat.dir_size = 0L;
      this.m_vvfat.counted_files = 0L;
      debug("Count Foldersize\n", var2, var3);
      this.count_size(this.m_folder);
      this.m_vvfat.dir_size /= 1000L;
      this.m_vvfat.dummy_file_name = new File("fat.dummy");
      this.m_vvfat.dummy_file = new RandomAccessFile(this.m_vvfat.dummy_file_name, "rw");
      this.m_vvfat.dummy_file.writeBytes("File-Descriptor-Test");
      this.m_vvfat.dummy_file.close();
      if (this.m_vvfat.counted_files >= 1000L && this.m_vvfat.counted_files < 7500L) {
         if (JOptionPane.showConfirmDialog(null, "The Redirection of " + this.m_vvfat.counted_files + " files may take some minutes.\nContinue?", "Warning", 0)
            == 1) {
            throw new VMException(T._("Building FAT-Structure aborted"));
         }
      } else if (this.m_vvfat.counted_files >= 7500L
         && JOptionPane.showConfirmDialog(
               null,
               "The Redirection of "
                  + this.m_vvfat.counted_files
                  + " files will take a lot of time and Java VM memory,"
                  + " which can cause a KVM-Session timeout\n"
                  + " or an \"Out-of-Memory\"-Error of the Java VM. "
                  + "Continue?",
               "Warning",
               0
            )
            == 1) {
         throw new VMException(T._("Building FAT-Structure aborted"));
      }

      if (this.m_vvfat.dir_size <= 4000000L) {
         var4 = 4;
      } else if (this.m_vvfat.dir_size >= 4000000L && this.m_vvfat.dir_size <= 8000000L) {
         var4 = 8;
      } else if (this.m_vvfat.dir_size >= 8000000L && this.m_vvfat.dir_size <= 16000000L) {
         var4 = 16;
      } else if (this.m_vvfat.dir_size >= 16000000L) {
         var4 = 32;
      }

      this.m_vvfat.sectors_per_cluster = this.m_vvfat.fat_type == 16 ? 64 : var4;
      this.m_vvfat.first_sectors_number = 1;
      this.m_vvfat.current_cluster = 2147483647L;
      this.m_vvfat.heads = 63L;
      this.m_vvfat.secs = 63L;
      if (this.m_vvfat.fat_type == 16 && this.m_vvfat.dir_size >= 2000000L) {
         JOptionPane.showMessageDialog(null, "Foldersize is too large for FAT16", "Alert", 0);
         throw new VMException(T._("Directory too large for FAT"));
      } else {
         this.m_vvfat.cyls = this.m_vvfat.fat_type == 16
            ? 1023L
            : (
               this.m_vvfat.cyls = this.m_vvfat.dir_size <= 1000000L
                  ? 1023
                  : (int)(2L * this.m_vvfat.dir_size / (this.m_vvfat.heads * this.m_vvfat.secs * 0.512))
            );
         this.m_vvfat.total_sectors = this.m_vvfat.cyls * this.m_vvfat.heads * this.m_vvfat.secs;
         this.m_vvfat.sector_count = this.m_vvfat.total_sectors;
         if (this.m_vvfat.sector_count > this.m_vvfat.total_sectors) {
            this.m_vvfat.sector_count = this.m_vvfat.total_sectors;
         }

         this.m_vvfat.sector_count = this.m_vvfat.total_sectors;
         this.m_vvfat.downcase_short_names = 1;
         this.init_vvfat();
         if (this.m_vvfat.first_sectors_number == 64) {
            this.init_mbr();
         }

         if (!var1) {
            this.m_vvfat.image_name = new File("tmp_image.vvfat");
            if (this.m_vvfat.image_name.exists()) {
               this.m_vvfat.image_name.delete();
            }

            this.m_vvfat.image = new RandomAccessFile(this.m_vvfat.image_name, "rw");
         }
      }
   }

   public void init_mbr() throws IOException {
      RedirectedFolder.mbr_t var3 = new RedirectedFolder.mbr_t();

      for (int var1 = 0; var1 < 4; var1++) {
         if (var1 == 0) {
            RedirectedFolder.partition_t var2;
            var3.partition[var1] = var2 = new RedirectedFolder.partition_t();
            var2.attributes = 128;
            var2.start_head = 1;
            var2.start_sector = 1;
            var2.start_cylinder = 0;
            var2.fs_type = this.m_vvfat.fat_type == 12 ? 1 : (this.m_vvfat.fat_type == 16 ? 6 : 11);
            var2.end_head = (int)this.m_vvfat.heads - 1;
            var2.end_sector = 255;
            var2.end_cylinder = 255;
            var2.start_sector_long = this.m_vvfat.secs;
            var2.end_sector_long = this.m_vvfat.sector_count;
         } else {
            var3.partition[var1] = new RedirectedFolder.partition_t();
         }
      }

      var3.magic[0] = 85;
      var3.magic[1] = -86;
      byte[] var4 = var3.getBytes();
      System.arraycopy(var4, 0, this.m_vvfat.first_sectors, 446, var4.length);
   }

   public void count_size(String var1) throws IOException {
      boolean var2 = false;
      boolean var3 = false;
      File var5 = new File(var1);
      debug("Reading File/Folder " + var5 + "\n", var2, var3);
      File[] var6 = var5.listFiles();

      for (int var4 = 0; var4 < var6.length; var4++) {
         File var7 = var6[var4];
         if (var7.isDirectory()) {
            debug("File " + var7 + " is a Directory\n", var2, var3);
            String var8 = var1.concat("/").concat(var7.getName());
            this.count_size(var8);
         } else {
            try {
               RandomAccessFile var10 = new RandomAccessFile(new File(var7.getAbsolutePath()), "r");
               if (var10 != null) {
                  this.m_vvfat.dir_size = this.m_vvfat.dir_size + var10.length();
                  this.m_vvfat.counted_files++;
                  var10.close();
               }
            } catch (FileNotFoundException var9) {
            }
         }
      }
   }

   public void init_vvfat() throws IOException, VMException {
      boolean var1 = false;
      boolean var2 = false;
      RedirectedFolder.bootsector_t var3 = new RedirectedFolder.bootsector_t();
      new RedirectedFolder.mapping_t();
      int var8 = -1;
      this.m_vvfat.cluster_size = this.m_vvfat.sectors_per_cluster * 512;
      this.m_vvfat.cluster_buffer = new byte[this.m_vvfat.cluster_size];
      int var7 = 1 + this.m_vvfat.sectors_per_cluster * 512 * 8 / this.m_vvfat.fat_type;
      this.m_vvfat.sectors_per_fat = (int)(this.m_vvfat.sector_count + var7) / var7;
      RedirectedFolder.array_t var5 = new RedirectedFolder.array_t();
      var5.next = 1;
      this.m_vvfat.directory.add(var5);
      RedirectedFolder.direntry_t var6;
      var5.direntry = var6 = new RedirectedFolder.direntry_t();
      var6.attributes = 40;
      var6.name = "DRV_REDI".toCharArray();
      var6.extension = "R  ".toCharArray();
      this.init_fat();
      this.m_vvfat.faked_sectors = this.m_vvfat.first_sectors_number + this.m_vvfat.sectors_per_fat * 2;
      this.m_vvfat.cluster_count = this.sector2cluster((int)this.m_vvfat.sector_count);
      this.m_vvfat.mapping.add(var5 = new RedirectedFolder.array_t());
      var5.next = 1;
      RedirectedFolder.mapping_t var4;
      var5.mapping = var4 = new RedirectedFolder.mapping_t();
      var4.begin = 0L;
      var4.dir_index = 0;
      var4.info.dir.parent_mapping_index = -1;
      var4.first_mapping_index = -1;
      var4.path = this.m_folder;
      var4.mode = this.MODE_DIRECTORY;
      var4.read_only = 0;
      this.m_vvfat.path = var4.path;
      var7 = 0;

      for (long var9 = this.m_vvfat.fat_type == 32 ? 2 : 0; var7 < this.m_vvfat.mapping.size(); var7++) {
         long var11 = 0L;
         var8 = this.m_vvfat.fat_type != 32 ? (var7 != 0 ? 1 : 0) : -1;
         var4 = this.m_vvfat.mapping.get(var7).mapping;
         if (var4.mode == this.MODE_DIRECTORY) {
            var4.begin = var9;
            debug("Entering Dir (reading content): " + var4.path + "\n", var1, var2);
            this.read_directory(var7);
            var4 = this.m_vvfat.mapping.get(var7).mapping;
         } else {
            var4.mode = this.MODE_NORMAL;
            var4.begin = var9;
            if (var4.end > 0L) {
               RedirectedFolder.direntry_t var13 = this.m_vvfat.directory.get(var4.dir_index).direntry;
               var4.end = var9 + 1L + (var4.end - 1L) / this.m_vvfat.cluster_size;
               this.set_begin_of_direntry(var13, var4.begin);
            } else {
               var4.end = var9 + 1L;
               var8 = 0;
            }
         }

         if (var8 != 0) {
            for (long var17 = var4.begin; var17 < var4.end - 1L; var17++) {
               this.fat_set(var17, var17 + 1L);
            }

            this.fat_set(var4.end - 1L, this.m_vvfat.max_fat_value);
         }

         var9 = var4.end;
         if (var9 > this.m_vvfat.cluster_count) {
            debug("Directory does not fit in FAT\n" + this.m_vvfat.fat_type + "\n", var1, var2);
            throw new VMException(T._("Directory too large for FAT"));
         }
      }

      this.m_vvfat.sectors_of_root_directory = (int)var4.end * this.m_vvfat.sectors_per_cluster;
      this.m_vvfat.last_cluster_of_root_directory = var4.end;
      this.fat_set(0L, this.m_vvfat.max_fat_value);
      this.fat_set(1L, this.m_vvfat.max_fat_value);
      this.m_vvfat.current_mapping = null;
      var3.jump[0] = -21;
      var3.jump[1] = 62;
      var3.jump[2] = -112;
      var3.name = "DRVREDIR".toCharArray();
      var3.sector_size = this.sectorSize;
      var3.sectors_per_cluster = (byte)this.m_vvfat.sectors_per_cluster;
      var3.reserved_sectors = 1;
      var3.number_of_fats = 2;
      var3.root_entries = this.m_vvfat.fat_type == 16 ? this.m_vvfat.sectors_of_root_directory * 16 : 0;
      var3.total_sectors16 = (int)(this.m_vvfat.sector_count > 65535L ? 0L : this.m_vvfat.sector_count);
      var3.media_type = (byte)(this.m_vvfat.fat_type != 12 ? 248 : (this.m_vvfat.sector_count == 5760L ? 249 : 248));
      byte[] var18 = this.m_vvfat.fat.firstElement();
      var18[0] = var3.media_type;
      var3.sectors_per_fat = this.m_vvfat.fat_type == 16 ? this.m_vvfat.sectors_per_fat : 0;
      var3.sectors_per_track = (int)this.m_vvfat.secs;
      var3.number_of_heads = (int)this.m_vvfat.heads;
      var3.hidden_sectors = this.m_vvfat.first_sectors_number == 1 ? 0 : 63;
      var3.total_sectors = this.m_vvfat.sector_count > 65535L ? this.m_vvfat.sector_count : 0L;
      if (this.m_vvfat.fat_type == 16) {
         var3.union.fat16.drive_number = (byte)(this.m_vvfat.fat_type == 12 ? 0 : 128);
         var3.union.fat16.current_head = 0;
         var3.union.fat16.signature = 41;
         var3.union.fat16.id = -1396894940;
         var3.union.fat16.volume_label = "DRVREDIR   ".toCharArray();
         var3.union.fat16.fat_type = "FAT16   ".toCharArray();
      } else if (this.m_vvfat.fat_type == 32) {
         var3.union.fat32.drive_number = (short)(this.m_vvfat.fat_type == 12 ? 0 : 128);
         var3.union.fat32.current_head = 0;
         var3.union.fat32.signature = 41;
         var3.union.fat32.id = 305419896L;
         var3.union.fat32.sectors_per_fat = this.m_vvfat.sectors_per_fat;
         var3.union.fat32.flags = 0;
         var3.union.fat32.major = 0;
         var3.union.fat32.minor = 0;
         var3.union.fat32.backup_boot_sector = 6;
         var3.union.fat32.first_cluster_of_root_directory = 2;
         var3.union.fat32.info_sector = 0;
         var3.union.fat32.volume_label = "DRVREDIR   ".toCharArray();
         var3.union.fat32.fat_type = "FAT32   ".toCharArray();
      }

      var3.magic[0] = 85;
      var3.magic[1] = 170;
      byte[] var12 = var3.getBytes();
      System.arraycopy(var12, 0, this.m_vvfat.first_sectors, (this.m_vvfat.first_sectors_number - 1) * 512, 512);
   }

   public void read_directory(int var1) throws IOException, VMException {
      boolean var2 = false;
      boolean var3 = false;
      RandomAccessFile var4 = null;
      Object var5 = null;
      new RedirectedFolder.mapping_t();
      RedirectedFolder.mapping_t var8 = this.m_vvfat.mapping.get(var1).mapping;
      String var10 = var8.path;
      long var11 = var8.begin;
      int var13 = var8.info.dir.parent_mapping_index;
      RedirectedFolder.mapping_t var15 = var13 >= 0 ? this.m_vvfat.mapping.get(var13).mapping : null;
      int var14 = (int)(var15 != null ? var15.begin : -1L);
      if (var10 == null) {
         var8.end = var8.begin;
         throw new VMException(T._("Building FAT-Structure failed"));
      } else {
         var8.info.dir.first_dir_index = (var11 != 0L || this.m_vvfat.fat_type != 16) && (var11 != 2L || this.m_vvfat.fat_type != 32)
            ? this.m_vvfat.directory.size()
            : 0;
         File[] var16 = new File[]{new File("."), new File("..")};
         File var17 = new File(var10);
         File[] var18 = var17.listFiles();
         File[] var6;
         if (var18 != null) {
            var6 = new File[var16.length + var18.length];
            System.arraycopy(var16, 0, var6, 0, var16.length);
            System.arraycopy(var18, 0, var6, var16.length, var18.length);
         } else {
            var6 = new File[var16.length];
            System.arraycopy(var16, 0, var6, 0, var16.length);
         }

         for (int var19 = 0; var19 < var6.length; var19++) {
            File var20 = var6[var19];
            var5 = null;
            var4 = null;
            if (var20.isFile()) {
               try {
                  var4 = new RandomAccessFile(new File(var20.getAbsolutePath()), "rw");
               } catch (FileNotFoundException var32) {
                  try {
                     this.m_vvfat.dummy_file = new RandomAccessFile("fat.dummy", "rw");

                     try {
                        var4 = new RandomAccessFile(new File(var20.getAbsolutePath()), "r");
                     } catch (FileNotFoundException var29) {
                        System.out.println("File: " + var20 + " is read-only.");
                     }
                  } catch (FileNotFoundException var31) {
                     if (!this.file_not_found_except) {
                        if (JOptionPane.showConfirmDialog(
                              null,
                              "The OS-dependent limit of File-Handles is reached. No further File-Locking possible.\nThis may lead to inconsistency in files or their content\nContinue without File-Locking?",
                              "Warning",
                              0
                           )
                           == 1) {
                           throw new VMException(T._("Building FAT-Structure aborted"));
                        }

                        this.ReleaseLocks(false);
                        this.file_not_found_except = true;
                     }
                  }

                  this.m_vvfat.dummy_file.close();
               }

               if (var4 == null) {
                  debug("Could not open file: " + var20 + " -> File skipped!\n", var2, var3);
                  continue;
               }

               try {
                  if (!this.file_not_found_except) {
                     var5 = var4.getChannel().tryLock();
                     int var21 = -1;

                     while (var5 == null) {
                        var21 = JOptionPane.showOptionDialog(
                           null,
                           "Could not obtain a file-lock. This may lead to inconsistency in files or their content\nPlease choose option?",
                           "Warning",
                           1,
                           3,
                           null,
                           this.dlg_options_lock,
                           this.dlg_options_lock[2]
                        );
                        if (var21 == 0) {
                           var5 = var4.getChannel().lock();
                        } else {
                           if (var21 == 1) {
                              break;
                           }

                           if (var21 == 2) {
                              throw new VMException(T._("Building FAT-Structure aborted"));
                           }
                        }
                     }
                  }
               } catch (NonWritableChannelException var30) {
                  debug("No WritableChannel-Lock: " + var20 + "\n", var2, var3);
               }
            } else {
               var4 = null;
            }

            Runtime var39 = Runtime.getRuntime();
            debug("Total Memory = " + var39.totalMemory() + " Free Memory = " + var39.freeMemory() + "\n", var2, var3);
            if ((float)var39.freeMemory() / (float)var39.totalMemory() * 100.0F < 1.0) {
               this.mem_low_counter++;
            }

            if (this.mem_low_counter > 100 && !this.urgent_warning) {
               this.urgent_warning = true;
               int var22 = JOptionPane.showOptionDialog(
                  null,
                  "The Standard Java VM Memory is almost used up. This usally happens when too many\nfiles/folders are redirected. It's recommended to abort the current process and reduce\nthe number of files/folder or use the redirection of physical drive instead.",
                  "Attention",
                  0,
                  3,
                  null,
                  this.dlg_options_memory,
                  this.dlg_options_memory[1]
               );
               if (var22 == 0) {
                  break;
               }

               if (var22 == 1) {
                  throw new VMException(T._("Building FAT-Structure aborted"));
               }
            }

            boolean var40 = var20.getName().compareTo(".") == 0;
            boolean var23 = var20.getName().compareTo("..") == 0;
            if (!var23 || var11 != 2L) {
               RedirectedFolder.direntry_t var9 = this.create_short_and_long_name(
                  this.m_vvfat.directory.indexOf(this.m_vvfat.directory.lastElement()),
                  var20.getName(),
                  !var40 && !var23 ? 0 : 1,
                  var8.info.dir.first_dir_index
               );
               var9.attributes = (byte)(var20.isDirectory() ? 16 : 32);
               var9.reserved[0] = var9.reserved[1] = 0;
               Calendar var24 = Calendar.getInstance();
               Calendar var25 = Calendar.getInstance();
               var24.setTime(new Date(var20.lastModified()));
               var9.ctime = var24.get(13) / 2 | var24.get(12) << 5 | var24.get(10) << 11;
               var9.cdate = var24.get(5) | var24.get(2) + 1 << 5 | var24.get(1) - 1980 << 9;
               var9.adate = var25.get(5) | var25.get(2) + 1 << 5 | var25.get(1) - 1980 << 9;
               var9.mtime = var24.get(13) / 2 | var24.get(12) << 5 | var24.get(10) << 11;
               var9.mdate = var24.get(5) | var24.get(2) + 1 << 5 | var24.get(1) - 1980 << 9;
               var9.begin_hi = 0;
               if (var23) {
                  this.set_begin_of_direntry(var9, var14);
               } else if (var40) {
                  this.set_begin_of_direntry(var9, var11);
               } else {
                  var9.begin = 0;
               }

               if (var4 != null) {
                  if (this.m_vvfat.fat_type != 32) {
                     if (var4.length() > 2147483647L) {
                        debug("File " + var20.getName() + " is larger than 2GB\n", var2, var3);
                        throw new VMException(T._("Too large file in folder found"));
                     }
                  } else {
                     long var26 = 16777215L;
                     if (var4.length() >> 8 > var26) {
                        debug("File " + var20.getName() + " is larger than 4GB\n " + var4.length() + "\n", var2, var3);
                        int var28 = JOptionPane.showOptionDialog(
                           null,
                           "The File " + var20.getName() + " is larger than 4GB and wont be mapped!\nContinue?",
                           "Attention",
                           0,
                           3,
                           null,
                           this.dlg_options_large_file,
                           this.dlg_options_large_file[1]
                        );
                        if (var28 == 0) {
                           continue;
                        }

                        if (var28 == 1) {
                           throw new VMException(T._("Too large file in folder found"));
                        }
                     }
                  }
               }

               var9.size = var20.isFile() ? var4.length() : 0L;
               if (!var40 && !var23 && (var20.isDirectory() || var20.isFile() && var4.length() > 0L)) {
                  RedirectedFolder.array_t var7 = new RedirectedFolder.array_t();
                  var7.next = this.m_vvfat.mapping.lastElement().next + 1;
                  this.m_vvfat.mapping.add(var7);
                  var7.mapping = this.m_vvfat.current_mapping = new RedirectedFolder.mapping_t();
                  this.m_vvfat.current_mapping.begin = 0L;
                  if (var4 != null) {
                     this.m_vvfat.current_mapping.end = var4.length();
                  } else {
                     this.m_vvfat.current_mapping.end = 0L;
                  }

                  this.m_vvfat.current_mapping.dir_index = this.m_vvfat.directory.lastElement().next - 1;
                  this.m_vvfat.current_mapping.first_mapping_index = -1;
                  if (var20.isDirectory()) {
                     this.m_vvfat.current_mapping.mode = this.MODE_DIRECTORY;
                     this.m_vvfat.current_mapping.info.dir.parent_mapping_index = var1;
                  } else {
                     this.m_vvfat.current_mapping.mode = this.MODE_UNDEFINED;
                     this.m_vvfat.current_mapping.info.file.offset = 0L;
                     this.m_vvfat.current_mapping.info.file.size = var4.length();
                  }

                  this.m_vvfat.current_mapping.path = var10.concat("/").concat(var20.getName());
                  this.m_vvfat.current_mapping.read_only = 0;
                  this.m_vvfat.current_mapping.writing_request = false;
                  this.m_vvfat.current_mapping.file = var4;
                  this.m_vvfat.current_mapping.lock = (FileLock)var5;
               }

               if (var4 != null && this.file_not_found_except) {
                  var4.close();
               }
            }
         }

         while (this.m_vvfat.directory.size() % (this.direntry_size * this.m_vvfat.sectors_per_cluster) != 0) {
            this.m_vvfat.directory.add(new RedirectedFolder.array_t());
         }

         var8 = this.m_vvfat.mapping.get(var1).mapping;
         var11 += (this.m_vvfat.directory.size() - var8.info.dir.first_dir_index) * this.direntry_size / this.m_vvfat.cluster_size;
         debug("Mapping.end = first_cluster: " + var11 + "\n", var2, var3);
         var8.end = var11;
         RedirectedFolder.direntry_t var36 = this.m_vvfat.directory.get(var8.dir_index).direntry;
         this.set_begin_of_direntry(var36, var8.begin);
      }
   }

   public void init_fat() {
      this.m_vvfat.fat.add(new byte[4]);
      switch (this.m_vvfat.fat_type) {
         case 12:
            this.m_vvfat.max_fat_value = 4095L;
            break;
         case 16:
            this.m_vvfat.max_fat_value = 65535L;
            break;
         case 32:
            this.m_vvfat.max_fat_value = 268435455L;
            break;
         default:
            this.m_vvfat.max_fat_value = 0L;
      }
   }

   public void fat_set(long var1, long var3) {
      if (this.m_vvfat.fat.size() < var1 + 1L) {
         this.m_vvfat.fat.setSize((int)var1 + 1);
      }

      if (this.m_vvfat.fat_type == 32) {
         byte[] var5 = new byte[]{(byte)(var3 & 255L), (byte)(var3 >> 8 & 255L), (byte)(var3 >> 16 & 255L), (byte)(var3 >> 24 & 15L)};
         this.m_vvfat.fat.set((int)var1, var5);
      } else if (this.m_vvfat.fat_type == 16) {
         byte[] var6 = new byte[]{(byte)(var3 & 255L), (byte)(var3 >> 8 & 255L)};
         this.m_vvfat.fat.set((int)var1, var6);
      }
   }

   public synchronized int ReadSectors_VFat(long var1, long var3, byte[] var5) throws IOException {
      boolean var6 = false;
      boolean var7 = false;

      try {
         byte[] var11 = new byte[512];
         int var8 = 0;

         while (var8 < var3) {
            if (var1 >= this.m_vvfat.sector_count) {
               return -1;
            }

            if (var1 < this.m_vvfat.faked_sectors - 1) {
               if (var1 < this.m_vvfat.first_sectors_number) {
                  System.arraycopy(this.m_vvfat.first_sectors, (int)var1 * 512, var5, var8 * 512, 512);
               } else if (var1 - this.m_vvfat.first_sectors_number < this.m_vvfat.sectors_per_fat) {
                  byte[] var12 = null;
                  if ((var1 - this.m_vvfat.first_sectors_number) * 128L <= this.m_vvfat.fat.size()) {
                     var12 = this.m_vvfat.getFATBytes(((int)var1 - this.m_vvfat.first_sectors_number) * 128);
                  }

                  if (var12 != null) {
                     System.arraycopy(var12, 0, var5, var8 * 512, var12.length);
                  } else {
                     System.arraycopy(var11, 0, var5, var8 * 512, 512);
                  }
               } else if (var1 - this.m_vvfat.first_sectors_number - this.m_vvfat.sectors_per_fat < this.m_vvfat.sectors_per_fat) {
                  byte[] var17 = null;
                  if ((var1 - this.m_vvfat.first_sectors_number - this.m_vvfat.sectors_per_fat) * 128L <= this.m_vvfat.fat.size()) {
                     var17 = this.m_vvfat.getFATBytes(((int)var1 - this.m_vvfat.first_sectors_number - this.m_vvfat.sectors_per_fat) * 128);
                  }

                  if (var17 != null) {
                     System.arraycopy(var17, 0, var5, var8 * 512, var17.length);
                  } else {
                     System.arraycopy(var11, 0, var5, var8 * 512, 512);
                  }
               }
            } else {
               long var9;
               if (this.m_vvfat.fat_type == 32) {
                  var9 = var1 - this.m_vvfat.faked_sectors + this.m_vvfat.sectors_per_cluster * 2;
               } else {
                  var9 = var1 - this.m_vvfat.faked_sectors;
               }

               long var18 = var9 % this.m_vvfat.sectors_per_cluster;
               long var14 = var9 / this.m_vvfat.sectors_per_cluster;
               debug(
                  "Start reading Sector " + var1 + " Number of Sectors " + var3 + " Read cluster: " + var14 + " Sector in Cluster: " + var18 + "\n", var6, var7
               );
               if (this.read_cluster((int)var14) != 0) {
                  Arrays.fill(this.m_vvfat.cluster_buffer, (byte)0);
               } else {
                  debug("" + this.m_vvfat.current_mapping.path + "\n", var6, var7);
               }

               System.arraycopy(this.m_vvfat.cluster_buffer, (int)var18 * 512, var5, var8 * 512, 512);
            }

            var8++;
            var1++;
         }

         return 0;
      } catch (Exception var16) {
         var16.printStackTrace();
         return -1;
      }
   }

   private synchronized int read_cluster(int var1) throws Exception {
      boolean var2 = false;
      boolean var3 = false;
      if (this.m_vvfat.current_cluster != var1) {
         int var4 = 0;
         if (this.m_vvfat.current_mapping != null && this.m_vvfat.current_mapping.begin <= var1 && this.m_vvfat.current_mapping.end > var1) {
            if (this.m_vvfat.current_mapping.mode == this.MODE_DIRECTORY) {
               long var14 = this.m_vvfat.current_mapping.info.dir.first_dir_index;
               long var13 = (var1 - this.m_vvfat.current_mapping.begin) * this.m_vvfat.cluster_size / 32L;
               debug("Dir_Offset: " + var14 + " Cluster_Offset: " + var13 + "\n", var2, var3);
               this.m_vvfat.current_cluster = var1;
               Arrays.fill(this.m_vvfat.cluster_buffer, (byte)0);
               byte[] var15 = this.m_vvfat.getDataBytes((int)var13 + (int)var14, this.m_vvfat.cluster_size);
               System.arraycopy(var15, 0, this.m_vvfat.cluster_buffer, 0, var15.length);
               return 0;
            }
         } else {
            RedirectedFolder.mapping_t var9 = this.find_mapping_for_cluster(var1);
            if (var9 != null && var9.mode == this.MODE_DIRECTORY) {
               this.m_vvfat.current_mapping = var9;
               debug("Mapping-Element: " + this.m_vvfat.current_mapping.path + "\n", var2, var3);
               long var7 = this.m_vvfat.current_mapping.info.dir.first_dir_index;
               long var5 = (var1 - this.m_vvfat.current_mapping.begin) * this.m_vvfat.cluster_size / this.direntry_size;
               debug("Dir_Offset: " + var7 + " Cluster_Offset: " + var5 + "\n", var2, var3);
               this.m_vvfat.current_cluster = var1;
               Arrays.fill(this.m_vvfat.cluster_buffer, (byte)0);
               byte[] var10 = this.m_vvfat.getDataBytes((int)var5 + (int)var7, this.m_vvfat.cluster_size);
               System.arraycopy(var10, 0, this.m_vvfat.cluster_buffer, 0, var10.length);
               return 0;
            }

            if (!this.file_not_found_except) {
               if (var9 == null) {
                  debug("no mapping found\n", var2, var3);
                  return -2;
               }

               if (this.m_vvfat.current_mapping != null) {
                  this.m_vvfat.current_mapping = null;
               }

               this.m_vvfat.current_mapping = var9;
            } else if (this.open_file(var9) != 0) {
               debug("failed opening file / no mapping found\n", var2, var3);
               return -2;
            }
         }

         long var12 = this.m_vvfat.cluster_size * (var1 - this.m_vvfat.current_mapping.begin) + this.m_vvfat.current_mapping.info.file.offset;
         if (!this.file_not_found_except) {
            this.m_vvfat.current_fd = this.m_vvfat.current_mapping.file;
         }

         this.m_vvfat.current_fd.seek(var12);
         Arrays.fill(this.m_vvfat.cluster_buffer, (byte)0);
         this.m_vvfat.cluster = this.m_vvfat.cluster_buffer;
         var4 = this.m_vvfat.current_fd.read(this.m_vvfat.cluster, 0, this.m_vvfat.cluster_size);
         if (var4 < 0) {
            this.m_vvfat.current_cluster = -1L;
            return -1;
         }

         this.m_vvfat.current_cluster = var1;
      }

      return 0;
   }

   public long cluster2sector(long var1) {
      return var1 >= 2L ? this.m_vvfat.faked_sectors + this.m_vvfat.sectors_per_cluster * (this.m_vvfat.fat_type == 32 ? var1 - 2L : var1) : 0L;
   }

   public long sector2cluster(long var1) {
      long var3;
      if (var1 < this.m_vvfat.faked_sectors) {
         var3 = 0L;
      } else {
         var3 = (var1 - this.m_vvfat.faked_sectors + 2 * this.m_vvfat.sectors_per_cluster) / this.m_vvfat.sectors_per_cluster;
      }

      return var3;
   }

   public synchronized boolean modify_fat(byte[] var1, long var2, long var4, long var6) {
      boolean var8 = false;
      boolean var9 = false;
      byte[] var10 = new byte[512];
      byte[] var11 = new byte[512];
      Object var12 = null;
      int var13 = 0;
      int var14 = 0;
      boolean var15 = false;

      while (var2 < var4 + var6 && this.sector2cluster(var4) == 0L) {
         if (var2 > this.m_vvfat.first_sectors_number + 2 * this.m_vvfat.sectors_per_fat) {
            debug("Breaked FAT-Research\n", var8, var9);
            break;
         }

         if (var2 == 0L) {
            debug("\nMBR at sector: " + var2 + "\n", var8, var9);
            System.arraycopy(var1, (int)(var2 - var4) * 512, var11, 0, 512);
            if (!Arrays.equals(var10, new byte[512])) {
               this.print_data_buffer(var11, false);
            }
         }

         if (var2 >= this.m_vvfat.first_sectors_number && var2 < this.m_vvfat.first_sectors_number + 2 * this.m_vvfat.sectors_per_fat) {
            System.arraycopy(var1, (int)(var2 - var4) * 512, var10, 0, 512);
            if (!Arrays.equals(var10, new byte[512])) {
               var14 = var2 >= this.m_vvfat.first_sectors_number + this.m_vvfat.sectors_per_fat
                  ? (int)var2 - this.m_vvfat.first_sectors_number - this.m_vvfat.sectors_per_fat
                  : (int)var2 - this.m_vvfat.first_sectors_number;
               debug("\nFAT at sector: " + var2 + "\n", var8, var9);

               for (byte var16 = 0; var16 < 512; var16 += 4) {
                  byte[] var17 = new byte[4];
                  System.arraycopy(var10, var16, var17, 0, 4);
                  int var18 = var17[0] & 255 | var17[1] << 8 & 0xFF00 | var17[2] << 16 & 0xFF0000 | var17[3] << 24 & 0xFF000000;
                  if (var18 != 0) {
                     debug("Offset: " + var14 + " ", var8, var9);
                     if (var16 != 0 && var16 != 4
                        || var2 != this.m_vvfat.first_sectors_number && var2 != this.m_vvfat.first_sectors_number + this.m_vvfat.sectors_per_fat) {
                        if (var18 == 268435455) {
                           debug(
                              "End-Marker found for Cluster: "
                                 + (var16 / 4 + (var14 >= this.m_vvfat.sectors_per_fat ? var14 - this.m_vvfat.sectors_per_fat : var14) * 128)
                                 + "\n",
                              var8,
                              var9
                           );
                        } else {
                           debug(
                              "Cluster "
                                 + (var16 / 4 + (var14 >= this.m_vvfat.sectors_per_fat ? var14 - this.m_vvfat.sectors_per_fat : var14) * 128)
                                 + "->"
                                 + var18
                                 + "\n",
                              var8,
                              var9
                           );
                        }
                     } else {
                        debug("Reserved\n", var8, var9);
                     }

                     var13 = 0;
                     var12 = null;
                     if (var16 / 4 + var14 * 128 < this.m_vvfat.fat.size()) {
                        try {
                           var12 = this.m_vvfat.fat.get(var16 / 4 + var14 * 128);
                           if (var12 != null) {
                              var13 = ((Object[])var12)[0] & 255
                                 | ((Object[])var12)[1] << 8 & 0xFF00
                                 | ((Object[])var12)[2] << 16 & 0xFF0000
                                 | ((Object[])var12)[3] << 24 & 0xFF000000;
                           }
                        } catch (Exception var22) {
                           var22.printStackTrace();
                        }

                        debug("Old Value: 0x" + Integer.toHexString(var13) + "\n", var8, var9);
                     } else {
                        debug("No Value Old Value\n", var8, var9);
                     }

                     if (var18 == var13) {
                        debug("SAME VALUES: 0x" + Integer.toHexString(var13) + " = 0x" + Integer.toHexString(var18) + "\n", var8, var9);
                     } else if (var14 != 0 || var16 > 8) {
                        debug("AT THIS POINT THE FAT HAS BEEN MODIFIED \n", var8, var9);
                        debug("Write new FAT-Value: 0x" + Integer.toHexString(var18) + " at: " + (var16 / 4 + var14 * 128) + "\n", var8, var9);
                        this.fat_set(var16 / 4 + var14 * 128, var18);

                        try {
                           RedirectedFolder.mapping_t var19 = this.find_mapping_for_cluster(var16 / 4 + var14 * 128);
                           if (var19 != null) {
                              debug("FAT changed --> Write data for mapping: " + var19.path + "\n", true, true);
                              if (!var19.writing_request) {
                                 var19.writing_request = true;
                              }
                           }
                        } catch (Exception var21) {
                           var21.printStackTrace();
                        }

                        var15 = true;
                     }
                  } else {
                     debug("No FAT-Data --> Set NULL\n", var8, var9);

                     try {
                        if (var16 / 4 + var14 * 128 < this.m_vvfat.fat.size()) {
                           this.m_vvfat.fat.set(var16 / 4 + var14 * 128, null);
                        }
                     } catch (Exception var20) {
                        var20.printStackTrace();
                     }
                  }

                  debug("\n", var8, var9);
               }
            }
         }

         var2++;
      }

      return var15;
   }

   public synchronized void insert_mapping(RedirectedFolder.array_t var1, RedirectedFolder.mapping_t var2) {
      System.out.println("insert_mapping");
      boolean var3 = false;
      boolean var4 = false;
      debug("insert mapping\n", true, true);
      RedirectedFolder.array_t var6 = new RedirectedFolder.array_t();
      var6.mapping = var2;

      try {
         int var5 = this.find_mapping_for_cluster_aux(var1.direntry.begin_hi << 16 & -65536 | var1.direntry.begin & 65535, 0, this.m_vvfat.mapping.size());
         if (var5 > 0) {
            if (var5 > this.m_vvfat.mapping.size() - 1) {
               var6.next = this.m_vvfat.mapping.lastElement().next + 1;
               debug("Add Mapping at the End\n", var3, var4);
               this.m_vvfat.mapping.add(var6);
            } else {
               debug(".next for actual = " + this.m_vvfat.mapping.get(var5 - 1).next + "\n", true, true);
               var6.next = this.m_vvfat.mapping.get(var5 - 1).next + 1;
               debug("Add Mapping at Position: " + var5 + "\n", var3, var4);
               this.m_vvfat.mapping.add(var5, var6);

               for (int var7 = var6.next; var7 < this.m_vvfat.mapping.size(); var7++) {
                  this.m_vvfat.mapping.get(var7).next++;
               }
            }
         } else if (var5 == 0) {
            var6.next = 1;
            this.m_vvfat.mapping.add(var6);
         }
      } catch (Exception var8) {
         var8.printStackTrace();
         debug("Error inserting mapping " + var8 + "\n", var3, var4);
      }
   }

   public synchronized long handle_incoming_data(byte[] var1, long var2, long var4, long var6, boolean var8) {
      System.out.println("handle_incoming_data");
      boolean var9 = false;
      boolean var10 = false;

      try {
         byte[] var13 = new byte[512];
         RedirectedFolder.commit_t var14 = null;
         boolean var15 = false;

         for (long var11 = var2; var11 < (int)var2 + (int)var6; var11++) {
            debug("look up for mapping for sector: " + var11 + "\n", var9, var10);
            var15 = false;
            RedirectedFolder.mapping_t var16 = this.find_mapping_for_cluster(this.sector2cluster(var11));
            System.arraycopy(var1, (int)(var11 - var2) * 512, var13, 0, 512);
            if (var16 == null) {
               debug("Really no Mapping for Sector: " + var11 + "\n", var9, var10);
            } else {
               debug("Sector: " + var11 + " is a part of Mapping" + var16.path + " !!!!!\n--> Prepare Commits \n", var9, var10);
               if (var16.mode == this.MODE_DIRECTORY) {
                  var15 = true;
               }
            }

            if (Arrays.equals(var13, new byte[512])) {
               debug("Zeros --> don't store\n", var9, var10);
            } else {
               debug("Data found ==> Store?? \n", var9, var10);
               if (var16 != null && !var16.writing_request) {
                  debug("Re-Enable Writing for: " + var16.path + "\n", var9, var10);
                  var16.writing_request = true;
               }

               var14 = new RedirectedFolder.commit_t();
               var14.data = new byte[512];
               System.arraycopy(var13, 0, var14.data, 0, 512);
               var14.sector = var11;
               var14.direntry_data = var15;
               this.print_data_buffer(var13, false);
               this.all_commits.add(var14);
               debug("Store Data for Sector: " + var11 + "\n", var9, var10);
               debug("LastElement of Commit-Vector: " + this.all_commits.indexOf(this.all_commits.lastElement()) + "\n", var9, var10);
               var4 += (var11 - var2) / this.m_vvfat.sectors_per_cluster;
               debug("\n", var9, var10);
            }
         }

         return var4;
      } catch (Exception var17) {
         debug("Error in data-handling\n", var9, var10);
         var17.printStackTrace();
         return var4;
      }
   }

   public synchronized int commit_data(RedirectedFolder.mapping_t var1) throws Exception {
      boolean var2 = true;
      boolean var3 = true;
      long var4 = 0L;
      byte var6 = 0;
      byte[] var7 = new byte[512];
      if (var1.cluster_chain == null || this.m_vvfat.modified_FAT) {
         var1.cluster_chain = this.get_cluster_chain(var1);
      }

      if (var1.cluster_chain == null) {
         debug("could not complete cluster-chain --> FAT-DATA is not complete\n", var2, var3);
         return -1;
      } else {
         debug("" + var1.path + " is split up in clusters: \n", var2, var3);
         byte[] var8 = new byte[this.m_vvfat.sectors_per_cluster * 512];
         byte[] var9 = null;
         if (var1.mode == this.MODE_DIRECTORY) {
            var9 = new byte[var1.info.dir.cluster_num * this.m_vvfat.sectors_per_cluster * 512];
         }

         for (int var10 = 0; var1.cluster_chain != null && var1.cluster_chain[var10] != 0L && var10 < var1.cluster_chain.length; var10++) {
            boolean var11 = false;
            if (var1.cluster_chain[var10] != -1L) {
               try {
                  this.m_vvfat.image.seek(this.cluster2sector(var1.cluster_chain[var10]) * 512L);
                  if (this.cluster2sector(var1.cluster_chain[var10]) * 512L + this.m_vvfat.sectors_per_cluster * 512 > this.m_vvfat.image.length()) {
                     debug("Just copy Part\n", var2, var3);
                     this.m_vvfat.image.readFully(var8, 0, (int)(this.m_vvfat.image.length() - this.cluster2sector(var1.cluster_chain[var10]) * 512L));
                     this.print_data_buffer(var8, true);
                  } else {
                     debug("copy complete\n", var2, var3);
                     this.m_vvfat.image.readFully(var8, 0, this.m_vvfat.sectors_per_cluster * 512);
                  }

                  if (Arrays.equals(var8, new byte[this.m_vvfat.sectors_per_cluster * 512])) {
                     continue;
                  }
               } catch (Exception var14) {
                  debug("Error in Reading Temp-Image: " + var14 + " --> commit later\n", var2, var3);
                  return -2;
               }

               if (var1.mode == this.MODE_DIRECTORY) {
                  System.arraycopy(var8, 0, var9, var10 * this.m_vvfat.sectors_per_cluster * 512, this.m_vvfat.sectors_per_cluster * 512);
               } else if (var1.mode == this.MODE_NORMAL) {
                  var4 = var1.cluster_chain[var10] - var1.begin;
                  if (var1.file == null) {
                     File var12 = new File(var1.path);
                     var1.file = new RandomAccessFile(var12, "rw");
                  }

                  try {
                     if (var4 * this.m_vvfat.sectors_per_cluster * 512L > var1.info.file.size) {
                        debug("Position out of file-bounds (too large)\n", true, false);
                        break;
                     }

                     if (var4 * this.m_vvfat.sectors_per_cluster * 512L < 0L) {
                        debug("Position out of file-bounds (negativ)\n", true, false);
                        continue;
                     }

                     if (var4 * this.m_vvfat.sectors_per_cluster * 512L <= var1.info.file.size
                        && (var4 + 1L) * this.m_vvfat.sectors_per_cluster * 512L > var1.info.file.size) {
                        debug("Last data to write (" + ((int)var1.info.file.size - (int)var4 * 512) + ") Bytes\n", var2, var3);

                        for (int var17 = 0; var17 < this.m_vvfat.sectors_per_cluster; var17++) {
                           System.arraycopy(var8, var17 * 512, var7, 0, 512);
                           if (!Arrays.equals(var7, new byte[512])) {
                              debug("Seek to: " + (var4 * this.m_vvfat.sectors_per_cluster + var17) * 512L + "\n", var2, var3);
                              var1.file.seek((var4 * this.m_vvfat.sectors_per_cluster + var17) * 512L);
                              if ((int)var1.info.file.size - ((int)var4 * this.m_vvfat.sectors_per_cluster + var17) * 512 >= 512) {
                                 var1.file.write(var7, 0, 512);
                              } else {
                                 var1.file.write(var7, 0, (int)var1.info.file.size - ((int)var4 * this.m_vvfat.sectors_per_cluster + var17) * 512);
                              }
                           } else {
                              var11 = true;
                           }
                        }

                        var1.writing_request = false;
                        var1.file.close();
                     } else {
                        for (int var16 = 0; var16 < this.m_vvfat.sectors_per_cluster; var16++) {
                           System.arraycopy(var8, var16 * 512, var7, 0, 512);
                           if (!Arrays.equals(var7, new byte[512])) {
                              var1.file.seek((var4 * this.m_vvfat.sectors_per_cluster + var16) * 512L);
                              var1.file.write(var7, 0, 512);
                           } else {
                              var11 = true;
                           }
                        }
                     }

                     if (!var11) {
                        var1.cluster_chain[var10] = -1L;
                     }
                  } catch (Exception var13) {
                     debug("Error in Writing to File: " + var13 + "\n", var2, var3);
                     var13.printStackTrace();
                  }
               }

               Arrays.fill(var8, (byte)0);
            }
         }

         if (var1.mode == this.MODE_DIRECTORY) {
            debug("Found Mapping for Directory: " + var1.path + "\n", var2, var3);
            this.parse_direntries(var9, var1);
            var1.writing_request = false;
         } else if (var1.mode == this.MODE_NORMAL) {
            debug("Found Mapping for File: " + var1.path + "\n", var2, var3);
         }

         return var6;
      }
   }

   public synchronized long[] get_cluster_chain(RedirectedFolder.mapping_t var1) {
      System.out.println("get_cluster_chain");
      boolean var2 = true;
      boolean var3 = false;

      try {
         var1.cluster_chain = var1.mode == this.MODE_NORMAL
            ? new long[(int)var1.info.file.size / (this.m_vvfat.sectors_per_cluster * 512) + 2]
            : new long[10000];
         Object var4 = null;
         int var5 = 0;
         int var6 = (int)var1.begin;
         if (this.m_vvfat.fat.size() <= var1.begin) {
            debug(
               "No Cluster allocated yet for this mapping --> FAT is incomplete\nFAT-Size: "
                  + this.m_vvfat.fat.size()
                  + "-1 mapping.begin: "
                  + var1.begin
                  + "\n",
               var2,
               var3
            );
            return null;
         } else {
            var4 = this.m_vvfat.fat.get((int)var1.begin);
            if (var4 == null) {
               debug("No FAT-ENTRY for this Mapping \n", var2, var3);
               debug(
                  "No Cluster allocated yet for this mapping --> FAT is incomplete\nFAT-Size: "
                     + this.m_vvfat.fat.size()
                     + "-1 mapping.begin: "
                     + var1.begin
                     + "\n",
                  var2,
                  var3
               );
               return null;
            } else {
               var1.cluster_chain[var5] = var1.begin;
               debug("Cluster_count: " + (var5 + 1) + " fat-begin (cluster): " + var1.begin + "\n", var2, var3);

               while (var6 != 268435455 && var4 != null) {
                  try {
                     if (var6 > this.m_vvfat.fat.size()) {
                        debug("FAT not complete yet", var2, var3);
                        return null;
                     }

                     var4 = this.m_vvfat.fat.get(var6);
                  } catch (Exception var8) {
                     debug("Could not get FAT-Value: " + var8 + "\n", var2, var3);
                     debug(
                        "No Cluster allocated yet for this mapping --> FAT is incomplete\nFAT-Size: "
                           + this.m_vvfat.fat.size()
                           + "-1 mapping.begin: "
                           + var1.begin
                           + "\n",
                        var2,
                        var3
                     );
                     return null;
                  }

                  var6 = ((Object[])var4)[0] & 255
                     | ((Object[])var4)[1] << 8 & 0xFF00
                     | ((Object[])var4)[2] << 16 & 0xFF0000
                     | ((Object[])var4)[3] << 24 & 0xFF000000;
                  debug("Cluster_count: " + (var5 + 1) + (var6 != 268435455 ? " index for next fat: " + var6 : " last cluster ") + "\n", var2, var3);
                  var5++;
                  if (var6 != 268435455) {
                     if (var6 > var1.end) {
                        var1.exceeds_mapping_bounds = true;
                     }

                     var1.cluster_chain[var5] = var6;
                  }
               }

               var1.info.dir.cluster_num = var5;
               return var1.cluster_chain;
            }
         }
      } catch (Exception var9) {
         debug("" + var9 + "\n", var2, var3);
         var9.printStackTrace();
         return null;
      }
   }

   public synchronized RedirectedFolder.mapping_t create_mapping(
      RedirectedFolder.direntry_t var1, RedirectedFolder.mapping_t var2, RedirectedFolder.file_name var3
   ) throws Exception {
      System.out.println("create_mapping");
      boolean var4 = true;
      boolean var5 = true;
      RedirectedFolder.mapping_t var6 = new RedirectedFolder.mapping_t();
      RandomAccessFile var7 = null;
      String var8 = new String(var3.name, 0, var3.len);
      var6.info.file.size = var1.size;
      var6.info.dir.parent_mapping_index = var2.dir_index;
      var6.begin = var1.begin_hi << 16 & -65536 | var1.begin & 65535;
      var6.writing_request = true;
      debug("direntry.attributes: " + var1.attributes + "\n", var4, var5);
      if ((var1.attributes & 16) != 0) {
         debug("Create Directory\n", var4, var5);
         File var9 = new File(var2.path.concat("/").concat(var8));
         var9.mkdir();
         var6.mode = this.MODE_DIRECTORY;
         int var10 = this.m_vvfat.directory.size();

         while (var10 % (this.m_vvfat.fat_type * this.m_vvfat.sectors_per_cluster) != 0) {
            var10++;
         }

         var6.info.dir.first_dir_index = var10;
         var6.end = var6.begin + 1L + 1 / this.m_vvfat.sectors_per_cluster;
      } else if ((var1.attributes & 32) != 0) {
         if (var1.size == 0L && (var1.begin_hi << 16 & -65536 | var1.begin & 65535) == 0) {
            debug("No valid File can be created\n", var4, var5);
            return null;
         }

         debug("Create File\n", var4, var5);
         File var12 = new File(var2.path.concat("/").concat(var8));

         try {
            var7 = new RandomAccessFile(var12, "rw");
            var7.setLength(var6.info.file.size);
            if (var7 == null) {
               debug("Error creating the file !?!?!?!\n", var4, var5);
            }
         } catch (Exception var11) {
            var11.printStackTrace();
         }

         var6.mode = this.MODE_NORMAL;
         var6.end = var6.begin + 1L + (var6.info.file.size - 1L) / this.m_vvfat.cluster_size;
      }

      debug(
         "\nCreating a Mapping for: "
            + var8
            + "\n"
            + "in Directory: "
            + var2.path
            + "\n"
            + "with filesize: "
            + var6.info.file.size
            + "\n"
            + "in Cluster (begin): "
            + var6.begin
            + " (end): "
            + var6.end
            + "\n"
            + "Startsector: "
            + this.cluster2sector(var6.begin)
            + " Endsector: "
            + this.cluster2sector(var6.end)
            + "\n",
         var4,
         var5
      );
      var6.file = var7;
      var6.path = var2.path.concat("/").concat(var8);
      RedirectedFolder.mapping_t var13 = this.find_mapping_for_cluster(var6.begin);
      if (var13 != null) {
         debug("There is a mapping: " + var13.path + " for cluster: " + var6.begin + " ABORT CREATION\n", var4, var5);
         if (var6.info.file.size > 0L) {
            debug("Adjust Mapping\n", var4, var5);
            return var6;
         } else {
            debug("Don't create Mapping\n", var4, var5);
            return null;
         }
      } else {
         return var6;
      }
   }

   public void commit_to_image() throws IOException {
      boolean var1 = false;
      boolean var2 = false;
      debug("Commit data to Image\n", var1, var2);
      long var3 = 0L;

      for (int var5 = 0; var5 < this.all_commits.size(); var5++) {
         var3 = this.all_commits.get(var5).sector;
         debug("Image-File-Length: " + this.m_vvfat.image.length() + " " + var3 * 512L + "\n", var1, var2);
         if (this.m_vvfat.image.length() < var3 * 512L) {
            debug(
               "Adjust Image Size: sector_to_write = " + var3 + " m_vvfat.faked_sectors = " + this.m_vvfat.faked_sectors + " --> size = " + var3 * 512L + "\n",
               var1,
               var2
            );
            this.m_vvfat.image.setLength(var3 * 512L);
         }

         this.m_vvfat.image.seek(var3 * 512L);
         this.m_vvfat.image.write(this.all_commits.get(var5).data, 0, 512);
      }

      this.all_commits.clear();
   }

   public int parse_direntries(byte[] var1, RedirectedFolder.mapping_t var2) throws Exception {
      boolean var3 = true;
      boolean var4 = true;
      RedirectedFolder.file_name var5 = new RedirectedFolder.file_name();
      RedirectedFolder.file_name var6 = new RedirectedFolder.file_name();
      this.fn_init(var5);
      this.fn_init(var6);
      byte[] var7 = new byte[32];
      boolean var10 = false;
      RedirectedFolder.array_t var12 = null;

      for (int var9 = 0; var9 < var1.length / 512 * 16; var9++) {
         System.arraycopy(var1, var9 * this.direntry_size, var7, 0, this.direntry_size);
         RedirectedFolder.direntry_t var8 = this.getDirEntry(var7);
         if (this.parse_long_name(var5, var7) < 0) {
            debug("Warning: non-ASCII filename\n", var3, var4);
            return -1;
         }

         if (this.parse_short_name(var6, var8) < 0) {
            debug("Warning: Error in Short-Name\n", var3, var4);
            return -1;
         }

         if (this.is_short_name(var8) && (var8.attributes & 1) != 0) {
            if (var8.equals(null)) {
               debug("Warning: tried to write to write-protected file\n", var3, var4);
               return -1;
            }

            Arrays.fill(var7, (byte)0);
         }

         if (var9 + var2.info.dir.first_dir_index < this.m_vvfat.directory.size()) {
            var12 = this.m_vvfat.directory.get(var9 + var2.info.dir.first_dir_index);
            if (var12 == null) {
               debug("Entry doesnt exist --> insert new one \n", true, false);
               var12 = new RedirectedFolder.array_t();
               var12.direntry = new RedirectedFolder.direntry_t();
            }
         } else {
            debug("Entry doesnt exist --> add new one \n", true, false);
            var12 = new RedirectedFolder.array_t();
            var12.direntry = new RedirectedFolder.direntry_t();
            this.m_vvfat.directory.add(var12);
         }

         if (this.is_long_name(var8) != 0) {
            if (var7[0] == -27) {
               try {
                  debug("delete / deleted direntry\n", var3, var4);
                  var12.direntry = null;
                  var12.fatdata = new byte[32];
                  this.m_vvfat.directory.set(var9 + var2.info.dir.first_dir_index, null);
                  var10 = false;
               } catch (Exception var20) {
                  var20.printStackTrace();
                  debug("Error in direntry deletion\n", var3, var4);
               }
            } else if (var12.direntry == null && var12.fatdata == null) {
               this.print_data_buffer(var7, true);
               debug("" + new String(var7) + "\t\t--> Long Entry" + " new \n", var3, var4);
               debug("" + new String(var5.name, 0, var5.len) + "\n", var3, var4);
               var12.fatdata = var7;
               var10 = true;
               debug("Set Direntry @: " + var9 + " " + var2.info.dir.first_dir_index + "\n", var3, var4);

               try {
                  if (this.m_vvfat.directory.size() < var9 + var2.info.dir.first_dir_index) {
                     this.m_vvfat.directory.setSize(var9 + var2.info.dir.first_dir_index);
                  }

                  this.m_vvfat.directory.set(var9 + var2.info.dir.first_dir_index, var12);
               } catch (Exception var19) {
                  var19.printStackTrace();
               }
            } else if (!Arrays.equals(var7, var12.fatdata) && !Arrays.equals(var7, var12.direntry != null ? var12.direntry.getDirBytes() : null)) {
               debug("" + new String(var7) + "\t\t--> Long Entry" + " changed\n", var3, var4);
               debug("" + new String(var5.name, 0, var5.len) + "\n", var3, var4);
               var10 = true;
            } else {
               this.print_data_buffer(var7, true);
               debug("" + new String(var7) + "\t\t--> Long Entry" + " exists\n", var3, var4);
               debug("" + new String(var5.name, 0, var5.len) + "\n", var3, var4);
            }
         } else if (this.is_short_name(var8)) {
            if ((var12.direntry != null || var12.fatdata != null) && Arrays.equals(var7, var12.direntry.getDirBytes())) {
               if (Arrays.equals(var7, var12.fatdata) || Arrays.equals(var7, var12.direntry.getDirBytes())) {
                  debug("" + new String(var7) + "\t\t--> Short Entry" + " exits\n", var3, var4);
                  debug("" + new String(var6.name, 0, var6.len) + "\n", var3, var4);
                  var10 = false;
               }
            } else {
               debug("" + new String(var7) + "\t\t--> Short Entry" + " new\n", var3, var4);
               debug("" + new String(var6.name, 0, var6.len) + "\n", var3, var4);
               var12.direntry = var8;

               try {
                  RedirectedFolder.mapping_t var11 = this.create_mapping(var8, var2, var10 ? var5 : var6);
                  if (var11 != null) {
                     debug("Commit File with " + var11.info.file.size + " Bytes\n", var3, var4);
                     if (var11.mode == this.MODE_NORMAL) {
                        debug("Commit-Data\n", var3, var4);
                        this.commit_data(var11);
                     } else if (var11.mode == this.MODE_DIRECTORY) {
                        debug("\n Directory Handling\n\n", var3, var4);
                     }

                     this.insert_mapping(var12, var11);
                     debug("\nRemaining Commit-Vector-Length = " + this.all_commits.size() + "\n", var3, var4);
                     var10 = false;
                     debug("Set Direntry @: " + var9 + " " + var2.info.dir.first_dir_index + "\n", var3, var4);

                     try {
                        if (this.m_vvfat.directory.size() < var9 + var2.info.dir.first_dir_index) {
                           this.m_vvfat.directory.setSize(var9 + var2.info.dir.first_dir_index);
                        }

                        this.m_vvfat.directory.set(var9 + var2.info.dir.first_dir_index, var12);
                     } catch (Exception var17) {
                        var17.printStackTrace();
                     }
                  } else {
                     debug("Mapping-Creation failed \n", var3, var4);
                  }
               } catch (Exception var18) {
                  debug("" + var18 + "\n", var3, var4);
                  var18.printStackTrace();
               }
            }
         } else if (!this.is_short_name(var8) && this.is_long_name(var8) == 0 && !this.is_free(var8)) {
            if (this.is_volume_label(var8)) {
               debug("Volumelabel: " + new String(var7) + "\n", var3, var4);
            } else if (var7[0] == -27) {
               if (var12.direntry != null) {
                  try {
                     debug("delete direntry - Search in Boundaries of Mapping Vector: 0-" + this.m_vvfat.mapping.size() + "\n", var3, var4);
                     int var13 = this.find_mapping_for_cluster_aux(
                        var12.direntry.begin_hi << 16 & -65536 | var12.direntry.begin & 65535, 0, this.m_vvfat.mapping.size()
                     );
                     RedirectedFolder.mapping_t var14 = this.find_mapping_for_cluster(var12.direntry.begin_hi << 16 & -65536 | var12.direntry.begin & 65535);
                     if (var14 != null) {
                        File var15 = new File(var14.path);
                        var15.delete();
                        debug("delete mapping\n", var3, var4);
                        this.m_vvfat.mapping.remove(var13);
                     }

                     this.m_vvfat.directory.set(var9 + var2.info.dir.first_dir_index, null);
                  } catch (Exception var16) {
                     var16.printStackTrace();
                  }
               } else {
                  debug("Already deleted\n", var3, var4);
               }
            } else {
               debug("Error !! undefined data: " + var9 + " " + new String(var7) + "\n", var3, var4);
            }
         }

         Arrays.fill(var7, (byte)0);
      }

      debug("end MODE_DIRECTORY\n", var3, var4);
      debug("Remaining Mappings: " + this.m_vvfat.mapping.size() + "\n", var3, var4);
      return 0;
   }

   public synchronized int WriteSectors_VFat(long var1, long var3, byte[] var5) {
      System.out.println("WriteSectors_VFat");
      boolean var6 = true;
      boolean var7 = true;

      try {
         long var8 = 0L;
         RedirectedFolder.mapping_t var12 = null;
         debug(
            "\n=========================================\n|  Write "
               + var3
               + " sectors beginning from "
               + var1
               + "  |"
               + "\n=========================================\n\n",
            var6,
            var7
         );
         if (var1 < this.m_vvfat.first_sectors_number + 2 * this.m_vvfat.sectors_per_fat) {
            this.m_vvfat.modified_FAT = this.modify_fat(var5, var1, var1, var3);
            this.handle_incoming_data(var5, var1, var8, var3, false);
            this.commit_to_image();
         }

         var8 = this.sector2cluster(var1);

         while (var8 <= this.sector2cluster(var1 + var3 - 1L)) {
            debug(
               "Cluster " + var8 + " Sector: " + var1 + " Number of Sectors: " + var3 + " Cluster2Sector(i): " + this.cluster2sector(var8) + "\n", var6, var7
            );
            debug("Look up Mapping for Write-Request (find_mapping_for_cluster(" + var8 + "))\n\n", var6, var7);
            var12 = this.find_mapping_for_cluster(var8);
            if (var12 == null) {
               debug("No mapping\n", var6, var7);
            } else {
               debug("Changes in File or Direntry: " + ((RedirectedFolder.mapping_t)var12).path + "\n", var6, var7);
            }

            var8 = this.handle_incoming_data(var5, var1, var8, var3, true);
            var8++;
            this.commit_to_image();
            Runtime var13 = Runtime.getRuntime();
            debug("Total Memory = " + var13.totalMemory() + " Free Memory = " + var13.freeMemory(), var6, true);
         }

         debug("Mapping - Vector contains " + this.m_vvfat.mapping.size() + " mappings\n", var6, var7);

         for (int var25 = 0; var25 < this.m_vvfat.mapping.size(); var25++) {
            var12 = this.m_vvfat.mapping.get(var25).mapping;
            if (var12 == null) {
               debug("No Mapping found!\n", var6, var7);
            } else {
               debug(
                  "Mapping: "
                     + var12.path
                     + " found "
                     + (var12.writing_request ? "--> should be written" : "--> do not to touch (no writing requested)")
                     + "\n",
                  var6,
                  var7
               );
            }

            if (var12.writing_request) {
               debug("" + var12.path + " is split up in clusters: \n", false, false);
               byte[] var14 = new byte[this.m_vvfat.sectors_per_cluster * 512];
               if (var12.mode != this.MODE_DIRECTORY) {
                  if (var12.mode == this.MODE_NORMAL) {
                     debug("Found Mapping for FILE: " + var12.path + " --> commit data\n", var6, var7);
                     this.commit_data(var12);
                  }
               } else {
                  debug("Found Mapping for DIRECTORY: " + var12.path + "\n", var6, var7);
                  if (var12.cluster_chain == null || this.m_vvfat.modified_FAT) {
                     debug("get cluster-chain!\n", var6, var7);
                     var12.cluster_chain = this.get_cluster_chain(var12);
                  }

                  if (var12.cluster_chain == null) {
                     debug("could not complete cluster-chain --> FAT-DATA is not complete\n", var6, var7);
                     this.m_vvfat.modified_FAT = false;
                  } else {
                     byte[] var15 = new byte[var12.info.dir.cluster_num * this.m_vvfat.sectors_per_cluster * 512];
                     debug("Alloc Buffer for " + var12.info.dir.cluster_num + " Clusters\n", var6, var7);

                     for (int var16 = 0;
                        var12.cluster_chain != null && var12.cluster_chain[var16] != 0L && (var12.cluster_chain[var16] & 268435455L) != 268435455L;
                        var16++
                     ) {
                        if (var12.exceeds_mapping_bounds && var12.cluster_chain[var16] > var12.end) {
                           RedirectedFolder.mapping_t var17 = this.find_mapping_for_cluster(var12.cluster_chain[var16]);
                           if (var17 == null) {
                              var17 = new RedirectedFolder.mapping_t();
                              RedirectedFolder.array_t var18 = new RedirectedFolder.array_t();
                              var18.direntry = new RedirectedFolder.direntry_t();
                              var17.begin = var17.end = var12.cluster_chain[var16];
                              var17.path = var12.path;
                              var17.cluster_chain = var12.cluster_chain;
                              var17.mode = this.MODE_DIRECTORY;
                              var17.info = var12.info;
                              this.set_begin_of_direntry(var18.direntry, var12.cluster_chain[var16]);
                              var18.direntry.attributes = 16;
                              var17.writing_request = true;
                              this.insert_mapping(var18, var17);
                           }
                        }

                        debug("Cluster: " + var12.cluster_chain[var16] + "\n", var6, var7);

                        try {
                           debug("Offset in Image: " + this.cluster2sector(var12.cluster_chain[var16]) * 512L + "\n", var6, var7);
                           this.m_vvfat.image.seek(this.cluster2sector(var12.cluster_chain[var16]) * 512L);
                           if (this.cluster2sector(var12.cluster_chain[var16]) * 512L + this.m_vvfat.sectors_per_cluster * 512 > this.m_vvfat.image.length()) {
                              debug("Just copy Part\n", var6, var7);
                              this.m_vvfat
                                 .image
                                 .readFully(var14, 0, (int)(this.m_vvfat.image.length() - this.cluster2sector(var12.cluster_chain[var16]) * 512L));
                           } else {
                              debug("copy complete\n", var6, var7);
                              this.m_vvfat.image.readFully(var14, 0, this.m_vvfat.sectors_per_cluster * 512);
                           }
                        } catch (Exception var19) {
                           debug("Error in reading cluster from file: " + this.cluster2sector(var12.cluster_chain[var16]) * 512L + "\n", var6, var7);
                        }

                        debug("" + var14.length + " " + var15.length + "\n", false, false);
                        System.arraycopy(var14, 0, var15, var16 * this.m_vvfat.sectors_per_cluster * 512, this.m_vvfat.sectors_per_cluster * 512);
                        Arrays.fill(var14, (byte)0);
                     }

                     this.parse_direntries(var15, var12);
                     var12.writing_request = false;
                  }
               }
            }
         }

         return 0;
      } catch (Exception var20) {
         debug(" Fehler in \"WriteSectors_VVFAT\"\n", var6, var7);
         var20.printStackTrace();
         return -1;
      }
   }

   public int parse_long_name(RedirectedFolder.file_name var1, byte[] var2) {
      try {
         if (var2[11] != 15) {
            return 1;
         } else {
            if ((var2[0] & 64) != 0) {
               var1.sequence_number = var2[0] & 63;
               var1.checksum = var2[13];
               var1.name[0] = 0;
            } else {
               if ((var2[0] & 63) != --var1.sequence_number) {
                  debug("return -1 ", false, false);
                  return -1;
               }

               if (var2[13] != var1.checksum) {
                  debug("return -2 ", false, false);
                  return -2;
               }

               if (var2[12] != 0 || var2[26] != 0 || var2[27] != 0) {
                  debug("return -3 ", false, false);
                  return -3;
               }
            }

            int var5 = 13 * (var1.sequence_number - 1);
            int var6 = 0;
            int var3 = 0;

            for (int var4 = 1; var3 < 13; var4 += 2) {
               if (var4 == 11) {
                  var4 = 14;
               } else if (var4 == 26) {
                  var4 = 28;
               }

               if (var2[var4 + 1] == 0) {
                  var1.name[var5 + var3] = (char)var2[var4];
                  var6++;
               } else {
                  if (var2[var4 + 1] != -1 || (var2[0] & 64) == 0) {
                     debug("return -4 @j: " + var4 + " ", false, false);
                     return -4;
                  }

                  var1.name[var5 + var3] = 0;
               }

               var3++;
            }

            if ((var2[0] & 64) != 0) {
               var1.len = var5 + var6 - 1;
            }

            return 0;
         }
      } catch (Exception var7) {
         var7.printStackTrace();
         return -1;
      }
   }

   public int parse_short_name(RedirectedFolder.file_name var1, RedirectedFolder.direntry_t var2) {
      char[] var5 = new String(var2.name).toLowerCase().toCharArray();
      char[] var6 = new String(var2.extension).toLowerCase().toCharArray();
      var1.len = 0;
      if (!this.is_short_name(var2)) {
         return 1;
      } else {
         int var4 = 7;

         while (var4 >= 0 && var2.name[var4] == ' ') {
            var4--;
         }

         int var3;
         for (var3 = 0; var3 <= var4; var3++) {
            if (var2.name[var3] <= ' ' || var2.name[var3] > 127) {
               return -1;
            }

            if (this.m_vvfat.downcase_short_names == 1) {
               var1.name[var3] = var5[var3];
               var1.len++;
            } else {
               var1.name[var3] = var2.name[var3];
               var1.len++;
            }
         }

         var4 = 2;

         while (var4 >= 0 && var2.extension[var4] == ' ') {
            var4--;
         }

         if (var4 >= 0) {
            var1.name[var3++] = '.';
            var1.len++;

            for (var1.name[var3 + var4 + 1] = 0; var4 >= 0; var4--) {
               if (var2.extension[var4] <= ' ' || var2.extension[var4] > 127) {
                  return -2;
               }

               if (this.m_vvfat.downcase_short_names == 1) {
                  var1.name[var3 + var4] = var6[var4];
                  var1.len++;
               } else {
                  var1.name[var3 + var4] = var2.extension[var4];
                  var1.len++;
               }
            }
         } else {
            var1.name[var3 + var4 + 1] = 0;
         }

         return 0;
      }
   }

   public boolean is_short_name(RedirectedFolder.direntry_t var1) {
      boolean var2 = !this.is_volume_label(var1) && this.is_long_name(var1) == 0 && !this.is_free(var1);
      boolean var3 = true;
      if ((var1.attributes >> 6 & 0xFF) != 0) {
         var2 = false;
      }

      for (int var4 = 7; var4 >= 0; var4--) {
         if (var3) {
            while (var4 > 0 && var1.name[var4] == ' ') {
               var4--;
            }

            var3 = false;
         }

         if (this.check_allowed_chars(var1.name[var4], var4)) {
            var2 = false;
         }
      }

      var3 = true;

      for (int var6 = 2; var6 >= 0; var6--) {
         if (var3) {
            while (var6 > 0 && var1.extension[var6] == ' ') {
               var6--;
            }

            var3 = false;
         }

         if (this.check_allowed_chars(var1.extension[var6], var6)) {
            var2 = false;
         }
      }

      return var2;
   }

   public boolean is_free(RedirectedFolder.direntry_t var1) {
      return var1.attributes == 0 || var1.name[0] == 229;
   }

   public boolean is_volume_label(RedirectedFolder.direntry_t var1) {
      return var1.attributes == 40;
   }

   int is_long_name(RedirectedFolder.direntry_t var1) {
      return var1.attributes == 15 ? 1 : 0;
   }

   public void set_begin_of_direntry(RedirectedFolder.direntry_t var1, long var2) {
      var1.begin = (int)(var2 & 65535L);
      var1.begin_hi = (int)(var2 >> 16 & 65535L);
   }

   public byte fat_chksum(RedirectedFolder.direntry_t var1) {
      byte var2 = 0;
      char[] var4 = new char[11];
      System.arraycopy(var1.name, 0, var4, 0, var1.name.length);
      System.arraycopy(var1.extension, 0, var4, var1.name.length, var1.extension.length);

      for (int var3 = 0; var3 < 11; var3++) {
         var2 = (byte)((byte)((var2 & 254) >> 1) | (byte)((var2 & 1) == 1 ? 128 : 0));
         var2 = (byte)(var2 + (byte)var4[var3]);
      }

      return var2;
   }

   public RedirectedFolder.direntry_t create_short_and_long_name(int var1, String var2, int var3, int var4) throws IOException {
      try {
         int var7 = 0;
         if (this.m_vvfat.directory.get(var1) != null) {
            var7 = this.m_vvfat.directory.get(var1).next;
         }

         RedirectedFolder.direntry_t var8 = new RedirectedFolder.direntry_t();
         new RedirectedFolder.direntry_t();
         if (var3 == 1) {
            RedirectedFolder.array_t var21 = new RedirectedFolder.array_t();
            var21.next = this.m_vvfat.directory.size() + 1;
            this.m_vvfat.directory.add(var21);
            var21.direntry = var8;
            var8.name = "        ".toCharArray();
            var8.extension = "   ".toCharArray();
            System.arraycopy(var2.toCharArray(), 0, var8.name, 0, var2.toCharArray().length);
            return var8;
         } else {
            RedirectedFolder.direntry_t var9 = this.create_long_filename(var2.toCharArray());
            int var5 = var2.length();
            char[] var11 = var2.toCharArray();
            int var6 = var5 - 1;

            while (var6 > 0 && var11[var6] != '.') {
               var6--;
            }

            if (var6 > 0) {
               var5 = var6 > 8 ? 8 : var6;
            } else if (var5 > 8) {
               var5 = 8;
            }

            RedirectedFolder.array_t var10 = new RedirectedFolder.array_t();
            var10.next = this.m_vvfat.directory.lastElement().next + 1;
            this.m_vvfat.directory.add(var10);
            var10.direntry = var8 = new RedirectedFolder.direntry_t();
            var8.name = "        ".toCharArray();
            var8.extension = "   ".toCharArray();
            var2.getChars(0, var5, var8.name, 0);
            if (var6 > 0) {
               if (var2.length() >= var6 + 4) {
                  var2.getChars(var6 + 1, var6 + 4, var8.extension, 0);
               }

               if (var2.length() < var6 + 4) {
                  var2.getChars(var6 + 1, var2.length(), var8.extension, 0);
               }
            }

            boolean var12 = true;

            for (int var18 = 2; var18 >= 0; var18--) {
               if (var12) {
                  while (var18 > 0 && var8.extension[var18] == ' ') {
                     var18--;
                  }

                  var12 = false;
               }

               if (this.check_allowed_chars(var8.name[var18], var18)) {
                  var8.extension[var18] = '_';
               } else if (var8.extension[var18] >= 'a' && var8.extension[var18] <= 'z') {
                  var8.extension[var18] = (char)(var8.extension[var18] + -32);
               }
            }

            var12 = true;

            for (int var19 = 7; var19 >= 0; var19--) {
               if (var12) {
                  while (var19 > 0 && var8.name[var19] == ' ') {
                     var19--;
                  }

                  var12 = false;
               }

               if (this.check_allowed_chars(var8.name[var19], var19)) {
                  var8.name[var19] = '_';
               } else if (var8.name[var19] >= 'a' && var8.name[var19] <= 'z') {
                  var8.name[var19] = (char)(var8.name[var19] + -32);
               }
            }

            int var13 = var4;

            while (true) {
               RedirectedFolder.direntry_t var15;
               do {
                  var15 = this.m_vvfat.directory.get(var13).direntry;
                  if (var15 == null) {
                     var13++;
                  } else {
                     if (this.is_long_name(var15) == 0
                        && new String(var8.name).compareTo(new String(var15.name)) == 0
                        && new String(var8.extension).compareTo(new String(var15.extension)) == 0) {
                        break;
                     }

                     var13++;
                  }
               } while (var15 != var8);

               if (var15.equals(var8)) {
                  if (var9 != null) {
                     byte var24 = this.fat_chksum(var8);
                     RedirectedFolder.array_t var25 = this.m_vvfat.directory.get(var7);

                     for (int var16 = var7; var25.direntry != var8 && this.is_long_name(var25.direntry) == 1; var25 = this.m_vvfat.directory.get(++var16)) {
                        var25.fatdata[13] = var24;
                     }
                  }

                  return var8;
               }

               if (var8.name[7] == ' ') {
                  for (int var14 = 6; var14 > 0 && var8.name[var14] == ' '; var14--) {
                     var8.name[var14] = '~';
                  }
               }

               int var23;
               for (var23 = 7; var23 > 0 && var8.name[var23] == '9'; var23--) {
                  var8.name[var23] = '0';
               }

               if (var23 > 0) {
                  if (var8.name[var23] >= '0' && var8.name[var23] <= '9') {
                     var8.name[var23]++;
                  } else {
                     var8.name[var23] = '0';
                  }
               }
            }
         }
      } catch (Exception var17) {
         var17.printStackTrace();
         return null;
      }
   }

   public RedirectedFolder.direntry_t create_long_filename(char[] var1) throws Exception {
      System.out.println("" + new String(var1));

      try {
         RedirectedFolder.array_t var2 = new RedirectedFolder.array_t();
         var2.fatdata = new byte[32];
         char[] var4 = new char[258];
         int var5 = this.short2long_name(var4, var1);
         int var6 = (var5 + 25) / 26;

         for (int var7 = 0; var7 < var6; var7++) {
            var2.next = this.m_vvfat.directory.lastElement().next + 1;
            this.m_vvfat.directory.add(var2);
            RedirectedFolder.direntry_t var3;
            var2.direntry = var3 = new RedirectedFolder.direntry_t();
            var3.name = "        ".toCharArray();
            var3.extension = "   ".toCharArray();
            var3.attributes = 15;
            var3.reserved[0] = 0;
            var3.begin = 0;
            var3.name[0] = (char)(var6 - var7 | (var7 == 0 ? 64 : 0));
            if (var7 + 1 < var6) {
               var2 = new RedirectedFolder.array_t();
               var2.fatdata = new byte[32];
            }
         }

         for (int var11 = 0; var11 < var5; var11++) {
            int var8 = var11 % 26;
            if (var8 < 10) {
               var8++;
            } else if (var8 < 22) {
               var8 = 14 + var8 - 10;
            } else {
               var8 = 28 + var8 - 22;
            }

            if (var11 % 26 == 0) {
               byte[] var9 = var2.direntry.getDirBytes();
               var2.fatdata[0] = var9[0];
               var2.fatdata[11] = var9[11];
               var2.fatdata[12] = var9[12];
               var2.fatdata[26] = var9[26];
               var2.fatdata[27] = var9[27];
            }

            var2 = this.m_vvfat.directory.get(var2.next - 1 - (var11 % 26 == 0 && var11 != 0 ? 1 : 0));
            var2.fatdata[var8] = (byte)var4[var11];
         }

         byte[] var13 = var2.direntry.getDirBytes();
         var2.fatdata[0] = var13[0];
         var2.fatdata[11] = var13[11];
         var2.fatdata[12] = var13[12];
         var2.fatdata[26] = var13[26];
         var2.fatdata[27] = var13[27];
         var2.direntry = this.getDirEntry(var2.fatdata);
         return var2.direntry;
      } catch (Exception var10) {
         var10.printStackTrace();
         return null;
      }
   }

   public int short2long_name(char[] var1, char[] var2) {
      int var3;
      for (var3 = 0; var3 < 129 && var3 < var2.length; var3++) {
         var1[2 * var3] = var2[var3];
         var1[2 * var3 + 1] = 0;
      }

      var1[2 * var3] = var1[2 * var3 + 1] = 0;

      for (var3 = 2 * var3 + 2; var3 % 26 > 0; var3++) {
         var1[var3] = 255;
      }

      return var3;
   }

   public boolean check_allowed_chars(char var1, int var2) {
      return var1 <= ' ' && var2 != 0
         || var1 > 127
         || var1 == '"'
         || var1 == '.'
         || var1 == '*'
         || var1 == '?'
         || var1 == '>'
         || var1 == '<'
         || var1 == '|'
         || var1 == '/'
         || var1 == '\\'
         || var1 == '['
         || var1 == ']'
         || var1 == ';'
         || var1 == ','
         || var1 == '+'
         || var1 == '='
         || var1 == '\''
         || var1 == '"';
   }

   private synchronized int find_mapping_for_cluster_aux(long var1, int var3, int var4) throws Exception {
      try {
         int var5 = var3 + 1;

         while (true) {
            var5 = (var3 + var4) / 2;
            RedirectedFolder.mapping_t var6 = this.m_vvfat.mapping.get(var5).mapping;
            if (var6.begin > var6.end) {
               throw new Exception(T._("mapping.begin < mapping.end"));
            }

            if (var6.begin >= var1) {
               if (var4 == var5) {
                  return var3;
               }

               var4 = var5;
            } else {
               if (var3 == var5) {
                  return var6.end <= var1 ? var4 : var3;
               }

               var3 = var5;
            }
         }
      } catch (Exception var7) {
         var7.printStackTrace();
         System.out.println(var7);
         return -1;
      }
   }

   private synchronized RedirectedFolder.mapping_t find_mapping_for_cluster(long var1) throws Exception {
      boolean var3 = false;
      boolean var4 = false;
      RedirectedFolder.mapping_t var5 = null;
      int var6 = this.find_mapping_for_cluster_aux(var1, 0, this.m_vvfat.mapping.indexOf(this.m_vvfat.mapping.lastElement()) + 1);
      debug("Index :" + var6 + "\n", var3, var4);
      if (var6 >= this.m_vvfat.mapping.size()) {
         debug("index >= m_vvfat.mapping.size() ==> NULLPOINTER\n", var3, var4);
         return null;
      } else {
         var5 = this.m_vvfat.mapping.get(var6).mapping;
         if (var5.begin > var1) {
            debug("mapping.begin>cluster_num  ==> NULLPOINTER\n", var3, var4);
            return null;
         } else {
            return var5;
         }
      }
   }

   private synchronized void vvfat_close_current_file() throws Exception {
      try {
         if (this.m_vvfat.current_mapping != null) {
            this.m_vvfat.current_mapping = null;
            if (this.m_vvfat.current_fd != null) {
               this.m_vvfat.current_fd.close();
               this.m_vvfat.current_fd = null;
            }
         }

         this.m_vvfat.current_cluster = -1L;
      } catch (Exception var2) {
         var2.printStackTrace();
      }
   }

   private synchronized int open_file(RedirectedFolder.mapping_t var1) throws Exception {
      boolean var2 = false;
      boolean var3 = false;

      try {
         if (var1 == null) {
            return -1;
         } else {
            debug("Try to open: " + var1.path + "\n", var2, var3);
            File var4 = new File(var1.path);
            if ((this.m_vvfat.current_mapping != null || this.m_vvfat.current_mapping.path.compareTo(var1.path) == 0) && var4.isFile()) {
               debug(".isFile()\n", var2, var3);
               RandomAccessFile var5 = new RandomAccessFile(var4, "r");
               if (var5 == null) {
                  return -1;
               } else {
                  this.vvfat_close_current_file();
                  this.m_vvfat.current_fd = var5;
                  this.m_vvfat.current_mapping = var1;
                  return 0;
               }
            } else {
               return 0;
            }
         }
      } catch (Exception var6) {
         var6.printStackTrace();
         return -1;
      }
   }

   public void print_commit_list() {
      boolean var1 = false;
      boolean var2 = false;
      debug("Commit-Vector-Length " + this.all_commits.size() + "\n", var1, var2);

      for (int var3 = 0; var3 < this.all_commits.size(); var3++) {
         debug("Sector: " + this.all_commits.get(var3).sector + " in Commit-List\n", var1, var2);
      }
   }

   public void print_data_buffer(byte[] var1, boolean var2) {
      boolean var3 = false;
      boolean var4 = false;
      if (var2) {
         if (log_file == null) {
            return;
         }

         for (int var5 = 0; var5 < var1.length; var5++) {
            debug(
               "0x"
                  + (
                     var1[var5] != 0
                        ? (
                           var1[var5] < 16
                              ? (var1[var5] < 0 ? Integer.toHexString(var1[var5] & 255) : "0" + Integer.toHexString(var1[var5] & 255))
                              : Integer.toHexString(var1[var5] & 255)
                        )
                        : "00"
                  )
                  + " ",
               var3,
               var4
            );
            if ((var5 + 1) % 16 == 0) {
               debug("\n", var3, var4);
            }

            if ((var5 + 1) % 512 == 0) {
               debug("\n", var3, var4);
            }
         }
      }
   }

   public boolean getDirEntry_proof(RedirectedFolder.direntry_t var1) {
      boolean var2 = false;
      boolean var3 = false;

      try {
         byte[] var4 = var1.getDirBytes();
         RedirectedFolder.direntry_t var5 = this.getDirEntry(var4);
         byte[] var6 = var5.getDirBytes();

         for (int var7 = 0; var7 < var6.length; var7++) {
            if (var4[var7] != var6[var7]) {
               debug("Error at: " + var7 + " for mapping " + this.m_vvfat.current_mapping.path + "\n", var2, var3);

               for (int var8 = 0; var8 < var4.length; var8++) {
                  debug(var4[var8] + " ", var2, var3);
               }

               debug("\n", var2, var3);

               for (int var10 = 0; var10 < var6.length; var10++) {
                  debug(var6[var10] + " ", var2, var3);
               }

               return false;
            }
         }

         return true;
      } catch (Exception var9) {
         return false;
      }
   }

   public class BDRVVVFATState {
      long total_sectors;
      long cyls;
      long heads;
      long secs;
      long translation;
      int first_sectors_number;
      byte[] first_sectors = new byte[32768];
      int fat_type;
      Vector<byte[]> fat = new Vector<>();
      Vector<RedirectedFolder.array_t> directory = new Vector<>();
      Vector<RedirectedFolder.array_t> mapping = new Vector<>();
      int cluster_size;
      int sectors_per_cluster;
      int sectors_per_fat;
      int sectors_of_root_directory;
      long last_cluster_of_root_directory;
      int faked_sectors;
      long sector_count;
      long cluster_count;
      long max_fat_value;
      RandomAccessFile current_fd;
      RedirectedFolder.mapping_t current_mapping;
      byte[] cluster;
      byte[] cluster_buffer;
      long current_cluster;
      String path;
      long dir_size;
      long counted_files;
      RandomAccessFile dummy_file;
      File dummy_file_name;
      int downcase_short_names;
      File image_name;
      RandomAccessFile image = null;
      boolean modified_FAT;
      boolean consitent_FAT;

      public byte[] getFATBytes(int var1) throws IOException {
         int var2 = 0;
         byte[] var3 = new byte[4];
         if (var1 > RedirectedFolder.this.m_vvfat.fat.size()) {
            return null;
         } else {
            ByteArrayOutputStream var4 = new ByteArrayOutputStream(RedirectedFolder.this.sectorSize);

            do {
               byte[] var5 = null;
               if (var1 < RedirectedFolder.this.m_vvfat.fat.size()) {
                  var5 = RedirectedFolder.this.m_vvfat.fat.get(var1);
               }

               var4.write(var5 != null ? var5 : var3);
               var1++;
               var2 += var5 != null ? var5.length : 4;
            } while (var2 < 512 && var1 < RedirectedFolder.this.m_vvfat.fat.size());

            if (var2 < 512) {
               var3 = new byte[512 - var2];
               var4.write(var3);
            }

            return var4.toByteArray();
         }
      }

      public byte[] getDataBytes(int var1, int var2) throws IOException {
         int var3 = 0;
         byte[] var4 = new byte[32];
         if (var1 > RedirectedFolder.this.m_vvfat.directory.size()) {
            return null;
         } else {
            ByteArrayOutputStream var6 = new ByteArrayOutputStream(RedirectedFolder.this.sectorSize);

            do {
               RedirectedFolder.array_t var5 = RedirectedFolder.this.m_vvfat.directory.get(var1);
               if (var5 != null && (var5.direntry != null || var5.fatdata != null)) {
                  if (var5.direntry != null && var5.fatdata == null) {
                     var4 = var5.fatdata = var5.direntry.getDirBytes();
                  } else if (var5.direntry == null && var5.fatdata != null) {
                     System.arraycopy(var5.fatdata, 0, var4, 0, var5.fatdata.length);
                  } else if (var5.direntry != null && var5.fatdata != null) {
                     if (var5.fatdata[11] == 15) {
                        System.arraycopy(var5.fatdata, 0, var4, 0, var5.fatdata.length);
                     } else {
                        var4 = var5.fatdata = var5.direntry.getDirBytes();
                     }
                  }
               }

               var6.write(var4);
               var1++;
               var3 += var4.length;
               Arrays.fill(var4, (byte)0);
            } while (var3 < var2 && var1 < RedirectedFolder.this.m_vvfat.directory.size());

            return var6.toByteArray();
         }
      }
   }

   public class array_t {
      RedirectedFolder.mapping_t mapping = null;
      RedirectedFolder.direntry_t direntry = null;
      byte[] fatdata = null;
      int next;
   }

   public class bootsector_t {
      byte[] jump = new byte[3];
      char[] name = new char[8];
      int sector_size;
      byte sectors_per_cluster;
      int reserved_sectors;
      byte number_of_fats;
      int root_entries;
      int total_sectors16;
      byte media_type;
      int sectors_per_fat;
      int sectors_per_track;
      int number_of_heads;
      long hidden_sectors;
      long total_sectors;
      RedirectedFolder.bootsector_t._union union = new RedirectedFolder.bootsector_t._union();
      short[] magic = new short[2];

      public byte[] getBytes() throws IOException {
         ByteArrayOutputStream var1 = new ByteArrayOutputStream(RedirectedFolder.this.sectorSize);
         var1.write(this.jump[0]);
         var1.write(this.jump[1]);
         var1.write(this.jump[2]);

         for (int var2 = 0; var2 < 8; var2++) {
            var1.write(this.name[var2] & 255);
         }

         var1.write(this.sector_size & 0xFF);
         var1.write(this.sector_size >> 8 & 0xFF);
         var1.write(this.sectors_per_cluster & 255);
         var1.write(this.reserved_sectors & 0xFF);
         var1.write(this.reserved_sectors >> 8 & 0xFF);
         var1.write(this.number_of_fats & 255);
         var1.write(this.root_entries & 0xFF);
         var1.write(this.root_entries >> 8 & 0xFF);
         var1.write(this.total_sectors16 & 0xFF);
         var1.write(this.total_sectors16 >> 8 & 0xFF);
         var1.write(this.media_type & 255);
         var1.write(this.sectors_per_fat & 0xFF);
         var1.write(this.sectors_per_fat >> 8 & 0xFF);
         var1.write(this.sectors_per_track & 0xFF);
         var1.write(this.sectors_per_track >> 8 & 0xFF);
         var1.write(this.number_of_heads & 0xFF);
         var1.write(this.number_of_heads >> 8 & 0xFF);
         var1.write((int)this.hidden_sectors & 0xFF);
         var1.write((int)(this.hidden_sectors >> 8) & 0xFF);
         var1.write((int)(this.hidden_sectors >> 16) & 0xFF);
         var1.write((int)(this.hidden_sectors >> 24) & 0xFF);
         var1.write((int)this.total_sectors & 0xFF);
         var1.write((int)(this.total_sectors >> 8) & 0xFF);
         var1.write((int)(this.total_sectors >> 16) & 0xFF);
         var1.write((int)(this.total_sectors >> 24) & 0xFF);
         if (RedirectedFolder.this.m_vvfat.fat_type == 16) {
            var1.write(this.union.fat16.drive_number & 255);
            var1.write(this.union.fat16.current_head & 255);
            var1.write(this.union.fat16.signature & 255);
            var1.write(this.union.fat16.id & 0xFF);
            var1.write(this.union.fat16.id >> 8 & 0xFF);
            var1.write(this.union.fat16.id >> 16 & 0xFF);
            var1.write(this.union.fat16.id >> 24 & 0xFF);

            for (int var3 = 0; var3 < 11; var3++) {
               var1.write(this.union.fat16.volume_label[var3] & 255);
            }

            for (int var4 = 0; var4 < 8; var4++) {
               var1.write(this.union.fat16.fat_type[var4] & 255);
            }

            var1.write(this.union.fat16.ignored);
         } else if (RedirectedFolder.this.m_vvfat.fat_type == 32) {
            var1.write((int)this.union.fat32.sectors_per_fat & 0xFF);
            var1.write((int)(this.union.fat32.sectors_per_fat >> 8) & 0xFF);
            var1.write((int)(this.union.fat32.sectors_per_fat >> 16) & 0xFF);
            var1.write((int)(this.union.fat32.sectors_per_fat >> 24) & 0xFF);
            var1.write(this.union.fat32.flags & 0xFF);
            var1.write(this.union.fat32.flags >> 8 & 0xFF);
            var1.write(this.union.fat32.major);
            var1.write(this.union.fat32.minor);
            var1.write(this.union.fat32.first_cluster_of_root_directory & 0xFF);
            var1.write(this.union.fat32.first_cluster_of_root_directory >> 8 & 0xFF);
            var1.write(this.union.fat32.first_cluster_of_root_directory >> 16 & 0xFF);
            var1.write(this.union.fat32.first_cluster_of_root_directory >> 24 & 0xFF);
            var1.write(this.union.fat32.info_sector & 0xFF);
            var1.write(this.union.fat32.info_sector >> 8 & 0xFF);
            var1.write(this.union.fat32.backup_boot_sector & 0xFF);
            var1.write(this.union.fat32.backup_boot_sector >> 8 & 0xFF);
            var1.write(this.union.fat32.reserved);
            var1.write(this.union.fat32.drive_number);
            var1.write(this.union.fat32.current_head);
            var1.write(this.union.fat32.signature);
            var1.write((int)this.union.fat32.id & 0xFF);
            var1.write((int)(this.union.fat32.id >> 8) & 0xFF);
            var1.write((int)(this.union.fat32.id >> 16) & 0xFF);
            var1.write((int)(this.union.fat32.id >> 24) & 0xFF);

            for (int var5 = 0; var5 < 11; var5++) {
               var1.write(this.union.fat32.volume_label[var5] & 255);
            }

            for (int var6 = 0; var6 < 8; var6++) {
               var1.write(this.union.fat32.fat_type[var6] & 255);
            }

            var1.write(this.union.fat32.ignored);
         }

         var1.write(this.magic[0] & 255);
         var1.write(this.magic[1] & 255);
         return var1.toByteArray();
      }

      class _union {
         RedirectedFolder.bootsector_t._union._fat16 fat16 = new RedirectedFolder.bootsector_t._union._fat16();
         RedirectedFolder.bootsector_t._union._fat32 fat32 = new RedirectedFolder.bootsector_t._union._fat32();

         public _union() {
         }

         class _fat16 {
            byte drive_number;
            byte current_head;
            byte signature;
            int id;
            char[] volume_label = new char[11];
            char[] fat_type = new char[8];
            byte[] ignored = new byte[448];

            public _fat16() {
            }
         }

         class _fat32 {
            long sectors_per_fat;
            int flags;
            byte major;
            byte minor;
            int first_cluster_of_root_directory;
            int info_sector;
            int backup_boot_sector;
            byte[] reserved = new byte[12];
            short drive_number;
            short current_head;
            short signature;
            long id;
            char[] volume_label = new char[11];
            char[] fat_type = new char[8];
            byte[] ignored = new byte[420];

            public _fat32() {
            }
         }
      }
   }

   public class commit_t {
      boolean direntry_data;
      long sector;
      byte[] data;
   }

   public class direntry_t {
      char[] name = new char[8];
      char[] extension = new char[3];
      byte attributes;
      byte[] reserved = new byte[2];
      int ctime;
      int cdate;
      int adate;
      int begin_hi;
      int mtime;
      int mdate;
      int begin;
      long size;

      public byte[] getDirBytes() throws IOException {
         ByteArrayOutputStream var1 = new ByteArrayOutputStream();

         for (int var2 = 0; var2 < 8; var2++) {
            var1.write(this.name[var2] & 255);
         }

         for (int var3 = 0; var3 < 3; var3++) {
            var1.write(this.extension[var3] & 255);
         }

         var1.write(this.attributes);
         var1.write(this.reserved[0]);
         var1.write(this.reserved[1]);
         var1.write(this.ctime & 0xFF);
         var1.write(this.ctime >> 8 & 0xFF);
         var1.write(this.cdate & 0xFF);
         var1.write(this.cdate >> 8 & 0xFF);
         var1.write(this.adate & 0xFF);
         var1.write(this.adate >> 8 & 0xFF);
         var1.write(this.begin_hi & 0xFF);
         var1.write(this.begin_hi >> 8 & 0xFF);
         var1.write(this.mtime & 0xFF);
         var1.write(this.mtime >> 8 & 0xFF);
         var1.write(this.mdate & 0xFF);
         var1.write(this.mdate >> 8 & 0xFF);
         var1.write(this.begin & 0xFF);
         var1.write(this.begin >> 8 & 0xFF);
         var1.write((int)this.size & 0xFF);
         var1.write((int)this.size >> 8 & 0xFF);
         var1.write((int)this.size >> 16 & 0xFF);
         var1.write((int)this.size >> 24 & 0xFF);
         return var1.toByteArray();
      }
   }

   public class file_name {
      char[] name = new char[1024];
      int checksum;
      int len;
      int sequence_number;
   }

   public class mapping_t {
      long begin;
      long end;
      int dir_index;
      int first_mapping_index;
      RedirectedFolder.mapping_t._info info = new RedirectedFolder.mapping_t._info();
      String path;
      int mode;
      int read_only;
      RandomAccessFile file;
      FileLock lock;
      long[] cluster_chain;
      boolean writing_request;
      boolean exceeds_mapping_bounds;

      public class _info {
         RedirectedFolder.mapping_t._info._file file = new RedirectedFolder.mapping_t._info._file();
         RedirectedFolder.mapping_t._info._dir dir = new RedirectedFolder.mapping_t._info._dir();

         public class _dir {
            int parent_mapping_index;
            int first_dir_index;
            int cluster_num;
         }

         public class _file {
            long offset;
            long size;
         }
      }
   }

   public class mbr_t {
      byte[] ignored = new byte[446];
      RedirectedFolder.partition_t[] partition = new RedirectedFolder.partition_t[4];
      byte[] magic = new byte[2];

      public byte[] getBytes() throws IOException {
         ByteArrayOutputStream var1 = new ByteArrayOutputStream();

         for (int var3 = 0; var3 < 4; var3++) {
            RedirectedFolder.partition_t var2 = this.partition[var3];
            byte[] var4 = var2.getPartBytes(var2);
            var1.write(var4);
         }

         var1.write(this.magic[0]);
         var1.write(this.magic[1]);
         return var1.toByteArray();
      }
   }

   public class partition_t {
      int attributes;
      int start_head;
      int start_sector;
      int start_cylinder;
      int fs_type;
      int end_head;
      int end_sector;
      int end_cylinder;
      long start_sector_long;
      long end_sector_long;

      public byte[] getPartBytes(RedirectedFolder.partition_t var1) throws IOException {
         ByteArrayOutputStream var2 = new ByteArrayOutputStream();
         var2.write(var1.attributes & 0xFF);
         var2.write(var1.start_head & 0xFF);
         var2.write(var1.start_sector & 0xFF);
         var2.write(var1.start_cylinder & 0xFF);
         var2.write(var1.fs_type & 0xFF);
         var2.write(var1.end_head & 0xFF);
         var2.write(var1.end_sector & 0xFF);
         var2.write(var1.end_cylinder & 0xFF);
         var2.write((int)var1.start_sector_long & 0xFF);
         var2.write((int)(var1.start_sector_long >> 8) & 0xFF);
         var2.write((int)(var1.start_sector_long >> 16) & 0xFF);
         var2.write((int)(var1.start_sector_long >> 24) & 0xFF);
         var2.write((int)var1.end_sector_long & 0xFF);
         var2.write((int)(var1.end_sector_long >> 8) & 0xFF);
         var2.write((int)(var1.end_sector_long >> 16) & 0xFF);
         var2.write((int)(var1.end_sector_long >> 24) & 0xFF);
         return var2.toByteArray();
      }
   }
}
