package nn.pp.vmcore.impl;

import java.io.IOException;
import java.util.logging.Logger;
import nn.pp.core.Platform;
import nn.pp.core.T;
import nn.pp.vmcore.RedirectableObject;
import nn.pp.vmcore.VMCore;
import nn.pp.vmcore.VMException;
import nn.pp.vmcore.VirtualMediaEventListener;

public abstract class RedirectedObject {
   protected boolean readOnly;
   protected VMCore.DriveType driveType;
   protected Logger logger;

   protected RedirectedObject(boolean var1, Logger var2) {
      this.readOnly = var1;
      this.logger = var2;
   }

   public static RedirectedObject loadRedirectedObject(RedirectableObject var0, boolean var1, Logger var2) throws VMException {
      if (var0 instanceof IsoImage) {
         return new RedirectedImage(((IsoImage)var0).getFile(), var1, var2);
      } else {
         if (var0 instanceof DriveDev) {
            if (Platform.isMac()) {
               return new RedirectedDriveMacOsX(((DriveDev)var0).getFile(), var1, var2);
            }

            if (Platform.isLinux()) {
               return new RedirectedDriveLinux(((DriveDev)var0).getFile(), var1, var2);
            }
         } else {
            if (var0 instanceof DriveNative) {
               return new RedirectedDriveNative((DriveNative)var0, var1, var2);
            }

            if (var0 instanceof Folder) {
               return new RedirectedFolder(((Folder)var0).getFolder(), var1, var2);
            }
         }

         throw new VMException(T._("No implementation found!"));
      }
   }

   public VMCore.DriveType getDriveType() {
      return this.driveType;
   }

   public synchronized void lockAccess(boolean var1, VMCore.LockFailBehavior var2, VirtualMediaEventListenerList var3) throws VMException {
      while (true) {
         try {
            this.lockAccess(var1);
            return;
         } catch (VMException var6) {
            if (var2 == VMCore.LockFailBehavior.IGNORE) {
               return;
            }

            if (var2 == VMCore.LockFailBehavior.ASK) {
               VirtualMediaEventListener.LockFailAction var5 = var3.fireDriveLockingFailed();
               if (var5 == VirtualMediaEventListener.LockFailAction.IGNORE) {
                  return;
               }

               if (var5 == VirtualMediaEventListener.LockFailAction.RETRY) {
                  continue;
               }

               throw var6;
            }

            throw var6;
         }
      }
   }

   public abstract void open() throws IOException, VMException;

   public abstract void close();

   protected abstract void lockAccess(boolean var1) throws VMException;

   public abstract void determineGeometry() throws IOException, VMException;

   public abstract int getSectorSize();

   public abstract long getLastSectorNo();

   public abstract void readSectors(long var1, long var3, byte[] var5) throws IOException, VMException;

   public abstract void writeSectors(long var1, long var3, byte[] var5) throws IOException, VMException;

   public synchronized RedirectedObject.MediumChangeState getMediumChangeState() {
      return RedirectedObject.MediumChangeState.NO_CHANGE;
   }

   public synchronized void mediumRemovedForChange() throws Exception {
   }

   public synchronized void mediumInsertedAfterChange() throws Exception {
   }

   public static enum MediumChangeState {
      NO_CHANGE,
      REMOVED,
      CHANGED;
   }
}
