package nn.pp.vmcore.impl;

import java.io.IOException;
import java.util.Timer;
import java.util.TimerTask;
import java.util.logging.ConsoleHandler;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.X509TrustManager;
import nn.pp.core.NotificationListener;
import nn.pp.core.T;
import nn.pp.core.impl.DeviceConnector;
import nn.pp.vmcore.RedirectableObject;
import nn.pp.vmcore.VMAdapter;
import nn.pp.vmcore.VMCore;
import nn.pp.vmcore.VMException;
import nn.pp.vmcore.VirtualMediaEventListener;
import nn.pp.vmcore.impl.msp.MspHandler;

public class VMCoreImpl implements VMCore {
   protected Logger logger;
   protected int msIndex;
   private Timer mediaTimer;
   private VMAdapter adapter = new VMAdapter() {
      @Override
      public void disconnected(Exception var1) {
         VMCoreImpl.this.disconnect(true);
      }
   };
   private X509TrustManager trustManager;
   private DeviceConnector connector;
   private boolean connected = false;
   private RedirectableObject redirectable;
   private RedirectedObject redirected;
   private boolean locked = false;
   private MspHandler mspHandler;
   private ListenerLists listeners = new ListenerLists();

   public VMCoreImpl(Logger var1, int var2) {
      if (var1 == null) {
         var1 = Logger.getLogger("Virtual Media");
         var1.setUseParentHandlers(false);
         var1.addHandler(new ConsoleHandler());
         var1.setLevel(Level.SEVERE);
      }

      this.logger = var1;
      this.msIndex = var2;
      this.addVirtualMediaEventListener(this.adapter, 0);
   }

   @Override
   public void dispose() {
      if (this.mediaTimer != null) {
         this.mediaTimer.cancel();
         this.mediaTimer = null;
      }

      if (this.connector != null) {
         this.connector = null;
      }

      if (this.adapter != null) {
         this.adapter = null;
      }

      if (this.trustManager != null) {
         this.trustManager = null;
      }

      if (this.mspHandler != null) {
         this.mspHandler = null;
      }

      if (this.redirectable != null) {
         this.redirectable = null;
      }

      if (this.redirected != null) {
         this.redirected = null;
      }

      this.removeVirtualMediaEventListener(this.adapter);
   }

   @Override
   public void setX509TrustManager(X509TrustManager var1) {
      this.trustManager = var1;
   }

   @Override
   public void connectVMWithUserLogin(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      RedirectableObject var6,
      boolean var7,
      VMCore.LockFailBehavior var8,
      String var9,
      String var10
   ) throws IOException, VMException {
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8, var9, var10, null, null, null, null);
   }

   @Override
   public void connectVMWithRdmSession(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      RedirectableObject var6,
      boolean var7,
      VMCore.LockFailBehavior var8,
      String var9,
      String var10,
      String var11
   ) throws IOException, VMException {
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8, null, null, null, var9, var10, var11);
   }

   @Override
   public void connectVMWithEricKey(
      String var1, int var2, boolean var3, String var4, int var5, RedirectableObject var6, boolean var7, VMCore.LockFailBehavior var8, String var9
   ) throws IOException, VMException {
      this.connectToHost(var1, var2, var3, var4, var5, var6, var7, var8, null, null, var9, null, null, null);
   }

   private void connectToHost(
      String var1,
      int var2,
      boolean var3,
      String var4,
      int var5,
      RedirectableObject var6,
      boolean var7,
      VMCore.LockFailBehavior var8,
      String var9,
      String var10,
      String var11,
      String var12,
      String var13,
      String var14
   ) throws IOException, VMException {
      this.redirectable = var6;
      if (this.connected) {
         throw new VMException(T._("Already connected!"));
      } else {
         this.redirected = RedirectedObject.loadRedirectedObject(var6, var7, this.logger);

         try {
            this.redirected.open();
            this.redirected.lockAccess(false, var8, this.listeners.virtualMediaEventListenerList);
            this.locked = true;
            this.redirected.determineGeometry();
            this.connector = new DeviceConnector(this.logger, this.trustManager);
            this.connector.connect(var1, var2, var3);
            if (!var3 && var13 != null && var14 != null) {
               this.connector.writeCCSGproxyModePrefix(var13);
               if (var14.equals("yes")) {
                  System.out.println("CC-Proxy[VM] mode: SSL enabled .. \n");
                  this.connector.connectSSLWithSocket(var1, var2);
               } else {
                  System.out.println("CC-Proxy[VM] mode: plaintext .. \n");
               }
            }

            this.mspHandler = MspHandler.loadMspHandler(this.connector, this.logger, this.listeners, this.redirected, var5, this.msIndex, var7);
            this.mspHandler.connect(var4, var9, var10, var11, var12);
            this.mediaTimer = new Timer("MediaChange");
            this.mediaTimer.schedule(new TimerTask() {
               @Override
               public void run() {
                  VMCoreImpl.this.checkMediumChange();
               }
            }, 500L, 500L);
            this.connected = true;
         } catch (VMException var16) {
            this.logger.log(Level.SEVERE, T._("Could not establish Virtual Media session"), (Throwable)var16);
            this.disconnect(true);
            throw var16;
         } catch (IOException var17) {
            this.logger.log(Level.SEVERE, T._("Could not establish Virtual Media session"), (Throwable)var17);
            this.disconnect(true);
            throw var17;
         } catch (Exception var18) {
            this.logger.log(Level.SEVERE, T._("Could not establish Virtual Media session"), (Throwable)var18);
            this.disconnect(true);
            throw new VMException(var18.getMessage());
         }
      }
   }

   @Override
   public void disconnect(boolean var1) {
      this.disconnect();
      if (!var1) {
         this.listeners.virtualMediaEventListenerList.fireVirtualMediaDriveDisConnected(true);
      }
   }

   @Override
   public void disconnect() {
      if (this.mspHandler != null) {
         this.mspHandler.close();
         this.connector.disconnect();
         this.mspHandler.dispose();
         this.mspHandler = null;
         this.connector = null;
      }

      if (this.mediaTimer != null) {
         this.mediaTimer.cancel();
         this.mediaTimer = null;
      }

      if (this.redirected != null) {
         System.out.println("Redirected Drive is not null");
         if (this.locked) {
            try {
               this.logger.log(Level.INFO, "Unlocking Drive:" + this.redirectable.getShortName());
               this.redirected.lockAccess(true, VMCore.LockFailBehavior.IGNORE, this.listeners.virtualMediaEventListenerList);
            } catch (Exception var2) {
               var2.printStackTrace();
            }
         }

         this.redirected.close();
         this.redirected = null;
      }

      this.redirectable = null;
      this.connected = false;
   }

   private void checkMediumChange() {
      if (this.redirected != null) {
         try {
            RedirectedObject.MediumChangeState var1 = this.redirected.getMediumChangeState();
            if (var1 != RedirectedObject.MediumChangeState.NO_CHANGE) {
               if (var1 == RedirectedObject.MediumChangeState.REMOVED) {
                  this.logger.log(Level.FINEST, "Medium has been removed.");
                  this.mediumRemovedForChange();
               } else if (var1 == RedirectedObject.MediumChangeState.CHANGED) {
                  this.logger.log(Level.FINEST, "Medium has been changed.");
                  this.mediumInsertedAfterChange();
               }
            }
         } catch (Exception var2) {
            this.disconnect(false);
         }
      }
   }

   private void mediumRemovedForChange() throws Exception {
      this.redirected.mediumRemovedForChange();
      this.mspHandler.sendMediumRemoval();
   }

   private void mediumInsertedAfterChange() throws Exception {
      this.redirected.lockAccess(true);
      this.redirected.close();
      this.redirected.open();
      this.redirected.lockAccess(false);
      this.redirected.mediumInsertedAfterChange();
      this.mspHandler.sendMediumChange();
   }

   @Override
   public void addNotificationListener(NotificationListener var1) {
      this.listeners.notificationListenerList.addListener(var1);
   }

   @Override
   public void removeNotificationListener(NotificationListener var1) {
      this.listeners.notificationListenerList.removeListener(var1);
   }

   @Override
   public void addVirtualMediaEventListener(VirtualMediaEventListener var1, int var2) {
      this.listeners.virtualMediaEventListenerList.addListener(var1, var2);
   }

   @Override
   public void removeVirtualMediaEventListener(VirtualMediaEventListener var1) {
      this.listeners.virtualMediaEventListenerList.removeListener(var1);
   }

   @Override
   public void setMsIndex(int var1) {
      this.msIndex = var1;
   }
}
