package nn.pp.vmcore.impl.msp;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nn.pp.core.T;
import nn.pp.core.impl.DeviceConnector;
import nn.pp.core.impl.ProtocolHandler;
import nn.pp.vmcore.VMCore;
import nn.pp.vmcore.VMException;
import nn.pp.vmcore.impl.ListenerLists;
import nn.pp.vmcore.impl.RedirectedObject;

public abstract class MspHandler extends ProtocolHandler<VMException> {
   protected ListenerLists listeners;
   protected RedirectedObject redirectedObject;
   private int rfbSessionId;
   private int msIndex;
   private boolean readOnly;
   private int mspOkCount = 0;
   private static int TOTAL_MSP_OK = 2;
   protected int connectionResponseReason;
   protected int readSectorCount;
   protected long readStartSector;
   protected int writeSectorCount;
   protected long writeStartSector;
   protected byte[] readBuffer = null;
   protected byte[] writeBuffer = null;

   public static MspHandler loadMspHandler(DeviceConnector var0, Logger var1, ListenerLists var2, RedirectedObject var3, int var4, int var5, boolean var6) throws IOException, VMException {
      MspVersionNegotiator var7 = new MspVersionNegotiator();
      var7.init(var0, var1, var2, var3, var4, var5, var6);
      var7.negotiateProtocolVersion();
      MspHandler var8 = loadMspHandler(var0, var1, var2, var3, var4, var5, var6, var7.versionMajor, var7.versionMinor);
      var8.versionMajor = var7.versionMajor;
      var8.versionMinor = var7.versionMinor;
      return var8;
   }

   public static MspHandler loadMspHandler(
      DeviceConnector var0, Logger var1, ListenerLists var2, RedirectedObject var3, int var4, int var5, boolean var6, int var7, int var8
   ) throws IOException, VMException {
      MspHandler var9;
      try {
         String var10 = getVersionString(var7, var8, '_');
         String var13 = "nn.pp.vmcore.impl.msp.V" + var10 + ".MspHandlerV" + var10;
         var1.log(Level.FINE, T._("Trying to load protocol handler:") + " " + var13);
         var9 = (MspHandler)Class.forName(var13).newInstance();
      } catch (Throwable var12) {
         String var11 = T._("Unable to load protocol handler!");
         var1.log(Level.SEVERE, var11, var12);
         throw new VMException(var11);
      }

      var9.init(var0, var1, var2, var3, var4, var5, var6);
      return var9;
   }

   @Override
   protected String getProtocolName() {
      return "MSP";
   }

   protected VMException loadException(String var1) {
      return new VMException(var1);
   }

   @Override
   public void close() {
      this.shouldRun = false;
   }

   @Override
   protected void disconnected(Exception var1) {
      this.listeners.virtualMediaEventListenerList.fireDisconnected(var1);
   }

   protected void init(DeviceConnector var1, Logger var2, ListenerLists var3, RedirectedObject var4, int var5, int var6, boolean var7) throws IOException {
      this.listeners = var3;
      this.redirectedObject = var4;
      this.rfbSessionId = var5;
      this.msIndex = var6;
      this.readOnly = var7;
      this.setMspCount(0);
      super.init(var1, var2);
   }

   public void sendMediumRemoval() throws IOException, VMException {
      this.sendConnectionRequest(false);
   }

   public void sendMediumChange() throws IOException, VMException {
      this.sendConnectionRequest(true);
   }

   protected boolean supportsRdmAuth() {
      return true;
   }

   protected boolean haveOldErrors() {
      return false;
   }

   private String getOldErrorReason(int var1) {
      switch (var1) {
         case 0:
            return T._("No error");
         case 1:
            return T._("Drive Redirection not available.");
         case 2:
            return T._("There is already a Drive Reconnection active on this device.");
         case 3:
            return T._("Another virtual image is already set on this device.");
         case 4:
         case 7:
         default:
            return T._("Other response error: 0x") + Integer.toHexString(var1);
         case 5:
            return T._("Authentication failed.");
         case 6:
            return T._("You are not allowed to establish Drive Redirection.");
         case 8:
            return T._("Mass storage index not available.");
      }
   }

   private String getOldQuitReason(int var1) {
      switch (var1) {
         case 0:
            return "User cancelled connection.";
         case 1:
            return "Device cancelled connection.";
         default:
            return T._("Unknown quit reason: 0x") + Integer.toHexString(var1);
      }
   }

   private int getMspMediumType(VMCore.DriveType var1) throws VMException {
      if (var1 == VMCore.DriveType.CDROM) {
         return 0;
      } else if (var1 == VMCore.DriveType.FLOPPY) {
         return 1;
      } else if (var1 == VMCore.DriveType.REMOVABLE || var1 == VMCore.DriveType.HARD_DISK_PARTITION || var1 == VMCore.DriveType.HARD_DISK_PARTITION_EXTERNAL) {
         return 2;
      } else if (var1 != VMCore.DriveType.HARD_DISK_FULL && var1 != VMCore.DriveType.HARD_DISK_FULL_EXTERNAL) {
         throw new VMException(T._("Unknown Drive Type"));
      } else {
         return 3;
      }
   }

   private void checkReadBufSize(int var1) {
      if (this.readBuffer == null || this.readBuffer.length < var1) {
         this.readBuffer = new byte[var1];
      }
   }

   protected void writeAuthRdmSessionIdMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeAuthLoginMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeAuthSessionIdMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected byte[] readAuthChallengeMsg() throws IOException, VMException {
      throw new UnsupportedOperationException();
   }

   protected void writeChallengeResponseMsg(String var1) throws IOException, VMException {
      throw new UnsupportedOperationException();
   }

   protected boolean readResponseConnectionMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeConnectionRequestMsg(int var1, int var2, int var3, boolean var4, RedirectedObject var5) throws IOException, VMException {
      throw new UnsupportedOperationException();
   }

   protected void writePingMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readPingMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writePongMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readPongMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected int readQuitMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeQuitMsg(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readRequestDataMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeSendDataMsg(int var1, int var2, int var3, byte[] var4) throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void readSendDataMsg() throws IOException {
      throw new UnsupportedOperationException();
   }

   protected void writeDataAckMsg(int var1) throws IOException {
      throw new UnsupportedOperationException();
   }

   @Override
   protected void negotiateProtocolVersion() throws IOException, VMException {
      throw new UnsupportedOperationException();
   }

   private void sendAuthentication() throws IOException, VMException {
      if (this.supportsRdmAuth() && this.rdmSessionID != null) {
         this.authenticateRdmSessionId();
      } else if (this.username != null && this.password != null) {
         this.authenticateUsername();
      } else {
         if (this.httpSessionID == null) {
            throw new VMException(T._("No proper authentication scheme found"));
         }

         this.authenticateHttpSessionId();
      }
   }

   private void authenticateRdmSessionId() throws IOException {
      this.writeAuthRdmSessionIdMsg();
   }

   private void authenticateUsername() throws IOException {
      this.writeAuthLoginMsg();
   }

   private void authenticateHttpSessionId() throws IOException, VMException {
      this.writeAuthSessionIdMsg();
      byte[] var1 = this.readAuthChallengeMsg();
      String var2 = null;

      try {
         var2 = new String(var1, "ISO-8859-1");
      } catch (UnsupportedEncodingException var5) {
      }

      String var3;
      if (var2.startsWith("{SHA256}")) {
         var3 = "SHA-256";
      } else {
         var3 = "MD5";
      }

      String var4 = this.getChallengeResponse(var1, var3);
      this.writeChallengeResponseMsg(var4);
   }

   protected void sendConnectionRequest(boolean var1) throws IOException, VMException {
      int var2 = var1 ? this.getMspMediumType(this.redirectedObject.getDriveType()) : 255;
      this.writeConnectionRequestMsg(var2, this.rfbSessionId, this.msIndex, this.readOnly, this.redirectedObject);
   }

   private void processConnectionResponse() throws IOException, VMException {
      boolean var1 = this.readResponseConnectionMsg();
      if (var1) {
         this.mspOkCount++;
         if (this.getMspCount() == TOTAL_MSP_OK) {
            this.listeners.virtualMediaEventListenerList.fireVirtualMediaDriveConnected(true);
         }
      }

      if (!var1) {
         if (this.haveOldErrors()) {
            throw new VMException(this.getOldErrorReason(this.connectionResponseReason));
         }

         MspNotificationEvent var2 = new MspNotificationEvent(0, this.connectionResponseReason);
         if (var2.isError() || var2.isQuit()) {
            this.close();
         }

         this.listeners.notificationListenerList.fireNotification(new MspNotificationEvent(0, this.connectionResponseReason));
      }
   }

   private void processPingMessage() throws IOException {
      this.readPingMsg();
      this.writePongMsg();
   }

   private void processPongMessage() throws IOException {
      this.readPongMsg();
   }

   private void processQuitMessage() throws IOException, VMException {
      int var1 = this.readQuitMsg();
      if (this.haveOldErrors()) {
         throw new VMException(this.getOldQuitReason(var1));
      } else {
         this.listeners.notificationListenerList.fireNotification(new MspNotificationEvent(1, var1));
         throw new VMException(var1, MspNotificationEvent.getMessageString(var1));
      }
   }

   private void processRequestDataMessage() throws IOException, VMException {
      this.readRequestDataMsg();
      int var1 = this.redirectedObject.getSectorSize();
      this.logger.log(Level.FINE, "Requested " + this.readSectorCount + " sectors beginning from " + this.readStartSector);
      byte var2 = 0;

      try {
         this.checkReadBufSize(this.readSectorCount * var1);
      } catch (Exception var5) {
         var2 = 1;
         this.logger.log(Level.WARNING, "Could not incerase read buffer.");
      }

      if (var2 == 0) {
         try {
            this.redirectedObject.readSectors(this.readStartSector, this.readSectorCount, this.readBuffer);
         } catch (Exception var4) {
            var2 = 2;
            this.logger.log(Level.WARNING, "Could not read drive sectors.", (Throwable)var4);
         }
      }

      if (var2 != 0) {
         this.readSectorCount = 0;
      }

      this.writeSendDataMsg(var2, this.readSectorCount, var1, this.readBuffer);
   }

   private void processSendDataMessage() throws IOException, VMException {
      this.readSendDataMsg();
      byte var1 = 0;

      try {
         if (!this.readOnly) {
            this.redirectedObject.writeSectors(this.writeStartSector, this.writeSectorCount, this.writeBuffer);
            var1 = 1;
         } else {
            this.logger.log(Level.INFO, T._("Cannot write data because device is read only."));
         }
      } catch (Exception var3) {
         this.logger.log(Level.WARNING, T._("Could not write drive sectors."), (Throwable)var3);
      }

      this.writeDataAckMsg(var1);
   }

   @Override
   protected void processProtocol() throws IOException, VMException {
      this.sendAuthentication();

      while (this.shouldRun) {
         int var1 = this.readServerMessageType();
         switch (var1) {
            case 2:
               this.processSendDataMessage();
               break;
            case 3:
               this.processQuitMessage();
               break;
            case 4:
               this.processPingMessage();
               break;
            case 5:
               this.processPongMessage();
               break;
            case 128:
               this.processConnectionResponse();
               break;
            case 129:
               this.processRequestDataMessage();
               break;
            default:
               this.logger.log(Level.SEVERE, T._("Unknown Protocol message received:") + " " + var1);
               throw new VMException(T._("Protocol Error: Unknown Protocol message received"));
         }

         if (this.inInitialHandshake) {
            this.processInitialHandshake(var1);
         }
      }
   }

   private void setMspCount(int var1) {
      this.mspOkCount = var1;
   }

   private int getMspCount() {
      return this.mspOkCount;
   }
}
