package nn.pp.vmcore.impl.msp.V01_02;

import java.io.IOException;
import java.util.logging.Level;
import nn.pp.vmcore.VMException;
import nn.pp.vmcore.impl.RedirectedObject;
import nn.pp.vmcore.impl.msp.MspHandler;
import nn.pp.vmcore.impl.msp.V01_00.MspHelloMsgV01_00;
import nn.pp.vmcore.impl.msp.V01_00.MspVersionMsgV01_00;

public class MspHandlerV01_02 extends MspHandler {
   private MspHelloMsgV01_00 helloMsg;
   private MspVersionMsgV01_00 versionMsg;
   private MspAuthRdmSessionIdMsgV01_02 authRdmSessionIdMsg;
   private MspAuthLoginMsgV01_02 authLoginMsg;
   private MspAuthHttpSessionIdMsgV01_02 authHttpSessionIdMsg;
   private MspAuthChallengeMsgV01_02 authChallengeMsg;
   private MspAuthResponseMsgV01_02 authResponseMsg;
   private MspResponseConnectionMsgV01_02 responseConnectionMsg;
   private MspRequestConnectionMsgV01_02 requestConnectionMsg;
   private MspPingMsgV01_02 pingMsg;
   private MspPongMsgV01_02 pongMsg;
   private MspQuitMsgV01_02 quitMsg;
   private MspRequestDataMsgV01_02 requestDataMsg;
   private MspSendDataMsgV01_02 sendDataMsg;
   private MspDataAckMsgV01_02 dataAckMsg;
   private boolean connectionRequestSent = false;

   @Override
   protected void loadPdus() {
      this.helloMsg = new MspHelloMsgV01_00();
      this.versionMsg = new MspVersionMsgV01_00();
      this.authRdmSessionIdMsg = new MspAuthRdmSessionIdMsgV01_02();
      this.authLoginMsg = new MspAuthLoginMsgV01_02();
      this.authHttpSessionIdMsg = new MspAuthHttpSessionIdMsgV01_02();
      this.authChallengeMsg = new MspAuthChallengeMsgV01_02();
      this.authResponseMsg = new MspAuthResponseMsgV01_02();
      this.responseConnectionMsg = new MspResponseConnectionMsgV01_02();
      this.requestConnectionMsg = new MspRequestConnectionMsgV01_02();
      this.pingMsg = new MspPingMsgV01_02();
      this.pongMsg = new MspPongMsgV01_02();
      this.quitMsg = new MspQuitMsgV01_02();
      this.requestDataMsg = new MspRequestDataMsgV01_02();
      this.sendDataMsg = new MspSendDataMsgV01_02();
      this.dataAckMsg = new MspDataAckMsgV01_02();
   }

   @Override
   protected boolean supportsRdmAuth() {
      return false;
   }

   @Override
   protected boolean haveOldErrors() {
      return true;
   }

   @Override
   protected void negotiateProtocolVersion() throws IOException, VMException {
      this.helloMsg.write(this.os);
      this.versionMsg.read(this.is);
      this.versionMajor = this.versionMsg.versionMajor;
      this.versionMinor = this.versionMsg.versionMinor;
      this.versionMsg.write(this.os, this.versionMajor, this.versionMinor);
   }

   @Override
   protected void processInitialHandshake(int var1) throws IOException, VMException {
      switch (var1) {
         case 128:
            if (!this.connectionRequestSent) {
               this.sendConnectionRequest(true);
               this.connectionRequestSent = true;
            } else {
               this.initialHandshakeFinished();
            }
      }
   }

   @Override
   public void close() {
      this.shouldRun = false;

      try {
         this.writeQuitMsg(0);
      } catch (IOException var2) {
         this.logger.log(Level.SEVERE, "IOexception sending MSp Quit Message", (Throwable)var2);
      }
   }

   @Override
   protected synchronized void writeAuthRdmSessionIdMsg() throws IOException {
      this.authRdmSessionIdMsg.write(this.os, this.rdmSessionID);
   }

   @Override
   protected synchronized void writeAuthLoginMsg() throws IOException {
      this.authLoginMsg.write(this.os, this.username, this.password);
   }

   @Override
   protected synchronized void writeAuthSessionIdMsg() throws IOException {
      this.authHttpSessionIdMsg.write(this.os);
   }

   @Override
   protected synchronized void writeChallengeResponseMsg(String var1) throws IOException, VMException {
      this.authResponseMsg.write(this.os, var1);
   }

   @Override
   protected synchronized void writeConnectionRequestMsg(int var1, int var2, int var3, boolean var4, RedirectedObject var5) throws IOException, VMException {
      this.requestConnectionMsg.write(this.os, var1, var2, var3, var4, var5);
   }

   @Override
   protected synchronized void writePingMsg() throws IOException {
      this.pingMsg.write(this.os);
   }

   @Override
   protected synchronized void writePongMsg() throws IOException {
      this.pongMsg.write(this.os);
   }

   @Override
   protected synchronized void writeSendDataMsg(int var1, int var2, int var3, byte[] var4) throws IOException {
      this.sendDataMsg.write(this.os, var1, var2, var3, var4);
   }

   @Override
   protected synchronized void writeDataAckMsg(int var1) throws IOException {
      this.dataAckMsg.write(this.os, var1);
   }

   @Override
   protected synchronized void writeQuitMsg(int var1) throws IOException {
      this.quitMsg.write(this.os, var1);
   }

   @Override
   protected byte[] readAuthChallengeMsg() throws IOException, VMException {
      this.authChallengeMsg.read(this.is);
      return this.authChallengeMsg.challenge;
   }

   @Override
   protected boolean readResponseConnectionMsg() throws IOException {
      this.responseConnectionMsg.read(this.is, true);
      this.connectionResponseReason = this.responseConnectionMsg.reason;
      return this.responseConnectionMsg.success;
   }

   @Override
   protected void readPingMsg() throws IOException {
      this.pingMsg.read(this.is, true);
   }

   @Override
   protected void readPongMsg() throws IOException {
      this.pongMsg.read(this.is, true);
   }

   @Override
   protected int readQuitMsg() throws IOException {
      this.quitMsg.read(this.is, true);
      return this.quitMsg.reason;
   }

   @Override
   protected void readRequestDataMsg() throws IOException {
      this.requestDataMsg.read(this.is, true);
      this.readSectorCount = this.requestDataMsg.sectorCount;
      this.readStartSector = this.requestDataMsg.startSector;
   }

   @Override
   protected void readSendDataMsg() throws IOException {
      this.sendDataMsg.read(this.is, true);
      this.writeBuffer = this.sendDataMsg.writeBuffer;
      this.writeStartSector = this.sendDataMsg.startSector;
      this.writeSectorCount = this.sendDataMsg.sectorCount;
   }
}
