package nn.pp.rccore;

import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.event.KeyEvent;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import javax.net.ssl.X509TrustManager;
import javax.swing.JComponent;
import javax.swing.KeyStroke;
import nn.pp.core.NotificationListener;

public interface RCCore {
   void dispose();

   JComponent getRCJComponent();

   void setX509TrustManager(X509TrustManager var1);

   void connectRCWithUserLogin(String var1, int var2, boolean var3, String var4, String var5, String var6) throws IOException, RCException;

   void connectRCWithRdmSession(String var1, int var2, boolean var3, String var4, String var5, String var6, String var7) throws IOException, RCException;

   void connectRCWithEricKey(String var1, int var2, boolean var3, String var4, String var5) throws IOException, RCException;

   void disconnect();

   boolean isEncodingChangeSupported();

   boolean isEncodingAutoSupported();

   List<RCCore.Predefine> getSupportedEncodingPredefines();

   List<RCCore.ColorDepth> getSupportedEncodingColorDepths();

   List<RCCore.Compression> getSupportedEncodingCompressions();

   boolean isEncodingLossySupported();

   boolean isEncodingAuto();

   RCCore.ColorDepth getEncodingColorDepth();

   RCCore.Compression getEncodingCompression();

   boolean isEncodingLossy();

   void setEncodingToAuto() throws IOException;

   void setEncodingPredefine(RCCore.Predefine var1) throws IOException;

   void setEncodingColorDepth(RCCore.ColorDepth var1, boolean var2) throws IOException;

   void setEncodingCompression(RCCore.Compression var1, boolean var2) throws IOException, IllegalArgumentException;

   void setEncodingLossy(boolean var1, boolean var2) throws IOException;

   List<RCCore.ColorDepth> getSupportedColorDepthsForCompression(RCCore.Compression var1);

   List<RCCore.Compression> getSupportedCompressionsForColorDepth(RCCore.ColorDepth var1);

   RCCore.ColorDepth getEncodingColorDepthForPredefine(RCCore.Predefine var1);

   RCCore.Compression getEncodingCompressionForPredefine(RCCore.Predefine var1);

   boolean getEncodingLossyForPredefine(RCCore.Predefine var1);

   boolean isVideoSettingsSupported();

   boolean isVideoAutoAdjustSupported();

   boolean isColorCalibrationSupported();

   void requestVideoSettingsUpdates() throws IOException;

   void stopVideoSettingsUpdates() throws IOException;

   IVideoSettings getVideoSettings();

   void setVideoSettings(IVideoSettings var1) throws IOException;

   void saveVideoSettings() throws IOException;

   void cancelVideoSettings() throws IOException;

   void resetVideoSettingsAllModes() throws IOException;

   void resetVideoSettingsThisMode() throws IOException;

   void resetVideoSettingsThisPort() throws IOException;

   void requestVideoAutoSense() throws IOException;

   void requestVideoColorCalibration() throws IOException;

   boolean isVideoRefreshSupported();

   void requestVideoRefresh() throws IOException;

   Dimension getResolution();

   boolean isMouseModeChangeSupported();

   List<RCCore.MouseMode> getSupportedMouseModes();

   RCCore.MouseMode getMouseMode();

   void setMouseMode(RCCore.MouseMode var1) throws IOException;

   boolean isSingleCursorModeSupported();

   boolean isSingleCursorMode();

   void setSingleCursorMode(boolean var1);

   void setCaptureRightAway(boolean var1);

   boolean isMouseSyncSupported();

   void syncMouse(RCCore.MouseSyncType var1) throws IOException;

   boolean isAudioStatusSupportEnabled();

   void sendKeyboardEvent(int var1, boolean var2) throws IOException;

   void sendKeyboardMacro(IKeyboardMacro var1, boolean var2);

   List<RCCore.KeyboardLed> getKeyboardLedState();

   List<IKeyboardMacro> getKeyboardMacroList();

   void setKeyboardMacroList(List<IKeyboardMacro> var1) throws IOException;

   void enforceSMMHotKeyCheck(boolean var1);

   void setMouseSyncHotkey(String var1, KeyStroke var2);

   void setHotkeys(Map<Integer, KeyStroke> var1);

   Locale getSoftKeyboardMapping();

   void setSoftKeyboardMapping(Locale var1) throws IOException;

   List<Locale> getSupportedLocalKeyboardMappings();

   Locale getLocalKeyboardMapping();

   void setLocalKeyboardMapping(Locale var1) throws IOException, IllegalArgumentException;

   boolean isLocalKeyboardMappingPersistent();

   void setLocalKeyboardMappingPersistent(boolean var1);

   boolean isVirtualMediaSupported();

   boolean isVirtualMediaReadOnly();

   int getVirtualMediaDriveCount();

   boolean isVirtualMediaRemoteIsoSupported();

   IUsbProfileList getUsbProfileList();

   void virtualMediaConfigChanged(IVMConfigInfo var1);

   void requestUsbProfileChange(int var1) throws IOException;

   List<IVMMountRequestResponse> getVirtualMediaRemoteIsoList();

   void mountOrUnmountRemoteIso(IVMMountRequestResponse var1) throws IOException, RCException;

   List<? extends IKvmPort> getPortList();

   void switchKvmPort(int var1, String var2) throws IOException, RCException;

   double getScalingX();

   double getScalingY();

   boolean isScaleToFit();

   boolean isScaleToFitKeepAr();

   void setScaling(double var1, double var3) throws IllegalArgumentException, UnsupportedOperationException;

   void setScaleToFit(boolean var1, boolean var2, Dimension var3) throws UnsupportedOperationException;

   RCCore.Interpolation getInterpolation();

   void setInterpolation(RCCore.Interpolation var1);

   RCCore.Smoothing getSmoothing();

   void setSmoothing(RCCore.Smoothing var1);

   void setOSD(String var1, int var2, boolean var3);

   Cursor getCursor();

   void setCursor(Cursor var1);

   int getServerSessionId();

   boolean hasMonitorModePermission();

   boolean isMonitorMode();

   void setMonitorMode(boolean var1);

   boolean hasExclusiveModePermission();

   boolean isExclusiveMode();

   void setExclusiveMode(boolean var1) throws IOException;

   int getConnectedUsers();

   BufferedImage getSnapshot(Rectangle var1) throws IllegalArgumentException;

   BufferedImage getSnapshot();

   void sendChatMessage(String var1) throws IOException;

   int getIncomingTrafficSpeed();

   int getOutgoingTrafficSpeed();

   int getFramesPerSecond();

   String getDeviceName();

   String getProtocolVersion();

   void addNotificationListener(NotificationListener var1);

   void removeNotificationListener(NotificationListener var1);

   void addConnectionEventListener(ConnectionEventListener var1, int var2);

   void removeConnectionEventListener(ConnectionEventListener var1);

   void addVideoEventListener(VideoEventListener var1, int var2);

   void removeVideoEventListener(VideoEventListener var1);

   void addAudioStatusListener(AudioStatusListener var1);

   void removeAudioStatusListener(AudioStatusListener var1);

   void addMouseModeListener(MouseModeListener var1, int var2);

   void removeMouseModeListener(MouseModeListener var1);

   void addKeyboardInfoListener(KeyboardInfoListener var1, int var2);

   void removeKeyboardInfoListener(KeyboardInfoListener var1);

   void addVirtualMediaInfoListener(VirtualMediaInfoListener var1, int var2);

   void removeVirtualMediaInfoListener(VirtualMediaInfoListener var1);

   void addKeyboardListener(KeyboardListener var1);

   void removeKeyboardListener(KeyboardListener var1);

   void addMouseEventListener(MouseEventListener var1, int var2);

   void removeMouseEventListener(MouseEventListener var1);

   int getKeyCode(int var1, char var2, int var3);

   void setAppletParameterMap(LinkedHashMap<String, String> var1);

   boolean isEthernetGigabitSupported();

   void setLowBandwidth(boolean var1);

   void setConnectionProperties(boolean var1, RCCore.Compression var2, RCCore.ColorDepth var3, RCCore.Smoothing var4);

   void sendKeyboardEvent(KeyEvent var1) throws RCException;

   void sendMouseEvent(boolean var1, int var2, int var3, int var4);

   void setClientFrameSizeChanged(Dimension var1);

   void setClientSessionInitProperties(Map<RCCore.ClientSessionInitProperties, String> var1);

   <CT> CT getCapablity(Class<CT> var1);

   boolean isOsdDisabled();

   void setOsdDisabled(boolean var1);

   boolean isTrafficSpeed();

   void setTrafficSpeed(boolean var1);

   boolean isFPS();

   void setFPS(boolean var1);

   void setVideoUpdateDelay(int var1);

   int getVideoUpdateDelay();

   void putClientProperty(Object var1, Object var2);

   Object getClientProperty(Object var1);

   public static enum ClientSessionInitProperties {
      SCAN_REFEENCE_ID;
   }

   public static enum ColorDepth {
      COLOR_32_BIT,
      COLOR_24_BIT,
      COLOR_16_BIT,
      COLOR_8_BIT,
      COLOR_4_BIT,
      GREY_4_BIT,
      GREY_3_BIT,
      GREY_2_BIT,
      BW_1_BIT;
   }

   public static enum Compression {
      VIDEO_OPTIMIZED,
      UNCOMPRESSED,
      LEVEL_1,
      LEVEL_2,
      LEVEL_3,
      LEVEL_4,
      LEVEL_5,
      LEVEL_6,
      LEVEL_7,
      LEVEL_8,
      LEVEL_9;
   }

   public static enum Interpolation {
      NONE,
      FAST,
      GOOD,
      BEST;
   }

   public static enum KeyboardLed {
      LED_CAPSLOCK,
      LED_NUMLOCK,
      LED_SCROLLLOCK;
   }

   public static enum MouseMode {
      ABSOLUTE,
      AUTOMATIC,
      STANDARD;
   }

   public static enum MouseSyncType {
      FAST,
      HARD,
      NORM;
   }

   public static enum Predefine {
      VIDEO_HICOLOR,
      VIDEO,
      LAN_HICOLOR,
      LAN,
      DSL,
      UMTS,
      ISDN,
      MODEM,
      GPRS,
      GSM,
      MODEM_4BIT;
   }

   public static enum Smoothing {
      LOW {
         @Override
         public Integer eval() {
            return new Integer(0);
         }
      },
      HIGH {
         @Override
         public Integer eval() {
            return new Integer(1);
         }
      },
      NONE {
         @Override
         public Integer eval() {
            return new Integer(2);
         }
      };

      private Smoothing() {
      }

      public abstract Integer eval();
   }
}
