package com.sun.deploy.association;

import com.sun.deploy.association.utility.AppUtility;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class Association {
   private String name;
   private String description;
   private String mimeType;
   private List fileExtensionList;
   private String iconFileName;
   private List actionList;
   private int hashcode;

   public String getName() {
      return this.name;
   }

   public void setName(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given mime file name is null.");
      } else {
         this.name = var1;
      }
   }

   public String getDescription() {
      return this.description;
   }

   public void setDescription(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given description is null.");
      } else {
         this.description = var1;
      }
   }

   public String getMimeType() {
      return this.mimeType;
   }

   public void setMimeType(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given MIME type is null.");
      } else {
         this.mimeType = var1;
      }
   }

   public boolean addFileExtension(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given file extension is null.");
      } else {
         var1 = AppUtility.addDotToFileExtension(var1);
         if (this.fileExtensionList == null) {
            this.fileExtensionList = new ArrayList();
         }

         return this.fileExtensionList.add(var1);
      }
   }

   public boolean removeFileExtension(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given file extension is null.");
      } else {
         var1 = AppUtility.addDotToFileExtension(var1);
         return this.fileExtensionList != null ? this.fileExtensionList.remove(var1) : false;
      }
   }

   public List getFileExtList() {
      if (this.fileExtensionList == null) {
         return null;
      } else {
         ArrayList var1 = new ArrayList();
         Iterator var2 = this.fileExtensionList.iterator();

         while (var2.hasNext()) {
            var1.add(var2.next());
         }

         return var1;
      }
   }

   public String getIconFileName() {
      return this.iconFileName;
   }

   public void setIconFileName(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given icon file name is null.");
      } else {
         this.iconFileName = var1;
      }
   }

   public boolean addAction(Action var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given action is null.");
      } else if (var1.getVerb() == null) {
         throw new IllegalArgumentException("the given action object has null verb field.");
      } else if (var1.getCommand() == null) {
         throw new IllegalArgumentException("the given action object has null command field.");
      } else {
         if (this.actionList == null) {
            this.actionList = new ArrayList();
         }

         return this.actionList.add(new Action(var1.getVerb(), var1.getCommand(), var1.getDescription()));
      }
   }

   public boolean removeAction(Action var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The given action is null.");
      } else if (var1.getVerb() == null || var1.getCommand() == null) {
         throw new IllegalArgumentException("the given action object has null verb field or command field.");
      } else {
         return this.actionList != null ? this.actionList.remove(var1) : false;
      }
   }

   public List getActionList() {
      if (this.actionList == null) {
         return null;
      } else {
         ArrayList var1 = new ArrayList();
         Iterator var2 = this.actionList.iterator();

         while (var2.hasNext()) {
            var1.add(var2.next());
         }

         return var1;
      }
   }

   public Action getActionByVerb(String var1) {
      if (this.actionList != null) {
         Iterator var2 = this.actionList.iterator();
         if (var2 != null) {
            while (var2.hasNext()) {
               Action var3 = (Action)var2.next();
               String var4 = var3.getVerb();
               if (var4.equalsIgnoreCase(var1)) {
                  return var3;
               }
            }
         }
      }

      return null;
   }

   public boolean equals(Object var1) {
      if (!(var1 instanceof Association)) {
         return false;
      } else {
         Association var2 = (Association)var1;
         String var6 = var2.getDescription();
         String var7 = var2.getIconFileName();
         String var8 = var2.getMimeType();
         boolean var3 = (this.description == null ? var6 == null : this.description.equals(var6))
            && (this.iconFileName == null ? var7 == null : this.iconFileName.equals(var7))
            && (this.mimeType == null ? var8 == null : this.mimeType.equals(var8));
         if (!var3) {
            return false;
         } else {
            List var9 = var2.getFileExtList();
            boolean var5 = false;
            if (this.fileExtensionList == null && var9 == null) {
               var5 = true;
            } else if (this.fileExtensionList != null && var9 != null && this.fileExtensionList.containsAll(var9) && var9.containsAll(this.fileExtensionList)) {
               var5 = true;
            }

            if (!var5) {
               return false;
            } else {
               List var10 = var2.getActionList();
               boolean var4 = false;
               if (this.actionList == null && var10 != null) {
                  var4 = true;
               } else if (this.actionList != null && var10 != null && this.actionList.containsAll(var10) && var10.containsAll(this.actionList)) {
                  var4 = true;
               }

               return var4;
            }
         }
      }
   }

   public int hashCode() {
      if (this.hashcode != 0) {
         int var1 = 17;
         if (this.name != null) {
            var1 = var1 * 37 + this.name.hashCode();
         }

         if (this.description != null) {
            var1 = var1 * 37 + this.description.hashCode();
         }

         if (this.mimeType != null) {
            var1 = var1 * 37 + this.mimeType.hashCode();
         }

         if (this.iconFileName != null) {
            var1 = var1 * 37 + this.iconFileName.hashCode();
         }

         if (this.fileExtensionList != null) {
            var1 = var1 * 37 + this.fileExtensionList.hashCode();
         }

         if (this.actionList != null) {
            var1 = var1 * 37 + this.actionList.hashCode();
         }

         this.hashcode = var1;
      }

      return this.hashcode;
   }

   public String toString() {
      String var1 = "\r\n";
      String var2 = "";
      var2 = var2.concat("MIME File Name: ");
      if (this.name != null) {
         var2 = var2.concat(this.name);
      }

      var2 = var2.concat(var1);
      var2 = var2.concat("Description: ");
      if (this.description != null) {
         var2 = var2.concat(this.description);
      }

      var2 = var2.concat(var1);
      var2 = var2.concat("MIME Type: ");
      if (this.mimeType != null) {
         var2 = var2.concat(this.mimeType);
      }

      var2 = var2.concat(var1);
      var2 = var2.concat("Icon File: ");
      if (this.iconFileName != null) {
         var2 = var2.concat(this.iconFileName);
      }

      var2 = var2.concat(var1);
      var2 = var2.concat("File Extension: ");
      if (this.fileExtensionList != null) {
         Iterator var3 = this.fileExtensionList.iterator();
         if (var3 != null) {
            while (var3.hasNext()) {
               var2 = var2.concat((String)var3.next());
               if (var3.hasNext()) {
                  var2 = var2.concat(" ");
               }
            }
         }
      }

      var2 = var2.concat(var1);
      var2 = var2.concat("Action List: ");
      if (this.actionList != null) {
         Iterator var16 = this.actionList.iterator();
         if (var16 != null) {
            var2 = var2.concat(var1);

            while (var16.hasNext()) {
               Action var4 = (Action)var16.next();
               var2 = var2.concat(var4.toString());
            }
         }
      }

      return var2.concat(var1);
   }
}
