package com.sun.deploy.association;

import com.sun.deploy.association.utility.AppAssociationReader;
import com.sun.deploy.association.utility.AppAssociationReaderFactory;
import com.sun.deploy.association.utility.AppAssociationWriter;
import com.sun.deploy.association.utility.AppAssociationWriterFactory;
import com.sun.deploy.association.utility.AppUtility;
import java.net.URL;
import java.util.Iterator;
import java.util.List;

public class AssociationService {
   private AppAssociationReader appAssocReader = AppAssociationReaderFactory.newInstance();
   private AppAssociationWriter appAssocWriter = AppAssociationWriterFactory.newInstance();

   public Association getMimeTypeAssociation(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified mime type is null");
      } else if (!this.appAssocReader.isMimeTypeExist(var1)) {
         return null;
      } else {
         Association var2 = new Association();
         List var3 = this.appAssocReader.getFileExtListByMimeType(var1);
         String var4 = this.appAssocReader.getIconFileNameByMimeType(var1);
         String var5 = this.appAssocReader.getDescriptionByMimeType(var1);
         List var6 = this.appAssocReader.getActionListByMimeType(var1);
         var2.setMimeType(var1);
         if (var3 != null) {
            Iterator var7 = var3.iterator();
            if (var7 != null) {
               while (var7.hasNext()) {
                  var2.addFileExtension((String)var7.next());
               }
            }
         }

         if (var4 != null) {
            var2.setIconFileName(var4);
         }

         if (var5 != null) {
            var2.setDescription(var5);
         }

         if (var6 != null) {
            Iterator var8 = var6.iterator();
            if (var8 != null) {
               while (var8.hasNext()) {
                  var2.addAction((Action)var8.next());
               }
            }
         }

         return var2;
      }
   }

   public Association getFileExtensionAssociation(String var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified file extension is null");
      } else {
         var1 = AppUtility.addDotToFileExtension(var1);
         if (!this.appAssocReader.isFileExtExist(var1)) {
            return null;
         } else {
            Association var2 = new Association();
            String var3 = this.appAssocReader.getMimeTypeByFileExt(var1);
            String var4 = this.appAssocReader.getIconFileNameByFileExt(var1);
            String var5 = this.appAssocReader.getDescriptionByFileExt(var1);
            List var6 = this.appAssocReader.getActionListByFileExt(var1);
            var2.addFileExtension(var1);
            if (var4 != null) {
               var2.setIconFileName(var4);
            }

            if (var3 != null) {
               var2.setMimeType(var3);
            }

            if (var5 != null) {
               var2.setDescription(var5);
            }

            if (var6 != null) {
               Iterator var7 = var6.iterator();
               if (var7 != null) {
                  while (var7.hasNext()) {
                     var2.addAction((Action)var7.next());
                  }
               }
            }

            return var2;
         }
      }
   }

   public Association getAssociationByContent(URL var1) {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified URL is null");
      } else {
         Association var2 = null;
         String var3 = this.appAssocReader.getMimeTypeByURL(var1);
         if (var3 != null) {
            var2 = this.getMimeTypeAssociation(var3);
         }

         if (var2 == null) {
            String var4 = AppUtility.getFileExtensionByURL(var1);
            if (var4 != null) {
               var2 = this.getFileExtensionAssociation(var4);
            }
         }

         return var2;
      }
   }

   public void registerUserAssociation(Association var1) throws AssociationAlreadyRegisteredException, RegisterFailedException {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified association is null");
      } else {
         try {
            this.appAssocWriter.checkAssociationValidForRegistration(var1);
         } catch (IllegalArgumentException var3) {
            throw var3;
         }

         if (this.appAssocWriter.isAssociationExist(var1, 1)) {
            throw new AssociationAlreadyRegisteredException("Assocation already exists!");
         } else {
            this.appAssocWriter.registerAssociation(var1, 1);
         }
      }
   }

   public void unregisterUserAssociation(Association var1) throws AssociationNotRegisteredException, RegisterFailedException {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified association is null");
      } else {
         try {
            this.appAssocWriter.checkAssociationValidForUnregistration(var1);
         } catch (IllegalArgumentException var3) {
            throw var3;
         }

         if (!this.appAssocWriter.isAssociationExist(var1, 1)) {
            throw new AssociationNotRegisteredException("Assocation not exists!");
         } else {
            this.appAssocWriter.unregisterAssociation(var1, 1);
         }
      }
   }

   public void registerSystemAssociation(Association var1) throws AssociationAlreadyRegisteredException, RegisterFailedException {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified association is null");
      } else {
         try {
            this.appAssocWriter.checkAssociationValidForRegistration(var1);
         } catch (IllegalArgumentException var3) {
            throw var3;
         }

         if (this.appAssocWriter.isAssociationExist(var1, 2)) {
            throw new AssociationAlreadyRegisteredException("Assocation already exists!");
         } else {
            this.appAssocWriter.registerAssociation(var1, 2);
         }
      }
   }

   public void unregisterSystemAssociation(Association var1) throws AssociationNotRegisteredException, RegisterFailedException {
      if (var1 == null) {
         throw new IllegalArgumentException("The specified association is null");
      } else {
         try {
            this.appAssocWriter.checkAssociationValidForUnregistration(var1);
         } catch (IllegalArgumentException var3) {
            throw var3;
         }

         if (!this.appAssocWriter.isAssociationExist(var1, 2)) {
            throw new AssociationNotRegisteredException("Assocation not existed!");
         } else {
            this.appAssocWriter.unregisterAssociation(var1, 2);
         }
      }
   }
}
