package com.sun.deploy.association.utility;

import com.sun.deploy.association.Action;
import com.sun.deploy.association.Association;
import com.sun.deploy.association.RegisterFailedException;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;

public class GnomeAppAssociationWriter implements AppAssociationWriter {
   static String GNOMEDIR_VALUE = GnomeAssociationUtil.getEnv("GNOMEDIR");
   static String GNOME_LINUX_SYSTEM_SHARE_DIR = GNOMEDIR_VALUE == null ? "/usr/share/" : GNOMEDIR_VALUE + "/share/";
   static String GNOME_SOLARIS_SYSTEM_SHARE_DIR = "/usr/share/gnome/";
   static String GNOME_LINUX_SYSTEM_MIME_INFO_DIR = GNOME_LINUX_SYSTEM_SHARE_DIR + "mime-info/";
   static String GNOME_SOLARIS_SYSTEM_MIME_INFO_DIR = GNOME_SOLARIS_SYSTEM_SHARE_DIR + "mime-info/";
   static String GNOME_LINUX_SYSTEM_APPLICATION_REGISTRY_DIR = GNOME_LINUX_SYSTEM_SHARE_DIR + "application-registry/";
   static String GNOME_SOLARIS_SYSTEM_APPLICATION_REGISTRY_DIR = GNOME_SOLARIS_SYSTEM_SHARE_DIR + "application-registry/";
   static String OSNAME = System.getProperty("os.name").toLowerCase();
   static String GNOME_SYSTEM_MIME_INFO_DIR = OSNAME.equals("linux") ? GNOME_LINUX_SYSTEM_MIME_INFO_DIR : GNOME_SOLARIS_SYSTEM_MIME_INFO_DIR;
   static String GNOME_SYSTEM_APPLICATION_REGISTRY_DIR = OSNAME.equals("linux")
      ? GNOME_LINUX_SYSTEM_APPLICATION_REGISTRY_DIR
      : GNOME_SOLARIS_SYSTEM_APPLICATION_REGISTRY_DIR;
   static String GNOME_USER_MIME_INFO_DIR = System.getProperty("user.home") + "/.gnome/mime-info/";
   static String GNOME_USER_APPLICATION_INFO_DIR = System.getProperty("user.home") + "/.gnome/application-info/";
   static String MIME_SUFFIX = ".mime";
   static String KEYS_SUFFIX = ".keys";
   static String APPLICATIONS_SUFFIX = ".applications";
   private String defaultAppID = null;
   private String defaultAppCommand = null;

   private String fileExtListToString(List var1) {
      String var2 = "";
      Iterator var3 = var1.iterator();
      if (var3 != null) {
         while (var3.hasNext()) {
            String var4 = (String)var3.next();
            if (var4 != null) {
               var4 = AppUtility.removeDotFromFileExtension(var4);
               if (var2.length() == 0) {
                  var2 = var2.concat(var4);
               } else {
                  var2 = var2.concat(' ' + var4);
               }
            }
         }
      } else {
         var2 = null;
      }

      return var2;
   }

   private String getSystemDotMimeFilePath(Association var1) {
      return GNOME_SYSTEM_MIME_INFO_DIR + var1.getName() + MIME_SUFFIX;
   }

   private String getSystemDotKeysFilePath(Association var1) {
      return GNOME_SYSTEM_MIME_INFO_DIR + var1.getName() + KEYS_SUFFIX;
   }

   private String getSystemDotApplicationsFilePath(Association var1) {
      return GNOME_SYSTEM_APPLICATION_REGISTRY_DIR + var1.getName() + APPLICATIONS_SUFFIX;
   }

   private String getUserDotMimeFilePath(Association var1) {
      return GNOME_USER_MIME_INFO_DIR + var1.getName() + MIME_SUFFIX;
   }

   private String getUserDotKeysFilePath(Association var1) {
      return GNOME_USER_MIME_INFO_DIR + var1.getName() + KEYS_SUFFIX;
   }

   private String getUserDotApplicationsFilePath(Association var1) {
      return GNOME_USER_APPLICATION_INFO_DIR + var1.getName() + APPLICATIONS_SUFFIX;
   }

   private void checkSystemMIMEDatabase() throws IOException {
      Object var1 = null;
      var1 = new File(GNOME_SYSTEM_MIME_INFO_DIR);
      if (!var1.exists()) {
         throw new IOException(
            "The system MIME info directory doesn't exist: "
               + GNOME_SYSTEM_MIME_INFO_DIR
               + ". Make sure Gnome 2.0+ is installed and env GNOMEDIR is set properly."
         );
      } else {
         var1 = new File(GNOME_SYSTEM_APPLICATION_REGISTRY_DIR);
         if (!var1.exists()) {
            throw new IOException(
               "The system MIME info directory doesn't exist: "
                  + GNOME_SYSTEM_APPLICATION_REGISTRY_DIR
                  + ". Make sure Gnome 2.0+ is installed and env GNOMEDIR is set properly."
            );
         } else {
            var1 = new File(GNOME_SYSTEM_MIME_INFO_DIR);
            if (!var1.canWrite()) {
               throw new IOException("No write permission to the system MIME info directory: " + GNOME_SYSTEM_MIME_INFO_DIR);
            } else {
               var1 = new File(GNOME_SYSTEM_APPLICATION_REGISTRY_DIR);
               if (!var1.canWrite()) {
                  throw new IOException("No write permission to the system MIME info directory: " + GNOME_SYSTEM_APPLICATION_REGISTRY_DIR);
               }
            }
         }
      }
   }

   private void checkUserMIMEDatabase() throws IOException {
      File var1 = null;
      var1 = new File(GNOME_USER_MIME_INFO_DIR);
      if (!var1.exists()) {
         boolean var2 = var1.mkdirs();
         if (!var2) {
            throw new IOException("The user MIME info directory doesn't exist, and fails to be created: " + GNOME_USER_MIME_INFO_DIR);
         }
      }

      var1 = new File(GNOME_USER_APPLICATION_INFO_DIR);
      if (!var1.exists()) {
         boolean var7 = var1.mkdirs();
         if (!var7) {
            throw new IOException("The user MIME info directory doesn't exist, and fails to be created: " + GNOME_USER_APPLICATION_INFO_DIR);
         }
      }

      var1 = new File(GNOME_USER_MIME_INFO_DIR);
      if (!var1.canWrite()) {
         throw new IOException("No write permission to the user MIME info directory: " + GNOME_USER_MIME_INFO_DIR);
      } else {
         var1 = new File(GNOME_USER_APPLICATION_INFO_DIR);
         if (!var1.canWrite()) {
            throw new IOException("No write permission to the user MIME info directory: " + GNOME_USER_MIME_INFO_DIR);
         }
      }
   }

   private void createFile(String var1) throws IOException {
      boolean var2 = false;
      File var3 = new File(var1);
      if (!var3.exists()) {
         var2 = var3.createNewFile();
         if (!var2) {
            throw new IOException("Create MIME file: " + var1 + " failed.");
         }
      }
   }

   private void parseOpenAction(Association var1) {
      List var2 = var1.getActionList();
      if (var2 != null) {
         Object var3 = null;
         Iterator var4 = var2.iterator();

         while (var4.hasNext() && this.defaultAppCommand == null) {
            Action var5 = (Action)var4.next();
            var3 = var5.getVerb();
            if (var3.equalsIgnoreCase("open")) {
               this.defaultAppCommand = var5.getCommand().trim();
            }
         }

         if (this.defaultAppCommand != null) {
            int var7 = this.defaultAppCommand.lastIndexOf(File.separator);
            if (var7 != -1 && var7 != this.defaultAppCommand.length() - 1) {
               this.defaultAppID = this.defaultAppCommand.substring(var7 + 1, this.defaultAppCommand.length());
            } else {
               this.defaultAppID = this.defaultAppCommand;
            }
         }
      }
   }

   private void writeDotMimeFile(Association var1, String var2) throws IOException {
      this.createFile(var2);
      String var3 = var1.getMimeType();
      List var4 = var1.getFileExtList();
      BufferedWriter var5 = null;

      try {
         var5 = new BufferedWriter(new FileWriter(var2, true));
         var5.write(var3 + "\n");
         Object var6 = null;
         if (var4 == null) {
            var6 = "";
         } else {
            var6 = this.fileExtListToString(var4);
         }

         var5.write("\text: " + var6 + "\n");
         var5.write("\n");
      } catch (IOException var14) {
         throw new IOException("Write mime info to " + var2 + " failed.");
      } finally {
         if (var5 != null) {
            try {
               var5.close();
            } catch (IOException var13) {
            }
         }
      }
   }

   private void writeDotKeysFile(Association var1, String var2) throws IOException {
      this.createFile(var2);
      String var3 = var1.getMimeType();
      String var4 = var1.getDescription();
      String var5 = var1.getIconFileName();
      BufferedWriter var6 = null;

      try {
         var6 = new BufferedWriter(new FileWriter(var2, true));
         var6.write(var3 + "\n");
         if (var4 != null) {
            var6.write("\tdescription=" + var4 + "\n");
         }

         if (var5 != null) {
            var6.write("\ticon_filename=" + var5 + "\n");
         }

         this.parseOpenAction(var1);
         if (this.defaultAppID != null) {
            var6.write("\tdefault_action_type=application\n");
            var6.write("\tdefault_application_id=" + this.defaultAppID + "\n");
            var6.write("\tshort_list_application_user_additions=" + this.defaultAppID + "\n");
         }

         var6.write("\n");
      } catch (IOException var15) {
         throw new IOException("Write mime info to " + var2 + " failed.");
      } finally {
         if (var6 != null) {
            try {
               var6.close();
            } catch (IOException var14) {
            }
         }
      }
   }

   private void writeDotApplicationsFile(Association var1, String var2) throws IOException {
      this.createFile(var2);
      BufferedWriter var3 = null;

      try {
         this.parseOpenAction(var1);
         if (this.defaultAppID != null && this.defaultAppCommand != null) {
            var3 = new BufferedWriter(new FileWriter(var2, true));
            var3.write(this.defaultAppID + "\n");
            var3.write("\tcommand=" + this.defaultAppCommand + "\n");
            var3.write("\tname=" + this.defaultAppID + "\n");
            var3.write("\tcan_open_multiple_files=false\n");
            var3.write("\trequires_terminal=false\n");
            String var4 = var1.getMimeType();
            var3.write("\tmime_types=" + var4 + "\n");
            var3.write("\n");
         }
      } catch (IOException var12) {
         throw new IOException("Write mime info to " + var2 + " failed.");
      } finally {
         if (var3 != null) {
            try {
               var3.close();
            } catch (IOException var11) {
            }
         }
      }
   }

   private boolean dotMimeFileContainsMimeType(File var1, String var2) {
      boolean var3 = false;

      try {
         BufferedReader var4 = new BufferedReader(new FileReader(var1));

         String var5;
         while ((var5 = var4.readLine()) != null) {
            if (var2.equals(var5)) {
               var3 = true;
               break;
            }
         }

         var4.close();
         return var3;
      } catch (IOException var6) {
         return false;
      }
   }

   public void checkAssociationValidForRegistration(Association var1) throws IllegalArgumentException {
      if (var1.getName() == null || var1.getMimeType() == null) {
         throw new IllegalArgumentException("The given association is invalid. It should specify both the name and mimeType fields to perform this operation.");
      }
   }

   public void checkAssociationValidForUnregistration(Association var1) throws IllegalArgumentException {
      if (var1.getName() == null) {
         throw new IllegalArgumentException("The given association is invalid. It should specify the name field to perform this operation.");
      }
   }

   public boolean isAssociationExist(Association var1, int var2) {
      Object var3 = null;
      if (var2 == 2) {
         var3 = new File(this.getSystemDotMimeFilePath(var1));
      } else {
         var3 = new File(this.getUserDotMimeFilePath(var1));
      }

      if (var3.exists()) {
         return var1.getMimeType() == null ? true : this.dotMimeFileContainsMimeType((File)var3, var1.getMimeType());
      } else {
         return false;
      }
   }

   public void registerAssociation(Association var1, int var2) throws RegisterFailedException {
      String var3 = null;
      String var4 = null;
      String var5 = null;

      try {
         if (var2 == 2) {
            this.checkSystemMIMEDatabase();
            var3 = this.getSystemDotMimeFilePath(var1);
            var4 = this.getSystemDotKeysFilePath(var1);
            var5 = this.getSystemDotApplicationsFilePath(var1);
         } else {
            this.checkUserMIMEDatabase();
            var3 = this.getUserDotMimeFilePath(var1);
            var4 = this.getUserDotKeysFilePath(var1);
            var5 = this.getUserDotApplicationsFilePath(var1);
         }

         this.writeDotMimeFile(var1, var3);
         this.writeDotKeysFile(var1, var4);
         this.writeDotApplicationsFile(var1, var5);
      } catch (IOException var7) {
         if (var3 != null) {
            new File(var3).delete();
         }

         if (var4 != null) {
            new File(var4).delete();
         }

         if (var5 != null) {
            new File(var5).delete();
         }

         throw new RegisterFailedException(var7.getMessage());
      }
   }

   public void unregisterAssociation(Association var1, int var2) throws RegisterFailedException {
      Object var3 = null;
      Object var4 = null;
      Object var5 = null;

      try {
         if (var2 == 2) {
            this.checkSystemMIMEDatabase();
            var3 = this.getSystemDotMimeFilePath(var1);
            var4 = this.getSystemDotKeysFilePath(var1);
            var5 = this.getSystemDotApplicationsFilePath(var1);
         } else {
            this.checkUserMIMEDatabase();
            var3 = this.getUserDotMimeFilePath(var1);
            var4 = this.getUserDotKeysFilePath(var1);
            var5 = this.getUserDotApplicationsFilePath(var1);
         }

         new File((String)var3).delete();
         new File((String)var4).delete();
         new File((String)var5).delete();
      } catch (IOException var7) {
         throw new RegisterFailedException(var7.getMessage());
      }
   }
}
