package com.sun.deploy.config;

import com.sun.deploy.panel.ControlPanel;
import com.sun.deploy.panel.PlatformSpecificUtils;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import com.sun.deploy.util.URLUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.security.Security;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;
import java.util.Properties;
import java.util.StringTokenizer;

public class Config {
   private static Properties _defaultProps = null;
   private static Properties _systemProps = null;
   private static Properties _props = null;
   private static Properties _changedProps = null;
   private static Properties _lockedProps = null;
   private static String _javaHome = null;
   private static String _userHome = null;
   private static String _systemHome = null;
   private static String _osHome = null;
   private static File _userConfigFile = null;
   private static long _lastChanged;
   private static boolean _dirty;
   private static final String PROPERTIES_FILE = "deployment.properties";
   private static final String CONFIG_FILE = "deployment.config";
   private static final String BASE = "deployment.";
   private static final String USER = "deployment.user.";
   private static final String SYSTEM = "deployment.system.";
   private static final String SEC = "deployment.security.";
   private static final String USEC = "deployment.user.security.";
   private static final String SSEC = "deployment.system.security.";
   private static final String PROX = "deployment.proxy.";
   private static final String JAVAPI = "deployment.javapi.";
   private static final String JAVAWS = "deployment.javaws.";
   public static final String VERSION_UPDATED_KEY = "deployment.version";
   public static final String VERSION_UPDATE_THIS = "1.5.0";
   public static final String CACHEDIR_KEY = "deployment.user.cachedir";
   public static final String CACHEDIR_DEF = "$USER_HOME" + File.separator + "cache";
   public static final String SYSCACHE_KEY = "deployment.system.cachedir";
   public static final String SEC_TLS_KEY = "deployment.security.TLSv1";
   public static final boolean SEC_TLS_DEF = false;
   public static final String SEC_SSLv2_KEY = "deployment.security.SSLv2Hello";
   public static final boolean SEC_SSLv2_DEF = true;
   public static final String SEC_SSLv3_KEY = "deployment.security.SSLv3";
   public static final boolean SEC_SSLv3_DEF = true;
   public static final String JAVAWS_CACHE_KEY = "deployment.javaws.cachedir";
   public static final String JAVAPI_CACHE_KEY = "deployment.javapi.cachedir";
   public static final String LOGDIR_KEY = "deployment.user.logdir";
   public static final String LOGDIR_DEF = "$USER_HOME" + File.separator + "log";
   public static final String JAVAWS_TRACEFILE_KEY = "deployment.javaws.traceFileName";
   public static final String JAVAWS_TRACEFILE_DEF = "";
   public static final String JAVAWS_LOGFILE_KEY = "deployment.javaws.logFileName";
   public static final String JAVAWS_LOGFILE_DEF = "";
   public static final String TMPDIR_KEY = "deployment.user.tmp";
   public static final String TMPDIR_DEF = "$USER_HOME" + File.separator + "tmp";
   public static final String USR_EXTDIR_KEY = "deployment.user.extdir";
   public static final String USR_EXTDIR_DEF = "$USER_HOME" + File.separator + "ext";
   public static final String SYS_EXTDIR_KEY = "deployment.system.extdir";
   public static final String USEC_POLICY_KEY = "deployment.user.security.policy";
   public static final String USEC_CACERTS_KEY = "deployment.user.security.trusted.cacerts";
   public static final String USEC_CACERTS_DEF = "$USER_HOME" + File.separator + "security" + File.separator + "trusted.cacerts";
   public static final String USEC_JSSECERTS_KEY = "deployment.user.security.trusted.jssecacerts";
   public static final String USEC_JSSECERTS_DEF = "$USER_HOME" + File.separator + "security" + File.separator + "trusted.jssecacerts";
   public static final String USEC_TRUSTED_CERTS_KEY = "deployment.user.security.trusted.certs";
   public static final String USEC_TRUSTED_CERTS_DEF = "$USER_HOME" + File.separator + "security" + File.separator + "trusted.certs";
   public static final String USEC_TRUSTED_JSSE_CERTS_KEY = "deployment.user.security.trusted.jssecerts";
   public static final String USEC_TRUSTED_JSSE_CERTS_DEF = "$USER_HOME" + File.separator + "security" + File.separator + "trusted.jssecerts";
   public static final String USEC_TRUSTED_CLIENT_CERTS_KEY = "deployment.user.security.trusted.clientauthcerts";
   public static final String USEC_TRUSTED_CLIENT_CERTS_DEF = "$USER_HOME" + File.separator + "security" + File.separator + "trusted.clientcerts";
   public static final String APPCONTEXT_APP_NAME_KEY = "deploy.trust.decider.app.name";
   public static final String SSEC_POLICY_KEY = "deployment.system.security.policy";
   public static final String SSEC_CACERTS_KEY = "deployment.system.security.cacerts";
   public static final String SSEC_CACERTS_DEF = "$JAVA_HOME" + File.separator + "lib" + File.separator + "security" + File.separator + "cacerts";
   public static final String SSEC_JSSECERTS_KEY = "deployment.system.security.jssecacerts";
   public static final String SSEC_JSSECERTS_DEF = "$JAVA_HOME" + File.separator + "lib" + File.separator + "security" + File.separator + "jssecacerts";
   public static final String SSEC_TRUSTED_CERTS_KEY = "deployment.system.security.trusted.certs";
   public static final String SSEC_TRUSTED_CERTS_DEF = "$JAVA_HOME" + File.separator + "lib" + File.separator + "security" + File.separator + "trusted.certs";
   public static final String SSEC_TRUSTED_JSSE_CERTS_KEY = "deployment.system.security.trusted.jssecerts";
   public static final String SSEC_TRUSTED_JSSE_CERTS_DEF = "$JAVA_HOME"
      + File.separator
      + "lib"
      + File.separator
      + "security"
      + File.separator
      + "trusted.jssecerts";
   public static final String SSEC_TRUSTED_CLIENT_CERTS_KEY = "deployment.system.security.trusted.clientauthcerts";
   public static final String SSEC_TRUSTED_CLIENT_CERTS_DEF = "$JAVA_HOME"
      + File.separator
      + "lib"
      + File.separator
      + "security"
      + File.separator
      + "trusted.clientcerts";
   public static final String SEC_ASKGRANT_SHOW_KEY = "deployment.security.askgrantdialog.show";
   public static final boolean SEC_ASKGRANT_SHOW_DEF = true;
   public static final String SEC_ASKGRANT_NOTCA_KEY = "deployment.security.askgrantdialog.notinca";
   public static final boolean SEC_ASKGRANT_NOTCA_DEF = true;
   public static final String SEC_USE_BROWSER_KEYSTORE_KEY = "deployment.security.browser.keystore.use";
   public static final boolean SEC_USE_BROWSER_KEYSTORE_DEF = true;
   public static final String SEC_USE_CLIENTAUTH_AUTO_KEY = "deployment.security.clientauth.keystore.auto";
   public static final boolean SEC_USE_CLIENTAUTH_AUTO_DEF = true;
   public static final String SEC_NOTINCA_WARN_KEY = "deployment.security.notinca.warning";
   public static final boolean SEC_NOTINCA_WARN_DEF = true;
   public static final String SEC_EXPIRED_WARN_KEY = "deployment.security.expired.warning";
   public static final boolean SEC_EXPIRED_WARN_DEF = true;
   public static final String SEC_JSSE_HOST_WARN_KEY = "deployment.security.jsse.hostmismatch.warning";
   public static final boolean SEC_JSSE_HOST_WARN_DEF = true;
   public static final String SEC_TRUSTED_POLICY_KEY = "deployment.security.trusted.policy";
   public static final String SEC_TRUSTED_POLICY_DEF = "";
   public static final String SEC_AWT_WARN_WINDOW_KEY = "deployment.security.sandbox.awtwarningwindow";
   public static final boolean SEC_AWT_WARN_WINDOW_DEF = true;
   public static final String SEC_SANDBOX_JNLP_ENHANCED_KEY = "deployment.security.sandbox.jnlp.enhanced";
   public static final boolean SEC_SANDBOX_JNLP_ENHANCED_DEF = true;
   public static final String SEC_AUTHENTICATOR_KEY = "deployment.security.authenticator";
   public static final boolean SEC_AUTHENTICATOR_DEF = true;
   public static final String REMOTE_JNLP_DOCS_KEY = "deployment.javaws.home.jnlp.url";
   public static final String REMOTE_JNLP_DOCS_DEF = "http://java.sun.com/products/javawebstart";
   public static final String REMOTE_J2SE_DOCS_KEY = "deployment.home.j2se.url";
   public static final String REMOTE_J2SE_DOCS_DEF = "http://java.sun.com/j2se/";
   public static final String JAVAWS_SSV_ENABLED_KEY = "deployment.javaws.ssv.enabled";
   public static final boolean JAVAWS_SSV_ENABLED_DEF = true;
   public static final int PROX_TYPE_UNKNOWN = -1;
   public static final int PROX_TYPE_NONE = 0;
   public static final int PROX_TYPE_MANUAL = 1;
   public static final int PROX_TYPE_AUTO = 2;
   public static final int PROX_TYPE_BROWSER = 3;
   public static final int PROX_TYPE_SYSTEM = 4;
   public static final String PROX_TYPE_KEY = "deployment.proxy.type";
   public static final int PROX_TYPE_DEF = 3;
   public static final String PROX_SAME_KEY = "deployment.proxy.same";
   public static final boolean PROX_SAME_DEF = false;
   public static final String PROX_LOCAL_KEY = "deployment.proxy.bypass.local";
   public static final boolean PROX_LOCAL_DEF = false;
   public static final String PROX_AUTOCFG_KEY = "deployment.proxy.auto.config.url";
   public static final String PROX_BYPASS_KEY = "deployment.proxy.bypass.list";
   public static final String PROX_HTTP_HOST_KEY = "deployment.proxy.http.host";
   public static final String PROX_HTTP_PORT_KEY = "deployment.proxy.http.port";
   public static final String PROX_HTTPS_HOST_KEY = "deployment.proxy.https.host";
   public static final String PROX_HTTPS_PORT_KEY = "deployment.proxy.https.port";
   public static final String PROX_FTP_HOST_KEY = "deployment.proxy.ftp.host";
   public static final String PROX_FTP_PORT_KEY = "deployment.proxy.ftp.port";
   public static final String PROX_SOX_HOST_KEY = "deployment.proxy.socks.host";
   public static final String PROX_SOX_PORT_KEY = "deployment.proxy.socks.port";
   public static final String PROX_OVERRIDE_KEY = "deployment.proxy.override.hosts";
   public static final String PROX_OVERRIDE_DEF = "";
   public static final String CACHE_MAX_KEY = "deployment.cache.max.size";
   public static final String CACHE_MAX_DEF = "-1";
   public static final String CACHE_COMPRESSION_KEY = "deployment.cache.jarcompression";
   public static final int CACHE_COMPRESSION_DEF = 0;
   public static final String CACHE_ENABLED_KEY = "deployment.javapi.cache.enabled";
   public static final boolean CACHE_ENABLED_DEF = true;
   public static final String OPR_ENABLED_KEY = "deployment.repository.enabled";
   public static final boolean OPR_ENABLED_DEF = true;
   public static final String OPR_ASK_SHOW_KEY = "deployment.repository.askdownloaddialog.show";
   public static final boolean OPR_ASK_SHOW_DEF = true;
   public static final String SPLASH_CACHE_INDEX_KEY = "deployment.javaws.splash.index";
   public static final String CONSOLE_MODE_HIDE = "HIDE";
   public static final String CONSOLE_MODE_SHOW = "SHOW";
   public static final String CONSOLE_MODE_DISABLED = "DISABLE";
   public static final String CONSOLE_MODE_KEY = "deployment.console.startup.mode";
   public static final String CONSOLE_MODE_DEF = "HIDE";
   public static final String TRACE_MODE_KEY = "deployment.trace";
   public static final boolean TRACE_MODE_DEF = false;
   public static final String TRACE_LEVEL_KEY = "deployment.trace.level";
   public static final String LOG_MODE_KEY = "deployment.log";
   public static final boolean LOG_MODE_DEF = false;
   public static final String LOG_CP_KEY = "deployment.control.panel.log";
   public static final boolean LOG_CP_DEF = false;
   public static final String USE_SYSTEM_LF_KEY = "deployment.system.lookandfeel";
   public static final String JPI_TRACE_FILE_KEY = "deployment.javapi.trace.filename";
   public static final String JPI_TRACE_FILE_DEF = "";
   public static final String JPI_LOG_FILE_KEY = "deployment.javapi.log.filename";
   public static final String JPI_LOG_FILE_DEF = "";
   public static final String SHOW_EXCEPTIONS_KEY = "deployment.javapi.lifecycle.exception";
   public static final boolean SHOW_EXCEPTIONS_DEF = false;
   public static final int JPI_RUNTIME_TYPE_JRE = 0;
   public static final int JPI_RUNTIME_TYPE_JDK = 1;
   public static final String JPI_RUNTIME_VER_KEY = "deployment.javapi.runtime.version";
   public static final String JPI_RUNTIME_VER_DEF = "";
   public static final String JPI_RUNTIME_TYPE_KEY = "deployment.javapi.runtime.type";
   public static final int JPI_RUNTIME_TYPE_DEF = 0;
   public static final String JPI_JAVA_PATH = ".path";
   public static final String JPI_JAVA_ARGS = ".args";
   public static final String JPI_JAVA_OSNAME = ".osname";
   public static final String JPI_JAVA_OSARCH = ".osarch";
   public static final String JPI_JRE_KEY = "deployment.javapi.jre.";
   public static final String JPI_JDK_KEY = "deployment.javapi.jdk.";
   public static final String ASSOCIATION_MODE_KEY = "deployment.javaws.associations";
   public static final String ASSOCIATION_MODE_NEVER = "NEVER";
   public static final String ASSOCIATION_MODE_NEW_ONLY = "NEW_ONLY";
   public static final String ASSOCIATION_MODE_ASK_USER = "ASK_USER";
   public static final String ASSOCIATION_MODE_REPLACE_ASK = "REPLACE_ASK";
   public static final String ASSOCIATION_MODE_DEF = "ASK_USER";
   public static final int ASSOCIATION_NEVER = 0;
   public static final int ASSOCIATION_NEW_ONLY = 1;
   public static final int ASSOCIATION_ASK_USER = 2;
   public static final int ASSOCIATION_REPLACE_ASK = 3;
   public static final int SHORTCUT_NEVER = 0;
   public static final int SHORTCUT_NO = 0;
   public static final int SHORTCUT_ALWAYS = 1;
   public static final int SHORTCUT_YES = 1;
   public static final int SHORTCUT_ASK_USER = 2;
   public static final int SHORTCUT_ASK_IF_HINTED = 3;
   public static final int SHORTCUT_ALWAYS_IF_HINTED = 4;
   public static final String SHORTCUT_MODE_NEVER = "NEVER";
   public static final String SHORTCUT_MODE_ALWAYS = "ALWAYS";
   public static final String SHORTCUT_MODE_ASK_USER = "ASK_USER";
   public static final String SHORTCUT_MODE_ASK_IF_HINTED = "ASK_IF_HINTED";
   public static final String SHORTCUT_MODE_ALWAYS_IF_HINTED = "ALWAYS_IF_HINTED";
   public static final String SHORTCUT_MODE_KEY = "deployment.javaws.shortcut";
   public static final String SHORTCUT_MODE_DEF = "ASK_IF_HINTED";
   public static final String SHORTCUT_UNINSTALL_KEY = "deployment.javaws.uninstall.shortcut";
   public static final boolean SHORTCUT_UNINSTALL_DEF = false;
   public static final String JAVAWS_JRE_PLATFORM_ID = ".platform";
   public static final String JAVAWS_JRE_PRODUCT_ID = ".product";
   public static final String JAVAWS_JRE_LOCATION = ".location";
   public static final String JAVAWS_JRE_PATH = ".path";
   public static final String JAVAWS_JRE_OS_ARCH = ".osarch";
   public static final String JAVAWS_JRE_OS_NAME = ".osname";
   public static final String JAVAWS_JRE_ISENABLED = ".enabled";
   public static final String JAVAWS_JRE_ISREGISTERED = ".registered";
   public static final String JAVAWS_JRE_KEY = "deployment.javaws.jre.";
   public static final String JAVAWS_JRE_INSTALL_KEY = "deployment.javaws.installURL";
   public static final String JAVAWS_JRE_INSTALL_DEF = "http://java.sun.com/products/autodl/j2se";
   public static final String AUTODOWNLOAD_MODE_ALWAYS = "ALWAYS";
   public static final String AUTODOWNLOAD_MODE_PROMPT = "PROMPT";
   public static final String AUTODOWNLOAD_MODE_NEVER = "NEVER";
   public static final String JAVAWS_JRE_AUTODOWNLOAD_KEY = "deployment.javaws.autodownload";
   public static final String JAVAWS_JRE_AUTODOWNLOAD_DEF = "ALWAYS";
   public static final String JAUTHENTICATOR_SYSTEM_PROP = "javaws.cfg.jauthenticator";
   public static final String BROWSER_PATH_KEY = "deployment.browser.path";
   public static final String BROWSER_PATH_DEF = "<No Browser Selected>";
   public static final String EXTENDED_BROWSER_ARGS_KEY = "deployment.browser.args";
   public static final String EXTENDED_BROWSER_ARGS_DEF = "-raise -remote openURL(%u,new-window)";
   public static final String CAPTURE_MIME_KEY = "deployment.capture.mime.types";
   public static final boolean CAPTURE_MIME_DEF = false;
   public static final String UPDATE_MIME_KEY = "deployment.update.mime.types";
   public static final boolean UPDATE_MIME_DEF = true;
   public static final String MIME_DEFAULTS_KEY = "deployment.mime.types.use.default";
   public static final boolean MIME_DEFAULTS_MIME_DEF = true;
   public static final String JAVAWS_MUFFIN_LIMIT_KEY = "deployment.javaws.muffin.max";
   public static final int JAVAWS_MUFFIN_LIMIT_DEF = 256;
   public static final String JAVAWS_UPDATE_TIMEOUT_KEY = "deployment.javaws.update.timeout";
   public static final int JAVAWS_UPDATE_TIMEOUT_DEF = 1500;
   public static final String SECURE_PROPS_KEY = "deployment.javaws.secure.properties";
   private static final String[] DefaultSecureProperties = new String[]{
      "sun.java2d.noddraw",
      "javax.swing.defaultlf",
      "javaws.cfg.jauthenticator",
      "swing.useSystemFontSettings",
      "swing.metalTheme",
      "http.agent",
      "http.keepAlive"
   };
   private static String[] secureVmArgs = new String[]{
      "-d32",
      "-client",
      "-server",
      "-verbose",
      "-version",
      "-showversion",
      "-help",
      "-X",
      "-ea",
      "-enableassertions",
      "-da",
      "-disableassertions",
      "-esa",
      "-enablesystemassertions",
      "-dsa",
      "-disablesystemassertions",
      "-Xmixed",
      "-Xint",
      "-Xnoclassgc",
      "-Xincgc",
      "-Xbatch",
      "-Xprof",
      "-Xdebug",
      "-Xfuture",
      "-Xrs",
      "-XX:+ForceTimeHighResolution",
      "-XX:-ForceTimeHighResolution"
   };
   private static String[] secureVmPrefixes = new String[]{
      "-ea:",
      "-enableassertions:",
      "-da:",
      "-disableassertions:",
      "-verbose:",
      "-Xms",
      "-Xmx",
      "-Xss",
      "-XX:NewRatio",
      "-XX:NewSize",
      "-XX:MaxNewSize",
      "-XX:PermSize",
      "-XX:MaxPermSize",
      "-XX:MaxHeapFreeRatio",
      "-XX:MinHeapFreeRatio",
      "-XX:UseSerialGC",
      "-XX:ThreadStackSize",
      "-XX:MaxInlineSize",
      "-XX:ReservedCodeCacheSize"
   };
   private static boolean _configOK = false;
   private static Config _config;
   private static String _os = System.getProperty("os.name");
   private static String _arch;
   private static String _platform;
   private static ControlPanel _ControlPanel = null;
   private static final String _javaVersionProperty = System.getProperty("java.version");
   private static final boolean _atLeast13 = !_javaVersionProperty.startsWith("1.2");
   private static final boolean _atLeast14 = !_javaVersionProperty.startsWith("1.2") && !_javaVersionProperty.startsWith("1.3");
   private static final boolean _atLeast15 = _atLeast14 && !_javaVersionProperty.startsWith("1.4");
   private static String _enterprizeConfig = null;
   private static long _start;
   private static long _end;

   public static void setControlPanel(ControlPanel var0) {
      _ControlPanel = var0;
   }

   public static boolean isJavaVersionAtLeast15() {
      return _atLeast15;
   }

   public static boolean isJavaVersionAtLeast14() {
      return _atLeast14;
   }

   public static boolean isJavaVersionAtLeast13() {
      return _atLeast13;
   }

   public static synchronized Config getInstance() {
      if (_config == null) {
         _config = ConfigFactory.newInstance();
      }

      return _config;
   }

   public static void reInit() {
      initialize();
   }

   public static boolean isConfigValid() {
      return _configOK;
   }

   private static boolean initialize() {
      boolean var0 = true;
      _defaultProps = getDefaultProps();
      _systemProps = new Properties();
      _userConfigFile = new File(_userHome + File.separator + getPropertiesFilename());
      File var1 = new File(_systemHome + File.separator + "deployment.config");
      if (!var1.exists()) {
         var1 = new File(_javaHome + File.separator + "lib" + File.separator + "deployment.config");
      }

      if (var1.exists()) {
         Properties var2 = loadPropertiesFile(new Properties(), var1);
         if (var2 != null) {
            String var3 = var2.getProperty("deployment.system.config.mandatory");
            boolean var4 = var3 != null && !var3.equalsIgnoreCase("false");
            String var5 = var2.getProperty("deployment.system.config");
            _enterprizeConfig = var5;
            if (var5 != null && !tryDownloading(var5, _systemProps)) {
               var0 = !var4;
            }
         }
      }

      refreshProps();
      versionUpdateCheck();
      Properties var6 = System.getProperties();
      Enumeration var7 = _props.propertyNames();

      while (var7.hasMoreElements()) {
         String var8 = (String)var7.nextElement();
         String var9 = getProperty(var8);
         if (var9 != null) {
            var6.put(var8, var9);
         }
      }

      System.setProperties(var6);
      setPolicyFiles();
      return var0;
   }

   public static void getBrowserSettings() {
      PlatformSpecificUtils.initBrowserSettings();
   }

   public static void setBrowserSettings() {
      PlatformSpecificUtils.applyBrowserSettings();
   }

   private static boolean tryDownloading(String var0, Properties var1) {
      try {
         URL var2 = new URL(var0);
         URLConnection var3 = var2.openConnection();
         InputStream var4 = var3.getInputStream();
         var1.load(var4);
         return true;
      } catch (Exception var5) {
         Trace.ignoredException(var5);
         return false;
      }
   }

   private static void setPolicyFiles() {
      String var0 = getSystemSecurityPolicyURL();
      String var1 = getUserSecurityPolicyURL();
      if (var0 != null || var1 != null) {
         int var2 = 1;
         Object var3 = null;

         while (Security.getProperty("policy.url." + var2) != null) {
            var2++;
         }

         if (var0 != null) {
            Security.setProperty("policy.url." + var2, var0);
            var2++;
         }

         if (var1 != null) {
            Security.setProperty("policy.url." + var2, var1);
            var2++;
         }
      }
   }

   public static void refreshProps() {
      Properties var0 = new Properties();
      Properties var1 = new Properties();
      Properties var2 = new Properties();
      Properties var3 = new Properties();
      Properties var4 = new Properties();
      _lockedProps = new Properties();
      _props = new Properties(_defaultProps);
      if (_userConfigFile.exists()) {
         loadPropertiesFile(var0, _userConfigFile);
         _lastChanged = _userConfigFile.lastModified();
      } else {
         _lastChanged = System.currentTimeMillis();
      }

      Enumeration var5 = _systemProps.keys();

      while (var5.hasMoreElements()) {
         String var6 = (String)var5.nextElement();
         String var7 = _systemProps.getProperty(var6);
         if (var6.startsWith("deployment.javaws.jre.")) {
            var2.setProperty(var6, var7);
         } else if (var6.endsWith(".locked")) {
            int var8 = var6.length() - ".locked".length();
            var6 = var6.substring(0, var8);
            String var9 = _systemProps.getProperty(var6);
            if (var9 != null) {
               _lockedProps.setProperty(var6, var9);
            }
         } else if (var6.startsWith("deployment.")) {
            _props.setProperty(var6, var7);
         }
      }

      var5 = var0.keys();

      while (var5.hasMoreElements()) {
         String var13 = (String)var5.nextElement();
         String var15 = var0.getProperty(var13);
         if (var13.startsWith("deployment.javaws.jre.")) {
            var1.setProperty(var13, var15);
         } else if (var13.startsWith("deployment.javapi.jre.")) {
            var3.setProperty(var13, var15);
         } else if (var13.startsWith("deployment.javapi.jdk.")) {
            var4.setProperty(var13, var15);
         } else if (var13.startsWith("deployment.") || var13.startsWith("javaplugin")) {
            _props.setProperty(var13, var15);
         }
      }

      var5 = _lockedProps.keys();

      while (var5.hasMoreElements()) {
         String var14 = (String)var5.nextElement();
         _props.setProperty(var14, _lockedProps.getProperty(var14));
      }

      JREInfo.initialize(var2, var1);
      PluginJavaInfo.initialize(var3, var4);
      _dirty = false;
      _changedProps = new Properties();
   }

   public static void refreshUnchangedProps() {
      Properties var0 = _changedProps;
      refreshProps();
      Enumeration var1 = var0.keys();

      while (var1.hasMoreElements()) {
         String var2 = (String)var1.nextElement();
         setProperty(var2, var0.getProperty(var2));
      }
   }

   public static String getPropertiesFilename() {
      return "deployment.properties";
   }

   public static boolean isDiskNewer() {
      return _userConfigFile.exists() && _userConfigFile.lastModified() > _lastChanged;
   }

   public static String booleanToString(boolean var0) {
      return var0 ? "true" : "false";
   }

   public static void refreshIfNecessary() {
      if (!_dirty && isDiskNewer()) {
         refreshProps();
      }
   }

   public static void store() {
      if (_dirty && isDiskNewer()) {
         Properties var0 = _changedProps;
         refreshProps();
         Enumeration var1 = var0.keys();

         while (var1.hasMoreElements()) {
            String var2 = (String)var1.nextElement();
            setProperty(var2, var0.getProperty(var2));
         }
      }

      Properties var11 = new Properties();
      Properties var12 = new Properties();
      Properties var13 = new Properties();
      Enumeration var3 = _props.keys();

      while (var3.hasMoreElements()) {
         String var4 = (String)var3.nextElement();
         if (!isLocked(var4)) {
            String var5 = _props.getProperty(var4);
            String var6 = _systemProps.getProperty(var4);
            String var7 = _defaultProps.getProperty(var4);
            if (var5 == null || var6 != null && !var5.equals(var6) || var6 == null && !var5.equals(var7)) {
               var11.setProperty(var4, var5);
            }
         }
      }

      PluginJavaInfo[] var14 = PluginJavaInfo.getAll();

      for (int var16 = 0; var16 < var14.length; var16++) {
         String var19 = var14[var16].getProduct();
         String var20 = var14[var16].getPath();
         String var8 = var14[var16].getVmArgs();
         if (var19 != null && !var19.trim().equals("") && var20 != null && !var20.trim().equals("") && isValidJPIJavaPath(var20)) {
            if (var14[var16].getProductName().equalsIgnoreCase("jre")) {
               var13.setProperty("deployment.javapi.jre." + var19 + ".path", var20);
               if (var8 != null) {
                  var13.setProperty("deployment.javapi.jre." + var19 + ".args", var8);
               }

               if (var14[var16].getOSArch() != null) {
                  var13.setProperty("deployment.javapi.jre." + var19 + ".osarch", var14[var16].getOSArch());
               }

               if (var14[var16].getOSName() != null) {
                  var13.setProperty("deployment.javapi.jre." + var19 + ".osname", var14[var16].getOSName());
               }
            } else {
               var13.setProperty("deployment.javapi.jdk." + var19 + ".path", var20);
               if (var8 != null) {
                  var13.setProperty("deployment.javapi.jdk." + var19 + ".args", var8);
               }
            }
         }
      }

      JREInfo[] var15 = JREInfo.get();

      for (int var17 = 0; var17 < var15.length; var17++) {
         if (!var15[var17].isSystemJRE()) {
            if (var15[var17].getPlatform() != null) {
               var12.setProperty("deployment.javaws.jre." + var17 + ".platform", var15[var17].getPlatform());
            }

            if (var15[var17].getProduct() != null) {
               var12.setProperty("deployment.javaws.jre." + var17 + ".product", var15[var17].getProduct());
            }

            if (var15[var17].getLocation() != null) {
               var12.setProperty("deployment.javaws.jre." + var17 + ".location", var15[var17].getLocation());
            }

            if (var15[var17].getPath() != null) {
               var12.setProperty("deployment.javaws.jre." + var17 + ".path", var15[var17].getPath());
            }

            if (var15[var17].getOSArch() != null) {
               var12.setProperty("deployment.javaws.jre." + var17 + ".osarch", var15[var17].getOSArch());
            }

            if (var15[var17].getOSName() != null) {
               var12.setProperty("deployment.javaws.jre." + var17 + ".osname", var15[var17].getOSName());
            }

            var12.setProperty("deployment.javaws.jre." + var17 + ".enabled", booleanToString(var15[var17].isEnabled()));
            var12.setProperty("deployment.javaws.jre." + var17 + ".registered", booleanToString(var15[var17].isRegistered()));
         }
      }

      _userConfigFile.getParentFile().mkdirs();

      try {
         FileOutputStream var18 = new FileOutputStream(_userConfigFile);

         try {
            var11.store(var18, getPropertiesFilename());
            var12.store(var18, "Java Web Start jre's");
            var13.store(var18, "Java Plugin jre's");
         } catch (IOException var9) {
            Trace.println("Exception: " + var9);
         }

         var18.flush();
         var18.close();
      } catch (IOException var10) {
      }

      _dirty = false;
      _changedProps = new Properties();
      _lastChanged = _userConfigFile.exists() ? _userConfigFile.lastModified() : System.currentTimeMillis();
   }

   public static boolean isValidJPIJavaPath(String var0) {
      String var1 = "java";
      if (System.getProperty("os.name").indexOf("Windows") != -1) {
         var1 = var1 + ".exe";
      }

      if (var0 != null) {
         if (var0.endsWith(File.separator)) {
            var0 = var0 + "bin" + File.separator + var1;
         } else {
            var0 = var0 + File.separator + "bin" + File.separator + var1;
         }

         File var2 = new File(var0);
         return var2.exists();
      } else {
         return false;
      }
   }

   public static void storeIfDirty() {
      if (_dirty) {
         store();
      }
   }

   public static Properties getProperties() {
      Properties var0 = new Properties(_props);
      Enumeration var3 = var0.propertyNames();

      while (var3.hasMoreElements()) {
         String var1 = (String)var3.nextElement();
         String var2 = var0.getProperty(var1);
         if (var2 != null) {
            var0.setProperty(var1, replaceVariables(var2).trim());
         }
      }

      return var0;
   }

   public static boolean isLocked(String var0) {
      return _lockedProps.containsKey(var0);
   }

   public static String getJavaHome() {
      if (_javaHome == null) {
         String var0 = System.getProperty("jnlpx.home");
         if (var0 != null) {
            var0 = var0.substring(0, var0.lastIndexOf(File.separator));
         } else {
            var0 = System.getProperty("java.home");
         }

         _javaHome = var0;
      }

      return _javaHome;
   }

   public static String getOSHome() {
      return _osHome;
   }

   public static String getSystemHome() {
      return _systemHome;
   }

   public static String getUserHome() {
      return _userHome;
   }

   public static String getOSName() {
      return _os;
   }

   public static String getOSArch() {
      return _arch;
   }

   public static String getOSPlatform() {
      return _platform;
   }

   public static String getProperty(String var0) {
      String var1 = _props.getProperty(var0);
      return var1 != null ? replaceVariables(var1).trim() : null;
   }

   public static void setProperty(String var0, String var1) {
      setProperty(var0, var1, true);
   }

   public static void setProperty(String var0, String var1, boolean var2) {
      if (isDiskNewer()) {
         refreshIfNecessary();
      }

      if (var1 != null && var1.length() != 0) {
         if (var2) {
            var1 = restoreVariables(var1);
         }

         if (!var1.equals(_props.getProperty(var0))) {
            _dirty = true;
            _props.setProperty(var0, var1);
            _changedProps.setProperty(var0, var1);
            if (_ControlPanel != null) {
               ControlPanel.propertyHasChanged();
            }
         }
      } else {
         _dirty = _dirty | _props.containsKey(var0);
         _props.remove(var0);
         _changedProps.remove(var0);
      }
   }

   public static int getIntProperty(String var0) {
      String var1 = getProperty(var0);
      if (var1 == null) {
         return -1;
      } else {
         try {
            return Integer.parseInt(var1);
         } catch (NumberFormatException var3) {
            return -1;
         }
      }
   }

   public static void setIntProperty(String var0, int var1) {
      setProperty(var0, Integer.toString(var1));
   }

   public static boolean getBooleanProperty(String var0) {
      String var1 = getProperty(var0);
      return var1 == null ? false : Boolean.valueOf(var1);
   }

   public static void setBooleanProperty(String var0, boolean var1) {
      setProperty(var0, booleanToString(var1));
   }

   private static String restoreVariables(String var0) {
      if (var0.indexOf(_javaHome) >= 0) {
         var0 = substitute(var0, "$JAVA_HOME", _javaHome);
      }

      if (var0.indexOf(_userHome) >= 0) {
         var0 = substitute(var0, "$USER_HOME", _userHome);
      }

      if (var0.indexOf(_systemHome) >= 0) {
         var0 = substitute(var0, "$SYSTEM_HOME", _systemHome);
      }

      return var0;
   }

   private static String replaceVariables(String var0) {
      if (var0.indexOf("$JAVA_HOME") >= 0) {
         var0 = substitute(var0, _javaHome, "$JAVA_HOME");
      }

      if (var0.indexOf("$USER_HOME") >= 0) {
         var0 = substitute(var0, _userHome, "$USER_HOME");
      }

      if (var0.indexOf("SYSTEM_HOME") >= 0) {
         var0 = substitute(var0, _systemHome, "$SYSTEM_HOME");
      }

      return var0;
   }

   private static String substitute(String var0, String var1, String var2) {
      int var3 = var0.indexOf(var2);
      return var3 < 0 ? var0 : var0.substring(0, var3) + var1 + var0.substring(var3 + var2.length());
   }

   private static void versionUpdateCheck() {
      String var0 = getProperty("deployment.version");
      if (var0 == null || var0.compareTo("1.5.0") < 0) {
         Properties var1 = translateMantisProperties(_props);
         if (var1.getProperty("deployment.javaws.cachedir") == null) {
            String var2 = _userHome + File.separator + "javaws" + File.separator + "cache";
            if (new File(var2).exists()) {
               var1.setProperty("deployment.javaws.cachedir", var2);
            }
         }

         Properties var8 = null;
         File var3 = new File(_userHome);
         String var4 = var3.getParent() + File.separator + ".deployment";
         String var5 = var4 + File.separator + "deployment.properties";
         File var6 = new File(var5);
         if (var6.exists()) {
            var8 = translateMantisProperties(loadPropertiesFile(new Properties(), var6));
            if (var8.getProperty("deployment.javaws.cachedir") == null) {
               String var7 = var4 + File.separator + "javaws" + File.separator + "cache";
               if (new File(var7).exists()) {
                  var8.setProperty("deployment.javaws.cachedir", var7);
               }
            }
         }

         if (var8 == null) {
            String var9 = System.getProperty("user.home") + File.separator + ".javaws";
            var4 = var9 + File.separator + "javaws.cfg";
            File var11 = new File(var4);
            if (var11.exists()) {
               var8 = translateOlderProperties(loadPropertiesFile(new Properties(), var11), var9);
            }
         }

         if (var8 != null) {
            setProperties(var8);
         }

         if (var1 != null) {
            setProperties(var1);
         }

         setProperty("deployment.browser.path", getInstance().getBrowserPath());
         setProperty("deployment.version", "1.5.0");
         setBooleanProperty("deployment.capture.mime.types", true);
         storeIfDirty();
      }
   }

   private static void setProperties(Properties var0) {
      Enumeration var1 = var0.keys();

      while (var1.hasMoreElements()) {
         String var2 = (String)var1.nextElement();
         setProperty(var2, var0.getProperty(var2));
      }
   }

   private static Properties loadPropertiesFile(Properties var0, File var1) {
      try {
         FileInputStream var2 = new FileInputStream(var1);
         var0.load(var2);
         var2.close();
         return var0;
      } catch (FileNotFoundException var3) {
         Trace.println("Cannot find prop file: " + var1.getAbsolutePath());
         return null;
      } catch (IOException var4) {
         Trace.println("IO Execption: " + var4);
         return null;
      }
   }

   private static Properties translateMantisProperties(Properties var0) {
      Properties var1 = new Properties();
      Enumeration var2 = var0.keys();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         String var4 = null;
         String var5 = var0.getProperty(var3);
         if (var3.startsWith("deployment.javaws.proxy")) {
            if (var3.equals("deployment.javaws.proxy.httpport")) {
               var4 = "deployment.proxy.http.port";
            } else if (var3.equals("deployment.javaws.proxy.http")) {
               var4 = "deployment.proxy.http.host";
            } else if (var3.equals("deployment.javaws.proxy.httpproxyoverride")) {
               var4 = "deployment.proxy.override.hosts";
            }
         } else if (var3.startsWith("deployment.javaws.")) {
            if (var3.equals("deployment.javaws.logFileName")) {
               var4 = "deployment.javaws.traceFileName";
            } else if (var3.equals("deployment.javaws.showConsole")) {
               if (var5.equals("true")) {
                  var4 = "deployment.console.startup.mode";
                  var5 = "SHOW";
               }
            } else if (var3.equals("deployment.javaws.updateTimeout")) {
               var4 = "deployment.javaws.update.timeout";
            }
         } else if (var3.startsWith("javaplugin")) {
            var1.setProperty(var3, var5);
            if (var3.equals("javaplugin.cache.disabled")) {
               var4 = "deployment.javapi.cache.enabled";
               var5 = var5.equals("true") ? "false" : "true";
            } else if (var3.equals("javaplugin.cache.size")) {
               var4 = "deployment.cache.max.size";
            } else if (var3.equals("javaplugin.cache.compression")) {
               var4 = "deployment.cache.jarcompression";
            } else if (var3.equals("javaplugin.console")) {
               var4 = "deployment.console.startup.mode";
               if (var5.equals("show")) {
                  var5 = "SHOW";
               } else if (var5.equals("hide")) {
                  var5 = "HIDE";
               } else {
                  var5 = "DISABLE";
               }
            } else if (var3.equals("javaplugin.exception")) {
               var4 = "deployment.javapi.lifecycle.exception";
            }
         }

         if (var4 != null && var5 != null && var5.length() > 0) {
            var1.setProperty(var4, var5);
         }
      }

      String var6 = var0.getProperty("deployment.javaws.cache.dir");
      if (var6 != null) {
         var1.setProperty("deployment.javaws.cachedir", var6);
      }

      return var1;
   }

   private static Properties translateOlderProperties(Properties var0, String var1) {
      Properties var2 = new Properties();
      Enumeration var3 = var0.keys();

      while (var3.hasMoreElements()) {
         String var4 = (String)var3.nextElement();
         String var5 = var0.getProperty(var4);
         if (!var4.startsWith("javaws.cfg.jre.") && !var4.startsWith("javaws.cfg.splash") && !var4.startsWith("javaws.cfg.player")) {
            if (var4.equals("javaws.cfg.cache.dir")) {
               var2.setProperty("deployment.javaws.cachedir", var5);
            }

            if (var4.startsWith("javaws.cfg.")) {
               if (var4.equals("javaws.cfg.proxy.httpport")) {
                  var4 = "deployment.proxy.http.port";
               } else if (var4.equals("javaws.cfg.proxy.http")) {
                  var4 = "deployment.proxy.http.host";
               } else if (var4.equals("javaws.cfg.proxy.httpproxyoverride")) {
                  var4 = "deployment.proxy.override.hosts";
               } else {
                  var4 = var4.replaceFirst("javaws.cfg.", "deployment.");
               }

               if (var5 != null && var5.length() > 0) {
                  var2.setProperty(var4, var5);
               }
            }
         }
      }

      if (var2.getProperty("deployment.javaws.cachedir") == null) {
         String var7 = var1 + File.separator + "cache";
         if (new File(var7).exists()) {
            var2.setProperty("deployment.javaws.cachedir", var7);
         }
      }

      return var2;
   }

   private static Properties getDefaultProps() {
      Properties var0 = new Properties();
      var0.setProperty("deployment.javapi.trace.filename", "");
      var0.setProperty("deployment.javapi.log.filename", "");
      var0.setProperty("deployment.javaws.associations", "ASK_USER");
      var0.setProperty("deployment.javaws.traceFileName", "");
      var0.setProperty("deployment.javaws.logFileName", "");
      var0.setProperty("deployment.security.TLSv1", "false");
      var0.setProperty("deployment.security.SSLv2Hello", "true");
      var0.setProperty("deployment.security.SSLv3", "true");
      var0.setProperty("deployment.user.cachedir", CACHEDIR_DEF);
      var0.setProperty("deployment.user.logdir", LOGDIR_DEF);
      var0.setProperty("deployment.user.tmp", TMPDIR_DEF);
      var0.setProperty("deployment.user.extdir", USR_EXTDIR_DEF);
      String var1 = _userHome + File.separator + "security" + File.separator + "java.policy";
      var0.setProperty("deployment.user.security.policy", "file://" + URLUtil.encodePath(var1));
      var0.setProperty("deployment.user.security.trusted.cacerts", USEC_CACERTS_DEF);
      var0.setProperty("deployment.user.security.trusted.jssecacerts", USEC_JSSECERTS_DEF);
      var0.setProperty("deployment.user.security.trusted.certs", USEC_TRUSTED_CERTS_DEF);
      var0.setProperty("deployment.user.security.trusted.jssecerts", USEC_TRUSTED_JSSE_CERTS_DEF);
      var0.setProperty("deployment.user.security.trusted.clientauthcerts", USEC_TRUSTED_CLIENT_CERTS_DEF);
      var0.setProperty("deployment.system.security.cacerts", SSEC_CACERTS_DEF);
      var0.setProperty("deployment.system.security.jssecacerts", SSEC_JSSECERTS_DEF);
      var0.setProperty("deployment.system.security.trusted.certs", SSEC_TRUSTED_CERTS_DEF);
      var0.setProperty("deployment.system.security.trusted.jssecerts", SSEC_TRUSTED_JSSE_CERTS_DEF);
      var0.setProperty("deployment.system.security.trusted.clientauthcerts", SSEC_TRUSTED_CLIENT_CERTS_DEF);
      var0.setProperty("deployment.security.askgrantdialog.show", "true");
      var0.setProperty("deployment.security.askgrantdialog.notinca", "true");
      var0.setProperty("deployment.security.browser.keystore.use", "true");
      var0.setProperty("deployment.security.clientauth.keystore.auto", "true");
      var0.setProperty("deployment.security.notinca.warning", "true");
      var0.setProperty("deployment.security.expired.warning", "true");
      var0.setProperty("deployment.security.jsse.hostmismatch.warning", "true");
      var0.setProperty("deployment.security.trusted.policy", "");
      var0.setProperty("deployment.security.sandbox.awtwarningwindow", "true");
      var0.setProperty("deployment.security.sandbox.jnlp.enhanced", "true");
      var0.setProperty("deployment.security.authenticator", "true");
      var0.setProperty("deployment.proxy.type", "3");
      var0.setProperty("deployment.proxy.same", "false");
      var0.setProperty("deployment.proxy.bypass.local", "false");
      var0.setProperty("deployment.proxy.override.hosts", "");
      var0.setProperty("deployment.cache.max.size", "-1");
      var0.setProperty("deployment.cache.jarcompression", "0");
      var0.setProperty("deployment.javapi.cache.enabled", "true");
      var0.setProperty("deployment.repository.enabled", "true");
      var0.setProperty("deployment.repository.askdownloaddialog.show", "true");
      var0.setProperty("deployment.console.startup.mode", "HIDE");
      var0.setProperty("deployment.trace", "false");
      var0.setProperty("deployment.log", "false");
      var0.setProperty("deployment.control.panel.log", "false");
      var0.setProperty("deployment.javapi.lifecycle.exception", "false");
      var0.setProperty("deployment.javapi.runtime.type", "0");
      var0.setProperty("deployment.javaws.shortcut", "ASK_IF_HINTED");
      var0.setProperty("deployment.javaws.uninstall.shortcut", "false");
      var0.setProperty("deployment.browser.path", "<No Browser Selected>");
      var0.setProperty("deployment.browser.args", "-raise -remote openURL(%u,new-window)");
      var0.setProperty("deployment.capture.mime.types", "false");
      var0.setProperty("deployment.update.mime.types", "true");
      var0.setProperty("deployment.mime.types.use.default", "true");
      var0.setProperty("deployment.javaws.installURL", "http://java.sun.com/products/autodl/j2se");
      var0.setProperty("deployment.javaws.autodownload", "ALWAYS");
      var0.setProperty("deployment.javaws.muffin.max", "256");
      var0.setProperty("deployment.javaws.update.timeout", "1500");
      var0.setProperty("deployment.javaws.home.jnlp.url", "http://java.sun.com/products/javawebstart");
      var0.setProperty("deployment.home.j2se.url", "http://java.sun.com/j2se/");
      var0.setProperty("deployment.javaws.ssv.enabled", "true");
      String var2 = System.getProperty("javaws.cfg.jauthenticator");
      if (var2 != null) {
         String var3 = "" + (!var2.equalsIgnoreCase("all") && !var2.equalsIgnoreCase("true"));
         var0.setProperty("deployment.security.authenticator", var3);
      }

      return var0;
   }

   public static void printProps() {
      Trace.println("\n_defaultProps:");
      printP(_defaultProps);
      Trace.println("\n_systemProps:");
      printP(_systemProps);
      Trace.println("\n_props:");
      printP(_props);
   }

   private static void printP(Properties var0) {
      Enumeration var1 = var0.keys();

      while (var1.hasMoreElements()) {
         String var2 = (String)var1.nextElement();
         String var3 = var0.getProperty(var2);
         Trace.println("  " + var2 + " : " + var3);
      }

      Trace.println("");
   }

   public static String getUserTrustedCertificateFile() {
      return getProperty("deployment.user.security.trusted.certs");
   }

   public static String getSystemTrustedCertificateFile() {
      return getProperty("deployment.system.security.trusted.certs");
   }

   public static String getUserTrustedHttpsCertificateFile() {
      return getProperty("deployment.user.security.trusted.jssecerts");
   }

   public static String getSystemTrustedHttpsCertificateFile() {
      return getProperty("deployment.system.security.trusted.jssecerts");
   }

   public static String getUserRootCertificateFile() {
      return getProperty("deployment.user.security.trusted.cacerts");
   }

   public static String getSystemRootCertificateFile() {
      return getProperty("deployment.system.security.cacerts");
   }

   public static String getUserSSLRootCertificateFile() {
      return getProperty("deployment.user.security.trusted.jssecacerts");
   }

   public static String getSystemSSLRootCertificateFile() {
      return getProperty("deployment.system.security.jssecacerts");
   }

   public static String getUserClientAuthCertFile() {
      return getProperty("deployment.user.security.trusted.clientauthcerts");
   }

   public static String getSystemClientAuthCertFile() {
      return getProperty("deployment.system.security.trusted.clientauthcerts");
   }

   public static String getUserCookieFile() {
      return _userHome + File.separator + "security" + File.separator + "cookie.txt";
   }

   public static String getCacheDirectory() {
      return getProperty("deployment.user.cachedir");
   }

   public static String getPluginCacheDir() {
      String var0 = getProperty("deployment.javapi.cachedir");
      return var0 != null ? var0 : getCacheDirectory() + File.separator + "javapi";
   }

   public static String getTempCacheDir() {
      return getCacheDirectory() + File.separator + "tmp";
   }

   public static String getSystemCacheDirectory() {
      return getProperty("deployment.system.cachedir");
   }

   public static void setCacheDirectory(String var0) {
      setProperty("deployment.user.cachedir", var0, true);
   }

   public static String getLogDirectory() {
      return getProperty("deployment.user.logdir");
   }

   public static String getTempDirectory() {
      return getProperty("deployment.user.tmp");
   }

   public static String getUserExtensionDirectory() {
      return getProperty("deployment.user.extdir");
   }

   public static String getSystemExtensionDirectory() {
      return getProperty("deployment.system.extdir");
   }

   public static String getUserSecurityPolicyURL() {
      return getProperty("deployment.user.security.policy");
   }

   public static String getSystemSecurityPolicyURL() {
      return getProperty("deployment.system.security.policy");
   }

   public static boolean useSystemLookAndFeel() {
      String var0 = getProperty("deployment.system.lookandfeel");
      return var0 != null ? Boolean.valueOf(var0) : getInstance().systemLookAndFeelDefault();
   }

   public static String getJavaCommand() {
      String var0 = System.getProperty("java.home");
      if (!var0.endsWith(File.separator)) {
         var0 = var0 + File.separator;
      }

      return var0 + "bin" + File.separator + getInstance().getPlatformSpecificJavaName();
   }

   public static String getJavawsCommand() {
      String var0 = getJavaHome();
      if (!var0.endsWith(File.separator)) {
         var0 = var0 + File.separator;
      }

      return var0 + "bin" + File.separator + "javaws" + getInstance().getPlatformExtension();
   }

   public static String getJavawsCacheDir() {
      String var0 = getProperty("deployment.javaws.cachedir");
      return var0 != null ? var0 : getCacheDirectory() + File.separator + "javaws";
   }

   public static String getSplashDir() {
      return getJavawsCacheDir() + File.separator + "splash";
   }

   public static String getSplashIndex() {
      return getSplashDir() + File.separator + "splash.xml";
   }

   public static void setSplashCache() {
      setProperty("deployment.javaws.splash.index", getSplashIndex(), false);
   }

   public static String[] getSecureProperties() {
      ArrayList var0 = new ArrayList(4);
      int var1 = 0;

      while (var1 < DefaultSecureProperties.length) {
         var0.add(DefaultSecureProperties[var1++]);
      }

      String var3 = getProperty("deployment.javaws.secure.properties");
      if (var3 != null) {
         StringTokenizer var2 = new StringTokenizer(var3, ",");

         while (var2.hasMoreTokens()) {
            var0.add(var2.nextToken());
         }
      }

      return var0.toArray(new String[0]);
   }

   public static boolean isSecureVmArg(String var0) {
      for (int var1 = 0; var1 < secureVmArgs.length; var1++) {
         if (var0.equals(secureVmArgs[var1])) {
            return true;
         }
      }

      for (int var2 = 0; var2 < secureVmPrefixes.length; var2++) {
         if (var0.startsWith(secureVmPrefixes[var2])) {
            return true;
         }
      }

      return false;
   }

   public static List getProxyOverrideList() {
      return null;
   }

   public static void setShortcutValue(int var0) {
      String var1;
      switch (var0) {
         case 0:
            var1 = "NEVER";
            break;
         case 1:
            var1 = "ALWAYS";
            break;
         case 2:
         default:
            var1 = "ASK_USER";
            break;
         case 3:
            var1 = "ASK_IF_HINTED";
            break;
         case 4:
            var1 = "ALWAYS_IF_HINTED";
      }

      setProperty("deployment.javaws.shortcut", var1);
   }

   public static int getShortcutValue() {
      String var0 = getProperty("deployment.javaws.shortcut");
      if (var0.equals("NEVER")) {
         return 0;
      } else if (var0.equals("ALWAYS")) {
         return 1;
      } else if (var0.equals("ASK_USER")) {
         return 2;
      } else if (var0.equals("ASK_IF_HINTED")) {
         return 3;
      } else {
         return var0.equals("ALWAYS_IF_HINTED") ? 4 : 0;
      }
   }

   public static void setAssociationValue(int var0) {
      String var1;
      switch (var0) {
         case 0:
            var1 = "NEVER";
            break;
         case 1:
            var1 = "NEW_ONLY";
            break;
         case 2:
         default:
            var1 = "ASK_USER";
            break;
         case 3:
            var1 = "REPLACE_ASK";
      }

      setProperty("deployment.javaws.associations", var1);
   }

   public static int getAssociationValue() {
      String var0 = getProperty("deployment.javaws.associations");
      if (var0.equals("NEVER")) {
         return 0;
      } else if (var0.equals("NEW_ONLY")) {
         return 1;
      } else if (var0.equals("ASK_USER")) {
         return 2;
      } else {
         return var0.equals("REPLACE_ASK") ? 3 : 0;
      }
   }

   public static long getCacheSizeMax() {
      long var0 = -1L;
      String var4 = getProperty("deployment.cache.max.size");
      if (var4 != null && var4.length() > 0) {
         long var2;
         if (var4.endsWith("M") || var4.endsWith("m")) {
            var2 = 1048576L;
            var4 = var4.substring(0, var4.length() - 1);
         } else if (!var4.endsWith("K") && !var4.endsWith("k")) {
            var2 = 1L;
         } else {
            var2 = 1024L;
            var4 = var4.substring(0, var4.length() - 1);
         }

         try {
            var0 = var2 * Long.valueOf(var4);
         } catch (NumberFormatException var6) {
            var0 = 104857600L;
         }
      }

      return var0;
   }

   public String getPlatformOSHome() {
      return null;
   }

   public String getPlatformSystemHome() {
      return null;
   }

   public String getPlatformUserHome() {
      return null;
   }

   public String getSystemJavawsPath() {
      return getJavawsCommand();
   }

   public String toExecArg(String var1) {
      return var1;
   }

   public String getLibraryPrefix() {
      return null;
   }

   public String getPlatformSpecificJavaName() {
      return null;
   }

   public String getPlatformExtension() {
      return null;
   }

   public String getDebugJavaPath(String var1) {
      return var1;
   }

   public String getLibrarySufix() {
      return null;
   }

   public boolean useAltFileSystemView() {
      return false;
   }

   public boolean showDocument(String var1) {
      return false;
   }

   public String getBrowserPath() {
      return null;
   }

   public String getMozillaUserProfileDirectory() {
      return null;
   }

   public int installShortcut(String var1, String var2, String var3, String var4, String var5, String var6, String var7) {
      return 0;
   }

   public boolean isLocalInstallSupported() {
      return true;
   }

   public int addRemoveProgramsAdd(String var1, String var2, boolean var3) {
      return 0;
   }

   public int addRemoveProgramsRemove(String var1, boolean var2) {
      return 0;
   }

   public boolean systemLookAndFeelDefault() {
      return true;
   }

   public String getSessionSpecificString() {
      return "";
   }

   public void notifyJREInstalled(String var1) {
   }

   private static void showIExplorerErrorDialog() {
      DialogFactory.showErrorDialog(ResourceManager.getMessage("browser.settings.fail.ie.text"), ResourceManager.getMessage("browser.settings.fail.caption"));
   }

   private static void showMozillaErrorDialog() {
      DialogFactory.showErrorDialog(ResourceManager.getMessage("browser.settings.fail.moz.text"), ResourceManager.getMessage("browser.settings.fail.caption"));
   }

   private static void showSuccessDialog() {
      DialogFactory.showInformationDialog(
         ResourceManager.getMessage("browser.settings.success.text"), ResourceManager.getMessage("browser.settings.success.caption")
      );
   }

   private static boolean showAlertDialog() {
      int var0 = DialogFactory.showConfirmDialog(ResourceManager.getMessage("browser.settings.alert.text"));
      return var0 == 0;
   }

   public static String getEnterprizeString() {
      return _enterprizeConfig;
   }

   public static boolean isDebugMode() {
      String var0 = System.getProperty("deploy.debugMode");
      return var0 != null && var0.equalsIgnoreCase("true");
   }

   public static boolean isDebugVMMode() {
      String var0 = System.getProperty("deploy.useDebugJavaVM");
      return var0 != null && var0.equalsIgnoreCase("true");
   }

   static {
      _javaHome = getJavaHome();
      _userHome = getInstance().getPlatformUserHome();
      _systemHome = getInstance().getPlatformSystemHome();
      _osHome = getInstance().getPlatformOSHome();
      if (_os.startsWith("Win")) {
         _os = "Windows";
      }

      _arch = System.getProperty("os.arch");
      _platform = System.getProperty("os.platform");
      _configOK = initialize();
   }
}
