package com.sun.deploy.config;

import com.sun.deploy.net.proxy.NSPreferences;
import com.sun.deploy.util.SearchPath;
import com.sun.deploy.util.Trace;
import com.sun.deploy.util.TraceLevel;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.security.AccessController;
import java.util.ArrayList;
import sun.security.action.GetPropertyAction;

public class UnixConfig extends Config {
   private String _userHome;
   private String _systemHome;
   private String _osHome;
   private static String[] PREFERRED_BROWSERS = new String[]{"mozilla", "netscape"};
   private static String[] SECONDARY_BROWSERS = new String[]{"firebird", "opera", "konqueror", "galeon"};
   private static final int ARGS_LIST_CAPACITY = 32;
   private static final int ARG_CAPACITY = 64;
   private static final char BACKSLASH = '\\';
   private static final char SINGLE_QUOTE = '\'';
   private static final char DOUBLE_QUOTE = '"';
   private static final char TAB = '\t';
   private static final char LINEFEED = '\n';
   private static final char RETURN = '\r';
   private static final char SPACE = ' ';

   public static void loadLibDeploy() {
      String var0 = System.getProperty("os.arch");
      if (var0.equals("x86")) {
         var0 = "i386";
      }

      if (Config.isDebugMode()) {
         System.load(Config.getJavaHome() + File.separator + "lib" + File.separator + var0 + File.separator + "libdeploy_g.so");
      } else {
         System.load(Config.getJavaHome() + File.separator + "lib" + File.separator + var0 + File.separator + "libdeploy.so");
      }
   }

   public String getPlatformUserHome() {
      if (this._userHome == null) {
         String var1 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.user.profile"));
         if (var1 == null || var1.trim().equals("")) {
            var1 = AccessController.doPrivileged(new GetPropertyAction("user.home"));
         }

         this._userHome = var1 + File.separator + ".java" + File.separator + "deployment";
      }

      return this._userHome;
   }

   public String getPlatformSystemHome() {
      if (this._systemHome == null) {
         this._systemHome = File.separator + "etc" + File.separator + ".java" + File.separator + "deployment";
      }

      return this._systemHome;
   }

   public String getPlatformOSHome() {
      if (this._osHome == null) {
         this._osHome = File.separator + "etc";
      }

      return this._osHome;
   }

   public String getPlatformExtension() {
      return "";
   }

   public String getLibraryPrefix() {
      return "lib";
   }

   public String getLibrarySufix() {
      return ".so";
   }

   public boolean useAltFileSystemView() {
      return false;
   }

   public boolean isLocalInstallSupported() {
      return getEnv("GNOME_DESKTOP_SESSION_ID") != null;
   }

   public boolean systemLookAndFeelDefault() {
      return getEnv("GNOME_DESKTOP_SESSION_ID") != null;
   }

   public String getSessionSpecificString() {
      return "";
   }

   public String getPlatformSpecificJavaName() {
      return "java";
   }

   public static native String getEnv(String var0);

   public String getBrowserPath() {
      File var1 = null;
      Object var2 = null;
      String var3 = null;
      var3 = getProperty("deployment.browser.path");
      if (var3 != null && var3.length() > 0 && !var3.equals(getProperty("<No Browser Selected>"))) {
         var1 = new File((String)var3);
         if (!var1.exists()) {
            if (var3.equals("netscape")) {
               var2 = PREFERRED_BROWSERS;
               var1 = null;
            } else {
               var2 = new String[PREFERRED_BROWSERS.length + 1];
               ((Object[])var2)[0] = var1.getName();
               System.arraycopy(PREFERRED_BROWSERS, 0, var2, 1, PREFERRED_BROWSERS.length);
               var1 = null;
            }
         }
      } else {
         var2 = PREFERRED_BROWSERS;
      }

      if (var1 != null) {
         var3 = var1.getAbsolutePath();
      } else {
         SearchPath var4 = new SearchPath(getEnv("PATH"));
         var1 = var4.findOne(PREFERRED_BROWSERS);
         if (var1 != null) {
            var3 = var1.getAbsolutePath();
         } else {
            var1 = var4.findOne(SECONDARY_BROWSERS);
            if (var1 != null) {
               var3 = var1.getAbsolutePath();
            } else {
               var3 = "<No Browser Selected>";
            }
         }
      }

      return var3;
   }

   public String getMozillaUserProfileDirectory() {
      String var1 = null;

      try {
         String var2 = System.getProperty("user.home");
         File var3 = new File(var2 + "/.mozilla/appreg");
         if (var3.exists()) {
            var1 = NSPreferences.getNS6UserProfileDirectory(var3);
         }
      } catch (IOException var4) {
      }

      return var1;
   }

   public boolean showDocument(String var1) {
      String var2 = this.getBrowserPath();
      boolean var3 = false;
      if (!var2.equals(getProperty("<No Browser Selected>"))) {
         File var4 = new File(var2);
         if (var4.exists()) {
            Object var5 = null;
            Process var6 = null;
            var5 = getExtendedBrowserArgs(var4, var1);
            if (var5 != null) {
               try {
                  Trace.println("Invoking browser with: \n     " + argsFromArray((String[])var5), TraceLevel.BASIC);
                  var6 = Runtime.getRuntime().exec((String[])var5);
                  InputStream var7 = var6.getErrorStream();
                  byte[] var8 = new byte[1024];
                  int var9 = var6.waitFor();
                  int var10 = var7.read(var8, 0, 1024);
                  if (var9 == 0 && var10 == -1) {
                     var3 = true;
                  }
               } catch (IOException var12) {
                  Trace.ignoredException(var12);
               } catch (InterruptedException var13) {
                  Trace.ignoredException(var13);
               }
            }

            if (!var3) {
               try {
                  var5 = getBasicBrowserArgs(var4, var1);
                  Trace.println("Invoking browser with: \n     " + argsFromArray((String[])var5), TraceLevel.BASIC);
                  var6 = Runtime.getRuntime().exec((String[])var5);
                  var3 = var6 != null;
               } catch (IOException var11) {
                  Trace.ignoredException(var11);
               }
            }
         }
      }

      return var3;
   }

   public static String argsFromArray(String[] var0) {
      StringBuffer var1 = new StringBuffer(2048);

      for (int var2 = 0; var2 < var0.length; var2++) {
         var1.append(var0[var2]).append(' ');
      }

      return var1.toString().trim();
   }

   public static String[] argsFromString(String var0) {
      ArrayList var1 = new ArrayList(32);
      StringBuffer var2 = new StringBuffer(64);
      boolean var3 = false;
      boolean var4 = false;
      int var5 = 0;
      String[] var6 = new String[0];
      if (var0 != null) {
         var5 = var0.length();
      }

      for (int var7 = 0; var7 < var5; var7++) {
         char var8 = var0.charAt(var7);
         switch (var8) {
            case '\t':
            case '\n':
            case '\r':
            case ' ':
               if (var4 || var3) {
                  var2.append(var8);
               } else if (var2.length() > 0) {
                  var1.add(var2.toString());
                  var2.delete(0, var2.length());
               }
               break;
            case '"':
               if (var4) {
                  var2.append(var8);
               }

               var3 = !var3;
               break;
            case '\'':
               if (var3) {
                  var2.append(var8);
               }

               var4 = !var4;
               break;
            case '\\':
               if (++var7 < var5) {
                  var2.append(var0.charAt(var7));
               }
               break;
            default:
               var2.append(var8);
         }
      }

      if (var2.length() > 0) {
         var1.add(var2.toString());
      }

      return var1.toArray(var6);
   }

   private static String[] getBasicBrowserArgs(File var0, String var1) {
      return new String[]{var0.getAbsolutePath(), var1};
   }

   private static String[] getExtendedBrowserArgs(File var0, String var1) {
      boolean var2 = false;
      String[] var3 = argsFromString(getProperty("deployment.browser.args"));
      String[] var4 = null;

      for (int var5 = 0; var5 < var3.length; var5++) {
         int var6 = 0;
         byte var7 = -1;

         for (int var8 = var3[var5].indexOf("%u", var6); var8 >= 0; var2 = true) {
            var3[var5] = var3[var5].substring(var6, var8) + var1 + var3[var5].substring(var8 + 2);
            var6 = var8 + 2;
            var8 = var3[var5].indexOf("%u", var6);
         }
      }

      if (var2) {
         var4 = new String[var3.length + 1];
         System.arraycopy(var3, 0, var4, 1, var3.length);
         var4[0] = var0.getAbsolutePath();
      }

      return var4;
   }

   public String getDebugJavaPath(String var1) {
      return var1.concat("_g");
   }

   static {
      loadLibDeploy();
   }
}
