package com.sun.deploy.net.cookie;

import java.net.URL;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.TreeMap;

abstract class CookieStore {
   protected transient TreeMap cookieJar = new TreeMap();

   public void recordCookie(HttpCookie var1) {
      if (!this.shouldRejectCookie(var1)) {
         this.loadCookieJar();
         String var2 = var1.getDomain().toLowerCase();
         ArrayList var3 = (ArrayList)this.cookieJar.get(var2);
         if (var3 == null) {
            var3 = new ArrayList();
         }

         if (this.addOrReplaceCookie(var3, var1)) {
            this.cookieJar.put(var2, var3);
            this.saveCookieJar();
         }
      }
   }

   protected abstract void loadCookieJar();

   protected abstract void saveCookieJar();

   protected abstract String getName();

   protected boolean addOrReplaceCookie(ArrayList var1, HttpCookie var2) {
      int var3 = var1.size();
      String var4 = var2.getPath();
      String var5 = var2.getName();
      HttpCookie var6 = null;
      int var7 = -1;

      for (int var8 = 0; var8 < var3; var8++) {
         HttpCookie var9 = (HttpCookie)var1.get(var8);
         String var10 = var9.getPath();
         if (var4.equals(var10)) {
            String var11 = var9.getName();
            if (var5.equals(var11)) {
               var6 = var9;
               var7 = var8;
               break;
            }
         }
      }

      if (var6 != null) {
         var1.set(var7, var2);
      } else {
         var1.add(var2);
      }

      return true;
   }

   protected boolean shouldRejectCookie(HttpCookie var1) {
      return var1.getDomain() == null || var1.getPath() == null || var1.getName() == null;
   }

   public String getRelevantCookies(URL var1) {
      this.loadCookieJar();
      String var2 = var1.getHost();
      String var3 = this.getCookiesForHost(var2, var1);

      int var4;
      while ((var4 = var2.indexOf(46, 1)) >= 0) {
         var2 = var2.substring(var4 + 1);
         String var5 = this.getCookiesForHost(var2, var1);
         if (var5 != null) {
            if (var3 == null) {
               var3 = var5;
            } else {
               var3 = var3 + "; " + var5;
            }
         }
      }

      return var3;
   }

   private String getCookiesForHost(String var1, URL var2) {
      ArrayList var3 = (ArrayList)this.cookieJar.get(var1);
      if (var3 == null) {
         return null;
      } else {
         String var4 = var2.getFile();
         int var5 = var4.indexOf(63);
         if (var5 > 0) {
            var4 = var4.substring(0, var5);
         }

         Iterator var6 = var3.iterator();
         ArrayList var7 = new ArrayList(10);

         while (var6.hasNext()) {
            HttpCookie var8 = (HttpCookie)var6.next();
            String var9 = var8.getPath();
            if (var4.startsWith(var9) && !var8.hasExpired()) {
               String var10 = var2.getProtocol();
               if (var10.equals("https") || var10.equals("http") && !var8.isSecure()) {
                  var7.add(var8);
               }
            }
         }

         Collections.sort(var7);
         var6 = var7.iterator();
         StringBuffer var12 = null;

         while (var6.hasNext()) {
            HttpCookie var13 = (HttpCookie)var6.next();
            if (var12 == null) {
               var12 = new StringBuffer(var13.getNameValue());
            } else {
               var12.append("; ").append(var13.getNameValue());
            }
         }

         return var12 == null ? null : var12.toString();
      }
   }

   public String toString() {
      StringBuffer var1 = new StringBuffer();
      var1.append(this.getName());
      var1.append("\n[\n");

      for (List var3 : this.cookieJar.values()) {
         for (HttpCookie var5 : var3) {
            var1.append("\t");
            var1.append(var5.toString());
            var1.append("\n");
         }
      }

      var1.append("]");
      return var1.toString();
   }
}
