package com.sun.deploy.net.cookie;

import com.sun.deploy.config.Config;
import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

public class GenericCookieHandler implements CookieHandler {
   private CookieStore sessionCookieStore = new SessionCookieStore();
   private CookieStore persistCookieStore;

   public GenericCookieHandler() {
      File var1 = new File(Config.getUserCookieFile());
      this.persistCookieStore = new NetscapeCookieStore(var1);
   }

   public synchronized String getCookieInfo(URL var1) throws CookieUnavailableException {
      try {
         if (var1.getPath() == null || var1.getPath().equals("")) {
            var1 = new URL(var1, "/");
         }
      } catch (MalformedURLException var3) {
         throw new CookieUnavailableException(var3.getMessage(), var3);
      }

      return this.getRelevantCookies(var1);
   }

   public synchronized void setCookieInfo(URL var1, String var2) throws CookieUnavailableException {
      this.recordCookie(var1, var2);
   }

   private void recordCookie(URL var1, String var2) {
      HttpCookie var3 = HttpCookie.create(var1, var2);
      if (var3 != null) {
         String[] var4 = new String[]{"com", "edu", "net", "org", "gov", "mil", "int"};
         String var5 = var3.getDomain();
         if (var5 != null) {
            var5 = var5.toLowerCase();
            String var6 = var1.getHost();
            var6 = var6.toLowerCase();
            boolean var7 = var6.equals(var5);
            if (!var7 && var6.endsWith(var5)) {
               int var8 = 2;

               for (int var9 = 0; var9 < var4.length; var9++) {
                  if (var5.endsWith(var4[var9])) {
                     var8 = 1;
                  }
               }

               int var12;
               for (var12 = var5.length(); var12 > 0 && var8 > 0; var8--) {
                  var12 = var5.lastIndexOf(46, var12 - 1);
               }

               if (var12 > 0) {
                  var7 = true;
               }
            }

            if (var7) {
               this.recordCookie(var3);
            }
         }
      }
   }

   private void recordCookie(HttpCookie var1) {
      if (!this.sessionCookieStore.shouldRejectCookie(var1)) {
         this.sessionCookieStore.recordCookie(var1);
      }

      if (!this.persistCookieStore.shouldRejectCookie(var1)) {
         this.persistCookieStore.recordCookie(var1);
      }
   }

   private String getRelevantCookies(URL var1) {
      String var2 = this.sessionCookieStore.getRelevantCookies(var1);
      String var3 = this.persistCookieStore.getRelevantCookies(var1);
      if (var2 == null) {
         return var3;
      } else {
         return var3 == null ? var2 : var2 + "; " + var3;
      }
   }

   public static void main(String[] var0) {
      try {
         GenericCookieHandler var1 = new GenericCookieHandler();
         URL var2 = new URL("http://java.sun.com/bar/index.html");
         URL var3 = new URL("http://java.sun.com");
         URL var4 = new URL("http://java.sun.com/xyz/bar/index.html");
         URL var5 = new URL("https://java.sun.com");
         URL var6 = new URL("https://java.sun.com/foo/xyz/index.html");
         URL var7 = new URL("https://java.sun.com/foobar/xyz/index.html");
         URL var8 = new URL("https://java.sun.com/xyz/foo/index.html");
         URL var9 = new URL("http://xyz.sun.com/");
         URL var10 = new URL("http://xyz.sun.com/ammo/index.html");
         System.out.println("Client --> " + var2);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var2));
         System.out.println("");
         System.out.println("Server --> " + var2);
         System.out.println("Set-Cookie: CUSTOMER_EXPIRED=WILE_E_COYOTE_EXPIRED; path=/; expires=Wednesday, 09-Nov-99 23:12:40 GMT");
         System.out.println("Set-Cookie: CUSTOMER_NOT_EXPIRED=WILE_E_COYOTE_NOT_EXPIRED; path=/; expires=Wednesday, 09-Nov-03 23:12:40 GMT");
         System.out.println("Set-Cookie: CUSTOMER_SECURE=WILE_E_COYOTE_SECURE; path=/; secure");
         System.out.println("");
         var1.setCookieInfo(var2, "CUSTOMER_EXPIRED=WILE_E_COYOTE_EXPIRED; path=/; expires=Wednesday, 09-Nov-99 23:12:40 GMT");
         var1.setCookieInfo(var2, "CUSTOMER_NOT_EXPIRED=WILE_E_COYOTE_NOT_EXPIRED; path=/; expires=Wednesday, 09-Nov-03 23:12:40 GMT");
         var1.setCookieInfo(var2, "CUSTOMER_SECURE=WILE_E_COYOTE_SECURE; path=/; secure");
         System.out.println("Client --> " + var3);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var3));
         System.out.println("");
         System.out.println("Server --> " + var4);
         System.out.println("Set-Cookie: PART_NUMBER=ROCKET_LAUNCHER_0001; path=/");
         System.out.println("");
         var1.setCookieInfo(var4, "PART_NUMBER=ROCKET_LAUNCHER_0001; path=/");
         System.out.println("Client --> " + var3);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var3));
         System.out.println("");
         System.out.println("Server --> " + var2);
         System.out.println("Set-Cookie: SHIPPING=FEDEX; path=/foo");
         System.out.println("Set-Cookie: SHIPPING_SECURE=UPS; path=/foo; secure");
         System.out.println("");
         var1.setCookieInfo(var2, "SHIPPING=FEDEX; path=/foo");
         var1.setCookieInfo(var2, "SHIPPING_SECURE=UPS; path=/foo; secure");
         System.out.println("Client --> " + var3);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var3));
         System.out.println("");
         System.out.println("Client --> " + var2);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var2));
         System.out.println("");
         System.out.println("Client --> " + var5);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var5));
         System.out.println("");
         System.out.println("Client --> " + var6);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var6));
         System.out.println("");
         System.out.println("Client --> " + var7);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var7));
         System.out.println("");
         System.out.println("Client --> " + var8);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var8));
         System.out.println("");
         System.out.println("Client --> " + var9);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var9));
         System.out.println("");
         System.out.println("Server --> " + var9);
         System.out.println("Set-Cookie: PART_NUMBER=ROCKET_LAUNCHER_0001; path=/");
         System.out.println("");
         var1.setCookieInfo(var9, "PART_NUMBER=ROCKET_LAUNCHER_0001; path=/");
         System.out.println("Client --> " + var9);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var9));
         System.out.println("");
         System.out.println("Server --> " + var9);
         System.out.println("Set-Cookie: PART_NUMBER=RIDING_ROCKET_0023; path=/ammo");
         System.out.println("");
         var1.setCookieInfo(var9, "PART_NUMBER=RIDING_ROCKET_0023; path=/ammo");
         System.out.println("Client --> " + var10);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var10));
         System.out.println("");
         System.out.println("Client --> " + var9);
         System.out.println("Cookie\t  : " + var1.getCookieInfo(var9));
         System.out.println("");
         System.out.println(var1.sessionCookieStore.toString());
         System.out.println("");
         System.out.println(var1.persistCookieStore.toString());
      } catch (Throwable var11) {
         var11.printStackTrace();
      }
   }
}
