package com.sun.deploy.net.cookie;

import java.net.URL;
import java.util.Date;
import java.util.StringTokenizer;

class HttpCookie implements Comparable {
   private static final int SIZE_LIMIT = 4096;
   private Date expirationDate = null;
   private String nameAndValue = null;
   private String path = null;
   private String domain = null;
   private boolean isSecure = false;

   private HttpCookie() {
   }

   private HttpCookie(Date var1, String var2, String var3, String var4, boolean var5) {
      this.expirationDate = var1;
      this.nameAndValue = var2;
      this.path = var3;
      this.domain = stripPort(var4);
      this.isSecure = var5;
   }

   private static String stripPort(String var0) {
      int var1 = var0.indexOf(58);
      return var1 == -1 ? var0 : var0.substring(0, var1);
   }

   static HttpCookie create(Date var0, String var1, String var2, String var3, boolean var4) {
      if (var1 != null && var2 != null && var3 != null) {
         if (var2.equals("")) {
            var2 = "/";
         }

         if (var1.length() > 4096) {
            var1 = var1.substring(0, 4096);
         }

         return new HttpCookie(var0, var1, var2, var3, var4);
      } else {
         return null;
      }
   }

   static HttpCookie create(URL var0, String var1) {
      StringTokenizer var2 = new StringTokenizer(var1, ";");
      if (!var2.hasMoreTokens()) {
         return null;
      } else {
         HttpCookie var3 = new HttpCookie();
         var3.nameAndValue = var2.nextToken().trim();
         if (var3.nameAndValue.length() > 4096) {
            var3.nameAndValue = var3.nameAndValue.substring(0, 4096);
         }

         while (var2.hasMoreTokens()) {
            String var4 = var2.nextToken().trim();
            if (var4.equalsIgnoreCase("secure")) {
               var3.isSecure = true;
            } else {
               int var5 = var4.indexOf("=");
               if (var5 >= 0) {
                  String var6 = var4.substring(0, var5);
                  String var7 = var4.substring(var5 + 1);
                  if (var6.equalsIgnoreCase("path")) {
                     var3.path = var7;
                  } else if (var6.equalsIgnoreCase("domain")) {
                     if (var7.indexOf(".") == 0) {
                        var3.domain = stripPort(var7.substring(1));
                     } else {
                        var3.domain = stripPort(var7);
                     }
                  } else if (var6.equalsIgnoreCase("expires")) {
                     var3.expirationDate = parseExpireDate(var7);
                  }
               }
            }
         }

         if (var3.domain == null) {
            var3.domain = var0.getHost();
         }

         if (var3.path == null) {
            var3.path = var0.getFile();
            int var8 = var3.path.lastIndexOf("/");
            if (var8 > -1) {
               var3.path = var3.path.substring(0, var8);
            }
         }

         return var3;
      }
   }

   public String getNameValue() {
      return this.nameAndValue;
   }

   public String getName() {
      int var1 = this.nameAndValue.indexOf("=");
      return this.nameAndValue.substring(0, var1);
   }

   public String getValue() {
      int var1 = this.nameAndValue.indexOf("=");
      return this.nameAndValue.substring(var1 + 1);
   }

   public String getDomain() {
      return this.domain;
   }

   public String getPath() {
      return this.path;
   }

   public Date getExpirationDate() {
      return this.expirationDate;
   }

   boolean hasExpired() {
      return this.expirationDate == null ? false : this.expirationDate.getTime() <= System.currentTimeMillis();
   }

   boolean isSaveable() {
      return this.expirationDate != null && this.expirationDate.getTime() > System.currentTimeMillis();
   }

   public boolean isSecure() {
      return this.isSecure;
   }

   private static Date parseExpireDate(String var0) {
      RfcDateParser var1 = new RfcDateParser(var0);
      return var1.getDate();
   }

   public String toString() {
      String var1 = this.nameAndValue;
      if (this.expirationDate != null) {
         var1 = var1 + "; expires=" + this.expirationDate;
      }

      if (this.path != null) {
         var1 = var1 + "; path=" + this.path;
      }

      if (this.domain != null) {
         var1 = var1 + "; domain=" + this.domain;
      }

      if (this.isSecure) {
         var1 = var1 + "; secure";
      }

      return var1;
   }

   public int compareTo(Object var1) {
      HttpCookie var2 = (HttpCookie)var1;
      if (var2 == this) {
         return 0;
      } else {
         int var3 = this.getDomain().compareTo(var2.getDomain());
         if (var3 != 0) {
            return var3;
         } else {
            var3 = this.getPath().compareTo(var2.getPath());
            return var3 != 0 ? var3 : this.getNameValue().compareTo(var2.getNameValue());
         }
      }
   }
}
