package com.sun.deploy.net.cookie;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.security.AccessController;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;
import java.util.TreeMap;

final class NetscapeCookieStore extends CookieStore {
   private Date lastAccessDate = new Date(0L);
   private File cookieFile = null;

   NetscapeCookieStore(File var1) {
      this.cookieFile = var1;
   }

   protected void loadCookieJar() {
      AccessController.doPrivileged(new NetscapeCookieStore$1(this));
   }

   private void loadCookieJarFromStorage() {
      if (this.cookieFile.exists()) {
         Date var1 = new Date(this.cookieFile.lastModified());
         if (var1.after(this.lastAccessDate)) {
            TreeMap var2 = new TreeMap();

            try {
               FileInputStream var3 = new FileInputStream(this.cookieFile);
               InputStreamReader var4 = new InputStreamReader(var3);
               BufferedReader var5 = new BufferedReader(var4);
               Object var6 = null;

               while ((var6 = var5.readLine()) != null) {
                  if (!var6.startsWith("#") && !var6.trim().equals("")) {
                     HttpCookie var7 = this.readCookieRecord((String)var6);
                     if (var7 != null && !var7.hasExpired() && !this.shouldRejectCookie(var7)) {
                        String var8 = var7.getDomain().toLowerCase();
                        ArrayList var9 = (ArrayList)var2.get(var8);
                        if (var9 == null) {
                           var9 = new ArrayList();
                        }

                        if (this.addOrReplaceCookie(var9, var7)) {
                           var2.put(var8, var9);
                        }
                     }
                  }
               }

               var5.close();
               var4.close();
               var3.close();
               this.lastAccessDate = new Date(this.cookieFile.lastModified());
               this.cookieJar = var2;
            } catch (IOException var10) {
               var10.printStackTrace();
            } catch (Throwable var11) {
               var11.printStackTrace();
            }
         }
      }
   }

   protected void saveCookieJar() {
      AccessController.doPrivileged(new NetscapeCookieStore$2(this));
   }

   private void saveCookieJarToStorage() {
      try {
         String var1 = System.getProperty("line.separator");
         StringBuffer var2 = new StringBuffer();
         var2.append("# Java Deployment HTTP Cookie File");
         var2.append(var1);
         var2.append("# http://www.netscape.com/newsref/std/cookie_spec.html");
         var2.append(var1);
         var2.append("# This is a generated file!  Do not edit.");
         var2.append(var1);
         var2.append(var1);

         for (List var4 : this.cookieJar.values()) {
            for (HttpCookie var6 : var4) {
               if (!var6.hasExpired()) {
                  this.writeCookieRecord(var6, var2);
                  var2.append(var1);
               }
            }
         }

         this.cookieFile.getParentFile().mkdirs();
         FileOutputStream var9 = new FileOutputStream(this.cookieFile);
         BufferedOutputStream var10 = new BufferedOutputStream(var9);
         PrintWriter var11 = new PrintWriter(var10);
         var11.println(var2.toString());
         var11.close();
         var10.close();
         var9.close();
         this.lastAccessDate = new Date(this.cookieFile.lastModified());
      } catch (IOException var7) {
         var7.printStackTrace();
      } catch (Throwable var8) {
         var8.printStackTrace();
      }
   }

   protected String getName() {
      return "Persistent Cookie Store";
   }

   protected boolean shouldRejectCookie(HttpCookie var1) {
      return super.shouldRejectCookie(var1) ? true : var1.getExpirationDate() == null || var1.hasExpired();
   }

   private HttpCookie readCookieRecord(String var1) {
      try {
         StringTokenizer var2 = new StringTokenizer(var1, "\t", true);
         if (var2.countTokens() < 10) {
            return null;
         } else {
            String var3 = var2.nextToken();
            if (var3.indexOf(".") == -1) {
               return null;
            } else {
               var2.nextToken();
               String var4 = var2.nextToken();
               if (var4.equals("\t")) {
                  var4 = "FALSE";
               } else {
                  var2.nextToken();
               }

               String var5 = var2.nextToken();
               if (var5.equals("\t")) {
                  var5 = "/";
               } else {
                  var2.nextToken();
               }

               String var6 = var2.nextToken();
               if (var6.equals("\t")) {
                  var6 = "TRUE";
               } else {
                  var2.nextToken();
               }

               boolean var7 = !var6.equalsIgnoreCase("false");
               Date var8 = new Date(new Long(var2.nextToken()) * 1000L);
               var2.nextToken();
               String var9 = var2.nextToken();
               if (!var9.equals("\t") && !var9.trim().equals("")) {
                  var2.nextToken();
                  String var10 = var2.nextToken();

                  while (var2.hasMoreTokens()) {
                     var10 = var10 + var2.nextToken();
                  }

                  String var11 = var9 + "=" + var10;
                  return HttpCookie.create(var8, var11, var5, var3, var7);
               } else {
                  return null;
               }
            }
         }
      } catch (NoSuchElementException var12) {
         return null;
      } catch (NumberFormatException var13) {
         return null;
      }
   }

   private void writeCookieRecord(HttpCookie var1, StringBuffer var2) {
      String var3 = var1.getDomain();
      var2.append(var3);
      var2.append("\t");
      if (var3.startsWith(".")) {
         var2.append("TRUE\t");
      } else {
         var2.append("FALSE\t");
      }

      var2.append(var1.getPath());
      var2.append("\t");
      if (var1.isSecure()) {
         var2.append("TRUE\t");
      } else {
         var2.append("FALSE\t");
      }

      var2.append(var1.getExpirationDate().getTime() / 1000L + "\t");
      var2.append(var1.getName());
      var2.append("\t");
      var2.append(var1.getValue());
   }
}
