package com.sun.deploy.net.proxy;

import com.sun.deploy.net.protocol.rmi.DeployRMISocketFactory;
import com.sun.deploy.services.Service;
import com.sun.deploy.services.ServiceManager;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.net.URL;
import java.rmi.server.RMISocketFactory;
import java.security.AccessController;
import java.util.HashMap;
import java.util.Properties;

public class DynamicProxyManager {
   private static HashMap proxyCache = new HashMap();
   private static ProxyHandler handler = null;

   public static synchronized ProxyInfo getProxyInfo(URL var0) {
      StringBuffer var1 = new StringBuffer();
      var1.append(var0.getProtocol());
      var1.append(var0.getHost());
      var1.append(var0.getPort());
      String var2 = var1.toString();
      ProxyInfo var3 = null;
      if (handler.isProxyCacheSupported()) {
         var3 = (ProxyInfo)proxyCache.get(var2);
      }

      if (var3 == null) {
         try {
            if (!var0.getHost().equals("127.0.0.1") && !var0.getHost().equals("localhost")) {
               ProxyInfo[] var4 = handler.getProxyInfo(var0);
               var3 = var4[0];
            }

            if (var3 == null) {
               var3 = new ProxyInfo(null);
            }

            proxyCache.put(var2.toString(), var3);
         } catch (ProxyUnavailableException var5) {
            Trace.msgNetPrintln("net.proxy.service.not_available", new Object[]{var0});
            var3 = new ProxyInfo(null);
         }
      }

      return var3;
   }

   public static synchronized void setNoProxy(URL var0) {
      StringBuffer var1 = new StringBuffer();
      var1.append(var0.getProtocol());
      var1.append(var0.getHost());
      var1.append(var0.getPort());
      String var2 = var1.toString();
      if (handler.isProxyCacheSupported()) {
         proxyCache.put(var2.toString(), new ProxyInfo(null));
      }
   }

   public static synchronized void reset() {
      try {
         proxyCache.clear();
         UserDefinedProxyConfig var0 = new UserDefinedProxyConfig();
         BrowserProxyInfo var1 = var0.getBrowserProxyInfo();
         Service var2 = ServiceManager.getService();
         if (var1.getType() == 3) {
            BrowserProxyConfig var3 = var2.getProxyConfig();
            var1 = var3.getBrowserProxyInfo();
         }

         switch (var1.getType()) {
            case 0:
               try {
                  handler = new DirectProxyHandler();
                  handler.init(var1);
               } catch (ProxyConfigException var12) {
                  Trace.ignoredException(var12);
               }
               break;
            case 1:
               try {
                  handler = new ManualProxyHandler();
                  handler.init(var1);
               } catch (ProxyConfigException var11) {
                  Trace.msgNetPrintln("net.proxy.loading.manual.error");

                  try {
                     var1.setType(0);
                     handler = new DirectProxyHandler();
                     handler.init(var1);
                  } catch (ProxyConfigException var10) {
                     Trace.ignoredException(var10);
                  }
               }
               break;
            case 2:
               try {
                  ProxyHandler var18 = var2.getAutoProxyHandler();
                  if (var18 == null) {
                     throw new ProxyConfigException("Unable to obtain auto proxy handler.");
                  }

                  handler = var18;
                  handler.init(var1);
               } catch (ProxyConfigException var9) {
                  Trace.msgNetPrintln("net.proxy.loading.auto.error");

                  try {
                     var1.setType(1);
                     handler = new ManualProxyHandler();
                     handler.init(var1);
                  } catch (ProxyConfigException var8) {
                     Trace.msgNetPrintln("net.proxy.loading.manual.error");

                     try {
                        var1.setType(0);
                        handler = new DirectProxyHandler();
                        handler.init(var1);
                     } catch (ProxyConfigException var7) {
                        Trace.ignoredException(var7);
                     }
                  }
               }
               break;
            case 3:
               try {
                  ProxyHandler var17 = var2.getBrowserProxyHandler();
                  if (var17 == null) {
                     throw new ProxyConfigException("Unable to obtain browser proxy handler.");
                  }

                  handler = var17;
                  handler.init(var1);
               } catch (ProxyConfigException var13) {
                  Trace.ignoredException(var13);
               }
               break;
            case 4:
               try {
                  ProxyHandler var16 = var2.getSystemProxyHandler();
                  if (var16 == null) {
                     throw new ProxyConfigException("Unable to obtain browser proxy handler.");
                  }

                  handler = var16;
                  handler.init(var1);
               } catch (ProxyConfigException var14) {
                  Trace.ignoredException(var14);
               }
               break;
            default:
               throw new IllegalStateException("DynamicProxyManager: Invalid Proxy Type");
         }

         try {
            if (var1.getType() != 0) {
               RMISocketFactory.setSocketFactory(new DeployRMISocketFactory());
            }
         } catch (Throwable var6) {
         }

         AccessController.doPrivileged(new DynamicProxyManager$1(var1));
         Trace.msgNetPrintln(var1.toString());
      } catch (Throwable var15) {
         var15.printStackTrace();
         DialogFactory.showExceptionDialog(var15);
      }
   }

   private static void setProperties(BrowserProxyInfo var0) {
      Properties var1 = System.getProperties();
      int var2 = var0.getType();
      StringBuffer var3 = new StringBuffer();
      if (var0.getHttpHost() != null) {
         var3.append("http=" + var0.getHttpHost());
         if (var0.getHttpPort() != -1) {
            var3.append(":" + var0.getHttpPort());
         }
      }

      if (var0.getHttpsHost() != null) {
         var3.append(",https=" + var0.getHttpsHost());
         if (var0.getHttpsPort() != -1) {
            var3.append(":" + var0.getHttpsPort());
         }
      }

      if (var0.getFtpHost() != null) {
         var3.append(",ftp=" + var0.getFtpHost());
         if (var0.getFtpPort() != -1) {
            var3.append(":" + var0.getFtpPort());
         }
      }

      if (var0.getGopherHost() != null) {
         var3.append(",gopher=" + var0.getGopherHost());
         if (var0.getGopherPort() != -1) {
            var3.append(":" + var0.getGopherPort());
         }
      }

      if (var0.getSocksHost() != null) {
         var3.append(",socks=" + var0.getSocksHost());
         if (var0.getSocksPort() != -1) {
            var3.append(":" + var0.getSocksPort());
         }
      }

      String var4 = var3.toString();
      String[] var5 = var0.getOverrides();
      String var6 = null;
      if (var5 != null) {
         var3 = new StringBuffer();
         boolean var7 = true;

         for (int var8 = 0; var8 < var5.length; var8++) {
            if (var8 != 0) {
               var3.append(",");
            }

            var3.append(var5[var8]);
         }

         var6 = var3.toString();
      }

      var1.remove("javaplugin.proxy.config.type");
      var1.remove("javaplugin.proxy.config.list");
      var1.remove("javaplugin.proxy.config.bypass");
      if (var2 == 0) {
         var1.put("javaplugin.proxy.config.type", "direct");
      } else if (var2 == 1) {
         var1.put("javaplugin.proxy.config.type", "manual");
         if (var4 != null) {
            var1.put("javaplugin.proxy.config.list", var4);
         }

         if (var6 != null) {
            var1.put("javaplugin.proxy.config.bypass", var6);
         }
      } else if (var2 == 2) {
         var1.put("javaplugin.proxy.config.type", "auto");
      } else if (var2 == 3) {
         var1.put("javaplugin.proxy.config.type", "browser");
         if (var4 != null) {
            var1.put("javaplugin.proxy.config.list", var4);
         }

         if (var6 != null) {
            var1.put("javaplugin.proxy.config.bypass", var6);
         }
      } else {
         var1.put("javaplugin.proxy.config.type", "unknown");
      }

      System.setProperties(var1);
   }
}
