package com.sun.deploy.net.proxy;

import com.sun.deploy.util.Trace;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public class NSPreferences {
   private static String parseValue(String var0) {
      int var1 = var0.indexOf(",");
      if (var1 != -1) {
         int var2 = var0.lastIndexOf(")");
         if (var2 != -1 && var1 + 1 < var2) {
            return var0.substring(var1 + 1, var2).trim();
         }
      }

      return null;
   }

   private static String parseString(String var0) {
      String var1 = parseValue(var0);
      return var1 != null && var1.length() > 1 && var1.startsWith("\"") && var1.endsWith("\"") ? var1.substring(1, var1.length() - 1) : null;
   }

   private static int parseInt(String var0) {
      String var1 = parseValue(var0);
      if (var1 != null) {
         try {
            return Integer.parseInt(var1);
         } catch (NumberFormatException var3) {
         }
      }

      return -1;
   }

   private static List parseList(String var0) {
      StringTokenizer var1 = new StringTokenizer(parseString(var0), ", ");
      ArrayList var2 = new ArrayList();

      while (var1.hasMoreTokens()) {
         var2.add("*" + var1.nextToken());
      }

      return var2;
   }

   private static boolean isKeyword(String var0, String var1) {
      int var2 = var0.indexOf("(");
      return var2 != -1 && var0.substring(var2 + 1, var0.length()).startsWith("\"" + var1 + "\"");
   }

   private static boolean getDeaultValue(File var0) {
      boolean var1 = false;

      try {
         if (var0.exists()) {
            BufferedReader var2 = new BufferedReader(new InputStreamReader(new FileInputStream(var0), "ISO-8859-1"));

            String var3;
            while ((var3 = var2.readLine()) != null) {
               if (var3.startsWith("pref") && isKeyword(var3, "config.use_system_prefs")) {
                  if (parseValue(var3).equals("true")) {
                     var1 = true;
                  } else {
                     var1 = false;
                  }
                  break;
               }
            }

            var2.close();
         }
      } catch (IOException var4) {
         Trace.ignoredException(var4);
      }

      return var1;
   }

   private static boolean getDefaultValueOfUseSystemPrefs() {
      boolean var0 = false;
      File var1 = new File("/usr/sfw/lib/mozilla/greprefs/all.js");
      File var2 = new File("/usr/lib/mozilla/greprefs/all.js");
      return getDeaultValue(var1) || getDeaultValue(var2);
   }

   protected static void parseFile(File var0, BrowserProxyInfo var1, float var2) {
      BufferedReader var3 = null;

      try {
         var3 = new BufferedReader(new InputStreamReader(new FileInputStream(var0), "ISO-8859-1"));
         String var5 = null;
         String var6 = null;
         int var7 = -1;
         int var8 = -1;
         boolean var9 = getDefaultValueOfUseSystemPrefs();

         String var4;
         while ((var4 = var3.readLine()) != null) {
            if (var4.startsWith("user_pref")) {
               if (isKeyword(var4, "network.proxy.type")) {
                  var7 = parseInt(var4);
                  if (var7 == 3 && System.getProperty("os.name").equals("SunOS") && var2 >= 4.0F) {
                     var1.setType(0);
                     var7 = 0;
                  } else {
                     var1.setType(var7);
                  }

                  Trace.msgNetPrintln("net.proxy.browser.proxyEnable", new Object[]{new Integer(var7)});
               } else if (isKeyword(var4, "network.proxy.http")) {
                  var5 = parseString(var4);

                  try {
                     URL var10 = new URL(var5);
                     var5 = var10.getHost();
                  } catch (MalformedURLException var17) {
                  }

                  Trace.netPrintln("    network.proxy.http=" + var5);
                  var1.setHttpHost(var5);
               } else if (isKeyword(var4, "network.proxy.http_port")) {
                  var8 = parseInt(var4);
                  Trace.netPrintln("    network.proxy.http_port=" + var8);
                  var1.setHttpPort(var8);
               } else if (isKeyword(var4, "network.proxy.ssl")) {
                  String var19 = parseString(var4);

                  try {
                     URL var11 = new URL(var19);
                     var19 = var11.getHost();
                  } catch (MalformedURLException var16) {
                  }

                  Trace.netPrintln("    network.proxy.ssl=" + var19);
                  var1.setHttpsHost(var19);
               } else if (isKeyword(var4, "network.proxy.ssl_port")) {
                  int var20 = parseInt(var4);
                  Trace.netPrintln("    network.proxy.ssl_port=" + var20);
                  var1.setHttpsPort(var20);
               } else if (isKeyword(var4, "network.proxy.ftp")) {
                  String var21 = parseString(var4);

                  try {
                     URL var27 = new URL(var21);
                     var21 = var27.getHost();
                  } catch (MalformedURLException var15) {
                  }

                  Trace.netPrintln("    network.proxy.ftp=" + var21);
                  var1.setFtpHost(var21);
               } else if (isKeyword(var4, "network.proxy.ftp_port")) {
                  int var22 = parseInt(var4);
                  Trace.netPrintln("    network.proxy.ftp_port=" + var22);
                  var1.setFtpPort(var22);
               } else if (isKeyword(var4, "network.proxy.gopher")) {
                  String var23 = parseString(var4);

                  try {
                     URL var28 = new URL(var23);
                     var23 = var28.getHost();
                  } catch (MalformedURLException var14) {
                  }

                  Trace.netPrintln("    network.proxy.gopher=" + var23);
                  var1.setGopherHost(var23);
               } else if (isKeyword(var4, "network.proxy.gopher_port")) {
                  int var24 = parseInt(var4);
                  Trace.netPrintln("    network.proxy.gopher_port=" + var24);
                  var1.setGopherPort(var24);
               } else if (isKeyword(var4, "network.proxy.socks")) {
                  String var25 = parseString(var4);

                  try {
                     URL var29 = new URL(var25);
                     var25 = var29.getHost();
                  } catch (MalformedURLException var13) {
                  }

                  Trace.netPrintln("    network.proxy.socks=" + var25);
                  var1.setSocksHost(var25);
               } else if (isKeyword(var4, "network.proxy.socks_port")) {
                  int var26 = parseInt(var4);
                  Trace.netPrintln("    network.proxy.socks_port=" + var26);
                  var1.setSocksPort(var26);
               } else if (isKeyword(var4, "network.proxy.no_proxies_on")) {
                  Trace.msgNetPrintln("net.proxy.browser.proxyOverride", new Object[]{parseString(var4)});
                  var1.setOverrides(parseList(var4));
               } else if (isKeyword(var4, "network.proxy.autoconfig_url")) {
                  var6 = parseString(var4);
                  Trace.msgNetPrintln("net.proxy.browser.autoConfigURL", new Object[]{var6});
                  var1.setAutoConfigURL(var6);
               } else if (isKeyword(var4, "config.use_system_prefs")) {
                  if (parseValue(var4).equals("true")) {
                     var9 = true;
                  } else {
                     var9 = false;
                  }
               }
            }
         }

         var3.close();
         if (var9) {
            var1.setType(4);
            return;
         }

         if (var7 == -1 && System.getProperty("os.name").equals("SunOS") && var2 >= 6.0F) {
            var1.setType(2);
            return;
         }

         if (var7 == -1 && System.getProperty("os.name").equals("Linux") && var2 >= 4.0F) {
            var1.setType(0);
            return;
         }

         if (var7 == -1 && System.getProperty("os.name").indexOf("Windows") != -1 && var2 >= 4.0F && var2 < 5.0F) {
            var1.setType(0);
            return;
         }

         if (var5 != null && var8 == -1 && System.getProperty("os.name").indexOf("Windows") != -1 && var2 >= 6.0F) {
            var8 = 8080;
            var1.setHttpPort(8080);
         }

         if (var5 != null && var8 != -1 && var7 == -1 && System.getProperty("os.name").indexOf("Windows") != -1 && var2 >= 6.0F) {
            var7 = 1;
            var1.setType(1);
         }

         if (var7 == -1 && var6 != null) {
            var1.setType(2);
         }
      } catch (IOException var18) {
         if (var3 != null) {
            try {
               var3.close();
            } catch (IOException var12) {
            }
         }
      }
   }

   public static File getNS6PrefsFile(File var0) throws IOException {
      return new File(getNS6UserProfileDirectory(var0), "prefs.js");
   }

   public static String getNS6UserProfileDirectory(File var0) throws IOException {
      NSRegistry var1 = new NSRegistry().open(var0);
      String var2 = null;
      Object var3 = null;
      if (var1 != null) {
         var3 = var1.get("Common/Profiles/CurrentProfile");
         if (var3 != null) {
            var2 = var1.get("Common/Profiles/" + var3 + "/directory");
         }

         var1.close();
      }

      if (var2 == null) {
         throw new IOException();
      } else {
         return var2;
      }
   }
}
