package com.sun.deploy.net.proxy;

import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.io.EOFException;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.StringTokenizer;

final class NSRegistry {
   private static final int magic = 1986282561;
   private RandomAccessFile in = null;
   private int rootOffset;
   private int majorVersion;
   private int minorVersion;

   private NSRegistry.Record readRecord(long var1) throws IOException {
      this.in.seek(var1);
      if (this.readInt() != var1) {
         throw new IOException("invalid offset for record [" + var1 + "]");
      } else {
         NSRegistry.Record var3 = new NSRegistry.Record();
         var3.name = this.readInt();
         var3.namelen = this.readUnsignedShort();
         var3.type = this.readUnsignedShort();
         var3.left = this.readInt();
         var3.down = this.readInt();
         var3.value = this.readInt();
         var3.valuelen = this.readUnsignedInt();
         var3.valuebuf = this.readUnsignedInt();
         return var3;
      }
   }

   private String readString(long var1, long var3) throws IOException {
      this.in.seek(var1);
      StringBuffer var5 = new StringBuffer();

      for (int var6 = 0; var6 < var3; var6++) {
         var5.append((char)this.in.read());
      }

      return var5.toString();
   }

   private short readShort() throws IOException {
      int var1 = this.in.read();
      int var2 = this.in.read();
      if ((var1 | var2) < 0) {
         throw new EOFException();
      } else {
         return (short)((var2 << 8) + (var1 << 0));
      }
   }

   private int readUnsignedShort() throws IOException {
      int var1 = this.in.read();
      int var2 = this.in.read();
      if ((var1 | var2) < 0) {
         throw new EOFException();
      } else {
         return (var2 << 8) + (var1 << 0);
      }
   }

   private int readInt() throws IOException {
      int var1 = this.in.read();
      int var2 = this.in.read();
      int var3 = this.in.read();
      int var4 = this.in.read();
      if ((var1 | var2 | var3 | var4) < 0) {
         throw new EOFException();
      } else {
         return (var4 << 24) + (var3 << 16) + (var2 << 8) + (var1 << 0);
      }
   }

   private long readUnsignedInt() throws IOException {
      int var1 = this.in.read();
      int var2 = this.in.read();
      int var3 = this.in.read();
      int var4 = this.in.read();
      if ((var1 | var2 | var3 | var4) < 0) {
         throw new EOFException();
      } else {
         return (var4 << 24) + (var3 << 16) + (var2 << 8) + (var1 << 0);
      }
   }

   NSRegistry open(File var1) {
      if (this.in != null) {
         return this;
      } else {
         try {
            this.in = new RandomAccessFile(var1, "r");
            if (this.readInt() != 1986282561) {
               throw new IOException("not a valid Netscape Registry File");
            } else {
               this.majorVersion = this.readUnsignedShort();
               this.minorVersion = this.readUnsignedShort();
               this.in.skipBytes(4);
               this.rootOffset = this.readInt();
               return this;
            }
         } catch (IOException var3) {
            return null;
         }
      }
   }

   void close() {
      if (this.in != null) {
         try {
            this.in.close();
         } catch (IOException var2) {
         }

         this.in = null;
      }
   }

   private String get(NSRegistry.Record var1, StringTokenizer var2) throws IOException {
      String var3 = var2.nextToken();
      if (var2.hasMoreTokens()) {
         int var6 = var1.down;

         while (var6 != 0) {
            NSRegistry.Record var7 = this.readRecord(var6);
            if (var3.equals(this.readString(var7.name, var7.namelen - 1))) {
               return this.get(var7, var2);
            }

            var6 = var7.left;
         }

         return null;
      } else {
         int var4 = var1.value;

         while (var4 != 0) {
            NSRegistry.Record var5 = this.readRecord(var4);
            if (var3.equals(this.readString(var5.name, var5.namelen - 1))) {
               return this.readString(var5.value, var5.valuelen - 1L);
            }

            var4 = var5.left;
         }

         return null;
      }
   }

   String get(String var1) {
      StringTokenizer var2 = new StringTokenizer(var1, "/");

      try {
         return this.get(this.readRecord(this.rootOffset), var2);
      } catch (IOException var4) {
         return null;
      }
   }

   private void dump(String var1, int var2) throws IOException {
      NSRegistry.Record var3 = this.readRecord(var2);
      System.out.println(var1 + this.readString(var3.name, var3.namelen - 1));

      for (int var4 = var3.down; var4 != 0; var4 = this.readRecord(var4).left) {
         this.dump(var1 + "    ", var4);
      }

      int var5 = var3.value;

      while (var5 != 0) {
         NSRegistry.Record var6 = this.readRecord(var5);
         String var7 = this.readString(var6.name, var6.namelen - 1);
         String var8 = this.readString(var6.value, var6.valuelen - 1L);
         System.out.println(var1 + "[" + var7 + " = " + var8 + "]");
         var5 = var6.left;
      }
   }

   void dump() {
      try {
         this.dump("", this.rootOffset);
      } catch (IOException var2) {
         var2.printStackTrace();
      }
   }

   public String toString() {
      String var1 = this.getClass().getName() + "@" + Integer.toHexString(this.hashCode());
      if (this.in != null) {
         var1 = var1 + "[version " + this.majorVersion + "." + this.minorVersion + "]";
      } else {
         var1 = var1 + "[closed]";
      }

      return var1;
   }

   private static String getNS45PrefsFilePath(String var0) {
      String var1 = null;

      try {
         File var2 = new File(var0, "nsreg.dat");
         NSRegistry var3 = new NSRegistry().open(var2);
         if (var3 != null) {
            String var4 = var3.get("Common/Netscape/ProfileManager/LastNetscapeUser");
            if (var4 != null) {
               var1 = var3.get("Users/" + var4 + "/ProfileLocation");
            }

            var3.close();
         }

         if (var1 != null) {
            var1 = var1 + File.separator + "prefs.js";
         }
      } catch (Exception var5) {
         Trace.printException(var5, ResourceManager.getMessage("net.proxy.nsprefs.error"), ResourceManager.getMessage("net.proxy.error.caption"));
      }

      return var1;
   }

   private static void showProxyErrorDialog() {
      DialogFactory.showErrorDialog(ResourceManager.getMessage("net.proxy.nsprefs.error"), ResourceManager.getMessage("net.proxy.error.caption"));
   }

   private static final class Record {
      int name;
      int namelen;
      int type;
      int left;
      int down;
      int value;
      long valuelen;
      long valuebuf;

      private Record() {
      }

      public boolean isKey() {
         return (this.type & 16) != 0;
      }

      public boolean isEntry() {
         return !this.isKey();
      }
   }
}
