package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.Trace;
import com.sun.deploy.util.TraceLevel;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.io.File;
import java.io.IOException;
import java.util.Hashtable;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.KeyStroke;
import javax.swing.border.Border;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.PlainDocument;

public class CacheSettingsDialog extends JDialog {
   private String LIB = "lib";
   private String PLUGIN_JAR = "plugin.jar";
   private String DEPLOY_JAR = "deploy.jar";
   private String VIEWER = "sun.plugin.cache.JarCacheViewer";
   private String CLASSPATH = "-classpath";
   private JTextField location;
   private JTextField size;
   private JButton choose;
   private JButton okBtn;
   private JButton cancelBtn;
   private JButton viewJwsCacheBtn;
   private JButton deleteFilesBtn;
   private JButton viewJpiCacheBtn;
   private JRadioButton unlimited;
   private JRadioButton maximum;
   private JComboBox units;
   private JSlider compression;

   public CacheSettingsDialog(Frame var1, boolean var2) {
      super(var1, var2);
      this.initComponents();
   }

   private void initComponents() {
      this.setTitle(this.getMessage("cache.settings.dialog.title"));
      JPanel var1 = new JPanel();
      var1.setLayout(new BoxLayout(var1, 0));
      var1.setBorder(BorderFactory.createEmptyBorder(6, 6, 6, 6));
      this.deleteFilesBtn = this.makeButton("cache.settings.dialog.delete_btn");
      this.deleteFilesBtn.addActionListener(new CacheSettingsDialog$1(this));
      this.deleteFilesBtn.setToolTipText(this.getMessage("temp.files.delete.btn.tooltip"));
      this.viewJwsCacheBtn = this.makeButton("cache.settings.dialog.view_jws_btn");
      this.viewJwsCacheBtn.addActionListener(new CacheSettingsDialog$2(this));
      this.viewJwsCacheBtn.setToolTipText(this.getMessage("cache.settings.dialog.view_jws_btn.tooltip"));
      this.viewJpiCacheBtn = this.makeButton("cache.settings.dialog.view_jpi_btn");
      this.viewJpiCacheBtn.addActionListener(new CacheSettingsDialog$3(this));
      this.viewJpiCacheBtn.setToolTipText(this.getMessage("cache.settings.dialog.view_jpi_btn.tooltip"));
      var1.add(this.deleteFilesBtn);
      var1.add(Box.createHorizontalGlue());
      var1.add(this.viewJwsCacheBtn);
      var1.add(Box.createHorizontalGlue());
      var1.add(this.viewJpiCacheBtn);
      this.getContentPane().add(var1, "North");
      JPanel var2 = new JPanel();
      GridBagLayout var3 = new GridBagLayout();
      GridBagConstraints var4 = new GridBagConstraints();
      var2.setLayout(var3);
      Border var5 = BorderFactory.createEtchedBorder();
      var2.setBorder(
         BorderFactory.createCompoundBorder(
            BorderFactory.createEmptyBorder(0, 4, 4, 4), BorderFactory.createTitledBorder(var5, this.getMessage("common.settings"), 0, 0)
         )
      );
      JLabel var6 = new JLabel(this.getMessage("cache.settings.dialog.cache_location"));
      var4.anchor = 17;
      var4.weighty = 3.0;
      var4.fill = 0;
      var4.insets = new Insets(5, 10, 5, 10);
      var3.setConstraints(var6, var4);
      var2.add(var6);
      this.location = new CacheSettingsDialog.LocationField(null);
      this.location.setDocument(new CacheSettingsDialog.LocationDocument(null));
      this.location.setEditable(false);
      var4.weightx = 1.0;
      var4.gridwidth = 3;
      var4.insets = new Insets(5, 0, 5, 2);
      var4.fill = 2;
      var3.setConstraints(this.location, var4);
      var2.add(this.location);
      this.choose = this.makeButton("cache.settings.dialog.change_btn");
      this.choose.setMargin(new Insets(0, 10, 0, 10));
      this.choose.addActionListener(new CacheSettingsDialog$4(this));
      this.choose.setToolTipText(this.getMessage("cache.settings.dialog.change_btn.tooltip"));
      var4.fill = 0;
      var4.gridwidth = 0;
      var4.insets = new Insets(5, 2, 5, 10);
      var4.weightx = 0.0;
      var3.setConstraints(this.choose, var4);
      var2.add(this.choose);
      JSmartTextArea var7 = new JSmartTextArea(this.getMessage("cache.settings.dialog.disk_space"));
      var7.setRows(2);
      var4.weightx = 0.0;
      var4.weighty = 0.0;
      var4.gridwidth = 1;
      var4.gridheight = 2;
      var4.insets = new Insets(5, 5, 10, 10);
      var3.setConstraints(var7, var4);
      var2.add(var7);
      var4.gridheight = 1;
      ButtonGroup var8 = new ButtonGroup();
      this.unlimited = new JRadioButton(this.getMessage("cache.settings.dialog.unlimited_btn"));
      this.unlimited.setToolTipText(this.getMessage("cache.settings.dialog.unlimited_btn.tooltip"));
      this.unlimited.addActionListener(new CacheSettingsDialog$5(this));
      this.unlimited.setMargin(new Insets(0, 0, 0, 0));
      var4.weightx = 1.0;
      var4.gridwidth = 0;
      var4.insets = new Insets(5, 0, 0, 0);
      var3.setConstraints(this.unlimited, var4);
      var8.add(this.unlimited);
      var2.add(this.unlimited);
      this.maximum = new JRadioButton(this.getMessage("cache.settings.dialog.max_btn"));
      this.maximum.setToolTipText(this.getMessage("cache.settings.dialog.max_btn.tooltip"));
      this.maximum.setMargin(new Insets(0, 0, 0, 0));
      this.maximum.addActionListener(new CacheSettingsDialog$6(this));
      var4.gridwidth = 1;
      var4.gridx = 1;
      var4.weightx = 0.0;
      var4.insets = new Insets(0, 0, 10, 0);
      var3.setConstraints(this.maximum, var4);
      var8.add(this.maximum);
      var2.add(this.maximum);
      this.size = new JTextField(7);
      this.size.setDocument(new CacheSettingsDialog.SizeDocument(null));
      var4.gridx = -1;
      var3.setConstraints(this.size, var4);
      var2.add(this.size);
      String[] var9 = new String[]{"MB", "KB", "bytes"};
      this.units = new JComboBox<>(var9);
      var4.gridwidth = 1;
      var4.insets = new Insets(0, 2, 10, 10);
      var3.setConstraints(this.units, var4);
      var2.add(this.units);
      JLabel var10 = new JLabel(this.getMessage("cache.settings.dialog.compression"));
      var10.setToolTipText(this.getMessage("cache.settings.dialog.compression.tooltip"));
      var4.anchor = 18;
      var4.gridy = 3;
      var4.weightx = 0.0;
      var4.weighty = 1.0;
      var4.gridwidth = 1;
      var4.insets = new Insets(5, 10, 5, 10);
      var3.setConstraints(var10, var4);
      var2.add(var10);
      this.compression = new JSlider(0, 9, 0);
      Hashtable var11 = new Hashtable(2);
      JLabel var12 = new JLabel(this.getMessage("cache.settings.dialog.none"));
      JLabel var13 = new JLabel(this.getMessage("cache.settings.dialog.high"));
      var11.put(new Integer(0), var12);
      var11.put(new Integer(9), var13);
      this.compression.setLabelTable(var11);
      this.compression.setPaintLabels(true);
      this.compression.setMajorTickSpacing(1);
      this.compression.setPaintTicks(true);
      this.compression.setSnapToTicks(true);
      var4.weightx = 1.0;
      var4.gridheight = 2;
      var4.gridwidth = 0;
      var4.fill = 2;
      var4.insets = new Insets(5, 0, 5, 10);
      var3.setConstraints(this.compression, var4);
      var2.add(this.compression);
      this.getContentPane().add(var2, "Center");
      this.okBtn = this.makeButton("common.ok_btn");
      this.okBtn.addActionListener(new CacheSettingsDialog$7(this));
      CacheSettingsDialog$8 var14 = new CacheSettingsDialog$8(this);
      this.cancelBtn = this.makeButton("common.cancel_btn");
      this.cancelBtn.addActionListener(var14);
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke('\u001b'), "cancel");
      this.getRootPane().getActionMap().put("cancel", var14);
      JPanel var15 = new JPanel();
      var15.setLayout(new FlowLayout(2));
      var15.add(this.okBtn);
      var15.add(this.cancelBtn);
      this.getContentPane().add(var15, "South");
      this.getRootPane().setDefaultButton(this.okBtn);
      this.pack();
      this.setResizable(false);
      this.initValues();
   }

   public void initValues() {
      this.location.setText(Config.getCacheDirectory());
      this.location.setToolTipText(this.location.getText());
      this.location.setHorizontalAlignment(2);
      boolean var1 = !Config.isLocked("deployment.user.cachedir");
      this.location.setEnabled(var1);
      this.location.setEditable(var1);
      this.choose.setEnabled(var1);
      String var4 = Config.getProperty("deployment.cache.max.size").trim();
      var1 = !Config.isLocked("deployment.cache.max.size");

      try {
         byte var5 = 0;
         if (var4.endsWith("M") || var4.endsWith("m")) {
            var4 = var4.substring(0, var4.length() - 1);
            var5 = 0;
         } else if (!var4.endsWith("K") && !var4.endsWith("k")) {
            var5 = 2;
         } else {
            var4 = var4.substring(0, var4.length() - 1);
            var5 = 1;
         }

         long var9 = Long.valueOf(var4);
         if (var9 == -1L) {
            this.unlimited.setSelected(true);
            this.size.setEnabled(false);
            this.size.setEditable(false);
            this.units.setEnabled(false);
         } else {
            this.maximum.setSelected(true);
            this.size.setText(var4);
            this.units.setSelectedIndex(var5);
         }
      } catch (NumberFormatException var6) {
         long var2 = 50L;
         this.maximum.setSelected(true);
         this.units.setSelectedIndex(0);
      }

      if (!var1) {
         this.unlimited.setEnabled(var1);
         this.maximum.setEnabled(var1);
         this.size.setEnabled(var1);
         this.units.setEnabled(var1);
      }

      var1 = !Config.isLocked("deployment.cache.jarcompression");
      this.compression.setValue(Config.getIntProperty("deployment.cache.jarcompression"));
      this.compression.setEnabled(var1);
   }

   private void viewJpiCacheBtnActionPerformed(ActionEvent var1) {
      String var2 = System.getProperty("java.home");
      String var3 = System.getProperty("javaplugin.user.profile");
      if (var3 == null) {
         var3 = "";
      }

      if (!var2.endsWith(File.separator)) {
         var2 = var2 + File.separator;
      }

      String[] var4 = new String[]{
         Config.getInstance().toExecArg(Config.getJavaCommand()),
         this.CLASSPATH,
         Config.getInstance()
            .toExecArg(var2 + this.LIB + File.separator + this.PLUGIN_JAR + File.pathSeparator + var2 + this.LIB + File.separator + this.DEPLOY_JAR),
         Config.getInstance().toExecArg("-Djavaplugin.user.profile=" + var3),
         this.VIEWER
      };
      Trace.println("Launching plug-in Cache Viewer: " + var4[0] + " " + var4[1] + " " + var4[2] + " " + var4[3] + " " + var4[4]);

      try {
         Runtime.getRuntime().exec(var4);
      } catch (IOException var6) {
         Trace.ignoredException(var6);
      }
   }

   private void viewJwsCacheBtnActionPerformed(ActionEvent var1) {
      String[] var2 = new String[]{Config.getJavawsCommand(), "-Xnosplash", "-viewer"};
      Trace.println("Launching javaws viewer: " + var2[0] + " " + var2[1], TraceLevel.BASIC);

      try {
         Runtime.getRuntime().exec(var2);
      } catch (IOException var4) {
         Trace.ignoredException(var4);
      }
   }

   private void chooseButtonActionPerformed(ActionEvent var1) {
      JFileChooser var2 = new JFileChooser();
      var2.setFileSelectionMode(1);
      var2.setDialogTitle(this.getMessage("cache.settings.dialog.chooser_title"));
      var2.setApproveButtonText(this.getMessage("cache.settings.dialog.select"));
      String var3 = this.getMessage("cache.settings.dialog.select_tooltip");
      var2.setApproveButtonToolTipText(var3);
      char var4 = this.getMessage("cache.settings.dialog.select_mnemonic").charAt(0);
      var2.setApproveButtonMnemonic(var4);
      File var5 = new File(this.location.getText());
      var2.setCurrentDirectory(var5);
      if (var2.showDialog(this, null) == 0) {
         String var6;
         try {
            var6 = var2.getSelectedFile().getCanonicalPath();
         } catch (IOException var8) {
            var6 = var2.getSelectedFile().getPath();
         }

         this.location.setText(var6);
         this.location.setToolTipText(var6);
      }
   }

   private void deleteFilesBtnActionPerformed(ActionEvent var1) {
      new DeleteFilesDialog(this);
   }

   private void radioButtonActionPerformed(ActionEvent var1) {
      if (var1.getSource().equals(this.unlimited)) {
         this.size.setEnabled(false);
         this.size.setEditable(false);
         this.units.setEnabled(false);
      } else {
         this.size.setEditable(true);
         this.size.setEnabled(true);
         this.units.setEnabled(true);
      }
   }

   private void okBtnActionPerformed(ActionEvent var1) {
      Config.setCacheDirectory(this.location.getText());
      this.updateSize();
      Config.setIntProperty("deployment.cache.jarcompression", this.compression.getValue());
      this.setVisible(false);
      this.dispose();
   }

   private void cancelBtnActionPerformed(ActionEvent var1) {
      this.setVisible(false);
      this.dispose();
   }

   private void closeDialog(WindowEvent var1) {
      this.setVisible(false);
      this.dispose();
   }

   private void updateSize() {
      String var1;
      if (this.unlimited.isSelected()) {
         var1 = "-1";
      } else {
         var1 = this.size.getText().trim();
         if (var1.equals("")) {
            var1 = "0";
         }

         long var2 = Long.valueOf(var1);
         var1 = Long.toString(var2);
         int var4 = this.units.getSelectedIndex();
         String[] var5 = new String[]{"m", "k", ""};
         var1 = var1 + var5[var4];
      }

      Config.setProperty("deployment.cache.max.size", var1);
   }

   private String getMessage(String var1) {
      return ResourceManager.getMessage(var1);
   }

   public JButton makeButton(String var1) {
      JButton var2 = new JButton(this.getMessage(var1));
      var2.setMnemonic(ResourceManager.getVKCode(var1 + ".mnemonic"));
      return var2;
   }

   private class LocationDocument extends PlainDocument {
      private LocationDocument() {
      }

      public void insertString(int var1, String var2, AttributeSet var3) throws BadLocationException {
         super.insertString(var1, var2, var3);
      }

      public void remove(int var1, int var2) throws BadLocationException {
         super.remove(var1, var2);
      }
   }

   private class LocationField extends JTextField {
      private LocationField() {
      }

      public Dimension getPreferredSize() {
         Dimension var1 = super.getPreferredSize();
         var1.width = 10;
         return var1;
      }
   }

   private class SizeDocument extends PlainDocument {
      private SizeDocument() {
      }

      public void insertString(int var1, String var2, AttributeSet var3) throws BadLocationException {
         if (this.isNumeric(var2)) {
            super.insertString(var1, var2, var3);
            CacheSettingsDialog.this.maximum.setSelected(true);
         } else {
            Toolkit.getDefaultToolkit().beep();
         }
      }

      public void remove(int var1, int var2) throws BadLocationException {
         super.remove(var1, var2);
         CacheSettingsDialog.this.maximum.setSelected(true);
      }

      private boolean isNumeric(String var1) {
         try {
            Long.valueOf(var1);
            return true;
         } catch (NumberFormatException var3) {
            return false;
         }
      }
   }
}
