package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.security.CertUtils;
import com.sun.deploy.security.CertificateDialog;
import com.sun.deploy.util.DeploySysRun;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.PrintStream;
import java.security.Key;
import java.security.KeyStore;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.Arrays;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Iterator;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JTabbedPane;
import javax.swing.KeyStroke;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import sun.misc.BASE64Encoder;

public class CertificatesDialog extends JDialog implements ChangeListener {
   private int USER_LEVEL = 0;
   private int SYSTEM_LEVEL = 1;
   private JComboBox certsComboBox;
   private JButton importButton;
   private JButton exportButton;
   private JButton removeButton;
   private JButton detailsButton;
   private JButton closeButton;
   private CertificatesInfo model;
   private JTabbedPane tabbedPane;
   private CertificateTabPanel userTab;
   private CertificateTabPanel systemTab;
   private String strTrustedCerts = getMessage("cert.type.trusted_certs");
   private String strSecureSite = getMessage("cert.type.secure_site");
   private String strSignerCa = getMessage("cert.type.signer_ca");
   private String strSecureSiteCa = getMessage("cert.type.secure_site_ca");
   private String strClientAuth = getMessage("cert.type.client_auth");
   private String[] certTypeName = new String[]{this.strTrustedCerts, this.strSecureSite, this.strSignerCa, this.strSecureSiteCa, this.strClientAuth};

   public CertificatesDialog(Frame var1, boolean var2) {
      super(var1, var2);
      this.model = new CertificatesInfo();
      this.initComponents();
   }

   private void initComponents() {
      this.getContentPane().setLayout(new BorderLayout());
      this.setDefaultCloseOperation(2);
      this.setTitle(getMessage("cert.settings"));
      this.addWindowListener(new CertificatesDialog$1(this));
      JPanel var1 = new JPanel();
      var1.setLayout(new BoxLayout(var1, 1));
      var1.setPreferredSize(new Dimension(500, 300));
      var1.setBorder(BorderFactory.createRaisedBevelBorder());
      JPanel var2 = new JPanel();
      var2.setLayout(new BoxLayout(var2, 0));
      JPanel var3 = new JPanel();
      var3.setLayout(new BoxLayout(var3, 1));
      var3.setBorder(BorderFactory.createEmptyBorder(10, 10, 5, 10));
      var3.add(Box.createHorizontalStrut(60));
      this.certsComboBox = new JComboBox();
      this.certsComboBox.setModel(new DefaultComboBoxModel<>(this.certTypeName));
      this.certsComboBox.addActionListener(new CertificatesDialog$2(this));
      var3.add(this.certsComboBox);
      var2.add(new JLabel(getMessage("cert.dialog.certtype")));
      var2.add(var3);
      var2.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 5));
      var1.add(var2);
      this.tabbedPane = new JTabbedPane();
      this.userTab = new CertificateTabPanel(this.model, this.USER_LEVEL);
      this.systemTab = new CertificateTabPanel(this.model, this.SYSTEM_LEVEL);
      this.tabbedPane.setName(" ");
      this.tabbedPane.addTab(getMessage("cert.dialog.user.level"), this.userTab);
      this.tabbedPane.addTab(getMessage("cert.dialog.system.level"), this.systemTab);
      this.tabbedPane.setSelectedIndex(0);
      this.tabbedPane.addChangeListener(this);
      var1.add(this.tabbedPane);
      JPanel var4 = new JPanel();
      var4.setBorder(BorderFactory.createEmptyBorder(0, 10, 5, 10));
      this.importButton = new JButton(getMessage("cert.import_button"));
      this.importButton.setMnemonic(ResourceManager.getVKCode("cert.import_button.mnemonic"));
      this.importButton.addActionListener(new CertificatesDialog$3(this));
      this.importButton.setToolTipText(getMessage("cert.import_btn.tooltip"));
      var4.add(this.importButton);
      this.exportButton = new JButton(getMessage("cert.export_button"));
      this.exportButton.setMnemonic(ResourceManager.getVKCode("cert.export_button.mnemonic"));
      this.exportButton.addActionListener(new CertificatesDialog$4(this));
      this.exportButton.setToolTipText(getMessage("cert.export_btn.tooltip"));
      var4.add(this.exportButton);
      this.removeButton = new JButton(getMessage("cert.remove_button"));
      this.removeButton.setMnemonic(ResourceManager.getVKCode("cert.remove_button.mnemonic"));
      this.removeButton.addActionListener(new CertificatesDialog$5(this));
      this.removeButton.setToolTipText(getMessage("cert.remove_btn.tooltip"));
      var4.add(this.removeButton);
      this.detailsButton = new JButton(getMessage("cert.details_button"));
      this.detailsButton.setMnemonic(ResourceManager.getVKCode("cert.details_button.mnemonic"));
      this.detailsButton.addActionListener(new CertificatesDialog$6(this));
      this.detailsButton.setToolTipText(getMessage("cert.details_btn.tooltip"));
      var4.add(this.detailsButton);
      var1.add(var4);
      this.getContentPane().add(var1, "Center");
      JPanel var5 = new JPanel();
      var5.setLayout(new FlowLayout(2));
      var5.setBorder(BorderFactory.createEmptyBorder(5, 10, 5, 10));
      this.closeButton = new JButton(getMessage("cert.close_button"));
      this.closeButton.setMnemonic(ResourceManager.getVKCode("cert.close_button.mnemonic"));
      CertificatesDialog$7 var6 = new CertificatesDialog$7(this);
      this.closeButton.addActionListener(var6);
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke('\u001b'), "cancel");
      this.getRootPane().getActionMap().put("cancel", var6);
      var5.add(this.closeButton);
      this.getContentPane().add(var5, "South");
      this.updateButtonState();
      this.getRootPane().setDefaultButton(this.closeButton);
      this.pack();
      this.setResizable(false);
   }

   private void certsComboBoxActionPerformed(ActionEvent var1) {
      this.reset();
   }

   private void closeButtonActionPerformed(ActionEvent var1) {
      this.setVisible(false);
      this.dispose();
   }

   private void importButtonActionPerformed(ActionEvent var1) {
      JFileChooser var2 = new JFileChooser();
      CertFileFilter var3 = new CertFileFilter();
      var3.addExtension("csr");
      var3.addExtension("p12");
      var3.setDescription("Certificate Files");
      var2.setFileFilter(var3);
      var2.setFileSelectionMode(0);
      var2.setDialogType(0);
      var2.setMultiSelectionEnabled(false);
      int var4 = var2.showOpenDialog(this);
      if (var4 == 0) {
         File var5 = var2.getSelectedFile();
         if (var5 == null) {
            return;
         }

         try {
            InputStream var6 = System.in;
            FileInputStream var11 = new FileInputStream(var5);
            boolean var12 = false;
            var12 = this.importCertificate(var11);
            if (!var12) {
               InputStream var14 = System.in;
               FileInputStream var15 = new FileInputStream(var5);
               String var9 = (String)this.certsComboBox.getSelectedItem();
               if (var9.equals(this.strClientAuth)) {
                  this.importPKCS12CertKey(var15);
               } else {
                  this.importPKCS12Certificate(var15);
               }
            }
         } catch (Throwable var10) {
            String var7 = getMessage("cert.dialog.import.file.text");
            String var8 = getMessage("cert.dialog.import.error.caption");
            DialogFactory.showExceptionDialog(this.getParent(), var10, var7, var8);
         }
      }

      this.reset();
   }

   private void exportButtonActionPerformed(ActionEvent var1) {
      String var2 = (String)this.certsComboBox.getSelectedItem();
      int var3 = -1;
      int var4 = this.USER_LEVEL;
      if (this.isUserLevelSelected()) {
         var4 = this.USER_LEVEL;
         var3 = this.userTab.getSelectedCertificateTableRow();
      } else {
         var4 = this.SYSTEM_LEVEL;
         var3 = this.systemTab.getSelectedCertificateTableRow();
      }

      if (var3 != -1) {
         Collection var5 = null;
         Object var6 = null;
         Certificate[] var7 = new Certificate[]{null};
         if (var2.equals(this.strTrustedCerts)) {
            var5 = this.model.getTrustedCertificates(var4);
         } else if (var2.equals(this.strSecureSite)) {
            var5 = this.model.getHttpsCertificates(var4);
         } else if (var2.equals(this.strSignerCa)) {
            var5 = this.model.getRootCACertificates(var4);
         } else if (var2.equals(this.strSecureSiteCa)) {
            var5 = this.model.getHttpsRootCACertificates(var4);
         } else if (var2.equals(this.strClientAuth)) {
            var5 = this.model.getClientAuthCertificates(var4);
         }

         Object[] var8 = var5.toArray();
         if (var2.equals(this.strClientAuth)) {
            var7 = (Certificate[])var8[var3];
            var6 = (X509Certificate)var7[0];
         } else {
            var6 = (X509Certificate)var8[var3];
         }

         if (var6 != null) {
            JFileChooser var9 = new JFileChooser();
            var9.setFileSelectionMode(0);
            var9.setDialogType(1);
            var9.setMultiSelectionEnabled(false);
            int var10 = var9.showSaveDialog(this);
            if (var10 == 0) {
               File var11 = var9.getSelectedFile();
               if (var11 == null) {
                  return;
               }

               PrintStream var12 = null;

               try {
                  if (var2.equals(this.strClientAuth)) {
                     this.exportPKCS12Cert(var7, var11, var4);
                  } else {
                     var12 = new PrintStream(new BufferedOutputStream(new FileOutputStream(var11)));
                     this.exportCertificate((X509Certificate)var6, var12);
                  }
               } catch (Throwable var19) {
                  String var14 = getMessage("cert.dialog.export.text");
                  String var15 = getMessage("cert.dialog.export.error.caption");
                  DialogFactory.showExceptionDialog(this.getParent(), var19, var14, var15);
               } finally {
                  if (var12 != null) {
                     var12.close();
                  }
               }
            }
         } else {
            String var24 = getMessage("cert.dialog.export.text");
            String var25 = getMessage("cert.dialog.export.error.caption");
            DialogFactory.showErrorDialog(this, var24, var25);
         }
      }
   }

   private void removeButtonActionPerformed(ActionEvent var1) {
      String var2 = (String)this.certsComboBox.getSelectedItem();
      int var3 = -1;
      int var4 = this.USER_LEVEL;
      if (this.isUserLevelSelected()) {
         var4 = this.USER_LEVEL;
         var3 = this.userTab.getSelectedCertificateTableRow();
      } else {
         var4 = this.SYSTEM_LEVEL;
         var3 = this.systemTab.getSelectedCertificateTableRow();
      }

      if (var3 != -1) {
         String var5 = getMessage("cert.dialog.remove.text");
         String var6 = getMessage("cert.dialog.remove.caption");
         int var7 = DialogFactory.showConfirmDialog(this, var5, var6);
         if (var7 == 0) {
            if (var2.equals(this.strTrustedCerts)) {
               Collection var8 = this.model.getTrustedCertificates(var4);
               Object[] var9 = var8.toArray();
               this.model.removeTrustedCertificate((Certificate)var9[var3]);
            } else if (var2.equals(this.strSecureSite)) {
               Collection var12 = this.model.getHttpsCertificates(var4);
               Object[] var16 = var12.toArray();
               this.model.removeHttpsCertificate((Certificate)var16[var3]);
            } else if (var2.equals(this.strSignerCa)) {
               Collection var13 = this.model.getRootCACertificates(var4);
               Object[] var17 = var13.toArray();
               this.model.removeRootCACertificate((Certificate)var17[var3]);
            } else if (var2.equals(this.strSecureSiteCa)) {
               Collection var14 = this.model.getHttpsRootCACertificates(var4);
               Object[] var18 = var14.toArray();
               this.model.removeHttpsRootCACertificate((Certificate)var18[var3]);
            } else if (var2.equals(this.strClientAuth)) {
               Collection var15 = this.model.getClientAuthCertificates(var4);
               Object[] var19 = var15.toArray();
               this.model.removeClientAuthCertificate(this, (Certificate[])var19[var3]);
            }

            this.reset();
         }
      }
   }

   private void detailsButtonActionPerformed(ActionEvent var1) {
      String var2 = (String)this.certsComboBox.getSelectedItem();
      int var3 = -1;
      if (this.isUserLevelSelected()) {
         var3 = this.userTab.getSelectedCertificateTableRow();
      } else {
         var3 = this.systemTab.getSelectedCertificateTableRow();
      }

      if (var3 != -1) {
         Collection var4 = null;
         Object var5 = null;
         Certificate[] var10000 = new Certificate[]{null};
         byte var7 = 0;
         if (!this.isUserLevelSelected()) {
            var7 = 1;
         }

         if (var2.equals(this.strTrustedCerts)) {
            var4 = this.model.getTrustedCertificates(var7);
         } else if (var2.equals(this.strSecureSite)) {
            var4 = this.model.getHttpsCertificates(var7);
         } else if (var2.equals(this.strSignerCa)) {
            var4 = this.model.getRootCACertificates(var7);
         } else if (var2.equals(this.strSecureSiteCa)) {
            var4 = this.model.getHttpsRootCACertificates(var7);
         } else if (var2.equals(this.strClientAuth)) {
            var4 = this.model.getClientAuthCertificates(var7);
         }

         Object[] var8 = var4.toArray();
         Certificate[] var6;
         if (var2.equals(this.strClientAuth)) {
            var6 = (Certificate[])var8[var3];
         } else {
            var6 = new Certificate[]{(Certificate)var8[var3]};
         }

         if (var6[0] != null) {
            CertificateDialog var9 = new CertificateDialog(this, var6, 0, var6.length);
            var9.DoModal();
         }
      }
   }

   private void closeDialog(WindowEvent var1) {
      this.setVisible(false);
      this.dispose();
   }

   private void exportPKCS12Cert(Certificate[] var1, File var2, int var3) {
      Object var4 = null;
      Object var5 = null;
      Object var6 = null;

      try {
         if (var3 == this.USER_LEVEL) {
            var6 = Config.getUserClientAuthCertFile();
         } else {
            var6 = Config.getSystemClientAuthCertFile();
         }

         KeyStore var7 = KeyStore.getInstance("JKS");
         FileInputStream var17 = new FileInputStream((String)var6);
         var4 = this.getPasswordDialog("cert.dialog.exportpassword.text", "cert.dialog.password.export.caption");
         var7.load(var17, (char[])var4);
         if (var4 != null) {
            String var18 = var7.getCertificateAlias(var1[0]);
            Key var10 = var7.getKey(var18, (char[])var4);
            FileOutputStream var11 = new FileOutputStream(var2);
            KeyStore var12 = KeyStore.getInstance("PKCS12");
            var12.load(null, null);
            var5 = this.getPasswordDialog("cert.dialog.savepassword.text", "cert.dialog.password.export.caption");
            if (var5 != null) {
               var12.setKeyEntry(var18, var10, (char[])var5, var1);
               var12.store(var11, (char[])var5);
            }
         }
      } catch (Exception var13) {
         String var8 = getMessage("cert.dialog.export.password.text");
         String var9 = getMessage("cert.dialog.export.error.caption");
         DialogFactory.showExceptionDialog(this.getParent(), var13, var8, var9);
      }
   }

   private void exportCertificate(X509Certificate var1, PrintStream var2) {
      BASE64Encoder var3 = new BASE64Encoder();
      var2.println("-----BEGIN CERTIFICATE-----");

      try {
         var3.encodeBuffer(var1.getEncoded(), var2);
      } catch (Throwable var5) {
      }

      var2.println("-----END CERTIFICATE-----");
   }

   void importPKCS12Certificate(InputStream var1) {
      char[] var2 = null;

      try {
         KeyStore var3 = KeyStore.getInstance("PKCS12");
         var2 = this.getPasswordDialog("cert.dialog.password.text", "cert.dialog.password.import.caption");
         if (var2 != null) {
            var3.load(var1, var2);
            Enumeration var13 = var3.aliases();

            for (String var14 = (String)this.certsComboBox.getSelectedItem(); var13.hasMoreElements(); this.reset()) {
               String var15 = (String)var13.nextElement();
               X509Certificate var7 = (X509Certificate)var3.getCertificate(var15);
               if (var14.equals(this.strTrustedCerts)) {
                  this.model.addTrustedCertificate(var7);
               } else if (var14.equals(this.strSecureSite)) {
                  this.model.addHttpsCertificate(var7);
               } else if (var14.equals(this.strSignerCa)) {
                  this.model.addCACertificate(var7);
               } else if (var14.equals(this.strSecureSiteCa)) {
                  this.model.addHttpsCACertificate(var7);
               }
            }
         }
      } catch (Throwable var11) {
         String var4 = "uninitializedValue";
         if (!this.compareCharArray(var2, var4.toCharArray())) {
            String var5 = getMessage("cert.dialog.import.password.text");
            String var6 = getMessage("cert.dialog.import.error.caption");
            DialogFactory.showExceptionDialog(this.getParent(), var11, var5, var6);
         }
      } finally {
         if (var2 != null) {
            Arrays.fill(var2, ' ');
         }
      }
   }

   void importPKCS12CertKey(InputStream var1) {
      char[] var2 = null;

      try {
         var2 = this.getPasswordDialog("cert.dialog.password.text", "cert.dialog.password.import.caption");
         if (var2 != null) {
            KeyStore var3 = KeyStore.getInstance("PKCS12");
            var3.load(var1, var2);
            Enumeration var13 = var3.aliases();

            while (var13.hasMoreElements()) {
               String var14 = (String)var13.nextElement();
               Certificate[] var6 = var3.getCertificateChain(var14);
               Key var7 = var3.getKey(var14, var2);
               this.model.addClientAuthCertChain(this, var6, var7);
            }
         }
      } catch (Throwable var11) {
         String var4 = getMessage("cert.dialog.import.password.text");
         String var5 = getMessage("cert.dialog.import.error.caption");
         DialogFactory.showExceptionDialog(this.getParent(), var11, var4, var5);
      } finally {
         if (var2 != null) {
            Arrays.fill(var2, ' ');
         }
      }
   }

   private boolean compareCharArray(char[] var1, char[] var2) {
      if (var1.length != var2.length) {
         return false;
      } else {
         for (int var3 = 0; var3 < var1.length; var3++) {
            if (var1[var3] != var2[var3]) {
               return false;
            }
         }

         return true;
      }
   }

   boolean importCertificate(InputStream var1) {
      CertificateFactory var2 = null;
      Object var3 = null;

      try {
         String var4 = (String)this.certsComboBox.getSelectedItem();
         var2 = CertificateFactory.getInstance("X.509");
         var3 = (X509Certificate)var2.generateCertificate(var1);
         if (var4.equals(this.strTrustedCerts)) {
            this.model.addTrustedCertificate((Certificate)var3);
         } else if (var4.equals(this.strSecureSite)) {
            this.model.addHttpsCertificate((Certificate)var3);
         } else if (var4.equals(this.strSignerCa)) {
            this.model.addCACertificate((Certificate)var3);
         } else if (var4.equals(this.strSecureSiteCa)) {
            this.model.addHttpsCACertificate((Certificate)var3);
         } else if (var4.equals(this.strClientAuth)) {
            return false;
         }

         this.reset();
      } catch (CertificateParsingException var7) {
         return false;
      } catch (CertificateException var8) {
         String var5 = getMessage("cert.dialog.import.format.text");
         String var6 = getMessage("cert.dialog.import.error.caption");
         DialogFactory.showExceptionDialog(this.getParent(), var8, var5, var6);
      }

      return true;
   }

   private void reset() {
      String var1 = (String)this.certsComboBox.getSelectedItem();
      Collection var2 = null;
      if (this.isUserLevelSelected()) {
         if (var1.equals(this.strTrustedCerts)) {
            var2 = this.model.getTrustedCertificates(this.USER_LEVEL);
         } else if (var1.equals(this.strSecureSite)) {
            var2 = this.model.getHttpsCertificates(this.USER_LEVEL);
         } else if (var1.equals(this.strSignerCa)) {
            var2 = this.model.getRootCACertificates(this.USER_LEVEL);
         } else if (var1.equals(this.strSecureSiteCa)) {
            var2 = this.model.getHttpsRootCACertificates(this.USER_LEVEL);
         } else if (var1.equals(this.strClientAuth)) {
            var2 = this.model.getClientAuthCertificates(this.USER_LEVEL);
         }
      } else if (var1.equals(this.strTrustedCerts)) {
         var2 = this.model.getTrustedCertificates(this.SYSTEM_LEVEL);
      } else if (var1.equals(this.strSecureSite)) {
         var2 = this.model.getHttpsCertificates(this.SYSTEM_LEVEL);
      } else if (var1.equals(this.strSignerCa)) {
         var2 = this.model.getRootCACertificates(this.SYSTEM_LEVEL);
      } else if (var1.equals(this.strSecureSiteCa)) {
         var2 = this.model.getHttpsRootCACertificates(this.SYSTEM_LEVEL);
      } else if (var1.equals(this.strClientAuth)) {
         var2 = this.model.getClientAuthCertificates(this.SYSTEM_LEVEL);
      }

      ReadOnlyTableModel var3;
      if (var2 != null && var2.size() != 0) {
         var3 = new ReadOnlyTableModel(var2.size());
         int var4 = 0;

         for (Iterator var5 = var2.iterator(); var5.hasNext(); var4++) {
            Object var6 = null;
            if (var1.equals(this.strClientAuth)) {
               Certificate[] var7 = (Certificate[])var5.next();
               var6 = (X509Certificate)var7[0];
            } else {
               var6 = (X509Certificate)var5.next();
            }

            var3.setValueAt(CertUtils.extractSubjectAliasName((X509Certificate)var6), var4, 0);
            var3.setValueAt(CertUtils.extractIssuerAliasName((X509Certificate)var6), var4, 1);
         }
      } else {
         var3 = new ReadOnlyTableModel();
      }

      if (this.isUserLevelSelected()) {
         this.userTab.setCertificateTableModel(var3);
      } else {
         this.systemTab.setCertificateTableModel(var3);
      }

      this.updateButtonState();
   }

   boolean isUserLevelSelected() {
      return this.tabbedPane.getSelectedIndex() == 0;
   }

   private void setEnabled(JComponent var1, boolean var2) {
      var1.setEnabled(var2);
      var1.repaint();
   }

   public void stateChanged(ChangeEvent var1) {
      this.reset();
   }

   private void updateButtonState() {
      if (this.isUserLevelSelected()) {
         boolean var1 = this.userTab.isCertificateSelected();
         this.setEnabled(this.removeButton, var1);
         this.setEnabled(this.exportButton, var1);
         this.setEnabled(this.importButton, true);
         this.setEnabled(this.detailsButton, var1);
      } else {
         boolean var2 = this.systemTab.isCertificateSelected();
         this.setEnabled(this.removeButton, false);
         this.setEnabled(this.exportButton, var2);
         this.setEnabled(this.importButton, false);
         this.setEnabled(this.detailsButton, var2);
      }
   }

   private char[] getPasswordDialog(String var1, String var2) {
      try {
         return (char[])DeploySysRun.execute(new CertificatesDialog$8(this, var1, var2));
      } catch (Exception var4) {
         Trace.ignoredException(var4);
         return null;
      }
   }

   private char[] getPasswordDialogImp(String var1, String var2) {
      String var3 = getMessage(var1);
      JPasswordField var4 = new JPasswordField();
      Object[] var5 = new Object[]{var3.toString(), var4};
      JButton var6 = new JButton(getMessage("cert.dialog.password.okButton"));
      JButton var7 = new JButton(getMessage("cert.dialog.password.cancelButton"));
      String var8 = getMessage(var2);
      Object[] var9 = new Object[]{var6, var7};
      int var10 = DialogFactory.showOptionDialog(this, 4, var5, var8, var9, var9[0]);
      char[] var11 = var4.getPassword();
      return var10 == 0 ? var11 : null;
   }

   private static String getMessage(String var0) {
      return ResourceManager.getMessage(var0);
   }
}
