package com.sun.deploy.panel;

import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.security.DeployClientAuthCertStore;
import com.sun.deploy.security.DeploySSLCertStore;
import com.sun.deploy.security.DeploySigningCertStore;
import com.sun.deploy.security.RootCertStore;
import com.sun.deploy.security.SSLRootCertStore;
import com.sun.deploy.util.Trace;
import java.security.Key;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashMap;
import javax.swing.JDialog;

class CertificatesInfo {
   private LinkedHashMap activeTrustedCertsMap = new LinkedHashMap();
   private LinkedHashMap activeHttpsCertsMap = new LinkedHashMap();
   private LinkedHashMap activeRootCACertsMap = new LinkedHashMap();
   private LinkedHashMap activeHttpsRootCACertsMap = new LinkedHashMap();
   private LinkedHashMap activeClientAuthCertsMap = new LinkedHashMap();
   private LinkedHashMap activeSysTrustedCertsMap = new LinkedHashMap();
   private LinkedHashMap activeSysHttpsCertsMap = new LinkedHashMap();
   private LinkedHashMap activeSysRootCACertsMap = new LinkedHashMap();
   private LinkedHashMap activeSysHttpsRootCACertsMap = new LinkedHashMap();
   private LinkedHashMap activeSysClientAuthCertsMap = new LinkedHashMap();

   public CertificatesInfo() {
      this.reset();
   }

   public Collection getTrustedCertificates(int var1) {
      return var1 == 0 ? this.activeTrustedCertsMap.keySet() : this.activeSysTrustedCertsMap.keySet();
   }

   public Collection getHttpsCertificates(int var1) {
      return var1 == 0 ? this.activeHttpsCertsMap.keySet() : this.activeSysHttpsCertsMap.keySet();
   }

   public Collection getRootCACertificates(int var1) {
      return var1 == 0 ? this.activeRootCACertsMap.keySet() : this.activeSysRootCACertsMap.keySet();
   }

   public Collection getHttpsRootCACertificates(int var1) {
      return var1 == 0 ? this.activeHttpsRootCACertsMap.keySet() : this.activeSysHttpsRootCACertsMap.keySet();
   }

   public Collection getClientAuthCertificates(int var1) {
      return var1 == 0 ? this.activeClientAuthCertsMap.keySet() : this.activeSysClientAuthCertsMap.keySet();
   }

   public void removeTrustedCertificate(Certificate var1) {
      DeploySigningCertStore var2 = new DeploySigningCertStore();

      try {
         var2.load();
         var2.remove(var1);
         var2.save();
         Object var3 = this.activeTrustedCertsMap.remove(var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void removeHttpsCertificate(Certificate var1) {
      DeploySSLCertStore var2 = new DeploySSLCertStore();

      try {
         var2.load();
         var2.remove(var1);
         var2.save();
         Object var3 = this.activeHttpsCertsMap.remove(var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void removeRootCACertificate(Certificate var1) {
      RootCertStore var2 = RootCertStore.getInstance();

      try {
         var2.load();
         var2.remove(var1);
         var2.save();
         Object var3 = this.activeRootCACertsMap.remove(var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void removeHttpsRootCACertificate(Certificate var1) {
      SSLRootCertStore var2 = new SSLRootCertStore();

      try {
         var2.load();
         var2.remove(var1);
         var2.save();
         Object var3 = this.activeHttpsRootCACertsMap.remove(var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void removeClientAuthCertificate(JDialog var1, Certificate[] var2) {
      DeployClientAuthCertStore var3 = new DeployClientAuthCertStore(var1);

      try {
         var3.load();
         boolean var4 = var3.remove(var2[0]);
         if (var4) {
            this.activeClientAuthCertsMap.remove(var2);
         }
      } catch (Exception var5) {
         Trace.printException(var5);
      }
   }

   public void addTrustedCertificate(Certificate var1) {
      DeploySigningCertStore var2 = new DeploySigningCertStore();

      try {
         var2.load();
         var2.add(var1);
         var2.save();
         this.activeTrustedCertsMap.put(var1, var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void addHttpsCertificate(Certificate var1) {
      DeploySSLCertStore var2 = new DeploySSLCertStore();

      try {
         var2.load();
         var2.add(var1);
         var2.save();
         this.activeHttpsCertsMap.put(var1, var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void addCACertificate(Certificate var1) {
      RootCertStore var2 = RootCertStore.getInstance();

      try {
         var2.load();
         var2.add(var1);
         var2.save();
         this.activeRootCACertsMap.put(var1, var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void addHttpsCACertificate(Certificate var1) {
      SSLRootCertStore var2 = new SSLRootCertStore();

      try {
         var2.load();
         var2.add(var1);
         var2.save();
         this.activeHttpsRootCACertsMap.put(var1, var1);
      } catch (Exception var4) {
         Trace.printException(var4);
      }
   }

   public void addClientAuthCertChain(JDialog var1, Certificate[] var2, Key var3) {
      DeployClientAuthCertStore var4 = new DeployClientAuthCertStore(var1);

      try {
         var4.load();
         if (!var4.contains(var2[0])) {
            boolean var5 = var4.addCertKey(var2, var3);
            if (var5) {
               var4.save();
               this.activeClientAuthCertsMap.put(var2, var2);
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }
   }

   public void reset() {
      this.activeTrustedCertsMap.clear();
      this.activeHttpsCertsMap.clear();
      this.activeRootCACertsMap.clear();
      this.activeHttpsRootCACertsMap.clear();
      this.activeClientAuthCertsMap.clear();
      this.activeSysTrustedCertsMap.clear();
      this.activeSysHttpsCertsMap.clear();
      this.activeSysRootCACertsMap.clear();
      this.activeSysHttpsRootCACertsMap.clear();
      this.activeSysClientAuthCertsMap.clear();

      try {
         DeploySigningCertStore var1 = new DeploySigningCertStore();
         var1.load();
         Iterator var2 = var1.iterator(0);
         Iterator var3 = var1.iterator(1);

         while (var2.hasNext()) {
            X509Certificate var4 = (X509Certificate)var2.next();
            this.activeTrustedCertsMap.put(var4, var4);
         }

         while (var3.hasNext()) {
            X509Certificate var22 = (X509Certificate)var3.next();
            this.activeSysTrustedCertsMap.put(var22, var22);
         }
      } catch (Exception var9) {
         Trace.printException(var9);
      }

      try {
         DeploySSLCertStore var10 = new DeploySSLCertStore();
         var10.load();
         Iterator var14 = var10.iterator(0);
         Iterator var18 = var10.iterator(1);

         while (var14.hasNext()) {
            X509Certificate var23 = (X509Certificate)var14.next();
            this.activeHttpsCertsMap.put(var23, var23);
         }

         while (var18.hasNext()) {
            X509Certificate var24 = (X509Certificate)var18.next();
            this.activeSysHttpsCertsMap.put(var24, var24);
         }
      } catch (Exception var8) {
         Trace.printException(var8);
      }

      try {
         RootCertStore var11 = RootCertStore.getInstance();
         var11.load();
         Iterator var15 = var11.iterator(0);
         Iterator var19 = var11.iterator(1);

         while (var15.hasNext()) {
            X509Certificate var25 = (X509Certificate)var15.next();
            this.activeRootCACertsMap.put(var25, var25);
         }

         while (var19.hasNext()) {
            X509Certificate var26 = (X509Certificate)var19.next();
            this.activeSysRootCACertsMap.put(var26, var26);
         }
      } catch (Exception var7) {
         Trace.printException(var7);
      }

      try {
         SSLRootCertStore var12 = new SSLRootCertStore();
         var12.load();
         Iterator var16 = var12.iterator(0);
         Iterator var20 = var12.iterator(1);

         while (var16.hasNext()) {
            X509Certificate var27 = (X509Certificate)var16.next();
            this.activeHttpsRootCACertsMap.put(var27, var27);
         }

         while (var20.hasNext()) {
            X509Certificate var28 = (X509Certificate)var20.next();
            this.activeSysHttpsRootCACertsMap.put(var28, var28);
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      try {
         DeployClientAuthCertStore var13 = new DeployClientAuthCertStore();
         var13.load();
         Iterator var17 = var13.iteratorChain(0);
         Iterator var21 = var13.iteratorChain(1);

         while (var17.hasNext()) {
            Certificate[] var29 = (Certificate[])var17.next();
            this.activeClientAuthCertsMap.put(var29, var29);
         }

         while (var21.hasNext()) {
            Certificate[] var30 = (Certificate[])var21.next();
            this.activeSysClientAuthCertsMap.put(var30, var30);
         }
      } catch (Exception var5) {
         Trace.printException(var5);
      }
   }

   private static String getMessage(String var0) {
      return ResourceManager.getMessage(var0);
   }
}
