package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.si.DeploySIListener;
import com.sun.deploy.si.SingleInstanceImpl;
import com.sun.deploy.si.SingleInstanceManager;
import com.sun.deploy.util.DeployUIManager;
import com.sun.deploy.util.FileTraceListener;
import com.sun.deploy.util.Trace;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.File;
import java.io.IOException;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;

public class ControlPanel extends JFrame implements DeploySIListener, PropertyChangeListener {
   private static final String JCP_ID = "JavaControlPanel" + Config.getInstance().getSessionSpecificString();
   private JTabbedPane tabbedPane;
   private GeneralPanel generalPanel;
   private SecurityPanel securityPanel;
   private JavaPanel javaPanel;
   private UpdatePanel updatePanel = null;
   private AdvancedPanel advancedPanel;
   private SingleInstanceImpl _sil = new SingleInstanceImpl();
   private JPanel decisionPanel;
   private JButton okButton;
   private static JButton applyButton;
   private JButton cancelButton;

   public ControlPanel() {
      this._sil.addSingleInstanceListener(this, JCP_ID);
      this.initComponents();
      Config.setControlPanel(this);
   }

   private void initComponents() {
      this.tabbedPane = new JTabbedPane();
      this.securityPanel = new SecurityPanel();
      this.javaPanel = new JavaPanel();
      this.generalPanel = new GeneralPanel();
      if (System.getProperty("os.name").indexOf("Windows") != -1) {
         UpdatePanel var1 = new UpdatePanel();
         if (var1.isJavaUpdateEnabled()) {
            this.updatePanel = var1;
         }
      }

      Config.getBrowserSettings();
      this.advancedPanel = new ControlPanel$1(this);
      this.setTitle(this.getMessage("control.panel.title"));
      this.addWindowListener(new ControlPanel$2(this));
      this.tabbedPane.setName(this.getMessage("control.panel.general"));
      this.tabbedPane.addTab(this.getMessage("control.panel.general"), this.generalPanel);
      if (this.updatePanel != null) {
         this.tabbedPane.addTab(this.getMessage("control.panel.update"), this.updatePanel);
      }

      this.tabbedPane.addTab(this.getMessage("control.panel.java"), this.javaPanel);
      this.tabbedPane.addTab(this.getMessage("control.panel.security"), this.securityPanel);
      this.getContentPane().add(this.tabbedPane, "Center");
      this.decisionPanel = new JPanel();
      this.decisionPanel.setLayout(new FlowLayout(2));
      this.okButton = this.makeButton("common.ok_btn");
      this.okButton.addActionListener(new ControlPanel$3(this));
      this.okButton.setToolTipText(this.getMessage("cpl.ok_btn.tooltip"));
      this.decisionPanel.add(this.okButton);
      this.cancelButton = this.makeButton("common.cancel_btn");
      ControlPanel$4 var2 = new ControlPanel$4(this);
      this.cancelButton.addActionListener(var2);
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke('\u001b'), "cancel");
      this.getRootPane().getActionMap().put("cancel", var2);
      this.cancelButton.setToolTipText(this.getMessage("cpl.cancel_btn.tooltip"));
      this.decisionPanel.add(this.cancelButton);
      applyButton = this.makeButton("common.apply_btn");
      applyButton.addActionListener(new ControlPanel$5(this));
      applyButton.setToolTipText(this.getMessage("cpl.apply_btn.tooltip"));
      this.decisionPanel.add(applyButton);
      this.getContentPane().add(this.decisionPanel, "South");
      this.getContentPane().invalidate();
      this.getRootPane().setDefaultButton(this.okButton);
      this.tabbedPane.addTab(this.getMessage("control.panel.advanced"), this.advancedPanel);
      applyButton.setEnabled(false);
      SwingUtilities.invokeLater(new ControlPanel$6(this));
      this.tabbedPane.addPropertyChangeListener(this);
      checkPreferredSizes(this.tabbedPane);
   }

   public void propertyChange(PropertyChangeEvent var1) {
      if (var1.getPropertyName().equals("font")) {
         SwingUtilities.invokeLater(new ControlPanel$7(this));
      }
   }

   public void resetBounds() {
      this.pack();
      Dimension var1 = this.getPreferredSize();
      Dimension var2 = Toolkit.getDefaultToolkit().getScreenSize();
      var1.width = Math.min(var1.width, var2.width);
      var1.height = Math.min(var1.height, var2.height);
      if (var1.width > 440) {
         int var3 = var1.width * var1.height;
         var1.width = 440;
         var1.height = var3 / 440 + 1;
      }

      this.setBounds((var2.width - var1.width) / 2, (var2.height - var1.height) / 2, var1.width, var1.height);
      this.setResizable(false);
   }

   private void okBtnActionPerformed(ActionEvent var1) {
      if (System.getProperty("os.name").indexOf("Windows") != -1 && this.updatePanel != null) {
         this.updatePanel.saveUpdateSettingsInReg();
      }

      Config.store();
      Config.setBrowserSettings();
      this.exitForm();
   }

   private void applyBtnActionPerformed(ActionEvent var1) {
      if (System.getProperty("os.name").indexOf("Windows") != -1 && this.updatePanel != null) {
         this.updatePanel.saveUpdateSettingsInReg();
      }

      Config.store();
      Config.setBrowserSettings();
      applyButton.setEnabled(false);
   }

   private void cancelBtnActionPerformed(ActionEvent var1) {
      this.exitForm();
   }

   private void exitForm() {
      this._sil.removeSingleInstanceListener(this);
      System.exit(0);
   }

   public static void main(String[] var0) {
      String var1 = "";

      for (int var2 = 0; var2 < var0.length; var2++) {
         var1 = var1 + (var2 > 0 ? " " : "") + var0[var2];
      }

      if (SingleInstanceManager.isServerRunning(JCP_ID) && SingleInstanceManager.connectToServer(var1)) {
         System.exit(0);
      }

      initTrace();
      ControlPanel var4 = new ControlPanel();
      if (var0.length == 2 && var0[0].equals("-tab")) {
         int var3 = getTabIndex(var0[1], var4);
         var4.tabbedPane.setSelectedIndex(var3);
      }

      SwingUtilities.invokeLater(new ControlPanel$8(var4));
   }

   public void newActivation(String[] var1) {
      if (var1.length > 0) {
         String var2 = var1[0];
         if (var2.startsWith("-tab")) {
            int var3 = getTabIndex(var2.substring(4), this);
            this.tabbedPane.setSelectedIndex(var3);
         }
      }

      SwingUtilities.invokeLater(new ControlPanel$9(this));
   }

   public Object getSingleInstanceListener() {
      return this;
   }

   private static int getTabIndex(String var0, ControlPanel var1) {
      int var2 = 0;
      String var3 = var0.trim();
      if (var3.equals("general")) {
         var2 = 0;
      } else if (var3.equals("update")) {
         if (var1.updatePanel != null) {
            var2 = 1;
         }
      } else if (var3.equals("security")) {
         var2 = var1.updatePanel == null ? 1 : 2;
      } else if (var3.equals("java")) {
         var2 = var1.updatePanel == null ? 2 : 3;
      } else if (var3.equals("advanced")) {
         var2 = var1.updatePanel == null ? 3 : 4;
      }

      return var2;
   }

   private static void initTrace() {
      if (Config.getBooleanProperty("deployment.control.panel.log")) {
         try {
            File var0 = new File(Config.getProperty("deployment.user.logdir"));
            if (var0.exists() && var0.isDirectory()) {
               FileTraceListener var1 = new FileTraceListener(File.createTempFile("jcp", ".log", var0), false);
               Trace.addTraceListener(var1);
            }

            Trace.redirectStdioStderr();
            Trace.setBasicTrace(true);
            Trace.setTempTrace(true);
         } catch (IOException var2) {
         }
      }
   }

   private String getMessage(String var1) {
      return ResourceManager.getMessage(var1);
   }

   public JButton makeButton(String var1) {
      JButton var2 = new JButton(this.getMessage(var1));
      var2.setMnemonic(ResourceManager.getVKCode(var1 + ".mnemonic"));
      return var2;
   }

   public static void propertyHasChanged() {
      enableApplyButton();
   }

   private static void enableApplyButton() {
      if (applyButton != null) {
         applyButton.setEnabled(true);
      }
   }

   private static void checkPreferredSizes(Component var0) {
      Dimension var1 = var0.getPreferredSize();
      if (var0 instanceof Container) {
         Component[] var2 = ((Container)var0).getComponents();
         int var3 = 0;

         while (var3 < var2.length) {
            checkPreferredSizes(var2[var3++]);
         }
      }
   }

   static {
      DeployUIManager.setLookAndFeel();
   }
}
