package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.config.JREInfo;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.Trace;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.Iterator;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTable;
import javax.swing.KeyStroke;
import javax.swing.border.LineBorder;
import javax.swing.border.TitledBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

public class JavawsJreDialog extends JDialog implements ActionListener, ChangeListener, ListSelectionListener {
   private final JButton _chooseBtn = this.makeButton("jnlp.jre.choose.button");
   private final JButton _findBtn = this.makeButton("jnlp.jre.find.button");
   private final JButton _addBtn = this.makeButton("jnlp.jre.add.button");
   private final JButton _removeBtn = this.makeButton("jnlp.jre.remove.button");
   private final JButton _okBtn = this.makeButton("jnlp.jre.ok.button");
   private final JButton _cancelBtn = this.makeButton("jnlp.jre.cancel.button");
   private final JavawsTableModel _sysTableModel;
   private final JavawsTableModel _userTableModel;
   private final JTabbedPane _tabbedPane = new JTabbedPane();
   private final JTable _userTable;
   private final JTable _sysTable;
   private final JScrollPane _userTab;
   private final JScrollPane _systemTab;

   public JavawsJreDialog(Frame var1, boolean var2) {
      super(var1, var2);
      this._userTableModel = new JavawsTableModel(false);
      this._userTable = new JTable(this._userTableModel);
      this._sysTableModel = new JavawsTableModel(true);
      this._sysTable = new JTable(this._sysTableModel);
      this._userTab = new JScrollPane(this._userTable);
      this._systemTab = new JScrollPane(this._sysTable);
      this.initComponents();
   }

   private void initComponents() {
      this.setTitle(ResourceManager.getMessage("jnlp.jre.title"));
      this.addWindowListener(new JavawsJreDialog$1(this));
      this._findBtn.setToolTipText(ResourceManager.getMessage("jnlp.jre.find_btn.tooltip"));
      this._addBtn.setToolTipText(ResourceManager.getMessage("jnlp.jre.add_btn.tooltip"));
      this._removeBtn.setToolTipText(ResourceManager.getMessage("jnlp.jre.remove_btn.tooltip"));
      JPanel var1 = new JPanel();
      var1.setLayout(new BorderLayout());
      var1.setBorder(new TitledBorder(ResourceManager.getMessage("jnlp.jre.versions")));
      Dimension var2 = new Dimension(500, 150);
      LineBorder var3 = new LineBorder(this._userTable.getForeground());
      this._userTable.setBorder(var3);
      this._userTable.setPreferredScrollableViewportSize(var2);
      this._sysTable.setBorder(var3);
      this._sysTable.setPreferredScrollableViewportSize(var2);
      this._tabbedPane.addTab(ResourceManager.getMessage("cert.dialog.user.level"), this._userTab);
      this._tabbedPane.addTab(ResourceManager.getMessage("cert.dialog.system.level"), this._systemTab);
      this._tabbedPane.setSelectedIndex(0);
      this._tabbedPane.addChangeListener(this);
      var1.add(this._tabbedPane, "North");
      Box var4 = Box.createHorizontalBox();
      var4.add(this._chooseBtn);
      var4.add(Box.createHorizontalGlue());
      var4.add(this._findBtn);
      var4.add(Box.createHorizontalStrut(5));
      var4.add(this._addBtn);
      var4.add(Box.createHorizontalStrut(5));
      var4.add(this._removeBtn);
      var1.add(var4, "South");
      this.getContentPane().add(var1, "North");
      JPanel var5 = new JPanel();
      var5.setLayout(new FlowLayout(2, 10, 5));
      var5.add(this._okBtn);
      var5.add(this._cancelBtn);
      this.getContentPane().add(var5, "South");
      this.getRootPane().setDefaultButton(this._okBtn);
      this.enableButtons();
      this.pack();
      this._userTable.getSelectionModel().addListSelectionListener(this);
      this._userTable.getColumnModel().getColumn(3).setCellRenderer(new PathRenderer());
      this._userTable.getColumnModel().getColumn(3).setCellEditor(new PathEditor());
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke('\u001b'), "cancel");
      this.getRootPane().getActionMap().put("cancel", new JavawsJreDialog$2(this));
   }

   public JButton makeButton(String var1) {
      JButton var2 = new JButton(ResourceManager.getMessage(var1));
      var2.setMnemonic(ResourceManager.getVKCode(var1 + ".mnemonic"));
      var2.addActionListener(this);
      return var2;
   }

   public void valueChanged(ListSelectionEvent var1) {
      this.enableButtons();
   }

   public void stateChanged(ChangeEvent var1) {
      this.enableButtons();
   }

   public void enableButtons() {
      Component var1 = this._tabbedPane.getSelectedComponent();
      if (var1 != null) {
         if (var1.equals(this._userTab)) {
            boolean var2 = false;
            boolean var3 = false;
            boolean var4 = false;

            for (int var5 = 0; var5 < this._userTableModel.getRowCount(); var5++) {
               if (this._userTable.isRowSelected(var5)) {
                  var3 = true;
                  if (this._userTableModel.getJRE(var5).isRegistered()) {
                     var4 = true;
                  }
               } else if (this._userTableModel.isPathValid(var5)) {
                  var2 = true;
               }
            }

            this._removeBtn.setEnabled(var3 && !var4 && var2);
            this._chooseBtn.setEnabled(var3);
            this._findBtn.setEnabled(true);
            this._addBtn.setEnabled(true);
         } else {
            this._removeBtn.setEnabled(false);
            this._chooseBtn.setEnabled(false);
            this._findBtn.setEnabled(false);
            this._addBtn.setEnabled(false);
         }
      }
   }

   private void closeDialog() {
      this.setVisible(false);
      this.dispose();
   }

   public void actionPerformed(ActionEvent var1) {
      JButton var2 = (JButton)var1.getSource();
      JTable var3 = this.getSelectedTable();
      JavawsTableModel var4 = (JavawsTableModel)var3.getModel();
      if (var2 == this._chooseBtn) {
         int var5 = var3.getSelectedRow();
         if (var5 != -1) {
            this.changePath(var5);
         }
      } else if (var2 == this._findBtn) {
         this.findJREs();
      } else if (var2 == this._addBtn) {
         var4.add(new JREInfo(null, null, null, null, Config.getOSName(), Config.getOSArch(), true, false), false, true);
         int var6 = var4.getRowCount() - 1;
         var3.requestFocus();
         var3.setRowSelectionInterval(var6, var6);
      } else if (var2 == this._removeBtn) {
         var4.remove(this._userTable.getSelectedRows());
      } else if (var2 == this._okBtn) {
         this.apply();
         ControlPanel.propertyHasChanged();
         this.closeDialog();
      } else if (var2 == this._cancelBtn) {
         this.closeDialog();
      }
   }

   private JTable getSelectedTable() {
      return this._tabbedPane.getSelectedComponent() == this._userTab ? this._userTable : this._sysTable;
   }

   public void apply() {
      JTable var1 = this._userTable;
      if (var1.isEditing()) {
         var1.getCellEditor().stopCellEditing();
      }

      JavawsTableModel var2 = (JavawsTableModel)var1.getModel();
      if (var2.getRowCount() > 0) {
         JREInfo.clear();

         for (int var3 = 0; var3 < var2.getRowCount(); var3++) {
            JREInfo.addJRE(var2.getJRE(var3));
         }
      }

      var1 = this._sysTable;
      if (var1.isEditing()) {
         var1.getCellEditor().stopCellEditing();
      }

      var2 = (JavawsTableModel)var1.getModel();
      if (var2.getRowCount() > 0) {
         for (int var6 = 0; var6 < var2.getRowCount(); var6++) {
            JREInfo.addJRE(var2.getJRE(var6));
         }
      }

      Iterator var7 = var2.getHiddenJREs().iterator();

      while (var7.hasNext()) {
         JREInfo.addJRE((JREInfo)var7.next());
      }
   }

   private void changePath(int var1) {
      JTable var2 = this.getSelectedTable();
      JavawsTableModel var3 = (JavawsTableModel)var2.getModel();
      JFileChooser var4 = new JFileChooser();
      String var5 = null;
      if (var1 >= 0) {
         var5 = var3.getJRE(var1).getPath();
      }

      File var6 = this.getFirstValidParent(var5);
      if (var6 != null && var6.exists()) {
         var4.setSelectedFile(var6);
      }

      if (var4.showOpenDialog(this) == 0) {
         var3.setValueAt(var4.getSelectedFile().getPath(), var1, 3);
      }
   }

   private void findJREs() {
      JTable var1 = this.getSelectedTable();
      JavawsTableModel var2 = (JavawsTableModel)var1.getModel();

      try {
         JREInfo[] var3 = JreFindDialog.search(this);
         if (var3 != null) {
            for (int var4 = 0; var4 < var3.length; var4++) {
               var2.add(var3[var4], false, true);
            }
         }
      } catch (Exception var5) {
         Trace.ignoredException(var5);
      }
   }

   private File getFirstValidParent(String var1) {
      if (var1 == null) {
         return null;
      } else {
         File var2 = new File(var1);

         while (var2 != null && !var2.exists()) {
            var1 = var2.getParent();
            if (var1 != null) {
               var2 = new File(var1);
            } else {
               var2 = null;
            }
         }

         return var2;
      }
   }
}
