package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.config.JREInfo;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.Trace;
import java.io.File;
import java.util.HashSet;

public class JavawsTableModel extends JreTableModel {
   private boolean _system;
   private HashSet _hidden;

   public JavawsTableModel(boolean var1) {
      super(
         new String[]{
            ResourceManager.getMessage("controlpanel.jre.platformTableColumnTitle"),
            ResourceManager.getMessage("controlpanel.jre.productTableColumnTitle"),
            ResourceManager.getMessage("controlpanel.jre.locationTableColumnTitle"),
            ResourceManager.getMessage("controlpanel.jre.pathTableColumnTitle"),
            ResourceManager.getMessage("controlpanel.jre.enabledTableColumnTitle")
         }
      );
      this._system = var1;
      this._hidden = new HashSet();
      this.refresh();
   }

   public void refresh() {
      String[] var1 = new String[]{Config.getJavawsCommand(), "-quick"};

      try {
         Runtime.getRuntime().exec(var1).waitFor();
      } catch (Exception var5) {
         Trace.ignoredException(var5);
      }

      if (Config.isDiskNewer()) {
         Config.refreshUnchangedProps();
      }

      JREInfo[] var2 = JREInfo.get();
      this._jres.clear();
      this._validPaths.clear();
      this._hidden.clear();
      Trace.println("refresh for system = " + this._system);

      for (int var3 = 0; var3 < var2.length; var3++) {
         JREInfo var4 = var2[var3];
         if (var4.getOSName() == null || var4.getOSArch() == null || var4.getOSName().equals(Config.getOSName()) && var4.getOSArch().equals(Config.getOSArch())
            )
          {
            if (var4.getPath() != null && this.isValidJREPath(var4.getPath())) {
               this.add(new JREInfo(var4), false, false);
            } else {
               this._hidden.add(new JREInfo(var4));
            }
         } else {
            this._hidden.add(new JREInfo(var4));
         }
      }

      this.fireTableDataChanged();
   }

   public HashSet getHiddenJREs() {
      return this._hidden;
   }

   public Object getValueAt(int var1, int var2) {
      switch (var2) {
         case 0:
            return this.getJRE(var1).getPlatform();
         case 1:
            return this.getJRE(var1).getProduct();
         case 2:
            return this.getJRE(var1).getLocation();
         case 3:
            return this.getJRE(var1).getPath();
         default:
            return new Boolean(this.getJRE(var1).isEnabled());
      }
   }

   public boolean isCellEditable(int var1, int var2) {
      return !this.getJRE(var1).isSystemJRE();
   }

   public Class getColumnClass(int var1) {
      if (var1 < 4) {
         return class$java$lang$String == null ? (class$java$lang$String = class$("java.lang.String")) : class$java$lang$String;
      } else {
         return class$java$lang$Boolean == null ? (class$java$lang$Boolean = class$("java.lang.Boolean")) : class$java$lang$Boolean;
      }
   }

   public void add(JREInfo var1, boolean var2, boolean var3) {
      if (var1.isSystemJRE() == this._system) {
         super.add(var1, var2, var3);
      }
   }

   public boolean isValidJREPath(String var1) {
      if (var1 == null) {
         return false;
      } else {
         File var2 = new File(var1);
         return var2.exists() && !var2.isDirectory();
      }
   }

   public void setValueAt(Object var1, int var2, int var3) {
      if (var2 < this._jres.size()) {
         JREInfo var4 = this.getJRE(var2);
         switch (var3) {
            case 0:
               this._jres
                  .set(
                     var2,
                     new JREInfo(
                        (String)var1,
                        var4.getProduct(),
                        var4.getLocation(),
                        var4.getPath(),
                        var4.getOSName(),
                        var4.getOSArch(),
                        var4.isEnabled(),
                        var4.isRegistered()
                     )
                  );
               break;
            case 1:
               this._jres
                  .set(
                     var2,
                     new JREInfo(
                        var4.getPlatform(),
                        (String)var1,
                        var4.getLocation(),
                        var4.getPath(),
                        var4.getOSName(),
                        var4.getOSArch(),
                        var4.isEnabled(),
                        var4.isRegistered()
                     )
                  );
               break;
            case 2:
               this._jres
                  .set(
                     var2,
                     new JREInfo(
                        var4.getPlatform(),
                        var4.getProduct(),
                        (String)var1,
                        var4.getPath(),
                        var4.getOSName(),
                        var4.getOSArch(),
                        var4.isEnabled(),
                        var4.isRegistered()
                     )
                  );
               break;
            case 3:
               this._jres
                  .set(
                     var2,
                     new JREInfo(
                        var4.getPlatform(),
                        var4.getProduct(),
                        var4.getLocation(),
                        (String)var1,
                        var4.getOSName(),
                        var4.getOSArch(),
                        var4.isEnabled(),
                        var4.isRegistered()
                     )
                  );
               this._validPaths.set(var2, null);
               break;
            default:
               this._jres
                  .set(
                     var2,
                     new JREInfo(
                        var4.getPlatform(),
                        var4.getProduct(),
                        var4.getLocation(),
                        var4.getPath(),
                        var4.getOSName(),
                        var4.getOSArch(),
                        (Boolean)var1,
                        var4.isRegistered()
                     )
                  );
         }

         this.fireTableRowsUpdated(var2, var2);
      }
   }
}
