package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.config.JREInfo;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.DialogFactory;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;
import javax.swing.Timer;

public class JreFindDialog extends JDialog implements ActionListener {
   private final JButton _cancelButton = new JButton(ResourceManager.getMessage("find.cancelButton"));
   private final JButton _prevButton = new JButton(ResourceManager.getMessage("find.prevButton"));
   private final JButton _nextButton = new JButton(ResourceManager.getMessage("find.nextButton"));
   private JLabel _titleLabel;
   private JComponent _mainComponent = null;
   private JPanel _buttonPanel;
   private File _directory;
   private int _state;
   private GridBagConstraints _constraints;
   private JTextArea _ta;
   private JREInfo[] _jres;

   public JreFindDialog(Frame var1) {
      super(var1, ResourceManager.getMessage("find.dialog.title"), true);
      this.setJREs(null);
      this._titleLabel = new JLabel(ResourceManager.getMessage("find.title"));
      setFont(this._titleLabel, 2, 18);
      this._cancelButton.addActionListener(this);
      this._nextButton.addActionListener(this);
      this._prevButton.addActionListener(this);
      this._cancelButton.setMnemonic(ResourceManager.getVKCode("find.cancelButtonMnemonic"));
      this._prevButton.setMnemonic(ResourceManager.getVKCode("find.prevButtonMnemonic"));
      this._nextButton.setMnemonic(ResourceManager.getVKCode("find.nextButtonMnemonic"));
      this._buttonPanel = new JPanel(new BorderLayout());
      JPanel var2 = new JPanel();
      var2.add(this._cancelButton);
      var2.add(this._prevButton);
      var2.add(this._nextButton);
      this._buttonPanel.add(var2, "East");
      String var3 = ResourceManager.getMessage("find.intro");
      this._ta = new JSmartTextArea(var3);
      this._directory = null;
      JreFindDialog$1 var4 = new JreFindDialog$1(this);
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke('\u001b'), "cancel");
      this.getRootPane().getActionMap().put("cancel", var4);
      this.setState(0);
   }

   public static JREInfo[] search(Component var0) {
      Frame var1 = var0 instanceof Frame
         ? (Frame)var0
         : (Frame)SwingUtilities.getAncestorOfClass(
            class$java$awt$Frame == null ? (class$java$awt$Frame = class$("java.awt.Frame")) : class$java$awt$Frame, var0
         );
      JreFindDialog var2 = new JreFindDialog(var1);
      var2.show();
      return var2._jres;
   }

   private static void setFont(JComponent var0, int var1, int var2) {
      int var3 = var0.getFont().getSize();
      var2 = Math.max(var3, var2);
      var0.setFont(var0.getFont().deriveFont(var1, var2));
   }

   public void show() {
      this.getContentPane().setLayout(new GridBagLayout());
      GridBagConstraints var1 = new GridBagConstraints();
      var1.gridx = var1.gridy = 0;
      var1.weightx = var1.weighty = 0.0;
      var1.fill = 0;
      var1.anchor = 10;
      var1.insets = new Insets(5, 5, 5, 5);
      this.getContentPane().add(this._titleLabel, var1);
      var1.gridy = 2;
      var1.weightx = var1.weighty = 0.0;
      var1.fill = 0;
      var1.anchor = 13;
      this.getContentPane().add(this._buttonPanel, var1);
      var1.gridy = 1;
      var1.weightx = var1.weighty = 1.0;
      var1.fill = 1;
      var1.anchor = 17;
      if (this._mainComponent != null) {
         this.getContentPane().add(this._mainComponent, var1);
      }

      this._constraints = var1;
      this.pack();
      Dimension var2 = this.getSize();
      var2.width = Math.max(var2.width, 500);
      var2.height = Math.max(var2.height, 420);
      Dimension var3 = Toolkit.getDefaultToolkit().getScreenSize();
      this.setBounds((var3.width - var2.width) / 2, (var3.height - var2.height) / 2, var2.width, var2.height);
      DialogFactory.positionDialog(this);
      this.addKeyListener(new JreFindDialog$2(this));
      super.show();
      this.dispose();
      this.setState(-1);
   }

   protected void cancel() {
      this.setJREs(null);
      this.setVisible(false);
   }

   protected void next() {
      int var1 = this.getState();
      if (++var1 == 3) {
         this.setVisible(false);
      } else {
         this.setState(var1);
      }
   }

   protected void previous() {
      int var1 = this.getState();
      this.setState(--var1);
   }

   public void actionPerformed(ActionEvent var1) {
      Object var2 = var1.getSource();
      if (var2.equals(this._cancelButton)) {
         this.cancel();
      } else if (var2.equals(this._prevButton)) {
         this.previous();
      } else if (var2.equals(this._nextButton)) {
         this.next();
      }
   }

   private void setDirectory(File var1) {
      this._directory = var1;
      this._nextButton.setEnabled(var1 != null);
   }

   private File getDirectory() {
      return this._directory;
   }

   private void setJREs(JREInfo[] var1) {
      this._jres = var1;
   }

   private void setState(int var1) {
      this._cancelButton.setEnabled(true);
      this._prevButton.setEnabled(false);
      this._nextButton.setEnabled(true);
      this._state = var1;
      if (this._mainComponent != null) {
         this.getContentPane().remove(this._mainComponent);
         this._mainComponent = null;
      }

      switch (this._state) {
         case 0:
            this._mainComponent = this._ta;
            break;
         case 1:
            this._mainComponent = new JreFindDialog.PathChooser(this._directory);
            break;
         case 2:
            JreFindDialog.SearchPanel var2 = new JreFindDialog.SearchPanel();
            this._mainComponent = var2;
            var2.start();
      }

      if (this._mainComponent != null) {
         this.getContentPane().add(this._mainComponent, this._constraints);
         this._mainComponent.revalidate();
         Dimension var4 = this.getSize();
         Dimension var3 = this.getPreferredSize();
         var4.width = Math.max(var4.width, var3.width);
         var4.height = Math.max(var4.height, var3.height);
         this.setSize(var4.width, var4.height);
      }

      this.repaint();
   }

   private int getState() {
      return this._state;
   }

   private class PathChooser extends JFileChooser {
      public PathChooser(File var2) {
         JreFindDialog.this._nextButton.setEnabled(JreFindDialog.this.getDirectory() != null);
         JreFindDialog.this._prevButton.setEnabled(true);
         this.setFileSelectionMode(2);
         this.addActionListener(new JreFindDialog$PathChooser$1(this, JreFindDialog.this));
         this.addPropertyChangeListener(new JreFindDialog$PathChooser$2(this, JreFindDialog.this));

         try {
            Class[] var3 = new Class[]{boolean.class};
            Method var4 = (JreFindDialog.class$javax$swing$JFileChooser == null
                  ? (JreFindDialog.class$javax$swing$JFileChooser = JreFindDialog.class$("javax.swing.JFileChooser"))
                  : JreFindDialog.class$javax$swing$JFileChooser)
               .getMethod("setControlButtonsAreShown", var3);
            if (var4 != null) {
               Object[] var5 = new Object[]{Boolean.FALSE};
               var4.invoke(this, var5);
            }
         } catch (NoSuchMethodException var6) {
         } catch (InvocationTargetException var7) {
         } catch (IllegalAccessException var8) {
         }

         this.setDialogType(0);
         if (var2 != null) {
            this.setCurrentDirectory(var2);
         } else {
            this.updateDirectory();
         }
      }

      private void updateDirectory() {
         File var1 = this.getSelectedFile();
         if (var1 == null) {
            var1 = this.getCurrentDirectory();
         }

         JreFindDialog.this.setDirectory(var1);
      }
   }

   private class SearchPanel extends JPanel implements ActionListener {
      private DefaultListModel model;
      private JList list;
      private JLabel searchLabel;
      private String searchPrefix = ResourceManager.getMessage("find.searching.prefix");
      private JLabel titleLabel;
      private JreFindDialog.SearchPanel.Searcher searcher;
      private Timer timer;
      private boolean active;

      public SearchPanel() {
         this.model = new DefaultListModel();
         this.list = new JList(this.model);
         this.list.setCellRenderer(new JreFindDialog$SearchPanel$1(this, JreFindDialog.this));
         this.list.addListSelectionListener(new JreFindDialog$SearchPanel$2(this));
         this.searchLabel = new JLabel(" ");
         JreFindDialog.setFont(this.searchLabel, 0, 12);
         this.titleLabel = new JLabel(ResourceManager.getMessage("find.searching.title"));
         JreFindDialog.setFont(this.titleLabel, 0, 12);
         this.setLayout(new GridBagLayout());
         GridBagConstraints var2 = new GridBagConstraints();
         var2.gridx = var2.gridy = 0;
         var2.weightx = 1.0;
         var2.weighty = 0.0;
         var2.fill = 2;
         var2.insets = new Insets(5, 2, 0, 2);
         var2.gridy = 0;
         this.add(this.titleLabel, var2);
         var2.gridy = 2;
         this.add(this.searchLabel, var2);
         var2.gridy = 1;
         var2.weighty = 1.0;
         var2.fill = 1;
         var2.insets.bottom = 0;
         this.add(new JScrollPane(this.list), var2);
      }

      public void start() {
         this.active = true;
         JreFindDialog.this._nextButton.setEnabled(false);
         JreFindDialog.this._prevButton.setEnabled(true);
         if (this.model != null) {
            this.model.removeAllElements();
         }

         this.timer = new Timer(100, this);
         this.timer.setRepeats(true);
         this.timer.start();
         this.searcher = new JreFindDialog.SearchPanel.Searcher(null);
         this.searcher.start(JreFindDialog.this.getDirectory());
      }

      public void stop() {
         this.active = false;
         this.stopSearching();
      }

      private void stopSearching() {
         if (this.searcher != null) {
            this.searcher.stop();
            this.searcher = null;
            this.timer.stop();
            this.timer = null;
         }
      }

      public void actionPerformed(ActionEvent var1) {
         if (!this.searcher.isFinished()) {
            File var2 = this.searcher.getCurrentFile();
            if (var2 != null) {
               this.searchLabel.setText(this.searchPrefix + var2.getPath());
            } else {
               this.searchLabel.setText(this.searchPrefix);
            }
         } else {
            if (this.model.getSize() > 0) {
               this.titleLabel.setText(ResourceManager.getMessage("find.foundJREs.title"));
            } else {
               this.titleLabel.setText(ResourceManager.getMessage("find.noJREs.title"));
            }

            JreFindDialog.this._nextButton.setEnabled(true);
            this.searchLabel.setText(" ");
            this.stopSearching();
         }
      }

      private void updateJREs() {
         if (this.active) {
            if (this.model != null) {
               int var1 = this.model.getSize();
               if (var1 > 0) {
                  JreFindDialog.this._nextButton.setEnabled(true);
                  int[] var2 = this.list.getSelectedIndices();
                  if (var2 != null && var2.length > 0) {
                     JREInfo[] var5 = new JREInfo[var2.length];

                     for (int var4 = 0; var4 < var2.length; var4++) {
                        var5[var4] = (JREInfo)this.model.getElementAt(var2[var4]);
                     }

                     JreFindDialog.this.setJREs(var5);
                  } else {
                     JREInfo[] var3 = new JREInfo[var1];
                     this.model.copyInto(var3);
                     JreFindDialog.this.setJREs(var3);
                  }
               } else {
                  JreFindDialog.this.setJREs(null);
                  JreFindDialog.this._nextButton.setEnabled(false);
               }
            } else {
               JreFindDialog.this.setJREs(null);
            }
         }
      }

      private void add(JreFindDialog.SearchPanel.Searcher var1, JREInfo var2) {
         SwingUtilities.invokeLater(new JreFindDialog$SearchPanel$3(this, var1, var2));
      }

      private class Searcher implements Runnable {
         private File file;
         private boolean stop;
         private File currentFile;
         private boolean finished;

         private Searcher() {
         }

         void start(File var1) {
            this.file = var1;
            new Thread(this).start();
            SearchPanel.this.updateJREs();
         }

         public File getCurrentFile() {
            return this.currentFile;
         }

         public void stop() {
            this.stop = true;
         }

         public void run() {
            this.check(this.file);
            this.finished = true;
         }

         public boolean isFinished() {
            return this.finished;
         }

         private void check(File var1) {
            this.currentFile = var1;
            String var2 = var1.getName();
            if (!var1.isFile() || !var2.equals("java") && !var2.equals("javaw.exe")) {
               if (!var1.isFile()) {
                  String[] var6 = var1.list();
                  if (var6 != null) {
                     int var4 = 0;

                     for (int var5 = var6.length; var4 < var5 && !this.stop; var4++) {
                        this.check(new File(var1, var6[var4]));
                     }
                  }
               }
            } else {
               JREInfo var3 = this.getVersion(var1);
               if (var3 != null) {
                  SearchPanel.this.add(this, var3);
               }
            }
         }

         private JREInfo getVersion(File var1) {
            if (!this.isValidJavaPath(var1)) {
               return null;
            } else {
               JREInfo var2 = JreLocator.getVersion(var1);
               if (var2 != null) {
                  var2.setOSName(Config.getOSName());
                  var2.setOSArch(Config.getOSArch());
               }

               return var2;
            }
         }

         private boolean isValidJavaPath(File var1) {
            String var2 = var1.getParent();
            if (!var2.endsWith(File.separator + "native_threads") && !var2.endsWith(File.separator + "green_threads")) {
               String var3 = File.separator + "jre" + File.separator + "bin";
               if (var2.endsWith(var3) && var2.length() > var3.length()) {
                  String var4 = var2.substring(0, var2.length() - var3.length() + 1) + "bin" + File.separator;
                  File var5 = new File(var4 + "java");
                  if (var5.exists() && var5.isFile()) {
                     return false;
                  }

                  var5 = new File(var4 + "javaw.exe");
                  if (var5.exists() && var5.isFile()) {
                     return false;
                  }
               }

               return true;
            } else {
               return false;
            }
         }
      }
   }
}
