package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.config.JREInfo;
import com.sun.deploy.util.Trace;
import com.sun.deploy.util.TraceLevel;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;

public class JreLocator {
   public static final int DEFAULT_TIMEOUT = 15000;
   private static final String PRODUCT_ID = "productVersion=";
   private static final String PLATFORM_ID = "platformVersion=";

   public static JREInfo getVersion(File var0) {
      return getVersion(var0, 15000);
   }

   public static JREInfo getVersion(File var0, int var1) {
      String var2 = Config.getJavaHome() + File.separator + "lib" + File.separator + "deploy.jar";
      String[] var3 = execute(
         new String[]{
            var0.getPath(),
            "-classpath",
            var2,
            (class$com$sun$deploy$panel$JreLocator == null
                  ? (class$com$sun$deploy$panel$JreLocator = class$("com.sun.deploy.panel.JreLocator"))
                  : class$com$sun$deploy$panel$JreLocator)
               .getName()
         },
         var1
      );
      JREInfo var4 = null;
      if (var3 != null) {
         var4 = extractVersion(var0.getPath(), var3[0]);
         if (var4 == null) {
            var4 = extractVersion(var0.getPath(), var3[1]);
         }

         if (var4 != null && var4.getPlatform().equals("1.2")) {
            var3 = execute(new String[]{var0.getPath(), "-fullversion"}, var1);
            if (var3 != null) {
               var4 = extractVersionFor12(var0.getPath(), var3[0]);
               if (var4 == null) {
                  var4 = extractVersionFor12(var0.getPath(), var3[1]);
               }
            }
         }
      }

      Trace.println("\tjre search returning: " + var4, TraceLevel.BASIC);
      return var4;
   }

   private static String[] execute(String[] var0, int var1) {
      Process var2 = null;
      boolean var3 = false;
      Trace.println("jre search executing", TraceLevel.BASIC);

      for (int var4 = 0; var4 < var0.length; var4++) {
         Trace.println(var4 + ": " + var0[var4], TraceLevel.BASIC);
      }

      try {
         var2 = Runtime.getRuntime().exec(var0);
      } catch (IOException var8) {
         var3 = true;
      }

      int var10 = -1;
      int var5 = var1 / 100;

      while (!var3) {
         try {
            Thread.sleep(100L);
         } catch (InterruptedException var7) {
         }

         try {
            var10 = var2.exitValue();
            var3 = true;
            Trace.println("\tfinished executing " + var10, TraceLevel.BASIC);
         } catch (IllegalThreadStateException var9) {
            if (--var5 == 0) {
               var3 = true;
               Trace.println("\tfailed " + var10, TraceLevel.BASIC);
               var2.destroy();
            }
         }
      }

      if (var3 && var10 == 0) {
         String[] var6 = new String[]{readFromStream(var2.getErrorStream()), readFromStream(var2.getInputStream())};
         Trace.println("result: " + var6[0], TraceLevel.BASIC);
         Trace.println("result: " + var6[1], TraceLevel.BASIC);
         return var6;
      } else {
         return null;
      }
   }

   private static String readFromStream(InputStream var0) {
      StringBuffer var1 = new StringBuffer();

      try {
         byte[] var2 = new byte[80];
         boolean var3 = false;

         while (!var3) {
            int var4 = var0.read(var2, 0, 80);
            if (var4 == -1) {
               var3 = true;
            } else if (var4 > 0) {
               var1.append(new String(var2, 0, var4));
            }
         }
      } catch (IOException var6) {
      }

      try {
         var0.close();
      } catch (IOException var5) {
      }

      return var1.toString();
   }

   private static JREInfo extractVersion(String var0, String var1) {
      String var2 = extractString("platformVersion=", var1);
      String var3 = extractString("productVersion=", var1);
      return var2 != null && var3 != null ? new JREInfo(var2, var3, null, var0, Config.getOSName(), Config.getOSArch(), true, false) : null;
   }

   private static String extractString(String var0, String var1) {
      int var2 = var1.indexOf(var0);
      if (var2 != -1) {
         int var3 = var1.indexOf(10, var2);
         String var4;
         if (var3 != -1) {
            var4 = var1.substring(var2 + var0.length(), var3);
         } else {
            var4 = var1.substring(var2 + var0.length());
         }

         if (var4.length() > 0 && var4.charAt(var4.length() - 1) == '\r') {
            var4 = var4.substring(0, var4.length() - 1);
         }

         return var4;
      } else {
         return null;
      }
   }

   private static JREInfo extractVersionFor12(String var0, String var1) {
      int var2 = var1.indexOf("1.2");
      int var3 = var1.length();
      if (var2 != -1 && var2 < var3 - 1) {
         int var4 = var1.indexOf(34, var2);
         if (var4 != -1) {
            String var5 = var1.substring(var2, var4);
            return new JREInfo("1.2", var5, null, var0, Config.getOSName(), Config.getOSArch(), true, false);
         }
      }

      return null;
   }

   private static String getClassPath(File var0) {
      File var1 = var0.getParentFile();
      if (var1 != null) {
         var1 = var1.getParentFile();
         if (var1 != null) {
            var1 = new File(var1, "lib");
            if (var1 != null && var1.exists()) {
               var1 = new File(var1, "classes.zip");
               if (var1 != null && var1.exists()) {
                  return getThisPath() + File.pathSeparator + var1.getPath();
               }
            }
         }
      }

      return getThisPath();
   }

   public static void main(String[] var0) {
      write("platformVersion=", System.getProperty("java.specification.version"));
      write("productVersion=", System.getProperty("java.version"));
   }

   private static void write(String var0, String var1) {
      if (var1 != null) {
         System.out.println(var0 + var1);
      }
   }

   private static String getThisPath() {
      return Config.getJavaHome() + File.separator + "lib" + File.separator + "javaws.jar";
   }
}
