package com.sun.deploy.panel;

import com.sun.deploy.config.PluginJavaInfo;
import com.sun.deploy.resources.ResourceManager;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.util.Enumeration;
import javax.swing.Box;
import javax.swing.DefaultCellEditor;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.KeyStroke;
import javax.swing.border.LineBorder;
import javax.swing.border.TitledBorder;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableColumn;

public class PluginJreDialog extends JDialog implements ListSelectionListener {
   private JTable jresTable;
   private JButton okBtn;
   private JButton cancelBtn;
   private JButton addBtn;
   private JButton removeBtn;

   public PluginJreDialog(Frame var1, boolean var2) {
      super(var1, var2);
      this.initComponents();
   }

   private void initComponents() {
      this.setTitle(this.getMessage("jpi.jres.dialog.title"));
      this.addWindowListener(new PluginJreDialog$1(this));
      JPanel var1 = new JPanel();
      var1.setLayout(new BorderLayout());
      var1.setBorder(new TitledBorder(this.getMessage("jpi.jres.dialog.border")));
      this.jresTable = new JTable(new PluginTableModel());
      this.jresTable.setBorder(new LineBorder(Color.black));
      this.jresTable.setPreferredScrollableViewportSize(new Dimension(500, 70));
      this.jresTable.getSelectionModel().addListSelectionListener(this);
      Enumeration var2 = this.jresTable.getColumnModel().getColumns();

      while (var2.hasMoreElements()) {
         TableColumn var3 = (TableColumn)var2.nextElement();
         var3.setCellEditor(new SpecialTableEditor());
         var3.setCellRenderer(new SpecialTableRenderer());
      }

      this.jresTable.getColumnModel().getColumn(2).setCellRenderer(new PathRenderer());
      this.jresTable.getColumnModel().getColumn(2).setCellEditor(new PathEditor());
      JScrollPane var7 = new JScrollPane(this.jresTable);
      var1.add(var7, "Center");
      JPanel var4 = new JPanel(new FlowLayout(0));
      this.addBtn = new JButton(this.getMessage("common.add_btn"));
      this.addBtn.addActionListener(new PluginJreDialog$2(this));
      this.addBtn.setToolTipText(this.getMessage("vm.options.add_btn.tooltip"));
      this.addBtn.setMnemonic(ResourceManager.getVKCode("common.add_btn.mnemonic"));
      this.removeBtn = new JButton(this.getMessage("common.remove_btn"));
      this.removeBtn.addActionListener(new PluginJreDialog$3(this));
      this.removeBtn.setMnemonic(ResourceManager.getVKCode("common.remove_btn.mnemonic"));
      this.removeBtn.setEnabled(false);
      this.removeBtn.setToolTipText(this.getMessage("vm.options.remove_btn.tooltip"));
      var4.add(this.addBtn);
      var4.add(this.removeBtn);
      if (System.getProperty("os.name").indexOf("Windows") != -1) {
         var1.add(Box.createGlue(), "South");
      } else {
         var1.add(var4, "South");
      }

      this.getContentPane().add(var1, "Center");
      JPanel var5 = new JPanel();
      var5.setLayout(new FlowLayout(2, 10, 5));
      this.okBtn = new JButton(this.getMessage("common.ok_btn"));
      this.okBtn.addActionListener(new PluginJreDialog$4(this));
      this.okBtn.setMnemonic(ResourceManager.getVKCode("common.ok_btn.mnemonic"));
      var5.add(this.okBtn);
      this.cancelBtn = new JButton(this.getMessage("common.cancel_btn"));
      PluginJreDialog$5 var6 = new PluginJreDialog$5(this);
      this.cancelBtn.addActionListener(var6);
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke('\u001b'), "cancel");
      this.getRootPane().getActionMap().put("cancel", var6);
      this.cancelBtn.setMnemonic(ResourceManager.getVKCode("common.cancel_btn.mnemonic"));
      var5.add(this.cancelBtn);
      this.getContentPane().add(var5, "South");
      this.getRootPane().setDefaultButton(this.okBtn);
      this.pack();
   }

   private void addBtnActionPerformed(ActionEvent var1) {
      PluginTableModel var2 = (PluginTableModel)this.jresTable.getModel();
      var2.add(new PluginJavaInfo(null, null, false, ""), false, true);
      int var3 = var2.getRowCount() - 1;
      this.jresTable.requestFocus();
      this.jresTable.setRowSelectionInterval(var3, var3);
   }

   private void removeBtnActionPerformed(ActionEvent var1) {
      ((PluginTableModel)this.jresTable.getModel()).remove(this.jresTable.getSelectedRows());
   }

   private void okBtnActionPerformed(ActionEvent var1) {
      if (this.jresTable.isEditing()) {
         this.jresTable.getCellEditor().stopCellEditing();
      }

      PluginTableModel var2 = (PluginTableModel)this.jresTable.getModel();
      if (var2.getRowCount() >= 0) {
         PluginJavaInfo.clear();

         for (int var3 = 0; var3 < var2.getRowCount(); var3++) {
            PluginJavaInfo.addJRE((PluginJavaInfo)var2.getJRE(var3));
         }
      }

      ControlPanel.propertyHasChanged();
      this.setVisible(false);
      this.dispose();
   }

   private void cancelBtnActionPerformed(ActionEvent var1) {
      this.setVisible(false);
      this.dispose();
   }

   private void closeDialog(WindowEvent var1) {
      this.setVisible(false);
      this.dispose();
   }

   private void setProductTableColumn(TableColumn var1) {
      JComboBox var2 = new JComboBox();
      var2.addItem(this.getMessage("jpi.jre.string"));
      var2.addItem(this.getMessage("jpi.jdk.string"));
      var1.setCellEditor(new DefaultCellEditor(var2));
      DefaultTableCellRenderer var3 = new DefaultTableCellRenderer();
      var3.setToolTipText(this.getMessage("jpi.jres.dialog.product.tooltip"));
      var1.setCellRenderer(var3);
   }

   private String getMessage(String var1) {
      return ResourceManager.getMessage(var1);
   }

   public void valueChanged(ListSelectionEvent var1) {
      this.enableButtons();
   }

   private void enableButtons() {
      int[] var1 = this.jresTable.getSelectedRows();
      PluginTableModel var2 = (PluginTableModel)this.jresTable.getModel();

      for (int var3 = 0; var3 < var1.length; var3++) {
         if (var2.getJRE(var1[var3]).isSystemJRE()) {
            this.removeBtn.setEnabled(false);
            break;
         }

         this.removeBtn.setEnabled(true);
      }
   }
}
