package com.sun.deploy.panel;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import java.awt.AWTKeyStroke;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.MouseEvent;
import java.util.Collections;
import java.util.EventObject;
import java.util.Iterator;
import java.util.SortedSet;
import java.util.TreeSet;
import java.util.Vector;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.JTree;
import javax.swing.KeyStroke;
import javax.swing.event.CellEditorListener;
import javax.swing.event.ChangeEvent;
import javax.swing.tree.DefaultTreeCellEditor;
import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.tree.TreeCellEditor;
import javax.swing.tree.TreePath;

public class TreeEditors {
   private static DefaultTreeCellEditor _radioEditor = null;
   private static DefaultTreeCellEditor _checkBoxEditor = null;
   private static DefaultTreeCellEditor _textFieldEditor = null;
   private static TreeEditors _instance = null;

   private static TreeEditors getInstance() {
      if (_instance == null) {
         _instance = new TreeEditors();
      }

      return _instance;
   }

   private DefaultTreeCellEditor getEditor(JTree var1, IProperty var2) {
      DefaultTreeCellRenderer var3 = TreeRenderers.getRenderer();
      if (var2 instanceof RadioProperty) {
         if (_radioEditor == null) {
            _radioEditor = new TreeEditors.RadioEditor(var1, var3);
         }

         return _radioEditor;
      } else if (var2 instanceof ToggleProperty) {
         if (_checkBoxEditor == null) {
            _checkBoxEditor = new TreeEditors.CheckBoxEditor(var1, var3);
         }

         return _checkBoxEditor;
      } else if (var2 instanceof TextFieldProperty) {
         if (_textFieldEditor == null) {
            _textFieldEditor = new TreeEditors.TextFieldEditor(var1, var3);
         }

         return _textFieldEditor;
      } else {
         return null;
      }
   }

   private static String getMessage(String var0) {
      return ResourceManager.getMessage(var0);
   }

   private class CheckBoxEditor extends TreeEditors.DeployEditor {
      private JCheckBox cb = new JCheckBox();

      public CheckBoxEditor(JTree var2, DefaultTreeCellRenderer var3) {
         super(var2, var3);
         this.cb.addActionListener(new TreeEditors$CheckBoxEditor$1(this));
      }

      public Component getTreeCellEditorComponent(JTree var1, Object var2, boolean var3, boolean var4, boolean var5, int var6) {
         IProperty var7 = (IProperty)var2;
         this.cb.setSelected(var7.isSelected());
         this.cb.setText(var7.getDescription());
         this.cb.setBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1));
         return this.cb;
      }

      public Object getCellEditorValue() {
         return this.cb.isSelected() ? "true" : "false";
      }
   }

   public static final class DelegateEditor implements TreeCellEditor {
      private Vector vListeners = new Vector();
      private TreeCellEditor currentEditor;
      private JTree tree;
      private CellEditorListener listener = new TreeEditors$DelegateEditor$1(this);

      public DelegateEditor(JTree var1) {
         this.tree = var1;
      }

      public Component getTreeCellEditorComponent(JTree var1, Object var2, boolean var3, boolean var4, boolean var5, int var6) {
         return this.currentEditor.getTreeCellEditorComponent(var1, var2, var3, var4, var5, var6);
      }

      public void addCellEditorListener(CellEditorListener var1) {
         this.vListeners.add(var1);
      }

      public void removeCellEditorListener(CellEditorListener var1) {
         this.vListeners.remove(var1);
      }

      public Object getCellEditorValue() {
         return this.currentEditor != null ? this.currentEditor.getCellEditorValue() : null;
      }

      public boolean isCellEditable(EventObject var1) {
         this.setCurrentEditor(var1);
         return this.currentEditor != null;
      }

      public boolean shouldSelectCell(EventObject var1) {
         return this.currentEditor == null ? true : this.currentEditor.shouldSelectCell(var1);
      }

      public boolean stopCellEditing() {
         return this.currentEditor != null ? this.currentEditor.stopCellEditing() : true;
      }

      public void cancelCellEditing() {
         if (this.currentEditor != null) {
            this.currentEditor.cancelCellEditing();
         }
      }

      private void setCurrentEditor(EventObject var1) {
         TreeCellEditor var2 = this.pickEditor(var1);
         if (this.currentEditor != null) {
            this.currentEditor.removeCellEditorListener(this.listener);
         }

         this.currentEditor = var2;
         if (this.currentEditor != null) {
            this.currentEditor.addCellEditorListener(this.listener);
         }
      }

      private TreeCellEditor pickEditor(EventObject var1) {
         DefaultTreeCellEditor var2 = null;
         if (var1 instanceof MouseEvent) {
            MouseEvent var3 = (MouseEvent)var1;
            TreePath var4 = this.tree.getPathForLocation(var3.getX(), var3.getY());
            if (var4.getLastPathComponent() instanceof IProperty) {
               IProperty var5 = (IProperty)var4.getLastPathComponent();
               if (!Config.isLocked(var5.getPropertyName())) {
                  var2 = TreeEditors.getInstance().getEditor(this.tree, var5);
               }
            }
         } else {
            TreePath var6 = this.tree.getSelectionPath();
            if (var6.getLastPathComponent() instanceof TextFieldProperty) {
               IProperty var7 = (IProperty)var6.getLastPathComponent();
               if (!Config.isLocked(var7.getPropertyName())) {
                  var2 = TreeEditors.getInstance().getEditor(this.tree, var7);
               }
            }
         }

         return var2;
      }
   }

   private class DeployEditor extends DefaultTreeCellEditor {
      private Vector vListeners = new Vector();
      private ChangeEvent changeEvent = new ChangeEvent(this);

      public DeployEditor(JTree var2, DefaultTreeCellRenderer var3) {
         super(var2, var3);
      }

      public void addCellEditorListener(CellEditorListener var1) {
         this.vListeners.add(var1);
      }

      public void removeCellEditorListener(CellEditorListener var1) {
         this.vListeners.add(var1);
      }

      public boolean isCellEditable(EventObject var1) {
         return true;
      }

      public boolean shouldSelectCell(EventObject var1) {
         if (var1 instanceof MouseEvent) {
            MouseEvent var2 = (MouseEvent)var1;
            return var2.getID() != 506;
         } else {
            return true;
         }
      }

      public boolean stopCellEditing() {
         return true;
      }

      public void cancelCellEditing() {
      }

      protected void editingStopped() {
         Vector var1 = (Vector)this.vListeners.clone();
         Iterator var2 = var1.iterator();

         while (var2.hasNext()) {
            ((CellEditorListener)var2.next()).editingStopped(this.changeEvent);
         }
      }

      protected void editingCancelled() {
         Vector var1 = (Vector)this.vListeners.clone();
         Iterator var2 = var1.iterator();

         while (var2.hasNext()) {
            ((CellEditorListener)var2.next()).editingCanceled(this.changeEvent);
         }
      }
   }

   private class RadioEditor extends TreeEditors.DeployEditor {
      private JRadioButton button = new JRadioButton();

      public RadioEditor(JTree var2, DefaultTreeCellRenderer var3) {
         super(var2, var3);
         this.button.addActionListener(new TreeEditors$RadioEditor$1(this));
      }

      public Component getTreeCellEditorComponent(JTree var1, Object var2, boolean var3, boolean var4, boolean var5, int var6) {
         IProperty var7 = (IProperty)var2;
         this.button.setSelected(var7.isSelected());
         this.button.setText(var7.getDescription());
         this.button.setBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1));
         return this.button;
      }

      public Object getCellEditorValue() {
         String var1 = "";
         if (this.button.isSelected()) {
            var1 = this.button.getText();
         }

         return var1;
      }
   }

   private class TextFieldEditor extends TreeEditors.DeployEditor {
      private JPanel panel = new JPanel();
      private JButton browse_btn = new JButton(TreeEditors.getMessage("deploy.advanced.browse.browse_btn"));
      private JTextField path = new JTextField("");

      public TextFieldEditor(JTree var2, DefaultTreeCellRenderer var3) {
         super(var2, var3);
         this.panel.setLayout(new BorderLayout());
         this.path.setColumns(22);
         this.panel.add(this.path, "Center");
         this.panel.add(this.browse_btn, "East");
         this.path.addActionListener(new TreeEditors$TextFieldEditor$1(this));
         this.browse_btn.addActionListener(new TreeEditors$TextFieldEditor$2(this, TreeEditors.this));
         SortedSet var4 = Collections.synchronizedSortedSet(new TreeSet());
         var4.add(AWTKeyStroke.getAWTKeyStroke(39, 0, true));
         this.panel.setFocusTraversalKeys(0, var4);
         var4.clear();
         var4.add(AWTKeyStroke.getAWTKeyStroke(37, 0, true));
         this.panel.setFocusTraversalKeys(1, var4);
         KeyStroke var5 = KeyStroke.getKeyStroke(9, 0, true);
         this.panel.getInputMap(1).put(var5, "StopEditingAction");
         this.panel.getActionMap().put("StopEditingAction", new TreeEditors$TextFieldEditor$3(this));
      }

      public Component getTreeCellEditorComponent(JTree var1, Object var2, boolean var3, boolean var4, boolean var5, int var6) {
         if (var3) {
            this.panel.setBackground(this.renderer.getBackgroundSelectionColor());
            this.panel.setBorder(BorderFactory.createLineBorder(this.renderer.getBorderSelectionColor()));
         } else {
            this.panel.setBackground(this.renderer.getBackgroundNonSelectionColor());
            this.panel.setBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1));
         }

         IProperty var7 = (IProperty)var2;
         this.path.setText(var7.getValue());
         this.path.setFont(var1.getFont());
         return this.panel;
      }

      public Object getCellEditorValue() {
         return this.path.getText();
      }
   }
}
