package com.sun.deploy.security;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.services.Service;
import com.sun.deploy.services.ServiceManager;
import com.sun.deploy.util.DeploySysRun;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.security.Provider;
import java.security.Security;
import java.text.MessageFormat;
import java.util.HashMap;
import javax.swing.JButton;
import javax.swing.JPasswordField;

public class BrowserKeystore {
   private static final String _javaVersionProperty = System.getProperty("java.version");
   private static final boolean atLeast14 = !_javaVersionProperty.startsWith("1.2") && !_javaVersionProperty.startsWith("1.3");
   private static final boolean atLeast15 = atLeast14 && !_javaVersionProperty.startsWith("1.4");
   private static Object cryptoManager = null;
   private static boolean initializeJSS = false;

   public static void registerSecurityProviders() {
      if (atLeast15) {
         Service var0 = ServiceManager.getService();
         if (var0.isIExplorer()) {
            try {
               Class var1 = Class.forName("com.sun.deploy.security.MSCryptoProvider", true, ClassLoader.getSystemClassLoader());
               if (var1 != null) {
                  Provider var2 = (Provider)var1.newInstance();
                  Security.insertProviderAt(var2, Security.getProviders().length + 1);
               }
            } catch (Throwable var4) {
            }
         }

         if (var0.isNetscape()) {
            if (isJSSCryptoConfigured()) {
               Trace.msgSecurityPrintln("browserkeystore.jss.config");

               try {
                  Class var5 = Class.forName("com.sun.deploy.security.MozillaJSSProvider", true, ClassLoader.getSystemClassLoader());
                  if (var5 != null) {
                     Provider var6 = (Provider)var5.newInstance();
                     Security.insertProviderAt(var6, Security.getProviders().length + 1);
                  }
               } catch (Throwable var3) {
                  Trace.msgSecurityPrintln("browserkeystore.jss.notconfig");
               }
            } else {
               Trace.msgSecurityPrintln("browserkeystore.jss.notconfig");
            }
         }
      }
   }

   public static synchronized Object getJSSCryptoManager() {
      if (cryptoManager == null && !initializeJSS) {
         initializeJSS = true;
         String var0 = Config.getInstance().getMozillaUserProfileDirectory();
         Trace.msgSecurityPrintln("browserkeystore.mozilla.dir", new Object[]{var0});
         if (var0 != null) {
            try {
               Class var1 = Class.forName("org.mozilla.jss.CryptoManager$InitializationValues", true, ClassLoader.getSystemClassLoader());
               Constructor var2 = var1.getConstructor(
                  class$java$lang$String == null ? (class$java$lang$String = class$("java.lang.String")) : class$java$lang$String
               );
               Object var3 = var2.newInstance(var0);
               Field var4 = var1.getField("installJSSProvider");
               var4.setBoolean(var3, false);
               Class var5 = Class.forName("org.mozilla.jss.CryptoManager", true, ClassLoader.getSystemClassLoader());
               Method var6 = var5.getMethod("initialize", var1);
               Object var7 = var6.invoke(null, var3);
               Method var8 = var5.getMethod("getInstance", null);
               Object var9 = var8.invoke(null, null);
               Class var10 = Class.forName("org.mozilla.jss.util.PasswordCallback", true, ClassLoader.getSystemClassLoader());
               Method var11 = var5.getMethod("setPasswordCallback", var10);
               BrowserKeystore.JSSPasswordCallbackInvocationHandler var12 = new BrowserKeystore.JSSPasswordCallbackInvocationHandler();
               Class var13 = Proxy.getProxyClass(ClassLoader.getSystemClassLoader(), var10);
               Object var14 = var13.getConstructor(
                     class$java$lang$reflect$InvocationHandler == null
                        ? (class$java$lang$reflect$InvocationHandler = class$("java.lang.reflect.InvocationHandler"))
                        : class$java$lang$reflect$InvocationHandler
                  )
                  .newInstance(var12);
               var11.invoke(var9, var14);
               cryptoManager = var9;
               Trace.msgSecurityPrintln("browserkeystore.jss.yes");
            } catch (ClassNotFoundException var15) {
               Trace.msgSecurityPrintln("browserkeystore.jss.no");
               return null;
            } catch (Throwable var16) {
               var16.printStackTrace();
               Trace.msgSecurityPrintln("browserkeystore.jss.no");
               return null;
            }
         }
      }

      return cryptoManager;
   }

   public static boolean isJSSCryptoConfigured() {
      return getJSSCryptoManager() != null;
   }

   private static class JSSPasswordCallbackInvocationHandler implements InvocationHandler {
      private HashMap passwordAttempts = new HashMap();

      private JSSPasswordCallbackInvocationHandler() {
      }

      public Object invoke(Object var1, Method var2, Object[] var3) throws Throwable {
         if (var3 != null && var3[0] != null) {
            Object var4 = var3[0];
            Class var5 = var4.getClass();
            Method var6 = var5.getMethod("getName", null);
            String var7 = (String)var6.invoke(var4, null);
            String var8 = var2.getName();
            Integer var9 = (Integer)this.passwordAttempts.get(var7);
            if (var9 == null || var9 < 2) {
               if (var9 == null) {
                  this.passwordAttempts.put(var7, new Integer(1));
               } else {
                  this.passwordAttempts.put(var7, new Integer(var9 + 1));
               }

               char[] var10 = this.getPasswordDialog(var7);
               Class var11 = Class.forName("org.mozilla.jss.util.Password", true, ClassLoader.getSystemClassLoader());
               Class[] var12 = new Class[]{
                  BrowserKeystore.array$C == null ? (BrowserKeystore.array$C = BrowserKeystore.class$("[C")) : BrowserKeystore.array$C
               };
               Constructor var13 = var11.getConstructor(var12);
               if (var10 != null) {
                  Object[] var14 = new Object[]{var10};
                  return var13.newInstance(var14);
               }
            }
         }

         Class var15 = Class.forName("org.mozilla.jss.util.PasswordCallback$GiveUpException", true, ClassLoader.getSystemClassLoader());
         throw (Throwable)var15.newInstance();
      }

      private char[] getPasswordDialog(String var1) {
         try {
            return (char[])DeploySysRun.execute(new BrowserKeystore$JSSPasswordCallbackInvocationHandler$1(this, var1));
         } catch (Exception var3) {
            Trace.ignoredException(var3);
            return null;
         }
      }

      private char[] getPasswordDialogImp(String var1) {
         MessageFormat var2 = new MessageFormat(ResourceManager.getMessage("browserkeystore.password.dialog.text"));
         Object[] var3 = new Object[]{var1};
         String var4 = var2.format(var3);
         JPasswordField var5 = new JPasswordField();
         Object[] var6 = new Object[]{var4.toString(), var5};
         JButton var7 = new JButton(ResourceManager.getMessage("browserkeystore.password.dialog.buttonOK"));
         JButton var8 = new JButton(ResourceManager.getMessage("browserkeystore.password.dialog.buttonCancel"));
         var7.setMnemonic(ResourceManager.getAcceleratorKey("browserkeystore.password.dialog.buttonOK"));
         var8.setMnemonic(ResourceManager.getAcceleratorKey("browserkeystore.password.dialog.buttonCancel"));
         String var9 = ResourceManager.getMessage("browserkeystore.password.dialog.caption");
         Object[] var10 = new Object[]{var7, var8};
         int var11 = DialogFactory.showOptionDialog(3, var6, var9, var10, var10[0]);
         char[] var12 = var5.getPassword();
         return var11 == 0 ? var12 : null;
      }
   }
}
