package com.sun.deploy.security;

import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.DeployUIManager;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Font;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextArea;
import javax.swing.JTree;
import javax.swing.ListSelectionModel;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.tree.DefaultMutableTreeNode;
import sun.misc.HexDumpEncoder;
import sun.security.x509.SerialNumber;

public class CertificateDialog {
   private Certificate[] certs = null;
   private int start = 0;
   private int end = 0;
   private Component parentComponent;
   JTree certChainTree = null;
   final JTable certInfoTable = new JTable();
   final JTextArea textArea = new JTextArea();
   Object[] msg;
   Object[] options;

   public CertificateDialog(Certificate[] var1, int var2, int var3) {
      this(null, var1, var2, var3);
   }

   public CertificateDialog(Component var1, Certificate[] var2, int var3, int var4) {
      if (var2 != null && var3 >= 0 && var4 >= 0 && var3 <= var4) {
         LookAndFeel var5 = null;

         try {
            var5 = DeployUIManager.setLookAndFeel();
            this.certs = var2;
            this.start = var3;
            this.end = var4;
            this.parentComponent = var1;
            UIManager.getBorder("TableHeader.cellBorder");
            UIManager.getBorder("Table.focusCellHighlightBorder");
            UIManager.getColor("Table.focusCellForeground");
            UIManager.getColor("Table.focusCellBackground");
            JTable var6 = new JTable();
            var6.getDefaultRenderer(class$java$lang$String == null ? (class$java$lang$String = class$("java.lang.String")) : class$java$lang$String);
            var6.getDefaultRenderer(class$java$lang$Object == null ? (class$java$lang$Object = class$("java.lang.Object")) : class$java$lang$Object);
            if (var2.length > var3 && var2[var3] instanceof X509Certificate) {
               Border var7 = BorderFactory.createEtchedBorder();
               this.certChainTree = this.buildCertChainTree(var2, var3, var4);
               this.certChainTree.addTreeSelectionListener(new CertificateDialog$1(this));
               this.showCertificateInfo((X509Certificate)var2[var3]);
               this.certInfoTable.setSelectionMode(0);
               ListSelectionModel var8 = this.certInfoTable.getSelectionModel();
               var8.addListSelectionListener(new CertificateDialog$2(this));
               this.textArea.setLineWrap(false);
               this.textArea.setEditable(false);
               this.textArea.setRows(10);
               this.textArea.setColumns(40);
               Font var9 = ResourceManager.getUIFont();
               Font var10 = new Font("Monospaced", 0, var9.getSize());
               this.textArea.setFont(var10);
               int var11 = var9.getSize();
               this.certInfoTable.setRowSelectionInterval(6, 6);
               JPanel var12 = new JPanel();
               var12.setLayout(new BorderLayout());
               Dimension var13 = this.certInfoTable.getPreferredScrollableViewportSize();
               int var14 = Math.max(120, 8 + 7 * var11);
               var13.setSize(var13.getWidth(), (double)var14);
               this.certInfoTable.setPreferredScrollableViewportSize(var13);
               JScrollPane var15 = new JScrollPane(this.certInfoTable);
               var15.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(0, 0, 5, 0), var15.getBorder()));
               var12.add(var15, "Center");
               var12.add(new JScrollPane(this.textArea), "South");
               var12.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 0));
               JPanel var16 = new JPanel();
               var16.setLayout(new BorderLayout());
               var13 = this.certChainTree.getPreferredScrollableViewportSize();
               var13.setSize(200.0, 100.0);
               var15 = new JScrollPane(this.certChainTree);
               var15.setPreferredSize(var13);
               var16.add(var15, "West");
               var16.add(var12, "East");
               this.msg = new Object[]{var16};
               JButton var17 = new JButton(getMessage("cert.dialog.close"));
               var17.setMnemonic(getAcceleratorKey("cert.dialog.close"));
               this.options = new Object[]{var17};
            }
         } finally {
            DeployUIManager.restoreLookAndFeel(var5);
         }
      } else {
         throw new IllegalArgumentException("Arguments to CertificateDialog constructor is not valid");
      }
   }

   public void DoModal() {
      if (!Trace.isAutomationEnabled()) {
         DialogFactory.showOptionDialog(this.parentComponent, this.msg, getMessage("cert.dialog.caption"), this.options, this.options[0]);
      }
   }

   private String formatDNString(String var1) {
      int var2 = var1.length();
      boolean var3 = false;
      boolean var4 = false;
      StringBuffer var5 = new StringBuffer();

      for (int var6 = 0; var6 < var2; var6++) {
         char var7 = var1.charAt(var6);
         if (var7 == '"' || var7 == '\'') {
            var4 = !var4;
         }

         if (var7 == ',' && !var4) {
            var5.append(",\n");
         } else {
            var5.append(var7);
         }
      }

      return var5.toString();
   }

   private JTree buildCertChainTree(Certificate[] var1, int var2, int var3) {
      DefaultMutableTreeNode var4 = null;
      DefaultMutableTreeNode var5 = null;

      for (int var6 = var2; var6 < var1.length && var6 < var3; var6++) {
         DefaultMutableTreeNode var7 = new DefaultMutableTreeNode(new CertificateInfo((X509Certificate)var1[var6]));
         if (var4 == null) {
            var4 = var7;
            var5 = var7;
         } else {
            var5.add(var7);
            var5 = var7;
         }
      }

      JTree var8 = new JTree(var4);
      var8.getSelectionModel().setSelectionMode(1);
      var8.putClientProperty("JTree.lineStyle", "Angled");
      return var8;
   }

   private void showCertificateInfo(X509Certificate var1) {
      String var2 = "V" + var1.getVersion();
      String var3 = "[xxxxx-xxxxx]";

      try {
         SerialNumber var4 = new SerialNumber(var1.getSerialNumber());
         var3 = "[" + var4.getNumber() + "]";
      } catch (Throwable var12) {
      }

      String var13 = "[" + var1.getSigAlgName() + "]";
      String var5 = this.formatDNString(var1.getIssuerDN().toString());
      String var6 = "[From: " + var1.getNotBefore() + ",\n To: " + var1.getNotAfter() + "]";
      String var7 = this.formatDNString(var1.getSubjectDN().toString());
      HexDumpEncoder var8 = new HexDumpEncoder();
      String var9 = var8.encodeBuffer(var1.getSignature());
      Object[][] var10 = new Object[][]{
         {getMessage("cert.dialog.field.Version"), var2},
         {getMessage("cert.dialog.field.SerialNumber"), var3},
         {getMessage("cert.dialog.field.SignatureAlg"), var13},
         {getMessage("cert.dialog.field.Issuer"), var5},
         {getMessage("cert.dialog.field.Validity"), var6},
         {getMessage("cert.dialog.field.Subject"), var7},
         {getMessage("cert.dialog.field.Signature"), var9}
      };
      String[] var11 = new String[]{getMessage("cert.dialog.field"), getMessage("cert.dialog.value")};
      this.certInfoTable.setModel(new CertificateDialog$3(this, var10, var11));
      this.certInfoTable.setRowSelectionInterval(6, 6);
      this.certInfoTable.repaint();
      this.textArea.repaint();
   }

   private static String getMessage(String var0) {
      return ResourceManager.getMessage(var0);
   }

   private static int getAcceleratorKey(String var0) {
      return ResourceManager.getAcceleratorKey(var0);
   }
}
