package com.sun.deploy.security;

import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.services.Service;
import com.sun.deploy.services.ServiceManager;
import com.sun.deploy.util.DeploySysRun;
import com.sun.deploy.util.DeployUIManager;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.awt.Component;
import java.awt.Frame;
import java.net.Authenticator;
import java.net.InetAddress;
import java.net.PasswordAuthentication;
import java.net.URL;
import java.net.Authenticator.RequestorType;
import java.util.Arrays;
import java.util.HashMap;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JTextField;
import javax.swing.LookAndFeel;

public class DeployAuthenticator extends Authenticator {
   private static final String SCHEME_NTLM = "NTLM";
   private static HashMap baSites = new HashMap();
   protected Frame parentFrame = null;

   private BrowserAuthenticator getBrowserAuthenticator() {
      Service var1 = ServiceManager.getService();
      return var1.getBrowserAuthenticator();
   }

   protected synchronized PasswordAuthentication getPasswordAuthentication() {
      PasswordAuthentication var1 = null;

      try {
         InetAddress var2 = this.getRequestingSite();
         String var3;
         if (var2 != null) {
            var3 = var2.toString();
         } else {
            var3 = this.getHost();
            if (var3 == null || var3.length() == 0) {
               var3 = this.getMessage("net.authenticate.unknownSite");
            }
         }

         StringBuffer var4 = new StringBuffer(this.getRequestingProtocol());
         var4.append(':');
         var4.append(this.getHost());
         var4.append(':');
         var4.append(this.getRequestingPort());
         var4.append(':');
         var4.append(this.getRequestingScheme());
         var4.append(':');
         var4.append(this.getRequestingPrompt());
         if (!baSites.containsKey(var4.toString())) {
            BrowserAuthenticator var5 = this.getBrowserAuthenticator();
            if (var5 != null) {
               var1 = var5.getAuthentication(
                  this.getRequestingProtocol(),
                  this.getHost(),
                  this.getRequestingPort(),
                  this.getRequestingScheme(),
                  this.getRequestingPrompt(),
                  this.getURL(),
                  this.isProxy()
               );
               if (var1 != null) {
                  baSites.put(var4.toString(), var4.toString());
                  return var1;
               }
            }
         }

         StringBuffer var7 = new StringBuffer();
         var7.append("Firewall authentication: site=");
         var7.append(this.getRequestingSite());
         var7.append(":" + this.getRequestingPort());
         var7.append(", protocol=");
         var7.append(this.getRequestingProtocol());
         var7.append(", prompt=");
         var7.append(this.getRequestingPrompt());
         var7.append(", scheme=");
         var7.append(this.getRequestingScheme());
         Trace.netPrintln(var7.toString());
         var1 = this.openDialog(var3, this.getRequestingPrompt(), this.getRequestingScheme());
      } catch (Exception var6) {
         Trace.netPrintException(var6);
      }

      return var1;
   }

   private PasswordAuthentication openDialog(String var1, String var2, String var3) {
      String var4 = var1;
      String var5 = var2;
      String var6 = var3;
      Frame var7 = this.parentFrame;

      try {
         return (PasswordAuthentication)DeploySysRun.execute(new DeployAuthenticator$1(this, var7, var4, var5, var6));
      } catch (Exception var9) {
         Trace.ignoredException(var9);
         return null;
      }
   }

   private PasswordAuthentication openDialogImpl(Component var1, String var2, String var3, String var4) {
      LookAndFeel var5 = null;

      PasswordAuthentication var22;
      try {
         var5 = DeployUIManager.setLookAndFeel();
         if (var2 == null) {
            var2 = "";
         }

         if (var3 == null) {
            var3 = "";
         }

         if (var4 == null) {
            var4 = "";
         }

         JTextField var6 = new JTextField();
         var6.setColumns(15);
         JLabel var7 = new JLabel(this.getMessage("net.authenticate.username"));
         var7.setDisplayedMnemonic(ResourceManager.getVKCode("net.authenticate.username.mnemonic"));
         var7.setLabelFor(var6);
         JPasswordField var8 = new JPasswordField();
         var8.setColumns(15);
         JLabel var9 = new JLabel(this.getMessage("net.authenticate.password"));
         var9.setDisplayedMnemonic(ResourceManager.getVKCode("net.authenticate.password.mnemonic"));
         var9.setLabelFor(var8);
         JTextField var10 = new JTextField();
         var10.setColumns(15);
         JLabel var11 = new JLabel(this.getMessage("net.authenticate.domain"));
         var11.setDisplayedMnemonic(ResourceManager.getVKCode("net.authenticate.domain.mnemonic"));
         var11.setLabelFor(var10);
         boolean var12 = var4 != null ? "NTLM".equalsIgnoreCase(var4) : false;
         JPanel var13 = new JPanel();
         var13.setLayout(new BoxLayout(var13, 1));
         var13.add(new JLabel(this.getMessage("net.authenticate.firewall")));
         var13.add(Box.createVerticalStrut(5));
         if (!var12) {
            var13.add(new JLabel(this.getMessage("net.authenticate.realm")));
            var13.add(Box.createVerticalStrut(5));
         }

         var13.add(new JLabel(this.getMessage("net.authenticate.scheme")));
         var13.add(Box.createVerticalStrut(15));
         var13.add(var7);
         var13.add(Box.createVerticalStrut(15));
         var13.add(var9);
         var13.add(Box.createVerticalStrut(15));
         if (var12) {
            var13.add(var11);
            var13.add(Box.createVerticalStrut(15));
         }

         JPanel var14 = new JPanel();
         var14.setLayout(new BoxLayout(var14, 1));
         var14.add(new JLabel(var2));
         var14.add(Box.createVerticalStrut(5));
         if (!var12) {
            var14.add(new JLabel(var3));
            var14.add(Box.createVerticalStrut(5));
         }

         var14.add(new JLabel(var4));
         var14.add(Box.createVerticalStrut(10));
         var14.add(var6);
         var14.add(Box.createVerticalStrut(10));
         var14.add(var8);
         if (var12) {
            var14.add(Box.createVerticalStrut(10));
            var14.add(var10);
         }

         JPanel var15 = new JPanel();
         var15.setLayout(new BoxLayout(var15, 0));
         var15.add(var13);
         var15.add(Box.createHorizontalStrut(15));
         var15.add(var14);
         Object[] var16 = new Object[]{var15};
         int var17 = DialogFactory.showConfirmDialog(var1, var16, this.getMessage("net.authenticate.caption"));
         if (var17 != 0) {
            return null;
         }

         char[] var19 = var8.getPassword();
         String var21 = var10.getText();
         String var20;
         if (var12 && var21 != null && var21.length() > 0) {
            var20 = var21 + '\\' + var6.getText();
         } else {
            var20 = var6.getText();
         }

         PasswordAuthentication var18 = new PasswordAuthentication(var20, var19);
         Arrays.fill(var19, ' ');
         var22 = var18;
      } finally {
         DeployUIManager.restoreLookAndFeel(var5);
      }

      return var22;
   }

   private String getMessage(String var1) {
      return ResourceManager.getMessage(var1);
   }

   public void setParentFrame(Frame var1) {
      this.parentFrame = var1;
   }

   public String getHost() {
      try {
         return this.getRequestingHost();
      } catch (NoSuchMethodError var2) {
         return "";
      }
   }

   public boolean isProxy() {
      try {
         return this.getRequestorType() == RequestorType.PROXY;
      } catch (NoSuchMethodError var2) {
         return false;
      }
   }

   public URL getURL() {
      try {
         return this.getRequestingURL();
      } catch (NoSuchMethodError var2) {
         return null;
      }
   }
}
