package com.sun.deploy.security;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.DeployUIManager;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.security.AccessController;
import java.security.Key;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Random;
import java.util.TreeSet;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPasswordField;
import javax.swing.LookAndFeel;

public final class DeployClientAuthCertStore implements CertStore {
   private static JDialog myParent = null;
   private static String _filenameUser = null;
   private static String _filenameSys = null;
   private char[] savePassword = null;
   private KeyStore _deploymentUserClientCerts = null;
   private KeyStore _deploymentSystemClientCerts = null;

   public DeployClientAuthCertStore() {
   }

   public DeployClientAuthCertStore(JDialog var1) {
      myParent = var1;
   }

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      this._deploymentUserClientCerts = this.load(_filenameUser);
      this._deploymentSystemClientCerts = this.load(_filenameSys);
   }

   private KeyStore load(String var1) throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.loading", new Object[]{var1});
      KeyStore var2 = KeyStore.getInstance("JKS");
      var2.load(null, null);

      try {
         AccessController.doPrivileged(new DeployClientAuthCertStore$1(this, var1, var2));
      } catch (PrivilegedActionException var5) {
         Exception var4 = var5.getException();
         if (var4 instanceof IOException) {
            throw (IOException)var4;
         }

         if (var4 instanceof CertificateException) {
            throw (CertificateException)var4;
         }

         if (var4 instanceof KeyStoreException) {
            throw (KeyStoreException)var4;
         }

         if (var4 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var4;
         }

         Trace.securityPrintException(var5);
      }

      Trace.msgSecurityPrintln("clientauthcertstore.cert.loaded", new Object[]{var1});
      return var2;
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.saving", new Object[]{_filenameUser});
      char[] var1 = this.getPasswordDialog("clientauth.password.dialog.text");
      if (var1 != null) {
         try {
            AccessController.doPrivileged(new DeployClientAuthCertStore$2(this, var1));
         } catch (PrivilegedActionException var4) {
            Exception var3 = var4.getException();
            if (var3 instanceof IOException) {
               throw (IOException)var3;
            }

            if (var3 instanceof CertificateException) {
               throw (CertificateException)var3;
            }

            if (var3 instanceof KeyStoreException) {
               throw (KeyStoreException)var3;
            }

            if (var3 instanceof NoSuchAlgorithmException) {
               throw (NoSuchAlgorithmException)var3;
            }

            Trace.securityPrintException(var4);
         }
      }

      Trace.msgSecurityPrintln("clientauthcertstore.cert.saved", new Object[]{_filenameUser});
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.adding");
      String var2 = this._deploymentUserClientCerts.getCertificateAlias(var1);
      if (var2 == null) {
         Random var3 = new Random();
         boolean var4 = false;
         Object var5 = null;

         do {
            var5 = "clientauthcert" + var3.nextLong();
            Certificate var6 = this._deploymentUserClientCerts.getCertificate((String)var5);
            if (var6 == null) {
               var4 = true;
            }
         } while (!var4);

         this._deploymentUserClientCerts.setCertificateEntry((String)var5, var1);
         Trace.msgSecurityPrintln("clientauthcertstore.cert.added", new Object[]{var5});
      }
   }

   public boolean addCertKey(Certificate[] var1, Key var2) throws KeyStoreException, IOException, CertificateException, NoSuchAlgorithmException {
      if (this.contains(var1[0])) {
         return false;
      } else {
         Random var3 = new Random();
         boolean var4 = false;
         Object var5 = null;

         do {
            var5 = "clientauthcert" + var3.nextLong();
            Certificate var6 = this._deploymentUserClientCerts.getCertificate((String)var5);
            if (var6 == null) {
               var4 = true;
            }
         } while (!var4);

         char[] var18 = this.getPasswordDialog("clientauth.password.dialog.text");
         if (var18 == null) {
            return false;
         } else {
            File var7 = new File(_filenameUser);
            label64:
            if (var7.exists()) {
               FileInputStream var8 = new FileInputStream(_filenameUser);
               BufferedInputStream var9 = new BufferedInputStream(var8);

               boolean var11;
               try {
                  this._deploymentUserClientCerts.load(var9, var18);
                  this._deploymentUserClientCerts.setKeyEntry((String)var5, var2, var18, var1);
                  break label64;
               } catch (Exception var15) {
                  Trace.securityPrintException(var15);
                  var11 = false;
               } finally {
                  var9.close();
                  var8.close();
               }

               return var11;
            } else {
               this._deploymentUserClientCerts.setKeyEntry((String)var5, var2, var18, var1);
            }

            this.setPassword(var18);
            return true;
         }
      }
   }

   public boolean remove(Certificate var1) throws IOException, KeyStoreException {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.removing");
      Object var2 = null;
      char[] var3 = this.getPasswordDialog("clientauth.password.dialog.text");
      if (var3 == null) {
         return false;
      } else {
         try {
            File var4 = new File(_filenameUser);
            KeyStore var5 = KeyStore.getInstance("JKS");
            var5.load(new BufferedInputStream(new FileInputStream(var4)), var3);
            var2 = this._deploymentUserClientCerts.getCertificateAlias(var1);
            if (var2 != null) {
               this._deploymentUserClientCerts.deleteEntry((String)var2);
            }

            this.setPassword(var3);
            this.save();
         } catch (Exception var6) {
            if (var6 instanceof IOException) {
               throw (IOException)var6;
            }

            if (var6 instanceof KeyStoreException) {
               throw (KeyStoreException)var6;
            }

            Trace.securityPrintException(var6);
            return false;
         }

         Trace.msgSecurityPrintln("clientauthcertstore.cert.removed", new Object[]{var2});
         return true;
      }
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.instore");
      Object var2 = null;
      var2 = this._deploymentSystemClientCerts.getCertificateAlias(var1);
      if (var2 != null) {
         return true;
      } else {
         var2 = this._deploymentUserClientCerts.getCertificateAlias(var1);
         return var2 != null;
      }
   }

   public boolean verify(Certificate var1) {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.canverify");
      return false;
   }

   public Iterator iterator(int var1) throws KeyStoreException {
      return null;
   }

   public Iterator iteratorChain(int var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.iterator");
      KeyStore var2 = this.getKeyStore(var1);
      Enumeration var3 = var2.aliases();
      TreeSet var4 = new TreeSet();

      while (var3.hasMoreElements()) {
         String var5 = (String)var3.nextElement();
         if (var2.isKeyEntry(var5)) {
            var4.add(var5);
         }
      }

      LinkedHashSet var9 = new LinkedHashSet();

      for (String var7 : var4) {
         Certificate[] var8 = var2.getCertificateChain(var7);
         if (var8 != null) {
            var9.add(var8);
         }
      }

      return var9.iterator();
   }

   private KeyStore getKeyStore(int var1) {
      Trace.msgSecurityPrintln("clientauthcertstore.cert.getkeystore");
      return var1 == 0 ? this._deploymentUserClientCerts : this._deploymentSystemClientCerts;
   }

   public char[] getPasswordDialog(String var1) {
      if (this.getPassword() != null) {
         return this.getPassword();
      } else {
         LookAndFeel var2 = null;

         char[] var12;
         try {
            var2 = DeployUIManager.setLookAndFeel();
            String var3 = getMessage(var1);
            JPasswordField var4 = new JPasswordField();
            Object[] var5 = new Object[]{var3.toString(), var4};
            JButton var6 = new JButton(getMessage("cert.dialog.password.okButton"));
            JButton var7 = new JButton(getMessage("cert.dialog.password.cancelButton"));
            String var8 = getMessage("cert.dialog.password.caption");
            Object[] var9 = new Object[]{var6, var7};
            int var10 = DialogFactory.showOptionDialog(myParent, 4, var5, var8, var9, var9[0]);
            char[] var11 = var4.getPassword();
            if (var10 != 0) {
               return null;
            }

            var12 = var11;
         } finally {
            DeployUIManager.restoreLookAndFeel(var2);
         }

         return var12;
      }
   }

   private void setPassword(char[] var1) {
      this.savePassword = var1;
   }

   private char[] getPassword() {
      return this.savePassword;
   }

   private static String getMessage(String var0) {
      return ResourceManager.getMessage(var0);
   }

   static {
      _filenameUser = Config.getUserClientAuthCertFile();
      _filenameSys = Config.getSystemClientAuthCertFile();
   }
}
