package com.sun.deploy.security;

import com.sun.deploy.util.Trace;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.security.GeneralSecurityException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

abstract class MozillaCertStore implements CertStore {
   protected static final int VALID_PEER = 1;
   protected static final int TRUSTED_PEER = 2;
   protected static final int VALID_CA = 8;
   protected static final int TRUSTED_CA = 16;
   protected static final int USER = 64;
   protected static final int TRUSTED_CLIENT_CA = 128;
   private Collection certs = new ArrayList();

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("mozilla.cert.loading", new Object[]{this.getName()});
      this.certs.clear();

      try {
         Class var1 = Class.forName("org.mozilla.jss.CryptoManager", true, ClassLoader.getSystemClassLoader());
         Object var2 = BrowserKeystore.getJSSCryptoManager();
         Method var3 = var1.getMethod("getCACerts", null);
         Object[] var4 = (Object[])var3.invoke(var2, null);

         for (int var5 = 0; var5 < var4.length; var5++) {
            Class var6 = Class.forName("org.mozilla.jss.crypto.X509Certificate", true, ClassLoader.getSystemClassLoader());
            Method var7 = var6.getMethod("getNickname", null);
            String var8 = (String)var7.invoke(var4[var5], null);
            Class var9 = Class.forName("org.mozilla.jss.CryptoManager$CertUsage", true, ClassLoader.getSystemClassLoader());
            Class[] var10 = new Class[]{
               class$java$lang$String == null ? (class$java$lang$String = class$("java.lang.String")) : class$java$lang$String, boolean.class, var9
            };
            Method var11 = var1.getMethod("isCertValid", var10);
            if (this.isTrustedSigningCACertStore()) {
               Field var12 = var9.getField("ObjectSigner");
               Object[] var13 = new Object[]{var8, Boolean.FALSE, var12.get(var4[var5])};
               Boolean var14 = (Boolean)var11.invoke(var2, var13);
               Field var15 = var9.getField("EmailSigner");
               var13[2] = var15.get(var4[var5]);
               Boolean var16 = (Boolean)var11.invoke(var2, var13);
               if (!var14 && !var16) {
                  continue;
               }
            }

            if (this.isTrustedSSLCACertStore()) {
               Field var18 = var9.getField("SSLCA");
               Object[] var20 = new Object[]{var8, Boolean.FALSE, var18.get(var4[var5])};
               Boolean var22 = (Boolean)var11.invoke(var2, var20);
               if (!var22) {
                  continue;
               }
            }

            Method var19 = var6.getMethod("getEncoded", null);
            byte[] var21 = (byte[])var19.invoke(var4[var5], null);
            this.generateCertificate(var21, this.certs);
         }
      } catch (Throwable var17) {
         var17.printStackTrace();
      }

      Trace.msgSecurityPrintln("mozilla.cert.loaded", new Object[]{this.getName()});
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      throw new KeyStoreException("Cannot store certificate in Mozilla \"" + this.getName() + "\" certificate store.");
   }

   public void add(Certificate var1) throws KeyStoreException {
      throw new KeyStoreException("Cannot add certificate in Mozilla \"" + this.getName() + "\" certificate store.");
   }

   public boolean remove(Certificate var1) throws IOException, KeyStoreException {
      throw new KeyStoreException("Cannot remove certificate from Mozilla \"" + this.getName() + "\" certificate store.");
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("mozilla.cert.instore", new Object[]{this.getName()});
      return this.certs.contains(var1);
   }

   public boolean verify(Certificate var1) {
      Trace.msgSecurityPrintln("mozilla.cert.canverify", new Object[]{this.getName()});
      Trace.msgSecurityPrintln("mozilla.cert.tobeverified", new Object[]{var1});

      for (X509Certificate var3 : this) {
         Trace.msgSecurityPrintln("mozilla.cert.tobecompared", new Object[]{this.getName(), var3});

         try {
            var1.verify(var3.getPublicKey());
            Trace.msgSecurityPrintln("mozilla.cert.verify.ok", new Object[]{this.getName()});
            return true;
         } catch (GeneralSecurityException var5) {
         }
      }

      Trace.msgSecurityPrintln("mozilla.cert.verify.fail", new Object[]{this.getName()});
      return false;
   }

   public Iterator iterator(int var1) {
      return this.certs.iterator();
   }

   private void generateCertificate(byte[] var1, Collection var2) {
      try {
         ByteArrayInputStream var3 = new ByteArrayInputStream(var1);
         CertificateFactory var4 = CertificateFactory.getInstance("X.509");

         for (X509Certificate var7 : var4.generateCertificates(var3)) {
            var2.add(var7);
         }
      } catch (CertificateException var8) {
         var8.printStackTrace();
      } catch (Throwable var9) {
         var9.printStackTrace();
      }
   }

   protected abstract String getName();

   protected abstract boolean isTrustedSigningCACertStore();

   protected abstract boolean isTrustedSSLCACertStore();
}
