package com.sun.deploy.security;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.InvalidParameterException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SignatureException;
import java.security.SignatureSpi;
import sun.security.util.DerOutputStream;
import sun.security.util.DerValue;

public abstract class MozillaJSSDSASignature extends SignatureSpi {
   private MozillaJSSDSAPrivateKey privateKey = null;

   protected abstract void update(byte[] var1, int var2, int var3);

   protected abstract byte[] getDigest() throws SignatureException;

   protected abstract void resetDigest();

   private Object getJSSSignature(Object var1) throws ClassNotFoundException, NoSuchMethodException, NoSuchFieldException, IllegalAccessException, InvocationTargetException {
      Class var2 = Class.forName("org.mozilla.jss.crypto.CryptoToken", true, ClassLoader.getSystemClassLoader());
      Class var3 = Class.forName("org.mozilla.jss.crypto.SignatureAlgorithm", true, ClassLoader.getSystemClassLoader());
      Class[] var4 = new Class[]{var3};
      Method var5 = var2.getMethod("getSignatureContext", var4);
      Field var6 = var3.getField("DSASignature");
      Object[] var7 = new Object[]{var6.get(null)};
      return var5.invoke(var1, var7);
   }

   protected void engineInitVerify(PublicKey var1) throws InvalidKeyException {
      throw new InvalidKeyException("Key not supported");
   }

   protected void engineInitSign(PrivateKey var1) throws InvalidKeyException {
      if (!(var1 instanceof MozillaJSSDSAPrivateKey)) {
         throw new InvalidKeyException("Key not supported");
      } else {
         this.privateKey = (MozillaJSSDSAPrivateKey)var1;
      }
   }

   protected void engineUpdate(byte var1) throws SignatureException {
      byte[] var2 = new byte[]{var1};
      this.update(var2, 0, 1);
   }

   protected void engineUpdate(byte[] var1, int var2, int var3) throws SignatureException {
      this.update(var1, var2, var3);
   }

   protected byte[] engineSign() throws SignatureException {
      byte[] var24;
      try {
         byte[] var1 = this.getDigest();
         Object var32 = this.privateKey.getJSSPrivateKey();
         Class var3 = Class.forName("org.mozilla.jss.crypto.PrivateKey", true, ClassLoader.getSystemClassLoader());
         Method var4 = var3.getMethod("getOwningToken", null);
         Object var5 = var4.invoke(var32, null);
         Object var6 = this.getJSSSignature(var5);
         Class var7 = Class.forName("org.mozilla.jss.crypto.Signature", true, ClassLoader.getSystemClassLoader());
         Class[] var8 = new Class[]{var3};
         Method var9 = var7.getMethod("initSign", var8);
         Object[] var10 = new Object[]{var32};
         Object var11 = var9.invoke(var6, var10);
         Class[] var12 = new Class[]{array$B == null ? (array$B = class$("[B")) : array$B};
         Method var13 = var7.getMethod("update", var12);
         Object[] var14 = new Object[]{var1};
         Object var15 = var13.invoke(var6, var14);
         Method var16 = var7.getMethod("sign", null);
         byte[] var17 = (byte[])var16.invoke(var6, null);
         byte[] var18 = new byte[20];
         byte[] var19 = new byte[20];
         System.arraycopy(var17, 0, var18, 0, 20);
         System.arraycopy(var17, 20, var19, 0, 20);
         BigInteger var20 = new BigInteger(var18);
         BigInteger var21 = new BigInteger(var19);
         DerOutputStream var22 = new DerOutputStream(100);
         var22.putInteger(var20);
         var22.putInteger(var21);
         DerValue var23 = new DerValue((byte)48, var22.toByteArray());
         var24 = var23.toByteArray();
      } catch (SignatureException var29) {
         throw var29;
      } catch (Throwable var30) {
         SignatureException var2 = new SignatureException("Error generating signature.");
         var2.initCause(var30);
         throw var2;
      } finally {
         this.resetDigest();
      }

      return var24;
   }

   protected boolean engineVerify(byte[] var1) throws SignatureException {
      throw new SignatureException("Signature verification not supported");
   }

   /** @deprecated */
   protected void engineSetParameter(String var1, Object var2) throws InvalidParameterException {
      throw new InvalidParameterException("Parameter not supported");
   }

   /** @deprecated */
   protected Object engineGetParameter(String var1) throws InvalidParameterException {
      throw new InvalidParameterException("Parameter not supported");
   }

   public static class NONEwithDSA extends MozillaJSSDSASignature {
      private static final int SHA1_LEN = 20;
      private final byte[] digestBuffer = new byte[20];
      private int offset;

      protected void update(byte[] var1, int var2, int var3) {
         if (var3 != 0 && var1 != null) {
            if (this.offset + var3 > 20) {
               this.offset = 21;
            } else {
               System.arraycopy(var1, var2, this.digestBuffer, this.offset, var3);
               this.offset += var3;
            }
         }
      }

      protected byte[] getDigest() throws SignatureException {
         if (this.offset != 20) {
            throw new SignatureException("Data for RawDSA must be exactly 20 bytes long");
         } else {
            this.offset = 0;
            return this.digestBuffer;
         }
      }

      protected void resetDigest() {
         this.offset = 0;
      }
   }

   public static class SHA1withDSA extends MozillaJSSDSASignature {
      private final MessageDigest dataSHA = MessageDigest.getInstance("SHA-1");

      public SHA1withDSA() throws NoSuchAlgorithmException {
         this.dataSHA.reset();
      }

      protected void update(byte[] var1, int var2, int var3) {
         if (var3 != 0 && var1 != null) {
            this.dataSHA.update(var1, var2, var3);
         }
      }

      protected byte[] getDigest() {
         return this.dataSHA.digest();
      }

      protected void resetDigest() {
         this.dataSHA.reset();
      }
   }
}
