package com.sun.deploy.security;

import com.sun.deploy.util.Trace;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.InvalidParameterException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SignatureException;
import java.security.SignatureSpi;
import sun.security.rsa.RSACore;
import sun.security.rsa.RSAPadding;

public final class MozillaJSSNONEwithRSASignature extends SignatureSpi {
   private byte[] buffer;
   private int bufOfs;
   private MozillaJSSRSAPrivateKey privateKey = null;

   protected void engineInitVerify(PublicKey var1) throws InvalidKeyException {
      throw new InvalidKeyException("Key not supported");
   }

   protected void engineInitSign(PrivateKey var1) throws InvalidKeyException {
      if (!(var1 instanceof MozillaJSSRSAPrivateKey)) {
         throw new InvalidKeyException("Key not supported");
      } else {
         this.privateKey = (MozillaJSSRSAPrivateKey)var1;
         int var2 = this.privateKey.bitLength() + 7 >> 3;
         if (var2 < 64) {
            throw new InvalidKeyException("RSA keys should be at least 512 bits long");
         } else {
            this.bufOfs = 0;

            try {
               RSAPadding var3 = RSAPadding.getInstance(1, var2, this.appRandom);
               int var4 = var3.getMaxDataSize();
               this.buffer = new byte[var4];
            } catch (InvalidAlgorithmParameterException var5) {
               Trace.securityPrintException(var5);
            }
         }
      }
   }

   private void update(byte[] var1, int var2, int var3) {
      if (var3 != 0 && var1 != null) {
         if (this.bufOfs + var3 > this.buffer.length) {
            this.bufOfs = this.buffer.length + 1;
         } else {
            System.arraycopy(var1, var2, this.buffer, this.bufOfs, var3);
            this.bufOfs += var3;
         }
      }
   }

   protected void engineUpdate(byte var1) throws SignatureException {
      byte[] var2 = new byte[]{var1};
      this.update(var2, 0, 1);
   }

   protected void engineUpdate(byte[] var1, int var2, int var3) throws SignatureException {
      this.update(var1, var2, var3);
   }

   protected byte[] engineSign() throws SignatureException {
      if (this.bufOfs > this.buffer.length) {
         throw new SignatureException("Data must not be longer than " + this.buffer.length + " bytes");
      } else {
         byte[] var29;
         try {
            byte[] var1 = RSACore.convert(this.buffer, 0, this.bufOfs);
            Object var2 = null;

            try {
               Object var3 = this.privateKey.getJSSPrivateKey();
               Class var4 = Class.forName("org.mozilla.jss.crypto.PrivateKey", true, ClassLoader.getSystemClassLoader());
               Method var5 = var4.getMethod("getOwningToken", null);
               Object var6 = var5.invoke(var3, null);
               Class var7 = Class.forName("org.mozilla.jss.crypto.CryptoToken", true, ClassLoader.getSystemClassLoader());
               Class var8 = Class.forName("org.mozilla.jss.crypto.SignatureAlgorithm", true, ClassLoader.getSystemClassLoader());
               Class[] var9 = new Class[]{var8};
               Method var10 = var7.getMethod("getSignatureContext", var9);
               Field var11 = var8.getField("RSASignature");
               Object[] var12 = new Object[]{var11.get(this.privateKey)};
               Object var13 = var10.invoke(var6, var12);
               Class var14 = Class.forName("org.mozilla.jss.crypto.Signature", true, ClassLoader.getSystemClassLoader());
               Class[] var15 = new Class[]{var4};
               Method var16 = var14.getMethod("initSign", var15);
               Object[] var17 = new Object[]{var3};
               Object var18 = var16.invoke(var13, var17);
               Class[] var19 = new Class[]{array$B == null ? (array$B = class$("[B")) : array$B};
               Method var20 = var14.getMethod("update", var19);
               Object[] var21 = new Object[]{var1};
               Object var22 = var20.invoke(var13, var21);
               Method var23 = var14.getMethod("sign", null);
               var2 = var23.invoke(var13, null);
            } catch (Throwable var27) {
               var27.printStackTrace();
            }

            var29 = (byte[])var2;
         } finally {
            this.bufOfs = 0;
         }

         return var29;
      }
   }

   protected boolean engineVerify(byte[] var1) throws SignatureException {
      throw new SignatureException("Signature verification not supported");
   }

   /** @deprecated */
   protected void engineSetParameter(String var1, Object var2) throws InvalidParameterException {
      throw new InvalidParameterException("Parameter not supported");
   }

   /** @deprecated */
   protected Object engineGetParameter(String var1) throws InvalidParameterException {
      throw new InvalidParameterException("Parameter not supported");
   }
}
