package com.sun.deploy.security;

import com.sun.deploy.util.Trace;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.security.Key;
import java.security.KeyStoreException;
import java.security.KeyStoreSpi;
import java.security.NoSuchAlgorithmException;
import java.security.SecurityPermission;
import java.security.UnrecoverableKeyException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Enumeration;
import java.util.Iterator;

public final class MozillaMyKeyStore extends KeyStoreSpi {
   private Collection keyEntries = new ArrayList();

   public Key engineGetKey(String var1, char[] var2) throws NoSuchAlgorithmException, UnrecoverableKeyException {
      if (var2 != null && var2.length > 0) {
         throw new UnrecoverableKeyException("Password is not required for Mozilla MY keystore.");
      } else if (!this.engineIsKeyEntry(var1)) {
         return null;
      } else {
         for (MozillaMyKeyStore.KeyEntry var4 : this.keyEntries) {
            if (var1.equals(var4.getAlias())) {
               return var4.getPrivateKey();
            }
         }

         return null;
      }
   }

   public Certificate[] engineGetCertificateChain(String var1) {
      for (MozillaMyKeyStore.KeyEntry var3 : this.keyEntries) {
         if (var1.equals(var3.getAlias())) {
            X509Certificate[] var4 = var3.getCertificateChain();
            return (X509Certificate[])var4.clone();
         }
      }

      return null;
   }

   public Certificate engineGetCertificate(String var1) {
      for (MozillaMyKeyStore.KeyEntry var3 : this.keyEntries) {
         if (var1.equals(var3.getAlias())) {
            X509Certificate[] var4 = var3.getCertificateChain();
            return var4[0];
         }
      }

      return null;
   }

   public Date engineGetCreationDate(String var1) {
      return new Date();
   }

   public void engineSetKeyEntry(String var1, Key var2, char[] var3, Certificate[] var4) throws KeyStoreException {
      throw new KeyStoreException("Cannot assign the given key to the given alias.");
   }

   public void engineSetKeyEntry(String var1, byte[] var2, Certificate[] var3) throws KeyStoreException {
      throw new KeyStoreException("Cannot assign the given key to the given alias.");
   }

   public void engineSetCertificateEntry(String var1, Certificate var2) throws KeyStoreException {
      throw new KeyStoreException("Cannot assign the given certificate to the given alias.");
   }

   public void engineDeleteEntry(String var1) throws KeyStoreException {
      throw new KeyStoreException("Mozilla does not support alias removal.");
   }

   public Enumeration engineAliases() {
      Iterator var1 = this.keyEntries.iterator();
      return new MozillaMyKeyStore$1(this, var1);
   }

   public boolean engineContainsAlias(String var1) {
      Enumeration var2 = this.engineAliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         if (var3.equals(var1)) {
            return true;
         }
      }

      return false;
   }

   public int engineSize() {
      return this.keyEntries.size();
   }

   public boolean engineIsKeyEntry(String var1) {
      return var1.startsWith("MozillaJSSRSAPrivateKey") || var1.startsWith("MozillaJSSDSAPrivateKey");
   }

   public boolean engineIsCertificateEntry(String var1) {
      return false;
   }

   public String engineGetCertificateAlias(Certificate var1) {
      for (MozillaMyKeyStore.KeyEntry var3 : this.keyEntries) {
         if (var3.certChain != null && var3.certChain[0].equals(var1)) {
            return var3.getAlias();
         }
      }

      return null;
   }

   public void engineStore(OutputStream var1, char[] var2) throws IOException, NoSuchAlgorithmException, CertificateException {
      throw new IOException("Mozilla cert store cannot be stored into stream.");
   }

   public void engineLoad(InputStream var1, char[] var2) throws IOException, NoSuchAlgorithmException, CertificateException {
      SecurityManager var3 = System.getSecurityManager();
      if (var3 != null) {
         var3.checkPermission(new SecurityPermission("authProvider.SunDeploy-MozillaJSS"));
      }

      if (var1 != null) {
         throw new IOException("Mozilla cert store cannot be loaded from stream.");
      } else {
         this.keyEntries.clear();

         try {
            Class var4 = Class.forName("org.mozilla.jss.CryptoManager", true, ClassLoader.getSystemClassLoader());
            Object var5 = BrowserKeystore.getJSSCryptoManager();
            Method var6 = var4.getMethod("getInternalKeyStorageToken", null);
            Object var7 = var6.invoke(var5, null);
            this.generateKeyAndCertificateFromToken(var5, var7);
            Method var8 = var4.getMethod("getExternalTokens", null);
            Enumeration var9 = (Enumeration)var8.invoke(var5, null);

            while (var9.hasMoreElements()) {
               Object var10 = var9.nextElement();
               this.generateKeyAndCertificateFromToken(var5, var10);
            }
         } catch (Throwable var11) {
            var11.printStackTrace();
         }
      }
   }

   private void generateKeyAndCertificateFromToken(Object var1, Object var2) throws Throwable {
      Class var3 = Class.forName("org.mozilla.jss.CryptoManager", true, ClassLoader.getSystemClassLoader());
      Class var4 = Class.forName("org.mozilla.jss.crypto.CryptoToken", true, ClassLoader.getSystemClassLoader());
      Method var5 = var4.getMethod("getCryptoStore", null);
      Object var6 = var5.invoke(var2, null);
      Class var7 = Class.forName("org.mozilla.jss.crypto.CryptoStore", true, ClassLoader.getSystemClassLoader());
      Method var8 = var7.getMethod("getCertificates", null);
      Object[] var9 = (Object[])var8.invoke(var6, null);

      for (int var10 = 0; var10 < var9.length; var10++) {
         Class var11 = Class.forName("org.mozilla.jss.crypto.X509Certificate", true, ClassLoader.getSystemClassLoader());
         Method var12 = var11.getMethod("getNickname", null);
         String var13 = (String)var12.invoke(var9[var10], null);
         if (var13 != null) {
            Class var14 = Class.forName("org.mozilla.jss.CryptoManager$CertUsage", true, ClassLoader.getSystemClassLoader());
            Class[] var15 = new Class[]{
               class$java$lang$String == null ? (class$java$lang$String = class$("java.lang.String")) : class$java$lang$String, boolean.class, var14
            };
            Method var16 = var3.getMethod("isCertValid", var15);
            Field var17 = var14.getField("SSLClient");
            Object[] var18 = new Object[]{var13, Boolean.FALSE, var17.get(var9[var10])};
            Boolean var19 = (Boolean)var16.invoke(var1, var18);
            if (var19) {
               try {
                  Class[] var20 = new Class[]{var11};
                  Method var21 = var3.getMethod("findPrivKeyByCert", var20);
                  Object[] var22 = new Object[]{var9[var10]};
                  Object var23 = var21.invoke(var1, var22);
                  Class var24 = Class.forName("org.mozilla.jss.crypto.PrivateKey", true, ClassLoader.getSystemClassLoader());
                  Method var25 = var24.getMethod("getType", null);
                  Object var26 = var25.invoke(var23, null);
                  Class var27 = Class.forName("org.mozilla.jss.crypto.PrivateKey$Type", true, ClassLoader.getSystemClassLoader());
                  Field var28 = var27.getField("RSA");
                  Field var29 = var27.getField("DSA");
                  Object var30 = var28.get(null);
                  Object var31 = var29.get(null);
                  if (var26.equals(var30) || var26.equals(var31)) {
                     Class[] var32 = new Class[]{var11};
                     Method var33 = var3.getMethod("buildCertificateChain", var32);
                     Object[] var34 = new Object[]{var9[var10]};
                     Object[] var35 = (Object[])var33.invoke(var1, var34);
                     ArrayList var36 = new ArrayList();

                     for (int var37 = 0; var37 < var35.length; var37++) {
                        Method var38 = var11.getMethod("getEncoded", null);
                        Object var39 = var38.invoke(var35[var37], null);
                        this.generateCertificate((byte[])var39, var36);
                     }

                     Method var41 = var24.getMethod("getStrength", null);
                     Integer var42 = (Integer)var41.invoke(var23, null);
                     if (var26.equals(var30)) {
                        this.generateRSAKeyAndCertificateChain(var23, var42, var36, this.keyEntries);
                     } else {
                        this.generateDSAKeyAndCertificateChain(var23, var42, var36, this.keyEntries);
                     }
                  }
               } catch (Throwable var40) {
                  Trace.msgSecurityPrintln("mozillamykeystore.priv.notfound", new Object[]{var13});
               }
            }
         }
      }
   }

   private void generateRSAKeyAndCertificateChain(Object var1, int var2, Collection var3, Collection var4) {
      try {
         X509Certificate[] var5 = new X509Certificate[var3.size()];
         int var6 = 0;

         for (Iterator var7 = var3.iterator(); var7.hasNext(); var6++) {
            var5[var6] = (X509Certificate)var7.next();
         }

         MozillaMyKeyStore.KeyEntry var9 = new MozillaMyKeyStore.KeyEntry(new MozillaJSSRSAPrivateKey(var1, var2), var5);
         var4.add(var9);
      } catch (Throwable var8) {
         var8.printStackTrace();
      }
   }

   private void generateDSAKeyAndCertificateChain(Object var1, int var2, Collection var3, Collection var4) {
      try {
         X509Certificate[] var5 = new X509Certificate[var3.size()];
         int var6 = 0;

         for (Iterator var7 = var3.iterator(); var7.hasNext(); var6++) {
            var5[var6] = (X509Certificate)var7.next();
         }

         MozillaMyKeyStore.KeyEntry var9 = new MozillaMyKeyStore.KeyEntry(new MozillaJSSDSAPrivateKey(var1, var2), var5);
         var4.add(var9);
      } catch (Throwable var8) {
         var8.printStackTrace();
      }
   }

   private void generateCertificate(byte[] var1, Collection var2) {
      try {
         ByteArrayInputStream var3 = new ByteArrayInputStream(var1);
         CertificateFactory var4 = CertificateFactory.getInstance("X.509");

         for (X509Certificate var7 : var4.generateCertificates(var3)) {
            var2.add(var7);
         }
      } catch (CertificateException var8) {
         var8.printStackTrace();
      } catch (Throwable var9) {
         var9.printStackTrace();
      }
   }

   protected String getName() {
      return "MY";
   }

   class KeyEntry {
      private MozillaJSSPrivateKey privateKey;
      private X509Certificate[] certChain;

      KeyEntry(MozillaJSSPrivateKey var2, X509Certificate[] var3) {
         this.privateKey = var2;
         this.certChain = var3;
      }

      String getAlias() {
         return this.privateKey.toString();
      }

      Key getPrivateKey() {
         return this.privateKey;
      }

      X509Certificate[] getCertificateChain() {
         return this.certChain;
      }
   }
}
