package com.sun.deploy.security;

import com.sun.deploy.config.Config;
import com.sun.deploy.util.Trace;
import java.io.IOException;
import java.security.AccessController;
import java.security.GeneralSecurityException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Random;
import java.util.TreeSet;

public final class RootCertStore implements CertStore {
   private static String _filenameUser = null;
   private static String _filenameSys = null;
   private long _userLastModified = 0L;
   private long _sysLastModified = 0L;
   private KeyStore _deploymentUserCACerts = CertUtils.createEmptyKeyStore();
   private KeyStore _deploymentSystemCACerts = CertUtils.createEmptyKeyStore();
   private static RootCertStore _rcs = null;

   private RootCertStore() {
   }

   public static synchronized RootCertStore getInstance() {
      if (_rcs == null) {
         _rcs = new RootCertStore();
      }

      return _rcs;
   }

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      if (_filenameUser != null) {
         long var1 = CertUtils.getFileLastModified(_filenameUser);
         if (var1 != this._userLastModified) {
            this._deploymentUserCACerts = this.load(_filenameUser);
            this._userLastModified = var1;
         }
      }

      if (_filenameSys != null) {
         long var3 = CertUtils.getFileLastModified(_filenameSys);
         if (var3 != this._sysLastModified) {
            this._deploymentSystemCACerts = this.load(_filenameSys);
            this._sysLastModified = var3;
         }
      }
   }

   private KeyStore load(String var1) throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("rootcertstore.cert.loading", new Object[]{var1});
      KeyStore var2 = KeyStore.getInstance("JKS");
      var2.load(null, null);

      try {
         AccessController.doPrivileged(new RootCertStore$1(this, var1, var2));
      } catch (PrivilegedActionException var5) {
         Exception var4 = var5.getException();
         if (var4 instanceof IOException) {
            throw (IOException)var4;
         }

         if (var4 instanceof CertificateException) {
            throw (CertificateException)var4;
         }

         if (var4 instanceof KeyStoreException) {
            throw (KeyStoreException)var4;
         }

         if (var4 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var4;
         }

         Trace.securityPrintException(var5);
      }

      Trace.msgSecurityPrintln("rootcertstore.cert.loaded", new Object[]{var1});
      return var2;
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("rootcertstore.cert.saving", new Object[]{_filenameUser});

      try {
         AccessController.doPrivileged(new RootCertStore$2(this));
      } catch (PrivilegedActionException var3) {
         Exception var2 = var3.getException();
         if (var2 instanceof IOException) {
            throw (IOException)var2;
         }

         if (var2 instanceof CertificateException) {
            throw (CertificateException)var2;
         }

         if (var2 instanceof KeyStoreException) {
            throw (KeyStoreException)var2;
         }

         if (var2 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var2;
         }

         Trace.securityPrintException(var3);
      }

      Trace.msgSecurityPrintln("cacertstore.cert.saved", new Object[]{_filenameUser});
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.adding");
      String var2 = this._deploymentUserCACerts.getCertificateAlias(var1);
      if (var2 == null) {
         Random var3 = new Random();
         boolean var4 = false;
         Object var5 = null;

         do {
            var5 = "usercacert" + var3.nextLong();
            Certificate var6 = this._deploymentUserCACerts.getCertificate((String)var5);
            if (var6 == null) {
               var4 = true;
            }
         } while (!var4);

         this._deploymentUserCACerts.setCertificateEntry((String)var5, var1);
         Trace.msgSecurityPrintln("rootcertstore.cert.added", new Object[]{var5});
      }
   }

   public boolean remove(Certificate var1) throws IOException, KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.removing");
      String var2 = this._deploymentUserCACerts.getCertificateAlias(var1);
      if (var2 != null) {
         this._deploymentUserCACerts.deleteEntry(var2);
      }

      Trace.msgSecurityPrintln("rootcertstore.cert.removed", new Object[]{var2});
      return true;
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.instore");
      Object var2 = null;
      var2 = this._deploymentSystemCACerts.getCertificateAlias(var1);
      if (var2 != null) {
         return true;
      } else {
         var2 = this._deploymentUserCACerts.getCertificateAlias(var1);
         return var2 != null;
      }
   }

   public boolean verify(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.canverify");
      Trace.msgSecurityPrintln("rootcertstore.cert.tobeverified", new Object[]{var1});
      new StringBuffer();
      Enumeration var3 = this._deploymentSystemCACerts.aliases();
      Enumeration var4 = this._deploymentUserCACerts.aliases();

      while (var3.hasMoreElements() || var4.hasMoreElements()) {
         Certificate var6;
         if (var3.hasMoreElements()) {
            String var5 = (String)var3.nextElement();
            var6 = this._deploymentSystemCACerts.getCertificate(var5);
         } else {
            String var9 = (String)var4.nextElement();
            var6 = this._deploymentUserCACerts.getCertificate(var9);
         }

         Trace.msgSecurityPrintln("rootcertstore.cert.tobecompared", new Object[]{var6});

         try {
            var1.verify(var6.getPublicKey());
            Trace.msgSecurityPrintln("rootcertstore.cert.verify.ok");
            return true;
         } catch (GeneralSecurityException var8) {
         }
      }

      Trace.msgSecurityPrintln("rootcertstore.cert.verify.fail");
      return false;
   }

   public Iterator iterator(int var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.iterator");
      LinkedHashSet var2 = new LinkedHashSet();
      KeyStore var3 = this.getKeyStore(var1);
      Enumeration var4 = var3.aliases();
      TreeSet var5 = new TreeSet();

      while (var4.hasMoreElements()) {
         String var6 = (String)var4.nextElement();
         var5.add(var6);
      }

      for (String var7 : var5) {
         Certificate var8 = var3.getCertificate(var7);
         var2.add(var8);
      }

      return var2.iterator();
   }

   public KeyStore getKeyStore(int var1) {
      Trace.msgSecurityPrintln("rootcertstore.cert.getkeystore");
      return var1 == 0 ? this._deploymentUserCACerts : this._deploymentSystemCACerts;
   }

   static {
      _filenameUser = Config.getUserRootCertificateFile();
      _filenameSys = Config.getSystemRootCertificateFile();
   }
}
