package com.sun.deploy.security;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.services.Service;
import com.sun.deploy.services.ServiceManager;
import com.sun.deploy.ui.AppInfo;
import com.sun.deploy.util.Trace;
import java.io.IOException;
import java.security.CodeSigner;
import java.security.CodeSource;
import java.security.GeneralSecurityException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.Principal;
import java.security.PublicKey;
import java.security.Timestamp;
import java.security.cert.CertPath;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class TrustDecider {
   private static RootCertStore rootStore = null;
   private static CertStore permanentStore = null;
   private static CertStore sessionStore = null;
   private static CertStore deniedStore = null;
   private static CertStore browserRootStore = null;
   private static CertStore browserTrustedStore = null;
   private static Map trustedPrincipals;
   private static boolean isBrowserRootStoreLoaded = false;

   public static void reset() {
      rootStore = RootCertStore.getInstance();
      permanentStore = new DeploySigningCertStore();
      sessionStore = new SessionCertStore();
      deniedStore = new DeniedCertStore();
      if (Config.getBooleanProperty("deployment.security.browser.keystore.use")) {
         Service var0 = ServiceManager.getService();
         browserRootStore = var0.getBrowserSigningRootCertStore();
         browserTrustedStore = var0.getBrowserTrustedCertStore();
         isBrowserRootStoreLoaded = false;
      }
   }

   public static boolean isAllPermissionGranted(CodeSource var0) throws CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, CertificateException, KeyStoreException, NoSuchAlgorithmException, IOException {
      return isAllPermissionGranted(var0, new AppInfo());
   }

   public static boolean isAllPermissionGranted(CodeSource var0, AppInfo var1) throws CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, CertificateException, KeyStoreException, NoSuchAlgorithmException, IOException {
      Certificate[] var2 = var0.getCertificates();
      if (var2 == null) {
         return false;
      } else {
         int var3 = 0;
         int var4 = 0;
         int var5 = 0;
         LinkedList var6 = new LinkedList();
         Object var7 = null;
         rootStore.load();
         permanentStore.load();
         sessionStore.load();
         deniedStore.load();
         if (browserRootStore != null && !isBrowserRootStoreLoaded) {
            browserRootStore.load();
            isBrowserRootStoreLoaded = true;
         }

         if (browserTrustedStore != null) {
            browserTrustedStore.load();
         }

         while (var4 < var2.length) {
            int var8 = var3;

            while (
               var8 + 1 < var2.length
                  && var2[var8] instanceof X509Certificate
                  && var2[var8 + 1] instanceof X509Certificate
                  && CertUtils.isIssuerOf((X509Certificate)var2[var8], (X509Certificate)var2[var8 + 1])
            ) {
               var8++;
            }

            var4 = var8 + 1;
            if (deniedStore.contains(var2[var3])) {
               var6.add(var5, new Boolean(true));
            } else {
               var6.add(var5, new Boolean(false));
               if (permanentStore.contains(var2[var3])) {
                  return true;
               }

               if (sessionStore.contains(var2[var3])) {
                  return true;
               }

               if (browserTrustedStore != null && browserTrustedStore.contains(var2[var3])) {
                  return true;
               }
            }

            var3 = var4;
            var5++;
         }

         boolean var35 = false;
         boolean var9 = false;
         boolean var10 = false;
         var3 = 0;
         var4 = 0;
         getCertMap(rootStore.getKeyStore(0), rootStore.getKeyStore(1));
         Date var11 = new Date();
         var2 = canonicalize(var2, var11);

         for (int var31 = 0; var4 < var2.length; var31++) {
            CertificateExpiredException var13 = null;
            CertificateNotYetValidException var14 = null;

            int var12;
            for (var12 = var3; var12 < var2.length; var12++) {
               X509Certificate var15 = null;
               Object var16 = null;
               if (var2[var12] instanceof X509Certificate) {
                  var15 = (X509Certificate)var2[var12];
               }

               if (var12 + 1 < var2.length && var2[var12 + 1] instanceof X509Certificate) {
                  var16 = (X509Certificate)var2[var12 + 1];
               } else {
                  var16 = var15;
               }

               try {
                  var15.checkValidity();
               } catch (CertificateExpiredException var25) {
                  if (var13 == null) {
                     var13 = var25;
                  }
               } catch (CertificateNotYetValidException var26) {
                  if (var14 == null) {
                     var14 = var26;
                  }
               }

               if (!rootStore.contains(var15)
                  && var12 + 1 != var2.length
                  && CertUtils.isIssuerOf(var15, (X509Certificate)var16)
                  && (browserRootStore == null || !browserRootStore.contains(var15))) {
                  CertUtils.checkUsageForCodeSigning(var15, var12 - var3);
               }

               if (!CertUtils.isIssuerOf(var15, (X509Certificate)var16)) {
                  break;
               }

               try {
                  var15.verify(var16.getPublicKey());
               } catch (GeneralSecurityException var24) {
                  Trace.msgSecurityPrintln("trustdecider.check.signature");
                  var7 = ResourceManager.getMessage("trustdecider.check.signature");
                  throw new CertificateException((String)var7);
               }
            }

            var4 = var12 < var2.length ? var12 + 1 : var12;
            Boolean var36 = (Boolean)var6.get(var31);
            if (!var36) {
               if (!Config.getBooleanProperty("deployment.security.askgrantdialog.show")) {
                  var7 = ResourceManager.getMessage("trustdecider.user.cannot.grant.any");
                  throw new CertificateException((String)var7);
               }

               boolean var38 = rootStore.verify(var2[var4 - 1]) || browserRootStore != null && browserRootStore.verify(var2[var4 - 1]);
               if (!var38) {
                  if (!Config.getBooleanProperty("deployment.security.askgrantdialog.notinca")) {
                     var7 = ResourceManager.getMessage("trustdecider.user.cannot.grant.notinca");
                     throw new CertificateException((String)var7);
                  }

                  var35 = true;
               }

               if (var13 != null || var14 != null) {
                  var9 = true;
               }

               Date var17 = null;

               try {
                  CodeSigner[] var18 = var0.getCodeSigners();
                  Timestamp var19 = var18[var31].getTimestamp();
                  if (var19 != null) {
                     Trace.msgSecurityPrintln("trustdecider.check.timestamping.yes");
                     var17 = var19.getTimestamp();
                     CertPath var20 = var19.getSignerCertPath();
                     if (var9) {
                        Trace.msgSecurityPrintln("trustdecider.check.timestamping.need");
                        Date var21 = ((X509Certificate)var2[var4 - 1]).getNotAfter();
                        Date var22 = ((X509Certificate)var2[var4 - 1]).getNotBefore();
                        if (var17.before(var21) && var17.after(var22)) {
                           Trace.msgSecurityPrintln("trustdecider.check.timestamping.valid");
                           boolean var23 = checkTSAPath(var20, var11);
                           if (var23) {
                              var9 = false;
                           } else {
                              var17 = null;
                           }
                        } else {
                           Trace.msgSecurityPrintln("trustdecider.check.timestamping.invalid");
                        }
                     } else {
                        Trace.msgSecurityPrintln("trustdecider.check.timestamping.noneed");
                     }
                  } else {
                     Trace.msgSecurityPrintln("trustdecider.check.timestamping.no");
                  }
               } catch (NoSuchMethodError var27) {
                  Trace.msgSecurityPrintln("trustdecider.check.timestamping.notfound");
               }

               int var39 = TrustDeciderDialog.showDialog(var2, var0.getLocation(), var3, var4, var35, var9, var17, var1, false);
               if (var39 == 0) {
                  Trace.msgSecurityPrintln("trustdecider.user.grant.session");
                  sessionStore.add(var2[var3]);
                  sessionStore.save();
                  var10 = true;
               } else if (var39 == 2) {
                  Trace.msgSecurityPrintln("trustdecider.user.grant.forever");
                  permanentStore.add(var2[var3]);
                  permanentStore.save();
                  var10 = true;
               } else {
                  Trace.msgSecurityPrintln("trustdecider.user.deny");
                  deniedStore.add(var2[var3]);
                  deniedStore.save();
               }

               if (var10) {
                  return true;
               }
            }

            var3 = var4;
         }

         return false;
      }
   }

   private static boolean checkTSAPath(CertPath var0, Date var1) {
      Trace.msgSecurityPrintln("trustdecider.check.timestamping.tsapath");

      try {
         List var2 = var0.getCertificates();
         Object[] var3 = var2.toArray();
         int var4 = var3.length;
         Certificate[] var5 = new Certificate[var4];

         for (int var6 = 0; var6 < var4; var6++) {
            var5[var6] = (Certificate)var3[var6];
         }

         var5 = canonicalize(var5, var1);
         int var15 = var5.length;
         Certificate var7 = var5[var15 - 1];
         if (rootStore.verify(var7) || browserRootStore != null && browserRootStore.verify(var7)) {
            Trace.msgSecurityPrintln("trustdecider.check.timestamping.inca");

            for (int var8 = 0; var8 < var15 - 1; var8++) {
               X509Certificate var9 = (X509Certificate)var5[var8];
               X509Certificate var10 = (X509Certificate)var5[var8 + 1];

               try {
                  CertUtils.checkUsageForCodeSigning(var9, var8, true);
                  var9.verify(var10.getPublicKey());
               } catch (GeneralSecurityException var12) {
                  Trace.msgSecurityPrintln("trustdecider.check.signature");
                  return false;
               }
            }

            return true;
         } else {
            Trace.msgSecurityPrintln("trustdecider.check.timestamping.notinca");
            return false;
         }
      } catch (Exception var13) {
         return false;
      }
   }

   private static synchronized void getCertMap(KeyStore var0, KeyStore var1) throws KeyStoreException {
      trustedPrincipals = new HashMap();
      if (var0 != null) {
         Enumeration var2 = var0.aliases();

         while (var2.hasMoreElements()) {
            String var3 = (String)var2.nextElement();
            if (var0.isCertificateEntry(var3)) {
               Certificate var4 = var0.getCertificate(var3);
               if (var4 instanceof X509Certificate) {
                  addTrustedCert((X509Certificate)var4);
               }
            }
         }
      }

      if (var1 != null) {
         Enumeration var5 = var1.aliases();

         while (var5.hasMoreElements()) {
            String var6 = (String)var5.nextElement();
            if (var1.isCertificateEntry(var6)) {
               Certificate var7 = var1.getCertificate(var6);
               if (var7 instanceof X509Certificate) {
                  addTrustedCert((X509Certificate)var7);
               }
            }
         }
      }
   }

   private static void addTrustedCert(X509Certificate var0) {
      Principal var1 = X509Util.getSubjectPrincipal(var0);
      Object var2 = (Collection)trustedPrincipals.get(var1);
      if (var2 == null) {
         var2 = new ArrayList();
         trustedPrincipals.put(var1, var2);
      }

      var2.add(var0);
   }

   private static Certificate[] canonicalize(Certificate[] var0, Date var1) throws CertificateException {
      ArrayList var2 = new ArrayList(var0.length);
      boolean var3 = false;
      if (var0.length == 0) {
         return var0;
      } else {
         for (int var4 = 0; var4 < var0.length; var4++) {
            X509Certificate var5 = (X509Certificate)var0[var4];
            X509Certificate var6 = getTrustedCertificate(var5, var1);
            if (var6 != null) {
               Trace.msgSecurityPrintln("trustdecider.check.canonicalize.updatecert");
               var5 = var6;
               var3 = true;
            }

            var2.add(var5);
            Principal var7 = X509Util.getSubjectPrincipal(var0[var4]);
            Principal var8 = X509Util.getIssuerPrincipal(var0[var4]);
            Principal var9 = null;
            if (var4 < var0.length - 1) {
               var9 = X509Util.getSubjectPrincipal(var0[var4 + 1]);
            }

            if (!var8.equals(var7) && !var8.equals(var9)) {
               X509Certificate var10 = getTrustedIssuerCertificate((X509Certificate)var0[var4], var1);
               if (var10 != null) {
                  Trace.msgSecurityPrintln("trustdecider.check.canonicalize.missing");
                  var3 = true;
                  var2.add(var10);
               }
            }
         }

         return var3 ? var2.toArray(new Certificate[var2.size()]) : var0;
      }
   }

   private static X509Certificate getTrustedCertificate(X509Certificate var0, Date var1) {
      Principal var2 = X509Util.getSubjectPrincipal(var0);
      List var3 = (List)trustedPrincipals.get(var2);
      if (var3 == null) {
         return null;
      } else {
         Principal var4 = X509Util.getIssuerPrincipal(var0);
         PublicKey var5 = var0.getPublicKey();
         Iterator var6 = var3.iterator();

         X509Certificate var7;
         while (true) {
            if (!var6.hasNext()) {
               return null;
            }

            var7 = (X509Certificate)var6.next();
            if (!var7.equals(var0) && X509Util.getIssuerPrincipal(var7).equals(var4) && var7.getPublicKey().equals(var5)) {
               try {
                  var7.checkValidity(var1);
                  break;
               } catch (Exception var9) {
               }
            }
         }

         Trace.msgSecurityPrintln("trustdecider.check.gettrustedcert.find");
         return var7;
      }
   }

   private static X509Certificate getTrustedIssuerCertificate(X509Certificate var0, Date var1) {
      Principal var2 = X509Util.getIssuerPrincipal(var0);
      List var3 = (List)trustedPrincipals.get(var2);
      if (var3 == null) {
         return null;
      } else {
         for (X509Certificate var5 : var3) {
            try {
               var5.checkValidity(var1);
            } catch (Exception var7) {
               continue;
            }

            Trace.msgSecurityPrintln("trustdecider.check.gettrustedissuercert.find");
            return var5;
         }

         return null;
      }
   }

   public static boolean isSigner(Certificate var0, Certificate var1) {
      try {
         var0.verify(var1.getPublicKey());
         return true;
      } catch (Exception var3) {
         return false;
      }
   }

   static {
      reset();
   }
}
