package com.sun.deploy.security;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.services.Service;
import com.sun.deploy.services.ServiceManager;
import com.sun.deploy.util.DeploySysRun;
import com.sun.deploy.util.DialogFactory;
import com.sun.deploy.util.Trace;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.Socket;
import java.security.AccessController;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.Principal;
import java.security.PrivateKey;
import java.security.PrivilegedActionException;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.HashMap;
import javax.net.ssl.KeyManager;
import javax.net.ssl.KeyManagerFactory;
import javax.net.ssl.SSLEngine;
import javax.net.ssl.X509KeyManager;
import javax.swing.JButton;
import javax.swing.JPasswordField;

public final class X509DeployKeyManager implements X509KeyManager {
   private X509KeyManager myKeyManager = null;
   private X509KeyManager browserKeyManager = null;
   private String mykeyStore = null;
   private KeyStore browserKeyStore = null;
   private boolean isWindows = Config.getOSName().indexOf("Windows") != -1;
   private static ThreadLocal clientCertDialogCancelled = new X509DeployKeyManager$1();
   private static ThreadLocal passwdDialogCancelled = new X509DeployKeyManager$2();

   public X509DeployKeyManager() {
      this.mykeyStore = Config.getUserClientAuthCertFile();
      if (Config.getBooleanProperty("deployment.security.browser.keystore.use")) {
         Service var1 = ServiceManager.getService();
         this.browserKeyStore = var1.getBrowserClientAuthKeyStore();
      }
   }

   private void init() throws KeyStoreException, NoSuchAlgorithmException, NoSuchProviderException, FileNotFoundException, IOException, UnrecoverableKeyException, CertificateException {
      try {
         AccessController.doPrivileged(new X509DeployKeyManager$3(this));
      } catch (PrivilegedActionException var3) {
         Exception var2 = var3.getException();
         if (var2 instanceof KeyStoreException) {
            throw (KeyStoreException)var2;
         }

         if (var2 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var2;
         }

         if (var2 instanceof NoSuchProviderException) {
            throw (NoSuchProviderException)var2;
         }

         if (var2 instanceof FileNotFoundException) {
            throw (FileNotFoundException)var2;
         }

         if (var2 instanceof IOException) {
            throw (IOException)var2;
         }

         if (var2 instanceof UnrecoverableKeyException) {
            throw (UnrecoverableKeyException)var2;
         }

         if (var2 instanceof CertificateException) {
            throw (CertificateException)var2;
         }

         Trace.securityPrintException(var3);
      }
   }

   private void do_init() throws KeyStoreException, NoSuchAlgorithmException, NoSuchProviderException, FileNotFoundException, IOException, UnrecoverableKeyException, CertificateException {
      if (this.browserKeyStore != null) {
         this.browserKeyStore.load(null, new char[0]);
         KeyManagerFactory var1 = KeyManagerFactory.getInstance("SunX509", "SunJSSE");
         var1.init(this.browserKeyStore, new char[0]);
         KeyManager[] var2 = var1.getKeyManagers();

         for (int var3 = 0; var3 < var2.length; var3++) {
            if (var2[var3] instanceof X509KeyManager) {
               this.browserKeyManager = (X509KeyManager)var2[var3];
               break;
            }
         }
      }

      File var10 = new File(this.mykeyStore);
      if (var10.exists()) {
         boolean var11 = true;

         while (var11) {
            try {
               char[] var12 = this.getPasswordDialog("clientauth.password.dialog.text");
               if (passwdDialogCancelled.get() == Boolean.TRUE) {
                  break;
               }

               String var13 = System.getProperty("javax.net.ssl.keyStoreType");
               if (var13 == null) {
                  var13 = "JKS";
               }

               KeyStore var14 = KeyStore.getInstance(var13);
               var14.load(new BufferedInputStream(new FileInputStream(this.mykeyStore)), var12);
               KeyManagerFactory var6 = KeyManagerFactory.getInstance("SunX509", "SunJSSE");
               var6.init(var14, var12);
               KeyManager[] var7 = var6.getKeyManagers();
               int var8 = 0;

               while (true) {
                  if (var8 < var7.length) {
                     if (!(var7[var8] instanceof X509KeyManager)) {
                        var8++;
                        continue;
                     }

                     this.myKeyManager = (X509KeyManager)var7[var8];
                  }

                  var11 = false;
                  break;
               }
            } catch (IOException var9) {
               var9.printStackTrace();
               if (!Trace.isAutomationEnabled()) {
                  String var4 = getMessage("clientauth.password.dialog.error.text");
                  String var5 = getMessage("clientauth.password.dialog.error.caption");
                  DialogFactory.showExceptionDialog(null, var9, var4, var5);
               }
            }
         }
      }
   }

   public synchronized String chooseClientAlias(String[] var1, Principal[] var2, Socket var3) {
      HashMap var4 = new HashMap();
      HashMap var5 = new HashMap();
      String var6 = null;
      if (clientCertDialogCancelled.get() != Boolean.FALSE) {
         return null;
      } else {
         for (int var7 = 0; var7 < var1.length; var7++) {
            String[] var8 = this.getClientAliases(var1[var7], var2);
            if (var8 != null && var8.length > 0) {
               for (int var9 = 0; var9 < var8.length; var9++) {
                  int var10 = CertType.PLUGIN.getType().length();
                  String var11 = var8[var9].substring(var10);
                  X509Certificate[] var12 = this.getCertificateChain(var11);
                  var4.put(var11, var12);
                  if (var8[var9].startsWith(CertType.PLUGIN.getType())) {
                     var5.put(var11, CertType.PLUGIN);
                  }

                  if (var8[var9].startsWith(CertType.BROWSER.getType())) {
                     var5.put(var11, CertType.BROWSER);
                  }
               }
            }
         }

         if (Config.getBooleanProperty("deployment.security.clientauth.keystore.auto") && var4.size() == 1) {
            Object[] var14 = var4.keySet().toArray();
            var6 = (String)var14[0];
         } else {
            var6 = AccessController.doPrivileged(new X509DeployKeyManager$4(this, var4, var5));
         }

         if (var6 == null) {
            clientCertDialogCancelled.set(Boolean.TRUE);
         }

         return var6;
      }
   }

   public String chooseEngineClientAlias(String[] var1, Principal[] var2, SSLEngine var3) {
      return this.chooseClientAlias(var1, var2, null);
   }

   public synchronized String chooseServerAlias(String var1, Principal[] var2, Socket var3) {
      try {
         if (this.myKeyManager == null && this.browserKeyManager == null && passwdDialogCancelled.get() == Boolean.FALSE) {
            this.init();
         }
      } catch (Exception var5) {
         var5.printStackTrace();
      }

      String var4 = null;
      if (this.myKeyManager != null) {
         var4 = this.myKeyManager.chooseServerAlias(var1, var2, var3);
      }

      if (var4 == null && this.browserKeyManager != null) {
         var4 = this.browserKeyManager.chooseServerAlias(var1, var2, var3);
      }

      return var4;
   }

   public String chooseEngineServerAlias(String var1, Principal[] var2, SSLEngine var3) {
      return this.chooseServerAlias(var1, var2, null);
   }

   public synchronized X509Certificate[] getCertificateChain(String var1) {
      try {
         if (this.myKeyManager == null && this.browserKeyManager == null && passwdDialogCancelled.get() == Boolean.FALSE) {
            this.init();
         }
      } catch (Exception var3) {
         var3.printStackTrace();
      }

      X509Certificate[] var2 = null;
      if (this.myKeyManager != null) {
         var2 = this.myKeyManager.getCertificateChain(var1);
      }

      if (var2 == null && this.browserKeyManager != null) {
         var2 = this.browserKeyManager.getCertificateChain(var1);
      }

      return var2;
   }

   public synchronized String[] getClientAliases(String var1, Principal[] var2) {
      try {
         if (this.myKeyManager == null && this.browserKeyManager == null && passwdDialogCancelled.get() == Boolean.FALSE) {
            this.init();
         }
      } catch (Exception var6) {
         var6.printStackTrace();
      }

      String[] var3 = null;
      String[] var4 = null;
      if (this.myKeyManager != null) {
         var3 = this.myKeyManager.getClientAliases(var1, var2);
      }

      if (this.browserKeyManager != null) {
         var4 = this.browserKeyManager.getClientAliases(var1, var2);
      }

      if (var3 == null) {
         if (var4 != null) {
            for (int var10 = 0; var10 < var4.length; var10++) {
               var4[var10] = CertType.BROWSER.getType() + var4[var10];
            }
         }

         return var4;
      } else if (var4 == null) {
         if (var3 != null) {
            for (int var9 = 0; var9 < var3.length; var9++) {
               var3[var9] = CertType.PLUGIN.getType() + var3[var9];
            }
         }

         return var3;
      } else {
         for (int var5 = 0; var5 < var3.length; var5++) {
            var3[var5] = CertType.PLUGIN.getType() + var3[var5];
         }

         for (int var7 = 0; var7 < var4.length; var7++) {
            var4[var7] = CertType.BROWSER.getType() + var4[var7];
         }

         String[] var8 = new String[var3.length + var4.length];
         System.arraycopy(var3, 0, var8, 0, var3.length);
         System.arraycopy(var4, 0, var8, var3.length, var4.length);
         return var8;
      }
   }

   public synchronized String[] getServerAliases(String var1, Principal[] var2) {
      try {
         if (this.myKeyManager == null && this.browserKeyManager == null && passwdDialogCancelled.get() == Boolean.FALSE) {
            this.init();
         }
      } catch (Exception var6) {
         var6.printStackTrace();
      }

      String[] var3 = null;
      String[] var4 = null;
      if (this.myKeyManager != null) {
         var3 = this.myKeyManager.getServerAliases(var1, var2);
      }

      if (this.browserKeyManager != null) {
         var4 = this.browserKeyManager.getServerAliases(var1, var2);
      }

      if (var3 == null) {
         return var4;
      } else if (var4 == null) {
         return var3;
      } else {
         String[] var5 = new String[var3.length + var4.length];
         System.arraycopy(var3, 0, var5, 0, var3.length);
         System.arraycopy(var4, 0, var5, var3.length, var4.length);
         return var5;
      }
   }

   public PrivateKey getPrivateKey(String var1) {
      try {
         if (this.myKeyManager == null && this.browserKeyManager == null && passwdDialogCancelled.get() == Boolean.FALSE) {
            this.init();
         }
      } catch (Exception var3) {
         var3.printStackTrace();
      }

      PrivateKey var2 = null;
      if (this.myKeyManager != null) {
         var2 = this.myKeyManager.getPrivateKey(var1);
      }

      if (var2 == null && this.browserKeyManager != null) {
         var2 = this.browserKeyManager.getPrivateKey(var1);
      }

      return var2;
   }

   private char[] getPasswordDialog(String var1) {
      try {
         char[] var2 = (char[])DeploySysRun.execute(new X509DeployKeyManager$5(this, var1));
         if (var2 == null) {
            passwdDialogCancelled.set(Boolean.TRUE);
         }

         return var2;
      } catch (Exception var3) {
         Trace.ignoredException(var3);
         return null;
      }
   }

   private char[] getPasswordDialogImp(String var1) {
      String var2 = getMessage(var1);
      JPasswordField var3 = new JPasswordField();
      Object[] var4 = new Object[]{var2.toString(), var3};
      JButton var5 = new JButton(getMessage("clientauth.password.dialog.buttonOK"));
      JButton var6 = new JButton(getMessage("clientauth.password.dialog.buttonCancel"));
      String var7 = getMessage("clientauth.password.dialog.caption");
      Object[] var8 = new Object[]{var5, var6};
      int var9 = DialogFactory.showOptionDialog(4, var4, var7, var8, var8[0]);
      char[] var10 = var3.getPassword();
      return var9 == 0 ? var10 : null;
   }

   private static String getMessage(String var0) {
      return ResourceManager.getMessage(var0);
   }

   private static int getAcceleratorKey(String var0) {
      return ResourceManager.getAcceleratorKey(var0);
   }
}
