package com.sun.deploy.security;

import com.sun.deploy.config.Config;
import com.sun.deploy.services.Service;
import com.sun.deploy.services.ServiceManager;
import com.sun.deploy.ui.AppInfo;
import com.sun.deploy.util.Trace;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.X509Certificate;
import javax.net.ssl.TrustManager;
import javax.net.ssl.TrustManagerFactory;
import javax.net.ssl.X509TrustManager;

public final class X509DeployTrustManager implements X509TrustManager {
   private X509TrustManager trustManager = null;
   private static CertStore rootStore = null;
   private static CertStore sslRootStore = null;
   private static CertStore permanentStore = null;
   private static CertStore sessionStore = null;
   private static CertStore deniedStore = null;
   private static CertStore browserSSLRootStore = null;
   private static boolean isBrowserSSLRootStoreLoaded = false;

   public static void reset() {
      rootStore = RootCertStore.getInstance();
      sslRootStore = new SSLRootCertStore();
      permanentStore = new DeploySSLCertStore();
      sessionStore = new SessionCertStore();
      deniedStore = new DeniedCertStore();
      if (Config.getBooleanProperty("deployment.security.browser.keystore.use")) {
         Service var0 = ServiceManager.getService();
         browserSSLRootStore = var0.getBrowserSSLRootCertStore();
         isBrowserSSLRootStoreLoaded = false;
      }
   }

   public X509DeployTrustManager() throws KeyStoreException, NoSuchAlgorithmException, NoSuchProviderException, CertificateException {
      TrustManagerFactory var1 = TrustManagerFactory.getInstance("SunX509", "SunJSSE");
      var1.init((KeyStore)null);
      TrustManager[] var2 = var1.getTrustManagers();
      this.trustManager = (X509TrustManager)var2[0];
   }

   public synchronized void checkClientTrusted(X509Certificate[] var1, String var2) throws CertificateException {
      boolean var3 = false;
      boolean var4 = false;
      if (this.trustManager == null) {
         throw new IllegalStateException("TrustManager should not be null");
      } else {
         int var5 = 1;

         try {
            rootStore.load();
            sslRootStore.load();
            permanentStore.load();
            sessionStore.load();
            deniedStore.load();
            if (browserSSLRootStore != null && !isBrowserSSLRootStoreLoaded) {
               browserSSLRootStore.load();
               isBrowserSSLRootStoreLoaded = true;
            }

            if (deniedStore.contains(var1[0])) {
               throw new CertificateException("Certificate has been denied");
            }

            try {
               this.trustManager.checkClientTrusted(var1, var2);
               return;
            } catch (CertificateException var10) {
               if (sessionStore.contains(var1[0])) {
                  return;
               }

               if (permanentStore.contains(var1[0])) {
                  return;
               }

               for (int var6 = 0; var6 < var1.length; var6++) {
                  if (!rootStore.verify(var1[var6])
                     && !sslRootStore.verify(var1[var6])
                     && (browserSSLRootStore == null || !browserSSLRootStore.verify(var1[var6]))) {
                     var3 = true;
                  }

                  try {
                     var1[var6].checkValidity();
                  } catch (CertificateExpiredException var8) {
                     var4 = true;
                  } catch (CertificateNotYetValidException var9) {
                     var4 = true;
                  }
               }

               if (!Trace.isAutomationEnabled()) {
                  var5 = TrustDeciderDialog.showDialog(var1, null, 0, var1.length, var3, var4, null, new AppInfo(), true);
               } else {
                  Trace.msgSecurityPrintln("x509trustmgr.automation.ignoreclientcert");
                  var5 = 0;
               }

               if (var5 == 0) {
                  sessionStore.add(var1[0]);
                  sessionStore.save();
               } else if (var5 == 2) {
                  permanentStore.add(var1[0]);
                  permanentStore.save();
               } else {
                  deniedStore.add(var1[0]);
                  deniedStore.save();
               }
            }
         } catch (CertificateException var11) {
            throw var11;
         } catch (Throwable var12) {
            var12.printStackTrace();
         }

         if (var5 != 0 && var5 != 2) {
            throw new CertificateException("Java couldn't trust Client");
         }
      }
   }

   public synchronized void checkServerTrusted(X509Certificate[] var1, String var2) throws CertificateException {
      boolean var3 = false;
      boolean var4 = false;
      if (this.trustManager == null) {
         throw new IllegalStateException("TrustManager should not be null");
      } else {
         int var5 = 1;

         try {
            rootStore.load();
            sslRootStore.load();
            permanentStore.load();
            sessionStore.load();
            deniedStore.load();
            if (browserSSLRootStore != null && !isBrowserSSLRootStoreLoaded) {
               browserSSLRootStore.load();
               isBrowserSSLRootStoreLoaded = true;
            }

            if (deniedStore.contains(var1[0])) {
               throw new CertificateException("Certificate has been denied");
            }

            try {
               this.trustManager.checkServerTrusted(var1, var2);
               return;
            } catch (CertificateException var10) {
               if (sessionStore.contains(var1[0])) {
                  return;
               }

               if (permanentStore.contains(var1[0])) {
                  return;
               }

               for (int var6 = 0; var6 < var1.length; var6++) {
                  if (!rootStore.verify(var1[var6])
                     && !sslRootStore.verify(var1[var6])
                     && (browserSSLRootStore == null || !browserSSLRootStore.verify(var1[var6]))) {
                     var3 = true;
                  }

                  try {
                     var1[var6].checkValidity();
                  } catch (CertificateExpiredException var8) {
                     var4 = true;
                  } catch (CertificateNotYetValidException var9) {
                     var4 = true;
                  }
               }

               if (!Trace.isAutomationEnabled()) {
                  var5 = TrustDeciderDialog.showDialog(var1, null, 0, var1.length, var3, var4, null, new AppInfo(), true);
               } else {
                  Trace.msgSecurityPrintln("x509trustmgr.automation.ignoreservercert");
                  var5 = 0;
               }

               if (var5 == 0) {
                  sessionStore.add(var1[0]);
                  sessionStore.save();
               } else if (var5 == 2) {
                  permanentStore.add(var1[0]);
                  permanentStore.save();
               } else {
                  deniedStore.add(var1[0]);
                  deniedStore.save();
               }
            }
         } catch (CertificateException var11) {
            throw var11;
         } catch (Throwable var12) {
            var12.printStackTrace();
         }

         if (var5 != 0 && var5 != 2) {
            throw new CertificateException("Java couldn't trust Server");
         }
      }
   }

   public X509Certificate[] getAcceptedIssuers() {
      return this.trustManager.getAcceptedIssuers();
   }

   static {
      reset();
   }
}
