package com.sun.deploy.si;

import com.sun.deploy.config.Config;
import com.sun.deploy.util.Trace;
import com.sun.deploy.util.TraceLevel;
import java.io.File;
import java.io.IOException;
import java.net.InetAddress;
import java.net.ServerSocket;
import java.security.AccessController;
import java.util.ArrayList;

public class SingleInstanceImpl {
   public static final String SI_FILEDIR = Config.getTempDirectory() + File.separator + "si" + File.separator;
   public static final String SI_MAGICWORD = "javaws.singleinstance.init";
   public static final String SI_MAGICWORD_OPENPRINT = "javaws.singleinstance.init.openprint";
   public static final String SI_ACK = "javaws.singleinstance.ack";
   public static final String SI_STOP = "javaws.singleinstance.stop";
   public static final String SI_EOF = "EOF";
   private ArrayList _sil_list = new ArrayList();
   private static boolean _serverStarted = false;
   private Object _lock = new Object();
   private SingleInstanceImpl.SingleInstanceServer _sis;
   private static int DEFAULT_FILESIZE = Integer.MAX_VALUE;

   public static String getSingleInstanceFilePrefix(String var0) {
      String var1 = var0.replace('/', '_');
      return var1.replace(':', '_');
   }

   public void addSingleInstanceListener(DeploySIListener var1, String var2) {
      if (var1 != null) {
         synchronized (this._lock) {
            if (!_serverStarted) {
               Trace.println("unique id: " + var2, TraceLevel.BASIC);

               try {
                  this._sis = new SingleInstanceImpl.SingleInstanceServer(var2, this);
               } catch (Exception var8) {
                  Trace.println("addSingleInstanceListener failed", TraceLevel.BASIC);
                  Trace.ignoredException(var8);
                  return;
               }

               _serverStarted = true;
            }
         }

         synchronized (this._sil_list) {
            if (!this._sil_list.contains(var1)) {
               this._sil_list.add(var1);
            }
         }
      }
   }

   public boolean isSame(String var1, String var2) {
      return true;
   }

   public String[] getArguments(String var1, String var2) {
      return new String[]{var1};
   }

   public void removeSingleInstanceListener(DeploySIListener var1) {
      synchronized (this._sil_list) {
         Object var3 = var1.getSingleInstanceListener();
         Object var4 = null;
         int var5 = -1;

         for (int var6 = 0; var6 < this._sil_list.size(); var6++) {
            var4 = ((DeploySIListener)this._sil_list.get(var6)).getSingleInstanceListener();
            if (var4.equals(var3)) {
               var5 = var6;
               break;
            }
         }

         if (var5 >= 0 && var5 < this._sil_list.size()) {
            this._sil_list.remove(var5);
            if (this._sil_list.isEmpty()) {
               AccessController.doPrivileged(new SingleInstanceImpl$1(this));
            }
         }
      }
   }

   class SingleInstanceServer extends Thread {
      ServerSocket _ss;
      int _port;
      String _idString;
      String[] _arguments;
      SingleInstanceImpl _impl;

      int getPort() {
         return this._port;
      }

      SingleInstanceServer(String var2, SingleInstanceImpl var3) throws IOException {
         this._idString = var2;
         this._impl = var3;
         this._ss = null;
         this._ss = new ServerSocket(0, 0, InetAddress.getByName("127.0.0.1"));
         this._port = this._ss.getLocalPort();
         Trace.println("server port at: " + this._port, TraceLevel.BASIC);
         this.start();
         this.createSingleInstanceFile(this._idString, this._port);
      }

      private String getSingleInstanceFilename(String var1, int var2) {
         String var3 = SingleInstanceImpl.SI_FILEDIR + SingleInstanceImpl.getSingleInstanceFilePrefix(var1) + "_" + var2;
         Trace.println("getSingleInstanceFilename: " + var3, TraceLevel.BASIC);
         return var3;
      }

      private void removeSingleInstanceFile(String var1, int var2) {
         new File(this.getSingleInstanceFilename(var1, var2)).delete();
         Trace.println("removed SingleInstanceFile: " + this.getSingleInstanceFilename(var1, var2), TraceLevel.BASIC);
      }

      private void createSingleInstanceFile(String var1, int var2) {
         String var3 = this.getSingleInstanceFilename(var1, var2);
         File var4 = new File(var3);
         File var5 = new File(SingleInstanceImpl.SI_FILEDIR);
         AccessController.doPrivileged(new SingleInstanceImpl$SingleInstanceServer$1(this, var5, var1, var4));
      }

      boolean isSameInstance(String var1) {
         if (this._impl.isSame(var1, this._idString)) {
            this._arguments = this._impl.getArguments(var1, this._idString);
            return true;
         } else {
            return false;
         }
      }

      public void run() {
         AccessController.doPrivileged(new SingleInstanceImpl$SingleInstanceServer$2(this));
      }
   }
}
