package com.sun.deploy.ui;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.security.CertificateDialog;
import com.sun.deploy.util.DialogListener;
import com.sun.deploy.util.Trace;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Cursor;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.net.URL;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.HashMap;
import java.util.Iterator;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextArea;
import javax.swing.KeyStroke;
import javax.swing.SwingUtilities;

public class DialogTemplate implements ActionListener {
   private JDialog dialog = null;
   private AppInfo ainfo = null;
   private String topText = null;
   private String appTitle = null;
   private String appPublisher = null;
   private URL appURL = null;
   private Frame dummyFrame = null;
   private boolean useErrorIcon = false;
   private boolean useSevereWarningIcon = false;
   private boolean useWarningIcon = false;
   private boolean useInfoIcon = false;
   private JPanel topPanel;
   private JPanel centerPanel;
   private JPanel bottomPanel;
   private JLabel topIcon;
   private JLabel securityIcon;
   private JLabel nameInfo;
   private JLabel publisherInfo;
   private JLabel urlInfo;
   private JButton okBtn;
   private JButton cancelBtn;
   private JCheckBox always;
   private UITextArea masthead = null;
   private static final int ICON_SIZE = 48;
   private int userAnswer = -1;
   private final int DIALOG_WIDTH = 510;
   private final int MAX_LARGE_SCROLL_WIDTH = 600;
   private final Color BG = Color.white;
   private final String SECURITY_ALERT_HIGH = "com/sun/deploy/resources/image/security_high.png";
   private final String SECURITY_ALERT_LOW = "com/sun/deploy/resources/image/security_low.png";
   private static int MAIN_TEXT_WIDTH = 426;
   private final String OK_ACTION = "OK";
   private final int MAX_BUTTONS = 2;
   private int start;
   private int end;
   private Certificate[] certs;
   private String[] alertStrs;
   private String[] infoStrs;
   private int securityInfoCount;
   private Color originalColor;
   private Cursor handCursor = new Cursor(12);
   private Cursor originalCursor = null;
   private String contentString = null;
   private String contentLabel = null;
   private String alwaysString = null;
   private boolean contentScroll = false;
   private boolean includeMasthead = true;
   private boolean includeAppInfo = true;
   private boolean largeScroll = false;
   private Throwable throwable = null;
   private JPanel detailPanel = null;
   private JList scrollList;
   private boolean showDetails = false;
   HashMap clientAuthCertsMap;
   int minFontSize = ResourceManager.getMinFontSize();

   DialogTemplate(AppInfo var1, Component var2, String var3, String var4) {
      Component var5 = this.deriveParent(var2, var3);
      if (var5 instanceof Dialog) {
         this.dialog = new JDialog((Dialog)var5, true);
      } else {
         this.dialog = new JDialog((Frame)var5, true);
      }

      this.dialog.setTitle(var3);
      this.ainfo = var1;
      this.topText = var4;
      this.appTitle = var1.getTitle();
      this.appPublisher = var1.getVendor();
      this.appURL = var1.getFrom();
   }

   void setSecurityContent(
      boolean var1,
      boolean var2,
      String var3,
      String var4,
      String[] var5,
      String[] var6,
      int var7,
      boolean var8,
      Certificate[] var9,
      int var10,
      int var11,
      boolean var12
   ) {
      this.certs = var9;
      this.start = var10;
      this.end = var11;
      this.alertStrs = var5;
      this.infoStrs = var6;
      this.securityInfoCount = var7;
      if (var5 != null && var5.length > 0) {
         this.useWarningIcon = true;
         if (var12) {
            this.useSevereWarningIcon = true;
         }
      }

      try {
         this.dialog.getContentPane().setLayout(new BorderLayout());
         this.dialog.getContentPane().add(this.createTopPanel(), "North");
         if (var1) {
            this.alwaysString = ResourceManager.getString("security.dialog.always");
         }

         this.dialog.getContentPane().add(this.createCenterPanel(var2, var3, var4), "Center");
         this.dialog.getContentPane().add(this.createBottomPanel(var8), "South");
         this.dialog.pack();
         this.dialog.setResizable(false);
      } catch (Throwable var14) {
         Trace.ignored(var14);
      }
   }

   void setSimpleContent(String var1, boolean var2, String var3, String var4, String var5, boolean var6, boolean var7) {
      this.contentString = var1;
      this.contentScroll = var2;
      this.throwable = this.throwable;
      this.detailPanel = this.detailPanel;
      this.includeMasthead = var6;
      this.includeAppInfo = var6;
      this.largeScroll = !var6;
      this.useWarningIcon = var7;
      if (var3 != null) {
         String[] var8 = new String[]{var3};
         if (var7) {
            this.alertStrs = var8;
         } else {
            this.infoStrs = var8;
         }
      }

      try {
         this.dialog.getContentPane().setLayout(new BorderLayout());
         this.dialog.getContentPane().add(this.createTopPanel(), "North");
         this.dialog.getContentPane().add(this.createCenterPanel(false, var4, var5), "Center");
         this.dialog.getContentPane().add(this.createBottomPanel(false), "South");
         this.dialog.pack();
         this.dialog.setResizable(var2);
      } catch (Throwable var9) {
         Trace.ignored(var9);
      }
   }

   private JPanel createTopPanel() {
      this.topPanel = new JPanel();
      this.topPanel.setBackground(this.BG);
      GridBagLayout var1 = new GridBagLayout();
      GridBagConstraints var2 = new GridBagConstraints();
      this.topPanel.setLayout(var1);
      int var3 = ResourceManager.getUIFont().getSize() + 4;
      this.masthead = new UITextArea(var3, MAIN_TEXT_WIDTH, true);
      this.masthead.setText(this.topText);
      Dimension var4 = this.masthead.getPreferredSize();
      this.masthead.setSize(var4.width, var4.height);
      this.masthead.setBorder(BorderFactory.createEmptyBorder(6, 12, 6, 6));
      if (this.includeMasthead) {
         var2.fill = 2;
         var2.gridwidth = -1;
         var2.anchor = 17;
         var1.setConstraints(this.masthead, var2);
         this.topPanel.add(this.masthead);
         this.topPanel.setBackground(Color.white);
         this.topPanel.setForeground(Color.white);
         this.topPanel.setOpaque(true);
         this.topIcon = new JLabel();
         this.topIcon.setHorizontalAlignment(0);
         this.topIcon.setBorder(BorderFactory.createEmptyBorder(6, 6, 6, 12));
         ImageIcon var5 = ResourceManager.getIcon("java48.image");
         if (this.useErrorIcon) {
            var5 = ResourceManager.getIcon("error48.image");
         }

         if (this.useInfoIcon) {
            var5 = ResourceManager.getIcon("info48.image");
         }

         this.topIcon.setIcon(var5);
         if (this.useWarningIcon) {
            if (this.useSevereWarningIcon) {
               var5 = ResourceManager.getIcon("major-warning48.image");
            } else {
               var5 = ResourceManager.getIcon("warning48.image");
            }

            this.topIcon.setIcon(var5);
         } else if (this.ainfo.getIconRef() != null) {
         }

         var2.fill = 0;
         var2.gridwidth = 0;
         var2.anchor = 13;
         var1.setConstraints(this.topIcon, var2);
         this.topPanel.add(this.topIcon);
      }

      JSeparator var7 = new JSeparator();
      var7.setPreferredSize(new Dimension(510, 1));
      var2.gridy = 1;
      var2.gridwidth = 0;
      var1.setConstraints(var7, var2);
      this.topPanel.add(var7);
      return this.topPanel;
   }

   private JPanel createCenterPanel(boolean var1, String var2, String var3) {
      this.centerPanel = new JPanel();
      this.centerPanel.setLayout(new BoxLayout(this.centerPanel, 1));
      this.centerPanel.setBorder(BorderFactory.createEmptyBorder(24, 24, 12, 12));
      this.centerPanel.setAlignmentX(1.0F);
      JPanel var4 = new JPanel();
      var4.setLayout(new BoxLayout(var4, 1));
      var4.setAlignmentX(0.0F);
      JLabel var5 = new JLabel(ResourceManager.getMessage("dialog.template.name"));
      Font var6 = var5.getFont().deriveFont(1);
      Font var7 = var5.getFont().deriveFont(0);
      var5.setFont(var6);
      JLabel var8 = new JLabel(ResourceManager.getMessage("dialog.template.publisher"));
      var8.setFont(var6);
      JLabel var9 = new JLabel(ResourceManager.getMessage("dialog.template.from"));
      var9.setFont(var6);
      JPanel var10 = new JPanel();
      var10.setLayout(new BoxLayout(var10, 1));
      var10.setAlignmentX(0.0F);
      this.nameInfo = new JLabel();
      this.publisherInfo = new JLabel();
      this.urlInfo = new JLabel();
      this.nameInfo.setFont(var7);
      this.publisherInfo.setFont(var7);
      this.urlInfo.setFont(var7);
      if (this.appTitle != null) {
         var4.add(var5);
         var4.add(Box.createVerticalStrut(12));
         var10.add(this.nameInfo);
         var10.add(Box.createVerticalStrut(12));
      }

      if (this.appPublisher != null) {
         var4.add(var8);
         var4.add(Box.createVerticalStrut(12));
         var10.add(this.publisherInfo);
         var10.add(Box.createVerticalStrut(12));
      }

      if (this.appTitle != null && this.appURL != null) {
         var4.add(var9);
         var10.add(this.urlInfo);
      }

      this.setInfo(this.appTitle, this.appPublisher, this.appURL);
      JPanel var11 = new JPanel();
      var11.setLayout(new FlowLayout(3, 0, 0));
      var11.add(var4);
      var11.add(Box.createHorizontalStrut(12));
      var11.add(var10);
      JPanel var12 = new JPanel();
      var12.setLayout(new FlowLayout(3, 0, 0));
      JPanel var13 = new JPanel();
      var13.setLayout(new BorderLayout());
      if (this.alwaysString != null) {
         String var14 = "security.dialog.always";
         this.always = new JCheckBox(this.alwaysString);
         this.always.setMnemonic(ResourceManager.getVKCode(var14 + ".mnemonic"));
         this.always.setSelected(var1);
         this.always.setFont(var7);
         int var15 = this.always.getBorder().getBorderInsets(this.always).left;
         var4.setBorder(BorderFactory.createEmptyBorder(0, var15, 0, 0));
         var12.add(this.always);
         var12.setBorder(BorderFactory.createEmptyBorder(0, 0, 12, 0));
      }

      if (this.contentString != null) {
         if (this.contentLabel != null) {
            JPanel var19 = new JPanel(new BorderLayout());
            var19.add(new JLabel(this.contentLabel), "West");
            var13.add(var19, "North");
         }

         if (this.contentScroll) {
            boolean var25 = this.largeScroll;
            JTextArea var20;
            if (this.largeScroll) {
               var20 = new JTextArea(this.contentString, 20, 80);
            } else {
               var20 = new JTextArea(this.contentString, 4, 40);
            }

            var20.setEditable(false);
            DialogTemplate$1 var16 = new DialogTemplate$1(this, var20, 20, 30, var25);
            var13.add(var16, "Center");
         } else {
            var13.add(new UITextArea(this.contentString), "Center");
         }

         var13.setBorder(BorderFactory.createEmptyBorder(0, 0, 12, 0));
      }

      if (this.scrollList != null) {
         if (this.contentLabel != null) {
            JPanel var21 = new JPanel(new BorderLayout());
            var21.add(new JLabel(this.contentLabel), "West");
            var13.add(var21, "North");
         }

         if (this.contentScroll) {
            JScrollPane var22 = new JScrollPane(this.scrollList, 20, 30);
            var13.add(var22, "Center");
         }

         if (this.showDetails) {
            FancyButton var23 = new FancyButton("security.more.info.details", Color.blue);
            Font var26 = ResourceManager.getUIFont();
            int var28 = var26.getSize() - 1;
            if (var28 < this.minFontSize) {
               var28 = this.minFontSize;
            }

            Font var17 = new Font(var26.getName(), var26.getStyle(), var28);
            var23.setFont(var17);
            var23.addMouseListener(new DialogTemplate$2(this));
            JPanel var18 = new JPanel();
            var18.setBorder(BorderFactory.createEmptyBorder(12, 0, 12, 0));
            var18.setLayout(new FlowLayout(4, 0, 0));
            var18.add(var23);
            var18.add(Box.createGlue());
            var13.add(var18, "South");
         }
      }

      JPanel var24 = new JPanel();
      var24.setLayout(new FlowLayout(4, 0, 0));
      this.okBtn = new JButton(var2 == null ? "" : ResourceManager.getMessage(var2));
      this.okBtn.addActionListener(this);
      this.okBtn.setActionCommand("OK");
      var24.add(this.okBtn);
      this.okBtn.setVisible(var2 != null);
      this.cancelBtn = new JButton(var3 == null ? "" : ResourceManager.getMessage(var3));
      this.cancelBtn.addActionListener(this);
      var24.add(Box.createHorizontalStrut(12));
      var24.add(this.cancelBtn);
      this.cancelBtn.setVisible(var3 != null);
      if (this.okBtn.isVisible()) {
         this.dialog.getRootPane().setDefaultButton(this.okBtn);
      } else if (this.cancelBtn.isVisible()) {
         this.dialog.getRootPane().setDefaultButton(this.cancelBtn);
      }

      JButton[] var27 = new JButton[]{this.okBtn, this.cancelBtn};
      resizeButtons(var27);
      if (this.includeAppInfo) {
         this.centerPanel.add(var11);
         this.centerPanel.add(Box.createVerticalStrut(12));
      }

      if (this.alwaysString != null) {
         this.centerPanel.add(var12);
      }

      if (this.contentString != null || this.scrollList != null) {
         this.centerPanel.add(var13);
      }

      JPanel var29 = new JPanel(new BorderLayout());
      var29.add(var24, "East");
      this.centerPanel.add(var29);
      if (Config.isJavaVersionAtLeast13()) {
         this.dialog.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke(27, 0), "cancel");
         this.dialog.getRootPane().getActionMap().put("cancel", new DialogTemplate$3(this));
      }

      return this.centerPanel;
   }

   private JPanel createBottomPanel(boolean var1) {
      this.bottomPanel = new JPanel();
      this.bottomPanel.setLayout(new BorderLayout());
      if (this.alertStrs == null && this.infoStrs == null) {
         this.bottomPanel.setBorder(BorderFactory.createEmptyBorder(0, 0, 2, 0));
      } else {
         JPanel var2 = new JPanel();
         var2.setLayout(new BorderLayout());
         byte var3 = 12;
         var2.setBorder(BorderFactory.createEmptyBorder(var3, var3, var3, var3));
         JSeparator var4 = new JSeparator();
         this.securityIcon = new JLabel();
         String var5 = "com/sun/deploy/resources/image/security_high.png";
         if (this.alertStrs != null && this.alertStrs.length != 0) {
            this.dialog.getRootPane().setDefaultButton(this.cancelBtn);
         } else {
            var5 = "com/sun/deploy/resources/image/security_low.png";
            if (this.always != null) {
               this.always.setSelected(true);
            }
         }

         this.securityIcon.setIcon(new ImageIcon(ClassLoader.getSystemResource(var5)));
         Font var6 = ResourceManager.getUIFont();
         int var7 = var6.getSize() - 1;
         if (var7 < this.minFontSize) {
            var7 = this.minFontSize;
         }

         int var8 = 0;
         if (var1) {
            JPanel var9 = new JPanel();
            var9.setLayout(new BoxLayout(var9, 1));
            var9.setBorder(BorderFactory.createEmptyBorder());
            FancyButton var10 = new FancyButton("dialog.template.more.info", Color.blue);
            Font var11 = new Font(var6.getName(), var6.getStyle(), var7);
            var10.setFont(var11);
            var10.addMouseListener(new DialogTemplate$4(this));
            var10.addActionListener(new DialogTemplate$5(this));
            var9.add(Box.createVerticalGlue());
            var9.add(var10);
            var9.add(Box.createVerticalGlue());
            var2.add(var9, "East");
            var8 = var10.getPreferredSize().width;
         }

         JPanel var15 = new JPanel();
         var15.setLayout(new BoxLayout(var15, 0));
         byte var16 = 20;
         var15.setBorder(BorderFactory.createEmptyBorder(0, var16, 0, 0));
         int var17 = 510 - var3 * 2 - this.securityIcon.getPreferredSize().width - var16 - var8;
         UITextArea var12 = new UITextArea(var7, var17, false);
         if ((this.alertStrs == null || this.alertStrs.length == 0) && this.infoStrs != null && this.infoStrs.length != 0) {
            Font var18 = new JLabel().getFont().deriveFont(0);
            var12.setFont(var18);
            var12.setText(this.infoStrs[0] != null ? this.infoStrs[0] : " ");
            Dimension var14 = var12.getPreferredSize();
            var12.setSize(var14.width, var14.height);
         } else if (this.alertStrs != null && this.alertStrs.length != 0) {
            var12.setText(this.alertStrs[0] != null ? this.alertStrs[0] : " ");
            Dimension var13 = var12.getPreferredSize();
            var12.setSize(var13.width, var13.height);
         }

         var15.add(var12);
         var15.add(Box.createHorizontalStrut(6));
         var2.add(this.securityIcon, "West");
         var2.add(var15, "Center");
         this.bottomPanel.add(var4, "North");
         this.bottomPanel.add(var2, "Center");
      }

      return this.bottomPanel;
   }

   void showMoreInfo() {
      MoreInfoDialog var1;
      if (this.throwable == null && this.detailPanel == null) {
         var1 = new MoreInfoDialog(this.dialog, this.alertStrs, this.infoStrs, this.securityInfoCount, this.certs, this.start, this.end);
      } else {
         var1 = new MoreInfoDialog(this.dialog, this.detailPanel, this.throwable, this.certs);
      }

      var1.setVisible(true);
   }

   void showCertificateDetails() {
      int var1 = this.scrollList.getSelectedIndex();
      X509Certificate[] var2 = null;

      for (Iterator var3 = this.clientAuthCertsMap.values().iterator(); var1 >= 0 && var3.hasNext(); var1--) {
         var2 = (X509Certificate[])var3.next();
      }

      if (var2 != null) {
         new CertificateDialog(this.dialog, var2, 0, var2.length).DoModal();
      }
   }

   public void setVisible(boolean var1) {
      if (var1) {
         DialogListener var2 = UIFactory.getDialogListener();
         JDialog var3 = this.dialog;
         Frame var4 = this.dummyFrame;
         DialogTemplate$6 var5 = new DialogTemplate$6(this, var2, var3, var4);
         if (SwingUtilities.isEventDispatchThread()) {
            var5.run();
         } else {
            try {
               SwingUtilities.invokeAndWait(var5);
            } catch (Exception var7) {
               Trace.ignored(var7);
            }
         }
      } else {
         this.dialog.setVisible(false);
         if (this.dummyFrame != null) {
            this.dummyFrame.setVisible(false);
         }
      }
   }

   public void setMasthead(String var1, boolean var2) {
      if (this.masthead != null) {
         this.topText = var1;
         this.masthead.setText(var1);
         if (var2) {
            this.masthead.setBorder(BorderFactory.createEmptyBorder(16, 12, 16, 6));
         } else {
            this.masthead.setBorder(BorderFactory.createEmptyBorder(6, 12, 6, 6));
         }
      }
   }

   public void setIcon(Image var1) {
      this.topIcon.setIcon(new ImageIcon(var1));
   }

   public static void resizeButtons(JButton[] var0) {
      int var1 = var0.length;
      int var2 = 50;

      for (int var3 = 0; var3 < var1; var3++) {
         if (var0[var3].getPreferredSize().width > var2) {
            var2 = var0[var3].getPreferredSize().width;
         }
      }

      for (int var5 = 0; var5 < var1; var5++) {
         Dimension var4 = var0[var5].getPreferredSize();
         var4.width = var2;
         var0[var5].setPreferredSize(var4);
      }
   }

   public void actionPerformed(ActionEvent var1) {
      String var2 = var1.getActionCommand();
      if (var2.equals("OK")) {
         this.userAnswer = 0;
         if (this.always != null && this.always.isSelected()) {
            this.userAnswer = 2;
         }

         if (this.scrollList != null) {
            this.userAnswer = this.scrollList.getSelectedIndex();
         }
      } else {
         if (this.throwable != null || this.detailPanel != null) {
            this.showMoreInfo();
            return;
         }

         this.userAnswer = 1;
         if (this.scrollList != null) {
            this.userAnswer = -1;
         }
      }

      this.setVisible(false);
   }

   public void cancelAction() {
      this.userAnswer = 1;
      this.setVisible(false);
   }

   public int getUserAnswer() {
      return this.userAnswer;
   }

   void setUserAnswer(int var1) {
      this.userAnswer = var1;
   }

   void setMastheadBackground(Image var1) {
      if (this.masthead != null) {
         this.masthead.setBackgroundImage(var1);
      }
   }

   public void disposeDialog() {
      this.dialog.dispose();
   }

   public Component deriveParent(Component var1, String var2) {
      if (var1 == null && Config.getOSName().equals("Windows")) {
         this.dummyFrame = new Frame(var2);
         this.dummyFrame.setLocation(-4096, -4096);
         return this.dummyFrame;
      } else {
         for (Object var3 = var1; var3 != null; var3 = var3.getParent()) {
            if (var3 instanceof Dialog || var3 instanceof Frame) {
               return (Component)var3;
            }
         }

         return (Component)null;
      }
   }

   public JDialog getDialog() {
      return this.dialog;
   }

   public void setInfo(String var1, String var2, URL var3) {
      if (this.nameInfo != null) {
         this.nameInfo.setText(var1);
      }

      if (this.publisherInfo != null) {
         this.appPublisher = var2;
         this.publisherInfo.setText(var2);
      }

      if (this.urlInfo != null) {
         this.appURL = var3;
         String var4 = " ";
         String var5 = "";
         if (var3 != null) {
            var4 = var3.getProtocol() + "://" + var3.getHost();
            int var6 = var3.getPort();
            if (var6 != -1) {
               var4 = var4 + ":" + Integer.toString(var6);
            }

            var5 = var3.toString();
         }

         this.urlInfo.setText(var4);
         this.urlInfo.setToolTipText(var5);
      }
   }

   void showOk(boolean var1) {
      JButton[] var2 = new JButton[]{this.okBtn, this.cancelBtn};
      resizeButtons(var2);
      this.okBtn.setVisible(var1);
   }

   public void imageAvailable(URL var1, String var2, Image var3, File var4) {
      int var5 = var3.getWidth(null);
      int var6 = var3.getHeight(null);
      JLabel var8 = this.topIcon;
      new Thread(new DialogTemplate$7(this, var3, var5, var6, var8)).start();
   }

   public void finalImageAvailable(URL var1, String var2, Image var3, File var4) {
      this.imageAvailable(var1, var2, var3, var4);
   }
}
