package com.sun.deploy.ui;

import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.security.CertificateDialog;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.security.cert.Certificate;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.KeyStroke;

class MoreInfoDialog extends JDialog {
   private FancyButton details;
   private String[] alerts;
   private String[] infos;
   private int securityInfoCount;
   private Certificate[] certs;
   private int start;
   private int end;
   private final String WARNING_ICON = "com/sun/deploy/resources/image/icon-warning16.png";
   private final String INFO_ICON = "com/sun/deploy/resources/image/icon-info16.png";
   private final int VERTICAL_STRUT = 18;
   private final int HORIZONTAL_STRUT = 12;
   private final int TEXT_WIDTH = 326;

   MoreInfoDialog(JDialog var1, String[] var2, String[] var3, int var4, Certificate[] var5, int var6, int var7) {
      super(var1, true);
      this.alerts = var2;
      this.infos = var3;
      this.securityInfoCount = var4;
      this.certs = var5;
      this.start = var6;
      this.end = var7;
      this.initComponents(null, null);
      this.setResizable(false);
   }

   MoreInfoDialog(JDialog var1, JPanel var2, Throwable var3, Certificate[] var4) {
      super(var1, true);
      this.certs = var4;
      this.start = 0;
      this.end = var4 == null ? 0 : var4.length;
      this.initComponents(var2, var3);
   }

   private void initComponents(JPanel var1, Throwable var2) {
      this.setTitle(ResourceManager.getMessage("security.more.info.title"));
      this.getContentPane().setLayout(new BorderLayout());
      JPanel var3 = new JPanel();
      var3.setBorder(BorderFactory.createEmptyBorder(16, 16, 12, 16));
      var3.setLayout(new BoxLayout(var3, 1));
      var3.setAlignmentX(0.0F);
      if (var1 != null) {
         var3.add(var1);
      } else if (var2 != null) {
         var3.add(Box.createHorizontalStrut(440));
         JPanel var4 = new JPanel(new BorderLayout());
         JLabel var5 = new JLabel(ResourceManager.getString("exception.details.label"));
         var5.setBorder(BorderFactory.createEmptyBorder(0, 0, 8, 0));
         var4.add(var5, "West");
         var3.add(var4);
         StringWriter var6 = new StringWriter();
         PrintWriter var7 = new PrintWriter(var6);
         var2.printStackTrace(var7);
         JTextArea var8 = new JTextArea(var6.toString(), 20, 60);
         var8.setFont(ResourceManager.getUIFont());
         var8.setEditable(false);
         var8.setLineWrap(true);
         var8.setWrapStyleWord(false);
         JScrollPane var9 = new JScrollPane(var8, 20, 30);
         var3.add(var9);
         if (this.certs != null) {
            var3.add(Box.createVerticalStrut(18));
            var3.add(this.getLinkPanel());
         }
      } else {
         var3.add(this.getSecurityPanel());
         if (this.certs != null) {
            var3.add(this.getLinkPanel());
         }

         var3.add(Box.createVerticalStrut(18));
         var3.add(this.getIntegrationPanel());
      }

      var3.add(Box.createVerticalStrut(18));
      var3.add(this.getBtnPanel());
      this.getContentPane().add(var3, "Center");
      this.pack();
      UIFactory.placeWindow(this);
      this.getRootPane().getInputMap(2).put(KeyStroke.getKeyStroke(27, 0), "cancel");
      this.getRootPane().getActionMap().put("cancel", new MoreInfoDialog$1(this));
   }

   private JPanel getSecurityPanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new BoxLayout(var1, 1));
      boolean var4 = this.certs == null;
      int var2 = !var4 && this.alerts != null ? 1 : 0;
      int var3 = this.alerts == null ? 0 : this.alerts.length;
      var1.add(this.blockPanel("com/sun/deploy/resources/image/icon-warning16.png", this.alerts, var2, var3));
      var2 = !var4 && this.alerts == null ? 1 : 0;
      var3 = this.securityInfoCount;
      var1.add(this.blockPanel("com/sun/deploy/resources/image/icon-info16.png", this.infos, var2, var3));
      return var1;
   }

   private JPanel getLinkPanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new BoxLayout(var1, 0));
      var1.setAlignmentX(0.0F);
      var1.add(Box.createHorizontalGlue());
      this.details = new FancyButton("security.more.info.details", Color.blue);
      this.details.addMouseListener(new MoreInfoDialog$2(this));
      this.details.addActionListener(new MoreInfoDialog$3(this));
      var1.add(this.details);
      return var1;
   }

   private JPanel getIntegrationPanel() {
      int var1 = this.securityInfoCount;
      int var2 = this.infos == null ? 0 : this.infos.length;
      return this.blockPanel("com/sun/deploy/resources/image/icon-info16.png", this.infos, var1, var2);
   }

   private JPanel getBtnPanel() {
      JPanel var1 = new JPanel();
      var1.setLayout(new BoxLayout(var1, 0));
      var1.setAlignmentX(0.0F);
      var1.add(Box.createHorizontalGlue());
      JButton var2 = new JButton(ResourceManager.getMessage("common.close_btn"));
      var2.addActionListener(new MoreInfoDialog$4(this));
      this.getRootPane().setDefaultButton(var2);
      var1.add(var2);
      return var1;
   }

   private JPanel blockPanel(String var1, String[] var2, int var3, int var4) {
      JPanel var5 = new JPanel();
      var5.setLayout(new BoxLayout(var5, 1));
      if (var2 != null) {
         for (int var6 = var3; var6 < var4; var6++) {
            JPanel var7 = new JPanel();
            var7.setLayout(new BoxLayout(var7, 0));
            var7.setAlignmentX(0.0F);
            JLabel var8 = new JLabel();
            var8.setIcon(new ImageIcon(ClassLoader.getSystemResource(var1)));
            var8.setAlignmentY(0.0F);
            var8.setAlignmentX(0.0F);
            UITextArea var9 = new UITextArea(new JLabel().getFont().getSize(), 326, false);
            var9.setText(var2[var6]);
            Dimension var10 = var9.getPreferredSize();
            var9.setSize(var10.width, var10.height);
            var9.setAlignmentY(0.0F);
            var9.setAlignmentX(0.0F);
            var7.add(var8);
            var7.add(Box.createHorizontalStrut(12));
            var7.add(var9);
            var7.add(Box.createHorizontalGlue());
            var5.add(var7);
            var5.add(Box.createVerticalStrut(18));
         }
      }

      return var5;
   }

   private void showCertDetails() {
      new CertificateDialog(this, this.certs, this.start, this.end).DoModal();
   }

   private void dismissAction() {
      this.setVisible(false);
      this.dispose();
   }
}
