package com.sun.deploy.util;

import com.sun.deploy.resources.ResourceManager;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Insets;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JViewport;
import javax.swing.KeyStroke;
import javax.swing.LookAndFeel;

public final class ConsoleWindow extends JFrame {
   private final ConsoleController controller;
   private JTextArea textArea;
   private JScrollPane scroller;
   private JScrollBar sbHor;
   private JScrollBar sbVer;
   private static final int TEXT_LIMIT = 1048575;

   public static ConsoleWindow create(ConsoleController var0) {
      LookAndFeel var1 = null;

      ConsoleWindow var2;
      try {
         var1 = DeployUIManager.setLookAndFeel();
         var2 = new ConsoleWindow(var0);
      } finally {
         DeployUIManager.restoreLookAndFeel(var1);
      }

      return var2;
   }

   public ConsoleWindow(ConsoleController var1) {
      super(ResourceManager.getMessage("console.caption"));
      this.controller = var1;
      this.setSize(450, 400);
      this.setResizable(true);
      this.setDefaultCloseOperation(0);
      this.getContentPane().setLayout(new BorderLayout());
      this.textArea = new JTextArea();
      this.textArea.setFont(ResourceManager.getUIFont());
      this.textArea.setEditable(false);
      this.textArea.setMargin(new Insets(0, 5, 0, 0));
      this.scroller = new JScrollPane(this.textArea);
      if (!System.getProperty("java.version").startsWith("1.2")) {
         JViewport var2 = this.scroller.getViewport();
         var2.setScrollMode(1);
      }

      this.sbVer = this.scroller.getVerticalScrollBar();
      this.sbHor = this.scroller.getHorizontalScrollBar();
      this.getContentPane().add(this.scroller, "Center");
      ConsoleWindow$1 var27 = new ConsoleWindow$1(this, var1);
      ConsoleWindow$2 var3 = new ConsoleWindow$2(this, var1);
      ConsoleWindow$3 var4 = new ConsoleWindow$3(this, var1);
      ConsoleWindow$4 var5 = new ConsoleWindow$4(this, var1);
      ConsoleWindow$5 var6 = new ConsoleWindow$5(this);
      ConsoleWindow$6 var7 = new ConsoleWindow$6(this);
      ConsoleWindow$7 var8 = new ConsoleWindow$7(this, var1);
      ConsoleWindow$8 var9 = new ConsoleWindow$8(this, var1);
      ConsoleWindow$9 var10 = new ConsoleWindow$9(this);
      ConsoleWindow$10 var11 = new ConsoleWindow$10(this);
      ConsoleWindow$11 var12 = new ConsoleWindow$11(this, var1);
      ConsoleWindow$12 var13 = new ConsoleWindow$12(this);
      ConsoleWindow$13 var14 = new ConsoleWindow$13(this, var13);
      ConsoleWindow$14 var15 = new ConsoleWindow$14(this, var13);
      ConsoleWindow$15 var16 = new ConsoleWindow$15(this);
      ConsoleWindow$16 var17 = new ConsoleWindow$16(this);
      ConsoleWindow$17 var18 = new ConsoleWindow$17(this);
      ConsoleWindow$18 var19 = new ConsoleWindow$18(this);
      ConsoleWindow$19 var20 = new ConsoleWindow$19(this);
      ConsoleWindow$20 var21 = new ConsoleWindow$20(this);
      ConsoleWindow$21 var22 = new ConsoleWindow$21(this, var1);
      if (var1.isJCovSupported()) {
         ConsoleWindow$22 var23 = new ConsoleWindow$22(this, var1);
         this.textArea.registerKeyboardAction(var23, KeyStroke.getKeyStroke(74, 0), 2);
      }

      if (var1.isDumpStackSupported()) {
         this.textArea.registerKeyboardAction(var27, KeyStroke.getKeyStroke(86, 0), 2);
      }

      if (var1.isProxyConfigReloadSupported()) {
         this.textArea.registerKeyboardAction(var5, KeyStroke.getKeyStroke(80, 0), 2);
      }

      if (var1.isSecurityPolicyReloadSupported()) {
         this.textArea.registerKeyboardAction(var4, KeyStroke.getKeyStroke(82, 0), 2);
      }

      if (var1.isClearClassLoaderSupported()) {
         this.textArea.registerKeyboardAction(var9, KeyStroke.getKeyStroke(88, 0), 2);
      }

      if (var1.isDumpClassLoaderSupported()) {
         this.textArea.registerKeyboardAction(var8, KeyStroke.getKeyStroke(76, 0), 2);
      }

      if (var1.isLoggingSupported()) {
         this.textArea.registerKeyboardAction(var22, KeyStroke.getKeyStroke(79, 0), 2);
      }

      this.textArea.registerKeyboardAction(var3, KeyStroke.getKeyStroke(84, 0), 2);
      this.textArea.registerKeyboardAction(var6, KeyStroke.getKeyStroke(83, 0), 2);
      this.textArea.registerKeyboardAction(var7, KeyStroke.getKeyStroke(72, 0), 2);
      this.textArea.registerKeyboardAction(var13, KeyStroke.getKeyStroke(77, 0), 2);
      this.textArea.registerKeyboardAction(var10, KeyStroke.getKeyStroke(67, 0), 2);
      this.textArea.registerKeyboardAction(var15, KeyStroke.getKeyStroke(71, 0), 2);
      this.textArea.registerKeyboardAction(var14, KeyStroke.getKeyStroke(70, 0), 2);
      this.textArea.registerKeyboardAction(var12, KeyStroke.getKeyStroke(81, 0), 2);
      this.textArea.registerKeyboardAction(var16, KeyStroke.getKeyStroke(48, 0), 2);
      this.textArea.registerKeyboardAction(var17, KeyStroke.getKeyStroke(49, 0), 2);
      this.textArea.registerKeyboardAction(var18, KeyStroke.getKeyStroke(50, 0), 2);
      this.textArea.registerKeyboardAction(var19, KeyStroke.getKeyStroke(51, 0), 2);
      this.textArea.registerKeyboardAction(var20, KeyStroke.getKeyStroke(52, 0), 2);
      this.textArea.registerKeyboardAction(var21, KeyStroke.getKeyStroke(53, 0), 2);
      JButton var28 = new JButton(ResourceManager.getMessage("console.clear"));
      var28.setMnemonic(ResourceManager.getAcceleratorKey("console.clear"));
      JButton var24 = new JButton(ResourceManager.getMessage("console.copy"));
      var24.setMnemonic(ResourceManager.getAcceleratorKey("console.copy"));
      JButton var25 = new JButton(ResourceManager.getMessage("console.close"));
      var25.setMnemonic(ResourceManager.getAcceleratorKey("console.close"));
      JPanel var26 = new JPanel();
      var26.setLayout(new FlowLayout(1));
      var26.add(var28);
      var26.add(new JLabel("    "));
      var26.add(var24);
      var26.add(new JLabel("    "));
      var26.add(var25);
      this.getContentPane().add(var26, "South");
      this.addWindowListener(new ConsoleWindow$23(this, var1));
      var28.addActionListener(var10);
      var24.addActionListener(var11);
      var25.addActionListener(var12);
   }

   public void append(String var1) {
      this.controller.invokeLater(new ConsoleWindow$24(this, var1));
   }

   public void setScrollPosition() {
      this.scroller.validate();
      this.sbVer.setValue(this.sbVer.getMaximum());
      this.sbHor.setValue(this.sbHor.getMinimum());
   }

   public void showConsole(boolean var1) {
      if (this.controller.isIconifiedOnClose()) {
         if (var1) {
            this.setState(0);
         } else {
            this.setState(1);
         }

         this.setVisible(true);
      } else {
         if (this.isVisible() != var1) {
            this.setVisible(var1);
         }

         if (var1) {
            this.toFront();
         }
      }
   }

   public boolean isConsoleVisible() {
      return this.controller.isIconifiedOnClose() ? this.getState() == 0 : this.isVisible();
   }

   public JTextArea getTextArea() {
      return this.textArea;
   }
}
