package com.sun.deploy.util;

import com.sun.deploy.config.Config;
import java.util.WeakHashMap;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;
import javax.swing.plaf.FontUIResource;
import javax.swing.plaf.metal.DefaultMetalTheme;
import javax.swing.plaf.metal.MetalLookAndFeel;
import javax.swing.plaf.metal.MetalTheme;
import sun.awt.AppContext;

public final class DeployUIManager {
   private static final String _v = System.getProperty("java.version");
   private static final boolean _isOldJava = _v.startsWith("1.2") || _v.startsWith("1.3") || _v.startsWith("1.4");
   private static WeakHashMap themeMap = new WeakHashMap();

   public static LookAndFeel setLookAndFeel() {
      LookAndFeel var0 = UIManager.getLookAndFeel();
      if (var0 instanceof MetalLookAndFeel) {
         themeMap.put(var0, getCurrentMetalTheme());
      }

      try {
         if (_isOldJava) {
            MetalLookAndFeel.setCurrentTheme(new DeployUIManager.DeployMetalTheme());
         }

         if (Config.useSystemLookAndFeel()) {
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
         } else {
            UIManager.setLookAndFeel(new MetalLookAndFeel());
         }
      } catch (Exception var2) {
      }

      return var0;
   }

   public static void restoreLookAndFeel(LookAndFeel var0) {
      try {
         if (var0 instanceof MetalLookAndFeel) {
            MetalTheme var1 = (MetalTheme)themeMap.get(var0);
            if (var1 != null) {
               MetalLookAndFeel.setCurrentTheme(var1);
            } else {
               MetalLookAndFeel.setCurrentTheme(new DefaultMetalTheme());
            }
         }

         if (var0 == null) {
            if (Config.useSystemLookAndFeel()) {
               UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
            } else {
               UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
            }
         } else {
            UIManager.setLookAndFeel(var0);
         }
      } catch (Exception var2) {
      }
   }

   private static MetalTheme getCurrentMetalTheme() {
      AppContext var0 = AppContext.getAppContext();
      return (MetalTheme)var0.get("currentMetalTheme");
   }

   static class DeployMetalTheme extends DefaultMetalTheme {
      private FontUIResource controlTextFont = null;
      private FontUIResource menuTextFont = null;
      private FontUIResource windowTitleFont = null;

      DeployMetalTheme() {
         FontUIResource var1 = super.getControlTextFont();
         this.controlTextFont = new FontUIResource(var1.getName(), var1.getStyle() & -2, var1.getSize());
         var1 = super.getMenuTextFont();
         this.menuTextFont = new FontUIResource(var1.getName(), var1.getStyle() & -2, var1.getSize());
         var1 = super.getWindowTitleFont();
         this.windowTitleFont = new FontUIResource(var1.getName(), var1.getStyle() & -2, var1.getSize());
      }

      public FontUIResource getControlTextFont() {
         return this.controlTextFont;
      }

      public FontUIResource getMenuTextFont() {
         return this.menuTextFont;
      }

      public FontUIResource getWindowTitleFont() {
         return this.windowTitleFont;
      }
   }
}
