package com.sun.deploy.util;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.ui.UIFactory;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dialog;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.Window;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.lang.reflect.Array;
import java.net.URL;
import java.security.AccessController;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.LookAndFeel;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

public final class DialogFactory {
   public static final int ERROR_MESSAGE = 1;
   public static final int INFORMATION_MESSAGE = 2;
   public static final int WARNING_MESSAGE = 3;
   public static final int QUESTION_MESSAGE = 4;
   public static final int PLAIN_MESSAGE = 5;
   public static final int YES_OPTION = 0;
   public static final int NO_OPTION = 1;
   private static String confirmDialogTitle = ResourceManager.getMessage("dialogfactory.confirmDialogTitle");
   private static String inputDialogTitle = ResourceManager.getMessage("dialogfactory.inputDialogTitle");
   private static String messageDialogTitle = ResourceManager.getMessage("dialogfactory.messageDialogTitle");
   private static String exceptionDialogTitle = ResourceManager.getMessage("dialogfactory.exceptionDialogTitle");
   private static String optionDialogTitle = ResourceManager.getMessage("dialogfactory.optionDialogTitle");
   private static String aboutDialogTitle = ResourceManager.getMessage("dialogfactory.aboutDialogTitle");
   private static String javaHomeLink = ResourceManager.getMessage("dialogfactory.java.home.link");
   private static DialogListener dialogListener = null;
   private static Icon _warningIcon = null;
   public static Icon _infoIcon = null;
   static Icon _javaIcon = null;
   static Icon _javaIcon48 = null;
   private static long tsLastActive = 0L;

   public static void addDialogListener(DialogListener var0) {
      if (dialogListener == null) {
         UIFactory.setDialogListener(var0);
         dialogListener = var0;
      }
   }

   public static Icon getWarningIcon() {
      if (_warningIcon == null) {
         Object var0 = UIManager.get("OptionPane.warningIcon");
         if (var0 instanceof Icon) {
            _warningIcon = (Icon)var0;
         } else {
            URL var1 = ClassLoader.getSystemResource("javax/swing/plaf/metal/icons/Warn.gif");
            _warningIcon = loadIcon(var1);
         }
      }

      return _warningIcon;
   }

   public static Icon getInfoIcon() {
      if (_infoIcon == null) {
         Object var0 = UIManager.get("OptionPane.informationIcon");
         if (var0 instanceof Icon) {
            _infoIcon = (Icon)var0;
         } else {
            URL var1 = ClassLoader.getSystemResource("javax/swing/plaf/metal/icons/Inform.gif");
            _infoIcon = loadIcon(var1);
         }
      }

      return _infoIcon;
   }

   public static Icon loadIcon() {
      if (_javaIcon == null) {
         _javaIcon = loadIcon(
            (class$com$sun$deploy$resources$ResourceManager == null
                  ? (class$com$sun$deploy$resources$ResourceManager = class$("com.sun.deploy.resources.ResourceManager"))
                  : class$com$sun$deploy$resources$ResourceManager)
               .getResource("images/java32.png")
         );
      }

      return _javaIcon;
   }

   public static Icon loadIcon48() {
      if (_javaIcon48 == null) {
         _javaIcon = loadIcon(
            (class$com$sun$deploy$resources$ResourceManager == null
                  ? (class$com$sun$deploy$resources$ResourceManager = class$("com.sun.deploy.resources.ResourceManager"))
                  : class$com$sun$deploy$resources$ResourceManager)
               .getResource("images/java32.png")
         );
      }

      return _javaIcon;
   }

   public static Icon loadIcon(URL var0) {
      Icon var1 = null;

      try {
         var1 = AccessController.doPrivileged(new DialogFactory$1(var0));
      } catch (Throwable var3) {
         var3.printStackTrace();
      }

      return var1;
   }

   public static void showAboutJavaDialog() {
      if (SwingUtilities.isEventDispatchThread()) {
         internalShowAboutJavaDialog();
      } else {
         try {
            SwingUtilities.invokeAndWait(new DialogFactory$2());
         } catch (Exception var1) {
         }
      }
   }

   private static synchronized void internalShowAboutJavaDialog() {
      LookAndFeel var0 = null;

      try {
         if (System.currentTimeMillis() - tsLastActive > 500L && AboutDialog.shouldStartNewInstance()) {
            var0 = DeployUIManager.setLookAndFeel();
            JFrame var1 = new JFrame(ResourceManager.getMessage("about.dialog.title"));
            AboutDialog var2 = new AboutDialog(var1, true, true);
            var2.pack();
            Dimension var3 = Toolkit.getDefaultToolkit().getScreenSize();
            Dimension var4 = var2.getSize();
            Dimension var5 = var1.getSize();
            var1.setLocation(-var5.width + 1, -var5.height + 1);
            var1.setVisible(true);
            var2.setLocation((var3.width - var4.width) / 2, (var3.height - var4.height) / 2);
            var2.setVisible(true);
            var1.setVisible(false);
            var1.dispose();
            tsLastActive = System.currentTimeMillis();
         }
      } catch (Exception var9) {
      } finally {
         if (var0 != null) {
            DeployUIManager.restoreLookAndFeel(var0);
         }
      }
   }

   public static int showConfirmDialog(Object var0) {
      return showConfirmDialog(null, var0, confirmDialogTitle);
   }

   public static int showConfirmDialog(Component var0, Object var1) {
      return showConfirmDialog(var0, var1, confirmDialogTitle);
   }

   public static String showInputDialog(Object var0) {
      return showInputDialog(null, var0, inputDialogTitle);
   }

   public static String showInputDialog(Component var0, Object var1) {
      return showInputDialog(var0, var1, inputDialogTitle);
   }

   public static void showInformationDialog(Object var0) {
      showInformationDialog(null, var0, messageDialogTitle);
   }

   public static void showInformationDialog(Component var0, Object var1) {
      showInformationDialog(var0, var1, messageDialogTitle);
   }

   public static void showErrorDialog(String var0) {
      showErrorDialog(null, var0, messageDialogTitle);
   }

   public static void showErrorDialog(Component var0, String var1) {
      showErrorDialog(var0, var1, messageDialogTitle);
   }

   public static void showExceptionDialog(Throwable var0) {
      showExceptionDialog(null, var0, var0.toString(), exceptionDialogTitle);
   }

   public static void showExceptionDialog(Component var0, Throwable var1) {
      showExceptionDialog(var0, var1, var1.toString(), exceptionDialogTitle);
   }

   public static int showConfirmDialog(Object var0, String var1) {
      return showConfirmDialog(null, var0, var1);
   }

   public static int showConfirmDialog(Component var0, Object var1, String var2) {
      try {
         return (Integer)DeploySysRun.execute(new DialogFactory$3(var0, var1, var2));
      } catch (Exception var4) {
         Trace.ignoredException(var4);
         return 1;
      }
   }

   private static int showConfirmDialogImpl(Component var0, Object var1, String var2) {
      LookAndFeel var3 = null;

      int var7;
      try {
         var3 = DeployUIManager.setLookAndFeel();
         JButton var4 = new JButton(ResourceManager.getMessage("dialogfactory.confirm.yes"));
         JButton var5 = new JButton(ResourceManager.getMessage("dialogfactory.confirm.no"));
         var4.setMnemonic(ResourceManager.getAcceleratorKey("dialogfactory.confirm.yes"));
         var5.setMnemonic(ResourceManager.getAcceleratorKey("dialogfactory.confirm.no"));
         Object[] var6 = new Object[]{var4, var5};
         if (var2 == null) {
            var2 = confirmDialogTitle;
         }

         var7 = showOptionDialogImpl(var0, 4, var1, var2, var6, var6[0], false);
      } finally {
         DeployUIManager.restoreLookAndFeel(var3);
      }

      return var7;
   }

   public static int showOptionDialog(Object var0, String var1, Object[] var2, Object var3) {
      return showOptionDialog(null, var0, var1, var2, var3);
   }

   public static int showOptionDialog(Component var0, Object var1, String var2, Object[] var3, Object var4) {
      return showOptionDialog(var0, 5, var1, var2, var3, var4);
   }

   public static int showDownloadDialog(int var0, String var1) {
      try {
         return (Integer)DeploySysRun.execute(new DialogFactory$4(var0, var1));
      } catch (Exception var3) {
         Trace.ignoredException(var3);
         return 1;
      }
   }

   private static int showDownloadDialogImpl(int var0, String var1) {
      LookAndFeel var2 = null;

      int var7;
      try {
         var2 = DeployUIManager.setLookAndFeel();
         String var3 = ResourceManager.getMessage("security.dialog.caption");
         JButton var4 = new JButton(ResourceManager.getMessage("security.dialog.buttonYes"));
         JButton var5 = new JButton(ResourceManager.getMessage("security.dialog.buttonNo"));
         var4.setMnemonic(ResourceManager.getAcceleratorKey("security.dialog.buttonYes"));
         var5.setMnemonic(ResourceManager.getAcceleratorKey("security.dialog.buttonNo"));
         Object[] var6 = new Object[]{var4, var5};
         var7 = showOptionDialogImpl(null, var0, var1, var3, var6, var6[0], false);
      } finally {
         DeployUIManager.restoreLookAndFeel(var2);
      }

      return var7;
   }

   static int showUpdateCheckDialog() {
      String var0 = ResourceManager.getMessage("autoupdatecheck.buttonYes");
      String var1 = ResourceManager.getMessage("autoupdatecheck.buttonNo");
      String var2 = ResourceManager.getMessage("autoupdatecheck.buttonAskLater");
      String var3 = ResourceManager.getMessage("autoupdatecheck.caption");
      String var4 = ResourceManager.getMessage("autoupdatecheck.message");
      JButton var5 = new JButton(var0);
      JButton var6 = new JButton(var1);
      JButton var7 = new JButton(var2);
      var5.setMnemonic(ResourceManager.getAcceleratorKey("autoupdatecheck.buttonYes"));
      var6.setMnemonic(ResourceManager.getAcceleratorKey("autoupdatecheck.buttonNo"));
      var7.setMnemonic(ResourceManager.getAcceleratorKey("autoupdatecheck.buttonAskLater"));
      Object[] var8 = new Object[]{var5, var6, var7};
      return showOptionDialogImpl(null, 3, var4, var3, var8, var8[0], false);
   }

   public static int showOptionDialog(int var0, Object var1, String var2, Object[] var3, Object var4) {
      return showOptionDialog(null, var0, var1, var2, var3, var4);
   }

   public static int showOptionDialog(Component var0, int var1, Object var2, String var3, Object[] var4, Object var5) {
      try {
         return (Integer)DeploySysRun.execute(new DialogFactory$5(var0, var1, var2, var3, var4, var5));
      } catch (Exception var7) {
         Trace.ignoredException(var7);
         return 1;
      }
   }

   public static void preLoadDialog(int var0, Object var1, String var2, Object[] var3, Object var4) {
      showOptionDialogImpl(null, var0, var1, var2, var3, var3[0], true);
   }

   private static int showOptionDialogImpl(Component var0, int var1, Object var2, String var3, Object[] var4, Object var5, boolean var6) {
      LookAndFeel var7 = null;

      int var16;
      try {
         var7 = DeployUIManager.setLookAndFeel();
         int var8 = -1;
         JOptionPane var9 = new JOptionPane();
         switch (var1) {
            case 1:
               var9.setMessageType(0);
               break;
            case 2:
               var9.setMessageType(1);
               break;
            case 3:
               var9.setMessageType(2);
               break;
            case 4:
               var9.setMessageType(2);
         }

         var9.setOptions(var4);
         var9.setInitialValue(var5);
         var9.setWantsInput(false);
         Object var10 = extractMessage(var9, var2);
         if (var3 == null) {
            var3 = optionDialogTitle;
         }

         if (showDialog(var9, var0, var3, var10, true, var6)) {
            Object var11 = var9.getValue();
            if (var11 != null) {
               for (int var12 = 0; var12 < var4.length; var12++) {
                  if (var4[var12].equals(var11)) {
                     var8 = var12;
                     break;
                  }
               }

               Trace.msgPrintln("dialogfactory.user.selected", new Object[]{new Integer(var8)}, TraceLevel.BASIC);
            }
         }

         var16 = var8;
      } finally {
         DeployUIManager.restoreLookAndFeel(var7);
      }

      return var16;
   }

   public static String showInputDialog(Object var0, String var1) {
      return showInputDialog(null, var0, var1);
   }

   public static String showInputDialog(Component var0, Object var1, String var2) {
      try {
         return (String)DeploySysRun.execute(new DialogFactory$6(var0, var1, var2));
      } catch (Exception var4) {
         Trace.ignoredException(var4);
         return null;
      }
   }

   private static String showInputDialogImpl(Component var0, Object var1, String var2) {
      LookAndFeel var3 = null;

      String var11;
      try {
         var3 = DeployUIManager.setLookAndFeel();
         String var4 = null;
         JOptionPane var5 = new JOptionPane();
         var5.setMessageType(3);
         var5.setOptionType(2);
         var5.setWantsInput(true);
         Object var6 = extractMessage(var5, var1);
         if (var2 == null) {
            var2 = inputDialogTitle;
         }

         if (showDialog(var5, var0, var2, var6)) {
            Object var7 = var5.getInputValue();
            if (var7 != null) {
               if (var7 instanceof String) {
                  var4 = var7.toString();
               }

               Trace.msgPrintln("dialogfactory.user.typed", new Object[]{var4});
            }
         }

         var11 = var4;
      } finally {
         DeployUIManager.restoreLookAndFeel(var3);
      }

      return var11;
   }

   public static void showMessageDialog(int var0, Object var1, String var2, boolean var3) {
      showMessageDialog(null, var0, var1, var2, var3);
   }

   public static void showMessageDialog(Component var0, int var1, Object var2, String var3, boolean var4) {
      try {
         DeploySysRun.execute(new DialogFactory$7(var0, var1, var2, var3, var4));
      } catch (Exception var6) {
         Trace.ignoredException(var6);
      }
   }

   private static void showMessageDialogImpl(Component var0, int var1, Object var2, String var3, boolean var4) {
      LookAndFeel var5 = null;

      try {
         var5 = DeployUIManager.setLookAndFeel();
         JOptionPane var6 = new JOptionPane();
         switch (var1) {
            case 1:
               var6.setMessageType(0);
               break;
            case 2:
               var6.setMessageType(1);
               break;
            case 3:
               var6.setMessageType(2);
               break;
            case 4:
               var6.setMessageType(3);
         }

         var6.setOptionType(-1);
         var6.setWantsInput(false);
         Object var7 = extractMessage(var6, var2);
         if (var3 == null) {
            var3 = messageDialogTitle;
         }

         showDialog(var6, var0, var3, var7, var4);
      } finally {
         DeployUIManager.restoreLookAndFeel(var5);
      }
   }

   public static void showInformationDialog(Object var0, String var1) {
      showInformationDialog(null, var0, var1);
   }

   public static void showInformationDialog(Component var0, Object var1, String var2) {
      showMessageDialog(var0, 2, var1, var2, true);
   }

   public static void showErrorDialog(String var0, String var1) {
      showErrorDialog(null, var0, var1);
   }

   public static void showErrorDialog(Component var0, String var1, String var2) {
      showMessageDialog(var0, 1, var1, var2, true);
   }

   public static void showExceptionDialog(Throwable var0, String var1) {
      showExceptionDialog(var0, var1, exceptionDialogTitle);
   }

   public static void showExceptionDialog(Component var0, Throwable var1, String var2) {
      showExceptionDialog(var0, var1, var2, exceptionDialogTitle);
   }

   public static void showExceptionDialog(Throwable var0, String var1, String var2) {
      showExceptionDialog(null, var0, var1, var2);
   }

   public static void showExceptionDialog(Component var0, Throwable var1, String var2, String var3) {
      try {
         DeploySysRun.execute(new DialogFactory$8(var0, var1, var2, var3));
      } catch (Exception var5) {
         Trace.ignoredException(var5);
      }
   }

   public static void showProxyDialog() {
      Trace.println("ProxyDialogNotImplemented !!!! XXX", TraceLevel.NETWORK);
   }

   private static void showExceptionDialogImpl(Component var0, Throwable var1, String var2, String var3) {
      LookAndFeel var4 = null;

      try {
         var4 = DeployUIManager.setLookAndFeel();
         JOptionPane var5 = new JOptionPane();
         var5.setMessageType(0);
         var5.setOptionType(-1);
         var5.setWantsInput(false);
         Component var6 = (Component)extractMessage(var5, var1);
         JPanel var7 = new JPanel();
         JButton var8 = new JButton(ResourceManager.getMessage("dialogfactory.moreInfo"));
         var8.setMnemonic(ResourceManager.getAcceleratorKey("dialogfactory.moreInfo"));
         var7.setLayout(new FlowLayout(2));
         var7.add(var8);
         JPanel var9 = new JPanel();
         JButton var10 = new JButton(ResourceManager.getMessage("dialogfactory.lessInfo"));
         var10.setMnemonic(ResourceManager.getAcceleratorKey("dialogfactory.lessInfo"));
         JPanel var11 = new JPanel();
         var11.setLayout(new FlowLayout(2));
         var11.add(var10);
         var9.setLayout(new BorderLayout());
         var9.add(var11, "Center");
         var9.add(var6, "South");
         JPanel var12 = new JPanel();
         var12.setLayout(new BorderLayout());
         var12.add(var7, "Center");
         var8.addActionListener(new DialogFactory$9(var12, var7, var9));
         var10.addActionListener(new DialogFactory$10(var12, var9, var7));
         Object[] var13 = new Object[]{extractMessage(var5, var2), var12};
         if (var3 == null) {
            var3 = exceptionDialogTitle;
         }

         showDialog(var5, var0, var3, var13);
      } finally {
         DeployUIManager.restoreLookAndFeel(var4);
      }
   }

   private static boolean showDialog(JOptionPane var0, Component var1, String var2, Object var3) {
      return showDialog(var0, var1, var2, var3, true, false);
   }

   private static boolean showDialog(JOptionPane var0, Component var1, String var2, Object var3, boolean var4) {
      return showDialog(var0, var1, var2, var3, var4, false);
   }

   private static boolean showDialog(JOptionPane var0, Component var1, String var2, Object var3, boolean var4, boolean var5) {
      boolean var6 = true;

      try {
         var0.setValue(null);
         DialogFactory$11 var7 = new DialogFactory$11(var1, var2, var4, var0, var3, var5);
         String var8 = AccessController.doPrivileged(new DialogFactory$12());
         if (var8 == null || var5 || SwingUtilities.isEventDispatchThread()) {
            var7.run();
         } else if (var4) {
            SwingUtilities.invokeAndWait(var7);
         } else {
            SwingUtilities.invokeLater(var7);
         }
      } catch (Throwable var9) {
         var9.printStackTrace();
         var6 = false;
      }

      return var6;
   }

   private static JFrame getFrameOwner(Component var0, String var1, boolean var2) {
      if (var0 == null && var2 && Config.getOSName().equals("Windows")) {
         JFrame var3 = new JFrame(var1);
         var3.setLocation(-200, -200);
         return var3;
      } else {
         return null;
      }
   }

   public static void placeWindow(Window var0) {
      Window var1 = var0.getOwner();
      Rectangle var2 = new Rectangle(new Point(0, 0), Toolkit.getDefaultToolkit().getScreenSize());
      Rectangle var3 = var0.getBounds();
      Rectangle var4 = var1 != null && var1.isVisible() ? var1.getBounds() : var2;
      double var5 = var4.height - var4.height / 1.618;
      var3.x = var4.x + (var4.width - var3.width) / 2;
      int var7 = (int)(var5 - var3.height / 2);
      int var8 = var1 == null ? 0 : var1.getInsets().top;
      var3.y = var4.y + Math.max(var7, var8);
      if (var3.x + var3.width > var2.width) {
         var3.x = Math.max(var2.width - var3.width, 0);
      }

      if (var3.y + var3.height > var2.height) {
         var3.y = Math.max(var2.height - var3.height, 0);
      }

      var0.setBounds(var3);
   }

   public static void positionDialog(Dialog var0) {
      Window var1 = var0.getOwner();
      if (var1 != null && var1.isVisible()) {
         placeWindow(var0);
      } else {
         Dimension var2 = Toolkit.getDefaultToolkit().getScreenSize();
         var0.setLocation((var2.width - var0.getWidth()) / 2, (var2.height - var0.getHeight()) / 2);
      }
   }

   private static Object extractMessage(JOptionPane var0, Throwable var1) {
      return formatExceptionMessage(var0, var1);
   }

   private static Object extractMessage(JOptionPane var0, String var1) {
      return formatStringMessage(var0, var1);
   }

   private static Object extractMessage(JOptionPane var0, Object[] var1) {
      Object[] var2 = null;
      if (var1 != null) {
         var2 = new Object[var1.length];

         for (int var3 = 0; var3 < var1.length; var3++) {
            var2[var3] = extractMessage(var0, var1[var3]);
         }
      }

      return var2;
   }

   private static Object extractMessage(JOptionPane var0, Object var1) {
      if (var1 instanceof Object[]) {
         return extractMessage(var0, (Object[])var1);
      } else if (var1 instanceof String) {
         return extractMessage(var0, (String)var1);
      } else {
         return var1 instanceof Exception ? extractMessage(var0, (Throwable)((Exception)var1)) : var1;
      }
   }

   private static Object formatStringMessage(JOptionPane var0, String var1) {
      if (var1 == null) {
         var1 = "null";
      }

      int var2 = var1.indexOf("</html>");
      if (var2 == -1) {
         DialogFactory$13 var3 = new DialogFactory$13();
         var3.setFont(ResourceManager.getUIFont());
         var3.setColumns(40);
         var3.setAutoscrolls(true);
         var3.setEditable(false);
         var3.setLineWrap(true);
         var3.setWrapStyleWord(true);
         var3.setText(var1);
         var3.addFocusListener(new DialogFactory$14());
         return var3;
      } else {
         return var2 + 7 == var1.length()
            ? new JLabel(var1)
            : new Object[]{new JLabel(var1.substring(0, var2 + 7)), formatStringMessage(var0, var1.substring(var2 + 7))};
      }
   }

   private static Object formatExceptionMessage(JOptionPane var0, Throwable var1) {
      StringWriter var2 = new StringWriter();
      PrintWriter var3 = new PrintWriter(var2);
      var1.printStackTrace(var3);
      DialogFactory$15 var4 = new DialogFactory$15();
      var4.setText("" + var2.toString());
      var4.setFont(ResourceManager.getUIFont());
      var4.setColumns(40);
      var4.setRows(10);
      var4.setEditable(false);
      var4.addFocusListener(new DialogFactory$16());
      JScrollPane var5 = new JScrollPane(var4);
      var4.setBackground(var0.getBackground());
      return var5;
   }

   private static void fixSwingLayoutBug(Object var0) {
      if (var0 != null) {
         if (var0 instanceof JTextArea) {
            JTextArea var3 = (JTextArea)var0;
            var3.getUI().getPreferredSize(var3);
         } else {
            if (var0.getClass().isArray()) {
               int var1 = Array.getLength(var0);

               for (int var2 = 0; var2 < var1; var2++) {
                  fixSwingLayoutBug(Array.get(var0, var2));
               }
            }
         }
      }
   }
}
