package com.sun.deploy.util;

import com.sun.deploy.config.Config;
import com.sun.deploy.resources.ResourceManager;
import java.awt.Component;
import java.io.PrintStream;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.StringTokenizer;

public class Trace {
   private static boolean _bAutomationOn = false;
   private static ArrayList queue = new ArrayList();
   private static ArrayList listenersList = new ArrayList();
   private static HashSet traceLevelList = new HashSet();
   private static PrintStream psOut = new PrintStream(new TracePrintStream());
   private static PrintStream psErr = new PrintStream(new TracePrintStream());

   private Trace() {
   }

   public static void redirectStdioStderr() {
      System.setOut(psOut);
      System.setErr(psErr);
   }

   public static void flush() {
      while (true) {
         synchronized (queue) {
            if (queue.isEmpty()) {
               return;
            }
         }

         try {
            Thread.sleep(200L);
         } catch (InterruptedException var2) {
         }
      }
   }

   public static boolean isEnabled() {
      return traceLevelList.size() > 1;
   }

   public static void setInitialTraceLevel() {
      String var0 = Config.getProperty("deployment.trace.level");
      if (var0 != null && !var0.equals("")) {
         StringTokenizer var1 = new StringTokenizer(var0, "|");

         while (var1.hasMoreTokens()) {
            String var2 = var1.nextToken();
            if (var2.equalsIgnoreCase("all")) {
               setBasicTrace(true);
               setCacheTrace(true);
               setNetTrace(true);
               setTempTrace(true);
               setSecurityTrace(true);
               setExtTrace(true);
               setLiveConnectTrace(true);
               break;
            }

            if (var2.equalsIgnoreCase("basic")) {
               setBasicTrace(true);
            } else if (var2.equalsIgnoreCase("cache")) {
               setCacheTrace(true);
            } else if (var2.equalsIgnoreCase("net")) {
               setNetTrace(true);
            } else if (var2.equalsIgnoreCase("temp")) {
               setTempTrace(true);
            } else if (var2.equalsIgnoreCase("security")) {
               setSecurityTrace(true);
            } else if (var2.equalsIgnoreCase("ext")) {
               setExtTrace(true);
            } else if (var2.equalsIgnoreCase("liveconnect")) {
               setLiveConnectTrace(true);
            }
         }
      }
   }

   public static void setBasicTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.BASIC);
      } else {
         traceLevelList.remove(TraceLevel.BASIC);
      }
   }

   public static void setNetTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.NETWORK);
      } else {
         traceLevelList.remove(TraceLevel.NETWORK);
      }
   }

   public static void setCacheTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.CACHE);
      } else {
         traceLevelList.remove(TraceLevel.CACHE);
      }
   }

   public static void setTempTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.TEMP);
      } else {
         traceLevelList.remove(TraceLevel.TEMP);
      }
   }

   public static void setSecurityTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.SECURITY);
      } else {
         traceLevelList.remove(TraceLevel.SECURITY);
      }
   }

   public static void setExtTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.EXTENSIONS);
      } else {
         traceLevelList.remove(TraceLevel.EXTENSIONS);
      }
   }

   public static void setLiveConnectTrace(boolean var0) {
      if (var0) {
         traceLevelList.add(TraceLevel.LIVECONNECT);
      } else {
         traceLevelList.remove(TraceLevel.LIVECONNECT);
      }
   }

   public static boolean isAutomationEnabled() {
      return _bAutomationOn;
   }

   public static void enableAutomation(boolean var0) {
      _bAutomationOn = var0;
   }

   private static void enQueue(TraceMessage var0) {
      synchronized (queue) {
         queue.add(var0);
         queue.notifyAll();
      }
   }

   public static void print(String var0, TraceLevel var1) {
      if (traceLevelList.contains(var1)) {
         TraceMessage var2 = new TraceMessage(var1, var0);
         enQueue(var2);
      }
   }

   public static void println(String var0, TraceLevel var1) {
      if (traceLevelList.contains(var1)) {
         TraceMessage var2 = new TraceMessage(var1, var0, true);
         enQueue(var2);
      }
   }

   public static void println(String var0) {
      println(var0, TraceLevel.DEFAULT);
   }

   public static void print(String var0) {
      print(var0, TraceLevel.DEFAULT);
   }

   public static void msgPrintln(String var0, Object[] var1, TraceLevel var2) {
      if (traceLevelList.contains(var2)) {
         String var3 = ResourceManager.getMessage(var0);
         MessageFormat var4 = new MessageFormat(var3);
         String var5 = MessageFormat.format(var3, var1);
         TraceMessage var6 = new TraceMessage(var2, var5, true);
         enQueue(var6);
      }
   }

   public static void msgPrintln(String var0, Object[] var1) {
      msgPrintln(var0, var1, TraceLevel.DEFAULT);
   }

   public static void addTraceListener(TraceListener var0) {
      synchronized (listenersList) {
         if (!listenersList.contains(var0)) {
            listenersList.add(var0);
         }
      }
   }

   public static void removeTraceListener(TraceListener var0) {
      int var1 = listenersList.indexOf(var0);
      synchronized (listenersList) {
         if (var1 != -1) {
            listenersList.remove(var1);
         }
      }
   }

   public static void resetTraceLevel() {
      traceLevelList.clear();
      traceLevelList.add(TraceLevel.DEFAULT);
   }

   public static void firePrintlnEvent(TraceMessage var0) {
      TraceListener var1 = null;
      synchronized (listenersList) {
         for (int var3 = 0; var3 < listenersList.size(); var3++) {
            var1 = (TraceListener)listenersList.get(var3);
            var1.print(var0.getMessage());
         }
      }
   }

   public static void ignoredException(Exception var0) {
      if (traceLevelList.size() > 1) {
         var0.printStackTrace();
      }
   }

   public static void ignored(Throwable var0) {
      if (traceLevelList.size() > 1) {
         var0.printStackTrace();
      }
   }

   public static void printException(Throwable var0) {
      printException(null, var0);
   }

   public static void printException(Component var0, Throwable var1) {
      printException(var0, var1, null, null);
   }

   public static void printException(Throwable var0, String var1, String var2) {
      printException(null, var0, var1, var2);
   }

   public static void printException(Component var0, Throwable var1, String var2, String var3) {
      printException(var0, var1, var2, var3, true);
   }

   public static void printException(Component var0, Throwable var1, String var2, String var3, boolean var4) {
      println("Ignored exception: " + var1);
      if (var4 && !isAutomationEnabled()) {
         if (var2 == null) {
            var2 = ResourceManager.getMessage("dialogfactory.general_error");
         }

         DialogFactory.showExceptionDialog(var0, var1, var2, var3);
      }
   }

   public static void netPrintln(String var0) {
      println(var0, TraceLevel.NETWORK);
   }

   public static void msgNetPrintln(String var0) {
      msgPrintln(var0, null, TraceLevel.NETWORK);
   }

   public static void msgNetPrintln(String var0, Object[] var1) {
      msgPrintln(var0, var1, TraceLevel.NETWORK);
   }

   public static void netPrintException(Throwable var0) {
      printException(null, var0, ResourceManager.getMessage("dialogfactory.net_error"), null, false);
   }

   public static void netPrintException(Throwable var0, String var1, String var2) {
      printException(null, var0, var1, var2, false);
   }

   public static void securityPrintln(String var0) {
      println(var0, TraceLevel.SECURITY);
   }

   public static void msgSecurityPrintln(String var0) {
      msgPrintln(var0, null, TraceLevel.SECURITY);
   }

   public static void msgSecurityPrintln(String var0, Object[] var1) {
      msgPrintln(var0, var1, TraceLevel.SECURITY);
   }

   public static void securityPrintException(Throwable var0) {
      printException(null, var0, ResourceManager.getMessage("dialogfactory.security_error"), null, true);
   }

   public static void securityPrintException(Throwable var0, String var1, String var2) {
      printException(null, var0, var1, var2, true);
   }

   public static void extPrintln(String var0) {
      println(var0, TraceLevel.EXTENSIONS);
   }

   public static void msgExtPrintln(String var0) {
      msgPrintln(var0, null, TraceLevel.EXTENSIONS);
   }

   public static void msgExtPrintln(String var0, Object[] var1) {
      msgPrintln(var0, var1, TraceLevel.EXTENSIONS);
   }

   public static void extPrintException(Throwable var0) {
      printException(null, var0, ResourceManager.getMessage("dialogfactory.ext_error"), null, true);
   }

   public static void extPrintException(Throwable var0, String var1, String var2) {
      printException(null, var0, var1, var2, true);
   }

   public static void liveConnectPrintln(String var0) {
      println(var0, TraceLevel.LIVECONNECT);
   }

   public static void msgLiveConnectPrintln(String var0) {
      msgPrintln(var0, null, TraceLevel.LIVECONNECT);
   }

   public static void msgLiveConnectPrintln(String var0, Object[] var1) {
      msgPrintln(var0, var1, TraceLevel.LIVECONNECT);
   }

   public static void liveConnectPrintException(Throwable var0) {
      printException(null, var0, null, null, false);
   }

   static {
      traceLevelList.add(TraceLevel.DEFAULT);
      Thread var0 = new Thread(new Trace.TraceMsgQueueChecker(), "traceMsgQueueThread");
      var0.setDaemon(true);
      var0.start();
   }

   private static class TraceMsgQueueChecker implements Runnable {
      private TraceMsgQueueChecker() {
      }

      public void run() {
         try {
            Thread.sleep(2000L);
         } catch (InterruptedException var7) {
         }

         while (true) {
            TraceMessage var1 = null;
            synchronized (Trace.queue) {
               if (Trace.queue.isEmpty()) {
                  try {
                     Trace.queue.wait();
                  } catch (InterruptedException var5) {
                     var5.printStackTrace();
                  }
               } else {
                  var1 = (TraceMessage)Trace.queue.remove(0);
               }
            }

            if (var1 != null) {
               Trace.firePrintlnEvent(var1);
            }
         }
      }
   }
}
