package com.sun.deploy.util;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.util.BitSet;

public class URLUtil {
   static BitSet encodedInPath = new BitSet(256);

   public static void setHostHeader(URLConnection var0) {
      int var1 = var0.getURL().getPort();
      String var2 = var0.getURL().getHost();
      if (var1 != -1 && var1 != 80) {
         var2 = var2 + ":" + var1;
      }

      var0.setRequestProperty("Host", var2);
   }

   public static URL getBase(URL var0) {
      if (var0 == null) {
         return null;
      } else {
         String var1 = var0.getFile();
         if (var1 != null) {
            int var2 = var1.lastIndexOf(47);
            if (var2 != -1) {
               var1 = var1.substring(0, var2 + 1);
            }

            try {
               return new URL(var0.getProtocol(), var0.getHost(), var0.getPort(), var1);
            } catch (MalformedURLException var4) {
               Trace.ignoredException(var4);
            }
         }

         return var0;
      }
   }

   public static URL asPathURL(URL var0) {
      if (var0 == null) {
         return null;
      } else {
         String var1 = var0.getFile();
         if (var1 != null && !var1.endsWith("/")) {
            try {
               return new URL(var0.getProtocol(), var0.getHost(), var0.getPort(), var0.getFile() + "/");
            } catch (MalformedURLException var3) {
            }
         }

         return var0;
      }
   }

   public static boolean equals(URL var0, URL var1) {
      if (var0 != null && var1 != null) {
         if ("http".equals(var0.getProtocol()) && "http".equals(var1.getProtocol()) && var0.getPort() != var1.getPort()) {
            var0 = normalizePort(var0);
            var1 = normalizePort(var1);
         }

         return var0.toString().equals(var1.toString());
      } else {
         return var1 == var0;
      }
   }

   public static int compareTo(URL var0, URL var1) {
      if ("http".equals(var0.getProtocol()) && "http".equals(var1.getProtocol()) && var0.getPort() != var1.getPort()) {
         var0 = normalizePort(var0);
         var1 = normalizePort(var1);
      }

      return var0.toString().compareTo(var1.toString());
   }

   private static URL normalizePort(URL var0) {
      if (var0.getPort() != -1) {
         return var0;
      } else {
         try {
            return new URL(var0.getProtocol(), var0.getHost(), 80, var0.getFile());
         } catch (MalformedURLException var2) {
            return var0;
         }
      }
   }

   public static String encodePath(String var0) {
      StringBuffer var1 = new StringBuffer();
      int var2 = var0.length();

      for (int var3 = 0; var3 < var2; var3++) {
         char var4 = var0.charAt(var3);
         if (var4 == File.separatorChar) {
            var1.append('/');
         } else if (var4 <= 127) {
            if (encodedInPath.get(var4)) {
               escape(var1, var4);
            } else {
               var1.append(var4);
            }
         } else if (var4 > 2047) {
            escape(var1, (char)(224 | var4 >> '\f' & 15));
            escape(var1, (char)(128 | var4 >> 6 & 63));
            escape(var1, (char)(128 | var4 >> 0 & 63));
         } else {
            escape(var1, (char)(192 | var4 >> 6 & 31));
            escape(var1, (char)(128 | var4 >> 0 & 63));
         }
      }

      if (!var0.equals(var1.toString())) {
         Trace.println("     String: " + var0, TraceLevel.BASIC);
         Trace.println(" encoded to: " + var1.toString(), TraceLevel.BASIC);
      }

      return var1.toString();
   }

   private static void escape(StringBuffer var0, char var1) {
      var0.append('%');
      var0.append(Character.forDigit(var1 >> 4 & 15, 16));
      var0.append(Character.forDigit(var1 & 15, 16));
   }

   public static String decodePath(String var0) {
      StringBuffer var1 = new StringBuffer();
      int var2 = 0;

      while (var2 < var0.length()) {
         char var3 = var0.charAt(var2);
         if (var3 != '%') {
            var2++;
         } else {
            try {
               var3 = unescape(var0, var2);
               var2 += 3;
               if ((var3 & 128) != 0) {
                  switch (var3 >> 4) {
                     case 12:
                     case 13:
                        char var8 = unescape(var0, var2);
                        var2 += 3;
                        var3 = (char)((var3 & 31) << 6 | var8 & '?');
                        break;
                     case 14:
                        char var4 = unescape(var0, var2);
                        var2 += 3;
                        char var5 = unescape(var0, var2);
                        var2 += 3;
                        var3 = (char)((var3 & 15) << 12 | (var4 & '?') << 6 | var5 & '?');
                        break;
                     default:
                        Trace.ignoredException(new IllegalArgumentException());
                  }
               }
            } catch (NumberFormatException var7) {
               Trace.ignoredException(var7);
            }
         }

         var1.append(var3);
      }

      if (!var0.equals(var1.toString())) {
         Trace.println("     String: " + var0, TraceLevel.BASIC);
         Trace.println(" decoded to: " + var1.toString(), TraceLevel.BASIC);
      }

      return var1.toString();
   }

   private static char unescape(String var0, int var1) {
      return (char)Integer.parseInt(var0.substring(var1 + 1, var1 + 3), 16);
   }

   public static String getEncodedPath(File var0) {
      String var1 = var0.getAbsolutePath();
      if (!var1.endsWith(File.separator) && var0.isDirectory()) {
         var1 = var1 + File.separator;
      }

      return encodePath(var1);
   }

   public static String getDecodedPath(URL var0) {
      String var1 = var0.getFile();
      var1 = var1.replace('/', File.separatorChar);
      return decodePath(var1);
   }

   public static String getPathFromURL(URL var0) {
      return getDecodedPath(var0);
   }

   static {
      encodedInPath.set(61);
      encodedInPath.set(59);
      encodedInPath.set(63);
      encodedInPath.set(47);
      encodedInPath.set(35);
      encodedInPath.set(32);
      encodedInPath.set(60);
      encodedInPath.set(62);
      encodedInPath.set(37);
      encodedInPath.set(34);
      encodedInPath.set(123);
      encodedInPath.set(125);
      encodedInPath.set(124);
      encodedInPath.set(92);
      encodedInPath.set(94);
      encodedInPath.set(91);
      encodedInPath.set(93);
      encodedInPath.set(96);

      for (int var0 = 0; var0 < 32; var0++) {
         encodedInPath.set(var0);
      }

      encodedInPath.set(127);
   }
}
