package com.sun.deploy.xml;

import com.sun.deploy.resources.ResourceManager;
import com.sun.deploy.util.Trace;
import com.sun.deploy.util.TraceLevel;
import java.io.ByteArrayInputStream;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.UnsupportedEncodingException;

public class XMLEncoding {
   private static final int BOM_LENGTH = 4;
   private static final int MAX_ENC_NAME = 512;
   private static final int SPACE = 32;
   private static final int TAB = 9;
   private static final int LINEFEED = 10;
   private static final int RETURN = 13;
   private static final int EQUAL = 61;
   private static final int DOUBLE_QUOTE = 34;
   private static final int SINGLE_QUOTE = 39;
   private static final int UTF_32_BE_BOM = 65279;
   private static final int UTF_32_LE_BOM = -131072;
   private static final int UTF_16_BE_BOM = -16842752;
   private static final int UTF_16_LE_BOM = -131072;
   private static final int UTF_8_BOM = -272908544;
   private static final int UNUSUAL_OCTET_1 = 15360;
   private static final int UNUSUAL_OCTET_2 = 3932160;
   private static final int UTF_16BE = 3932223;
   private static final int UTF_16LE = 1006649088;
   private static final int EBCDIC = 1282385812;
   private static final int XML_DECLARATION = 1010792557;
   private static final String UTF_32_ENC = "UTF-32";
   private static final String UTF_16_ENC = "UTF-16";
   private static final String UTF_16BE_ENC = "UTF-16BE";
   private static final String UTF_16LE_ENC = "UTF-16LE";
   private static final String UTF_8_ENC = "UTF-8";
   private static final String IBM037_ENC = "IBM037";
   private static final String XML_DECL_START = "<?xml";
   private static final String ENCODING_DECL = "encoding";

   public static String decodeXML(byte[] var0) throws IOException {
      byte var1 = 0;
      Object var2 = null;
      if (var0.length < 4) {
         throw new EOFException(ResourceManager.getMessage("encoding.error.not.xml"));
      } else {
         int var3 = 0xFF000000 & var0[0] << 24 | 0xFF0000 & var0[1] << 16 | 0xFF00 & var0[2] << 8 | 255 & var0[3];
         switch (var3) {
            case -131072:
            case 65279:
               var2 = "UTF-32";
               break;
            case 15360:
            case 3932160:
               throw new UnsupportedEncodingException(ResourceManager.getMessage("encoding.error.unusual.octet"));
            case 3932223:
               var2 = "UTF-16BE";
               Trace.println("Detected UTF-16BE encoding from first four bytes", TraceLevel.BASIC);
               break;
            case 1006649088:
               var2 = "UTF-16LE";
               Trace.println("Detected UTF-16LE encoding from first four bytes", TraceLevel.BASIC);
               break;
            case 1010792557:
               var2 = examineEncodingDeclaration(var0, "UTF-8");
               break;
            case 1282385812:
               var2 = examineEncodingDeclaration(var0, "IBM037");
               break;
            default:
               int var4 = var3 & -256;
               switch (var4) {
                  case -272908544:
                     var1 = 3;
                     var2 = "UTF-8";
                     break;
                  default:
                     int var5 = var3 & -65536;
                     switch (var5) {
                        case -16842752:
                        case -131072:
                           var2 = "UTF-16";
                           break;
                        default:
                           var2 = "UTF-8";
                     }
               }
         }

         return new String(var0, var1, var0.length - var1, (String)var2);
      }
   }

   private static String examineEncodingDeclaration(byte[] var0, String var1) throws IOException {
      boolean var2 = false;
      boolean var3 = false;
      boolean var4 = false;
      boolean var5 = false;
      boolean var6 = false;
      boolean var7 = false;
      int var8 = 0;
      int var9 = -1;
      Reader var10 = null;
      String var11 = var1 != null ? var1 : "UTF-8";
      var10 = new InputStreamReader(new ByteArrayInputStream(var0), var11);
      var9 = var10.read();

      for (int var12 = 0; var12 < "<?xml".length() && !var6; var12++) {
         if (var9 != "<?xml".charAt(var12)) {
            var6 = true;
            break;
         }

         var9 = var10.read();
      }

      var2 = true;

      while (var2 && !var6) {
         switch (var9) {
            case -1:
               var6 = true;
               break;
            case 9:
            case 10:
            case 13:
            case 32:
               var9 = var10.read();
               break;
            default:
               var2 = false;
         }
      }

      var2 = true;

      while (var2 && !var6) {
         if (var9 == -1) {
            var6 = true;
            break;
         }

         if (var3) {
            switch (var9) {
               case 9:
               case 10:
               case 13:
               case 32:
                  break;
               case 34:
               case 39:
                  if (var4) {
                     var2 = false;
                  } else {
                     var3 = false;
                     var6 = true;
                  }
                  break;
               case 61:
                  if (!var4) {
                     var4 = true;
                  } else {
                     var3 = false;
                     var6 = true;
                  }
                  break;
               default:
                  var3 = false;
                  if (var4) {
                     var6 = true;
                  }
            }

            if (!var3) {
               var8 = 0;
               continue;
            }
         } else if (var9 == "encoding".charAt(var8++)) {
            if ("encoding".length() == var8) {
               var3 = true;
            }
         } else if (var9 == 63) {
            var5 = true;
            var8 = 0;
         } else {
            if (var9 == 62 && var5) {
               var6 = true;
               continue;
            }

            var8 = 0;
         }

         var9 = var10.read();
      }

      if (!var6) {
         StringBuffer var21 = new StringBuffer(512);
         if ((var9 >= 97 && var9 <= 122) | (var9 >= 65 && var9 <= 90)) {
            var21.append((char)var9);
            var2 = true;

            while (var2 && !var6) {
               var9 = var10.read();
               if ((var9 < 97 || var9 > 122) && (var9 < 65 || var9 > 90) && (var9 < 48 || var9 > 57) && var9 != 95 && var9 != 46 && var9 != 45) {
                  if (var9 != 34 && var9 != 39) {
                     var6 = true;
                  } else {
                     var7 = true;
                     var6 = true;
                     var11 = var21.toString();
                  }
               } else {
                  var21.append((char)var9);
               }
            }
         } else {
            var6 = true;
         }
      }

      return var11;
   }
}
