package com.sun.deploy.xml;

import java.io.PrintWriter;
import java.io.StringWriter;

public class XMLNode {
   private boolean _isElement = true;
   private String _name;
   private XMLAttribute _attr;
   private XMLNode _parent;
   private XMLNode _nested;
   private XMLNode _next;

   public XMLNode(String var1) {
      this(var1, null, null, null);
      this._isElement = false;
   }

   public XMLNode(String var1, XMLAttribute var2) {
      this(var1, var2, null, null);
   }

   public XMLNode(String var1, XMLAttribute var2, XMLNode var3, XMLNode var4) {
      this._name = var1;
      this._attr = var2;
      this._nested = var3;
      this._next = var4;
      this._parent = null;
   }

   public String getName() {
      return this._name;
   }

   public XMLAttribute getAttributes() {
      return this._attr;
   }

   public XMLNode getNested() {
      return this._nested;
   }

   public XMLNode getNext() {
      return this._next;
   }

   public boolean isElement() {
      return this._isElement;
   }

   public void setParent(XMLNode var1) {
      this._parent = var1;
   }

   public XMLNode getParent() {
      return this._parent;
   }

   public void setNext(XMLNode var1) {
      this._next = var1;
   }

   public void setNested(XMLNode var1) {
      this._nested = var1;
   }

   public boolean equals(Object var1) {
      if (var1 != null && var1 instanceof XMLNode) {
         XMLNode var2 = (XMLNode)var1;
         return match(this._name, var2._name) && match(this._attr, var2._attr) && match(this._nested, var2._nested) && match(this._next, var2._next);
      } else {
         return false;
      }
   }

   public String getAttribute(String var1) {
      for (XMLAttribute var2 = this._attr; var2 != null; var2 = var2.getNext()) {
         if (var1.equals(var2.getName())) {
            return var2.getValue();
         }
      }

      return "";
   }

   private static boolean match(Object var0, Object var1) {
      return var0 == null ? var1 == null : var0.equals(var1);
   }

   public void printToStream(PrintWriter var1) {
      this.printToStream(var1, 0);
   }

   public void printToStream(PrintWriter var1, int var2) {
      if (!this.isElement()) {
         var1.print(this._name);
      } else if (this._nested == null) {
         String var3 = this._attr == null ? "" : " " + this._attr.toString();
         lineln(var1, var2, "<" + this._name + var3 + "/>");
      } else {
         String var4 = this._attr == null ? "" : " " + this._attr.toString();
         lineln(var1, var2, "<" + this._name + var4 + ">");
         this._nested.printToStream(var1, var2 + 1);
         if (this._nested.isElement()) {
            lineln(var1, var2, "</" + this._name + ">");
         } else {
            var1.print("</" + this._name + ">");
         }
      }

      if (this._next != null) {
         this._next.printToStream(var1, var2);
      }
   }

   private static void lineln(PrintWriter var0, int var1, String var2) {
      var0.println("");

      for (int var3 = 0; var3 < var1; var3++) {
         var0.print("  ");
      }

      var0.print(var2);
   }

   public String toString() {
      StringWriter var1 = new StringWriter(1000);
      PrintWriter var2 = new PrintWriter(var1);
      this.printToStream(var2);
      var2.close();
      return var1.toString();
   }
}
