package com.sun.deploy.xml;

import com.sun.deploy.util.Trace;
import com.sun.deploy.util.TraceLevel;

public class XMLParser {
   public XMLNode _root;
   public String _source;
   public String _current;
   public int _tokenType;
   public String _tokenData;
   public static final int TOKEN_EOF = 1;
   public static final int TOKEN_END_TAG = 2;
   public static final int TOKEN_BEGIN_TAG = 3;
   public static final int TOKEN_CLOSE_TAG = 4;
   public static final int TOKEN_EMPTY_CLOSE_TAG = 5;
   public static final int TOKEN_PCDATA = 6;
   public static final GeneralEntity[] REQUIRED_CHARACTER_REFERENCES = new GeneralEntity[]{
      new GeneralEntity("quot", "\""),
      new GeneralEntity("amp", "&"),
      new GeneralEntity("apos", "'"),
      new GeneralEntity("lt", "<"),
      new GeneralEntity("gt", ">")
   };
   private static final String CDStart = "<![CDATA[";
   private static final String CDEnd = "]]>";

   public XMLParser(String var1) {
      Trace.println("new XMLParser with source:", TraceLevel.TEMP);
      Trace.println(var1, TraceLevel.TEMP);
      this._source = var1;
      this._current = var1;
      this._root = null;
      this._tokenData = null;
   }

   public XMLNode parse() throws BadTokenException {
      try {
         this.nextToken(this._current);
         this._root = this.parseXMLElement(this._current);
      } catch (NullPointerException var2) {
         Trace.println("NULL Pointer Exception: " + var2, TraceLevel.TEMP);
         throw var2;
      } catch (BadTokenException var3) {
         Trace.println("JNLP Parse Exception: " + var3, TraceLevel.TEMP);
         throw var3;
      }

      Trace.println("\n\nreturning ROOT as follows:\n" + this._root, TraceLevel.TEMP);
      return this._root;
   }

   private void nextToken(String var1) throws BadTokenException {
      this._current = this.skipFilling(var1);
      if (this._current == null) {
         this._tokenType = 1;
      } else if (this._current.startsWith("</")) {
         this._tokenType = 2;
         this._current = this.skipXMLName(this.skipForward(this._current, 2, 0));
      } else if (this._current.startsWith("<")) {
         this._tokenType = 3;
         this._current = this.skipXMLName(this.skipForward(this._current, 1, 0));
      } else if (this._current.startsWith(">")) {
         this._tokenType = 4;
         this._current = this.skipForward(this._current, 1, 0);
      } else if (this._current.startsWith("/>")) {
         this._tokenType = 5;
         this._current = this.skipForward(this._current, 2, 0);
      } else {
         this._tokenType = 6;
         this._current = this.skipPCData(var1, '<');
      }
   }

   private String skipPCData(String var1, char var2) throws BadTokenException {
      int var3 = var1.indexOf(var2);
      String var4 = null;
      if (var3 >= 0) {
         int var5 = var1.indexOf("<![CDATA[");
         if (var5 >= 0 && var5 <= var3) {
            String var6 = this.parseCharacterReferences(var1.substring(0, var5));
            String var7 = var1.substring(var5 + "<![CDATA[".length());
            int var8 = var7.indexOf("]]>");
            if (var8 < 0) {
               this._current = var7;
               throw new BadTokenException("Found the start of a PCDATA element with no end marker.", this._source, this.getLineNumber());
            }

            var4 = this.skipPCData(var7.substring(var8 + "]]>".length()), var2);
            this._tokenData = var6 + var7.substring(0, var8) + this._tokenData;
         } else {
            this._tokenData = this.parseCharacterReferences(var1.substring(0, var3));
            var4 = var1.substring(var3);
         }
      } else if (var1.trim().length() != 0) {
         this._current = var1;
         throw new BadTokenException("Failed to find the '" + var2 + "' charater that marks the end of a CDATA element.", this._source, this.getLineNumber());
      }

      return var4;
   }

   private XMLNode parseXMLElement(String var1) throws BadTokenException {
      if (this._tokenType != 3) {
         if (this._tokenType == 6) {
            XMLNode var10 = new XMLNode(this._tokenData);
            this.nextToken(this._current);
            return var10;
         } else {
            return null;
         }
      } else {
         String var9 = this._tokenData;
         XMLAttribute var8 = this.parseXMLAttribute(this._current);
         XMLAttribute var6 = var8;

         while (var6 != null) {
            XMLAttribute var7 = this.parseXMLAttribute(this._current);
            var6.setNext(var7);
            var6 = var7;
         }

         XMLNode var2 = new XMLNode(var9, var8);
         this.nextToken(this._current);
         if (this._tokenType != 5 && this._tokenType != 4 && this._tokenType != 1) {
            throw new BadTokenException(this._source, this.getLineNumber());
         } else {
            if (this._tokenType == 5) {
               this.nextToken(this._current);
            } else if (this._tokenType == 4) {
               this.nextToken(this._current);
               XMLNode var4 = this.parseXMLElement(this._current);
               if (var4 != null) {
                  var2.setNested(var4);
                  var4.setParent(var2);
               }

               if (this._tokenType == 2) {
                  do {
                     this.nextToken(this._current);
                  } while (this._tokenType != 1 && this._tokenType != 4);

                  this.nextToken(this._current);
               }
            }

            if (this._tokenType != 1) {
               XMLNode var5 = this.parseXMLElement(this._current);
               var2.setNext(var5);
            }

            return var2;
         }
      }
   }

   private XMLAttribute parseXMLAttribute(String var1) throws BadTokenException {
      if (var1 == null) {
         return null;
      } else {
         this._current = this.skipFilling(var1);
         if (this._current != null && !this._current.startsWith(">") && !this._current.startsWith("/>")) {
            this._current = this.skipAttributeName(this._current);
            String var2 = this._tokenData;
            this._current = this.skipFilling(this._current);
            if (!this._current.startsWith("=")) {
               if (var1.equals(this._current)) {
                  this._current = this.skipForward(this._current, 1, 0);
               }

               return this.parseXMLAttribute(this._current);
            } else {
               this._current = this.skipForward(this._current, 1, 0);
               this._current = this.skipWhitespace(this._current);
               String var3;
               if (!this._current.startsWith("\"") && !this._current.startsWith("'")) {
                  this._current = this.skipNonSpace(this._current);
                  var3 = this._tokenData;
               } else {
                  char var4 = this._current.charAt(0);
                  this._current = this.skipForward(this._current, 1, 0);
                  this._current = this.skipPCData(this._current, var4);
                  var3 = this._tokenData;
                  this._current = this.skipForward(this._current, 1, 0);
               }

               if (var3 != null) {
                  var3 = var3.trim();
               }

               return new XMLAttribute(var2, var3);
            }
         } else {
            return null;
         }
      }
   }

   private String parseCharacterReferences(String var1) {
      String var2 = var1;
      int var3 = var1.indexOf("&");
      if (var3 >= 0) {
         String var4 = var1.substring(0, var3);
         String var5 = "&";
         String var6 = var1.substring(var3 + 1);
         int var7 = var1.indexOf(";", var3);
         if (var7 > var3) {
            boolean var8 = false;
            var5 = var1.substring(var3 + 1, var7);
            var6 = var1.substring(var7 + 1);
            if (var5.startsWith("#")) {
               try {
                  byte var9 = 10;
                  byte var10 = 1;
                  char[] var11 = new char[]{'\u0000'};
                  if (var5.startsWith("#x")) {
                     var9 = 16;
                     var10 = 2;
                  }

                  var11[0] = (char)Integer.parseInt(var5.substring(var10), var9);
                  var5 = new String(var11);
                  var8 = true;
               } catch (NumberFormatException var12) {
               }
            } else {
               for (int var13 = 0; var13 < REQUIRED_CHARACTER_REFERENCES.length; var13++) {
                  if (REQUIRED_CHARACTER_REFERENCES[var13].equals(var5)) {
                     var5 = REQUIRED_CHARACTER_REFERENCES[var13].getValue();
                     var8 = true;
                     break;
                  }
               }
            }

            if (!var8) {
               var5 = "&" + var5 + ";";
               Trace.println("Unrecognized character entity reference: " + var5, TraceLevel.BASIC);
            }
         }

         var2 = var4 + var5 + this.parseCharacterReferences(var6);
      }

      return var2;
   }

   private String skipForward(String var1, int var2, int var3) {
      return var2 >= 0 && var2 + var3 < var1.length() ? var1.substring(var2 + var3) : null;
   }

   private String skipNonSpace(String var1) throws BadTokenException {
      int var2 = 0;
      if (var1 == null) {
         return null;
      } else {
         int var3 = var1.length();

         while (var2 < var3 && !Character.isWhitespace(var1.charAt(var2))) {
            var2++;
         }

         return this.skipPCData(var1, var1.charAt(var2));
      }
   }

   private String skipWhitespace(String var1) {
      int var2 = 0;
      if (var1 == null) {
         return null;
      } else {
         while (var2 < var1.length() && Character.isWhitespace(var1.charAt(var2))) {
            var2++;
         }

         return var1.substring(var2);
      }
   }

   private boolean legalTokenStartChar(char var1) {
      return var1 >= 'a' && var1 <= 'z' || var1 >= 'A' && var1 <= 'Z' || var1 == '_' || var1 == ':';
   }

   private boolean legalTokenChar(char var1) {
      return var1 >= 'a' && var1 <= 'z' || var1 >= 'A' && var1 <= 'Z' || var1 >= '0' && var1 <= '9' || var1 == '_' || var1 == ':' || var1 == '.' || var1 == '-';
   }

   private String skipAttributeName(String var1) {
      if (var1 == null) {
         return null;
      } else {
         int var2 = var1.indexOf("=");
         if (var2 >= 0) {
            this._tokenData = var1.substring(0, var2);
            if (this._tokenData != null) {
               this._tokenData = this._tokenData.trim();
            }
         } else {
            this._tokenData = null;
         }

         return this.skipForward(var1, var2, 0);
      }
   }

   private String skipXMLName(String var1) {
      int var2 = 0;
      if (var1 == null) {
         return null;
      } else {
         if (this.legalTokenStartChar(var1.charAt(0))) {
            var2 = 1;

            while (var2 < var1.length() && this.legalTokenChar(var1.charAt(var2))) {
               var2++;
            }
         }

         this._tokenData = var1.substring(0, var2);
         if (this._tokenData != null) {
            this._tokenData = this._tokenData.trim();
         }

         return this.skipForward(var1, var2, 0);
      }
   }

   private String skipXMLComment(String var1) {
      if (var1 != null && var1.startsWith("<!--")) {
         int var2 = var1.indexOf("-->", 4);
         return this.skipForward(var1, var2, 3);
      } else {
         return var1;
      }
   }

   private String skipXMLDocType(String var1) {
      if (var1 != null && var1.startsWith("<!")) {
         int var2 = var1.indexOf(">", 2);
         return this.skipForward(var1, var2, 1);
      } else {
         return var1;
      }
   }

   private String skipXMLProlog(String var1) {
      if (var1 != null && var1.startsWith("<?")) {
         int var2 = var1.indexOf("?>", 2);
         return this.skipForward(var1, var2, 2);
      } else {
         return var1;
      }
   }

   private String skipFilling(String var1) {
      String var2 = var1;

      String var3;
      do {
         var3 = var2;
         var2 = this.skipWhitespace(var2);
         var2 = this.skipXMLComment(var2);
         var2 = this.skipXMLDocType(var2);
         var2 = this.skipXMLProlog(var2);
      } while (var2 != var3);

      return var2;
   }

   private int getLineNumber() {
      int var1;
      if (this._current == null) {
         var1 = this._source.length();
      } else {
         var1 = this._source.indexOf(this._current);
      }

      int var2 = 0;
      int var3 = 0;

      while (var3 < var1 && var3 != -1) {
         var3 = this._source.indexOf("\n", var3);
         if (var3 >= 0) {
            var3++;
            var2++;
         }
      }

      return var2;
   }
}
