package sun.net.www.protocol.https;

import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.text.MessageFormat;
import java.util.List;
import java.util.Map;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLSocketFactory;
import sun.net.www.MessageHeader;
import sun.plugin.cache.CachedFile;
import sun.plugin.cache.FileCache;
import sun.plugin.net.cookie.PluginCookieManager;
import sun.plugin.net.proxy.PluginProxyManager;
import sun.plugin.net.proxy.ProxyInfo;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.util.ProgressInputStream;
import sun.plugin.util.ThreadGroupLocal;
import sun.plugin.util.Trace;

final class PluginDelegateHttpsURLConnection extends DelegateHttpsURLConnection {
   private String proxy = null;
   private int proxyPort = -1;
   private MessageHeader cachedHeaders = null;
   private boolean progressTracking = false;
   private int callCount = 0;
   private static MessageFormat mf1 = new MessageFormat(ResourceHandler.getMessage("net.connect.no_proxy"));
   private static MessageFormat mf2 = new MessageFormat(ResourceHandler.getMessage("net.connect.proxy_is"));
   private static Method New;
   private boolean securityCheck = false;
   private boolean cacheConnect = false;
   private boolean realConnect = false;
   private boolean checkSetCookie = false;
   private InputStream cacheStream = null;
   static Class class$sun$net$www$protocol$https$HttpsClient;
   static Class class$javax$net$ssl$SSLSocketFactory;
   static Class class$java$net$URL;
   static Class class$javax$net$ssl$HostnameVerifier;
   static Class class$java$lang$String;

   static {
      try {
         New = AccessController.doPrivileged(new PluginDelegateHttpsURLConnection$1());
      } catch (PrivilegedActionException var1) {
         Trace.netPrintException(var1);
      }
   }

   public synchronized void addCookieHeader() {
      String var1 = PluginCookieManager.getCookieInfo(this.url);
      if (var1 != null) {
         this.addRequestProperty("cookie", var1);
      }

      this.checkSetCookie = false;
   }

   public synchronized void checkCookieHeader() {
      if (!this.checkSetCookie) {
         this.checkSetCookie = true;
         Map var1 = this.getHeaderFields();

         for (String var3 : var1.keySet()) {
            if (var3 != null && var3.equalsIgnoreCase("Set-Cookie")) {
               for (String var6 : (List)var1.get(var3)) {
                  if (var6 != null) {
                     PluginCookieManager.setCookieInfo(this.url, var6);
                  }
               }
            }
         }
      }
   }

   private void checkPermission() throws IOException {
      if (!this.securityCheck) {
         SecurityManager var1 = System.getSecurityManager();
         if (var1 != null) {
            var1.checkConnect(this.url.getHost(), this.url.getPort());
         }

         this.securityCheck = true;
      }
   }

   public synchronized void connect() throws IOException {
      if (!this.isConnected()) {
         this.checkPermission();
         if (this.getRequestMethod().equalsIgnoreCase("GET") && ThreadGroupLocal.get("javaplugin.progressTracking") != null) {
            this.progressTracking = true;
         }

         this.connectWithCache();
         if (this.cacheStream == null) {
            this.connectSetup();
            this.superConnect();
         }

         this.setConnected(true);
      }
   }

   private void connectSetup() throws IOException {
      if (!this.realConnect) {
         if (this.proxy == null) {
            ProxyInfo var1 = PluginProxyManager.getProxyInfo(this.url);
            if (var1 != null) {
               this.proxy = var1.getProxy();
               this.proxyPort = var1.getPort();
            }
         }

         if (this.proxy == null) {
            Object[] var2 = new Object[]{this.url};
            Trace.netPrintln(mf1.format(var2), 2);
         } else {
            Object[] var3 = new Object[]{this.url, this.proxy + (this.proxyPort != -1 ? ":" + this.proxyPort : "")};
            Trace.netPrintln(mf2.format(var3), 2);
         }

         if (this.getRequestProperty("cookie") == null) {
            String var4 = PluginCookieManager.getCookieInfo(this.url);
            if (var4 != null) {
               this.addRequestProperty("cookie", var4);
            }
         }

         this.realConnect = true;
      }
   }

   private void connectWithCache() throws IOException {
      if (!this.cacheConnect) {
         if (this.getUseCaches() && this.getRequestMethod().equalsIgnoreCase("GET")) {
            try {
               CachedFile var1 = FileCache.get(this.url);
               if (var1 != null) {
                  InputStream var2 = null;

                  try {
                     var2 = AccessController.doPrivileged(new PluginDelegateHttpsURLConnection$2(this, var1));
                  } catch (PrivilegedActionException var4) {
                  }

                  if (var2 != null) {
                     this.responseCode = 200;
                     this.cachedHeaders = var1.getHeaderFields();
                     if (this.progressTracking) {
                        this.cacheStream = new ProgressInputStream(var2, this);
                     } else {
                        this.cacheStream = var2;
                     }
                  }
               }
            } catch (IOException var5) {
               Trace.netPrintException(var5);
            }
         }

         this.cacheConnect = true;
      }
   }

   public synchronized void disconnect() {
      super.disconnect();
      if (this.cacheStream != null) {
         this.cacheStream = null;
      }

      if (this.cachedHeaders != null) {
         this.cachedHeaders.reset();
      }
   }

   private void superConnect() throws IOException {
      if (!this.isConnected()) {
         if (this.proxy == null) {
            this.setNewClient(this.url, true);
         } else {
            this.setProxiedClient(this.url, this.proxy, this.proxyPort, true);
         }
      }
   }

   public boolean usingProxy() {
      ProxyInfo var1 = PluginProxyManager.getProxyInfo(this.url);
      return var1 != null && var1.getProxy() != null;
   }

   public synchronized InputStream getInputStream() throws IOException {
      this.connect();

      InputStream var2;
      try {
         this.callCount++;
         if (this.cacheStream != null) {
            return this.cacheStream;
         }

         InputStream var1 = super.getInputStream();
         if (this.callCount != 1) {
            return var1;
         }

         if (var1 != null) {
            if (this.progressTracking && !(var1 instanceof ProgressInputStream)) {
               this.cacheStream = new ProgressInputStream(var1, this);
            } else {
               this.cacheStream = var1;
            }
         }

         this.checkCookieHeader();
         var2 = this.cacheStream;
      } finally {
         this.callCount--;
      }

      return var2;
   }

   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError().initCause(var2);
      }
   }

   public String getHeaderField(String var1) {
      String var2 = null;

      try {
         this.getInputStream();
      } catch (IOException var4) {
      }

      if (this.cachedHeaders != null) {
         var2 = this.cachedHeaders.findValue(var1);
      } else {
         var2 = super.getHeaderField(var1);
      }

      return var2;
   }

   protected void proxiedConnect(URL var1, String var2, int var3, boolean var4) throws IOException {
      if (!this.isConnected()) {
         SSLSocketFactory var5 = this.getSSLSocketFactory();
         HostnameVerifier var6 = this.getHostnameVerifier();
         Object[] var7 = new Object[]{var5, var1, var6, var2, new Integer(var3), new Boolean(var4)};

         try {
            this.http = (HttpsClient)New.invoke(null, var7);
         } catch (IllegalAccessException var10) {
            IllegalAccessError var9 = new IllegalAccessError();
            var9.initCause(var10);
            throw var9;
         } catch (InvocationTargetException var11) {
            throw (IOException)var11.getTargetException();
         }

         this.setConnected(true);
      }
   }

   public PluginDelegateHttpsURLConnection(URL var1, Handler var2, HttpsURLConnection var3) throws IOException {
      super(var1, var2, var3);
   }
}
