package sun.plugin;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.Insets;
import java.security.AccessController;
import java.util.Enumeration;
import java.util.TreeSet;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JViewport;
import javax.swing.KeyStroke;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.services.BrowserService;
import sun.plugin.services.ServiceProvider;
import sun.plugin.util.PluginSysUtil;
import sun.plugin.util.PluginUIManager;
import sun.security.action.GetPropertyAction;

class ConsoleWindow extends JFrame {
   private JTextArea textArea;
   private JScrollPane scroller;
   private JScrollBar sbHor;
   private JScrollBar sbVer;
   private boolean onWindows;
   private boolean isMozilla;
   private boolean iconifiedOnClose;
   private static final int TEXT_LIMIT = 1048575;

   ConsoleWindow() {
      super(ResourceHandler.getMessage("console.caption"));
      PluginUIManager.setTheme();
      this.onWindows = false;
      this.isMozilla = false;
      this.iconifiedOnClose = false;

      try {
         String var1 = AccessController.doPrivileged(new GetPropertyAction("os.name"));
         if (var1.indexOf("Windows") != -1) {
            this.onWindows = true;
         }

         String var2 = AccessController.doPrivileged(new GetPropertyAction("mozilla.workaround", "false"));
         if (var2 != null && var2.equalsIgnoreCase("true")) {
            this.isMozilla = true;
         }

         BrowserService var3 = ServiceProvider.getService();
         this.iconifiedOnClose = var3.isConsoleIconifiedOnClose();
      } catch (Exception var27) {
         var27.printStackTrace();
      }

      this.setSize(450, 400);
      this.setResizable(true);
      this.setDefaultCloseOperation(0);
      if (!this.onWindows && this.isMozilla) {
         this.getRootPane().setDoubleBuffered(false);
         ((JPanel)this.getContentPane()).setDoubleBuffered(false);
      }

      this.getContentPane().setLayout(new BorderLayout());
      this.textArea = new JTextArea();
      this.textArea.setEditable(false);
      this.textArea.setMargin(new Insets(0, 5, 0, 0));
      this.scroller = new JScrollPane(this.textArea);
      JViewport var28 = this.scroller.getViewport();
      var28.setScrollMode(1);
      this.sbVer = this.scroller.getVerticalScrollBar();
      this.sbHor = this.scroller.getHorizontalScrollBar();
      this.getContentPane().add(this.scroller, "Center");
      ConsoleWindow$1 var29 = new ConsoleWindow$1(this);
      ConsoleWindow$2 var30 = new ConsoleWindow$2(this);
      ConsoleWindow$3 var4 = new ConsoleWindow$3(this);
      ConsoleWindow$4 var5 = new ConsoleWindow$4(this);
      ConsoleWindow$5 var6 = new ConsoleWindow$5(this);
      ConsoleWindow$6 var7 = new ConsoleWindow$6(this);
      ConsoleWindow$7 var8 = new ConsoleWindow$7(this);
      ConsoleWindow$8 var9 = new ConsoleWindow$8(this);
      ConsoleWindow$9 var10 = new ConsoleWindow$9(this);
      ConsoleWindow$10 var11 = new ConsoleWindow$10(this);
      ConsoleWindow$11 var12 = new ConsoleWindow$11(this);
      ConsoleWindow$12 var13 = new ConsoleWindow$12(this);
      ConsoleWindow$13 var14 = new ConsoleWindow$13(this, var13);
      ConsoleWindow$14 var15 = new ConsoleWindow$14(this, var13);
      ConsoleWindow$15 var16 = new ConsoleWindow$15(this);
      ConsoleWindow$16 var17 = new ConsoleWindow$16(this);
      ConsoleWindow$17 var18 = new ConsoleWindow$17(this);
      ConsoleWindow$18 var19 = new ConsoleWindow$18(this);
      ConsoleWindow$19 var20 = new ConsoleWindow$19(this);
      ConsoleWindow$20 var21 = new ConsoleWindow$20(this);
      ConsoleWindow$21 var22 = new ConsoleWindow$21(this);
      if (this.onWindows) {
         String var23 = System.getProperty("javaplugin.vm.options");
         if (var23.indexOf("-Xrunjcov") != -1) {
            ConsoleWindow$22 var24 = new ConsoleWindow$22(this);
            this.textArea.registerKeyboardAction(var24, KeyStroke.getKeyStroke(74, 0), 2);
         }
      }

      this.textArea.registerKeyboardAction(var29, KeyStroke.getKeyStroke(86, 0), 2);
      this.textArea.registerKeyboardAction(var30, KeyStroke.getKeyStroke(84, 0), 2);
      this.textArea.registerKeyboardAction(var5, KeyStroke.getKeyStroke(80, 0), 2);
      this.textArea.registerKeyboardAction(var4, KeyStroke.getKeyStroke(82, 0), 2);
      this.textArea.registerKeyboardAction(var6, KeyStroke.getKeyStroke(83, 0), 2);
      this.textArea.registerKeyboardAction(var7, KeyStroke.getKeyStroke(72, 0), 2);
      this.textArea.registerKeyboardAction(var13, KeyStroke.getKeyStroke(77, 0), 2);
      this.textArea.registerKeyboardAction(var10, KeyStroke.getKeyStroke(67, 0), 2);
      this.textArea.registerKeyboardAction(var15, KeyStroke.getKeyStroke(71, 0), 2);
      this.textArea.registerKeyboardAction(var14, KeyStroke.getKeyStroke(70, 0), 2);
      this.textArea.registerKeyboardAction(var12, KeyStroke.getKeyStroke(81, 0), 2);
      this.textArea.registerKeyboardAction(var16, KeyStroke.getKeyStroke(48, 0), 2);
      this.textArea.registerKeyboardAction(var17, KeyStroke.getKeyStroke(49, 0), 2);
      this.textArea.registerKeyboardAction(var18, KeyStroke.getKeyStroke(50, 0), 2);
      this.textArea.registerKeyboardAction(var19, KeyStroke.getKeyStroke(51, 0), 2);
      this.textArea.registerKeyboardAction(var20, KeyStroke.getKeyStroke(52, 0), 2);
      this.textArea.registerKeyboardAction(var21, KeyStroke.getKeyStroke(53, 0), 2);
      this.textArea.registerKeyboardAction(var9, KeyStroke.getKeyStroke(88, 0), 2);
      this.textArea.registerKeyboardAction(var8, KeyStroke.getKeyStroke(76, 0), 2);
      this.textArea.registerKeyboardAction(var22, KeyStroke.getKeyStroke(79, 0), 2);
      JButton var31 = new JButton(ResourceHandler.getMessage("console.clear"));
      var31.setMnemonic(ResourceHandler.getAcceleratorKey("console.clear"));
      JButton var32 = new JButton(ResourceHandler.getMessage("console.copy"));
      var32.setMnemonic(ResourceHandler.getAcceleratorKey("console.copy"));
      JButton var25 = new JButton(ResourceHandler.getMessage("console.close"));
      var25.setMnemonic(ResourceHandler.getAcceleratorKey("console.close"));
      JPanel var26 = new JPanel();
      var26.setLayout(new FlowLayout(1));
      var26.add(var31);
      var26.add(new JLabel("    "));
      var26.add(var32);
      var26.add(new JLabel("    "));
      var26.add(var25);
      this.getContentPane().add(var26, "South");
      this.addWindowListener(new ConsoleWindow$23(this));
      var31.addActionListener(var10);
      var32.addActionListener(var11);
      var25.addActionListener(var12);
   }

   public static void displaySystemProperties() {
      TreeSet var0 = new TreeSet();
      Enumeration var1 = System.getProperties().propertyNames();

      while (var1.hasMoreElements()) {
         var0.add(var1.nextElement());
      }

      StringBuffer var5 = new StringBuffer();
      var5.append(ResourceHandler.getMessage("console.dump.properties"));
      var5.append(ResourceHandler.getMessage("console.menu.text.top"));

      for (String var3 : var0) {
         String var4 = System.getProperty(var3);
         if (var4 != null) {
            if (var4.equals("\n")) {
               var4 = "\\n";
            } else if (var4.equals("\r")) {
               var4 = "\\r";
            } else if (var4.equals("\r\n")) {
               var4 = "\\r\\n";
            } else if (var4.equals("\n\r")) {
               var4 = "\\n\\r";
            } else if (var4.equals("\n\n")) {
               var4 = "\\n\\n";
            } else if (var4.equals("\r\r")) {
               var4 = "\\r\\r";
            }
         }

         var5.append(var3 + " = " + var4 + "\n");
      }

      var5.append(ResourceHandler.getMessage("console.menu.text.tail"));
      var5.append(ResourceHandler.getMessage("console.done"));
      System.out.println(var5.toString());
   }

   public void setScrollPosition() {
      this.scroller.validate();
      this.sbVer.setValue(this.sbVer.getMaximum());
      this.sbHor.setValue(this.sbHor.getMinimum());
   }

   public boolean isConsoleVisible() {
      return this.iconifiedOnClose ? this.getState() == 0 : this.isVisible();
   }

   public void showConsole(boolean var1) {
      if (this.iconifiedOnClose) {
         if (var1) {
            this.setState(0);
         } else {
            this.setState(1);
         }

         this.setVisible(true);
      } else {
         if (this.isVisible() != var1) {
            this.setVisible(var1);
         }

         if (var1) {
            this.toFront();
         }
      }
   }

   public static String displayHelp() {
      StringBuffer var0 = new StringBuffer();
      var0.append(ResourceHandler.getMessage("console.menu.text.top"));
      var0.append(ResourceHandler.getMessage("console.menu.text.c"));
      var0.append(ResourceHandler.getMessage("console.menu.text.f"));
      var0.append(ResourceHandler.getMessage("console.menu.text.g"));
      var0.append(ResourceHandler.getMessage("console.menu.text.h"));
      String var1 = AccessController.doPrivileged(new GetPropertyAction("os.name"));
      if (var1.indexOf("Windows") != -1 && System.getProperty("javaplugin.vm.options").indexOf("-Xrunjcov") != -1) {
         var0.append(ResourceHandler.getMessage("console.menu.text.j"));
      }

      var0.append(ResourceHandler.getMessage("console.menu.text.l"));
      var0.append(ResourceHandler.getMessage("console.menu.text.m"));
      var0.append(ResourceHandler.getMessage("console.menu.text.o"));
      var0.append(ResourceHandler.getMessage("console.menu.text.p"));
      var0.append(ResourceHandler.getMessage("console.menu.text.q"));
      var0.append(ResourceHandler.getMessage("console.menu.text.r"));
      var0.append(ResourceHandler.getMessage("console.menu.text.s"));
      var0.append(ResourceHandler.getMessage("console.menu.text.t"));
      var0.append(ResourceHandler.getMessage("console.menu.text.v"));
      var0.append(ResourceHandler.getMessage("console.menu.text.x"));
      var0.append(ResourceHandler.getMessage("console.menu.text.0"));
      var0.append(ResourceHandler.getMessage("console.menu.text.tail"));
      return var0.toString();
   }

   public static String displayVersion() {
      StringBuffer var0 = new StringBuffer();
      var0.append(ResourceHandler.getMessage("product_name"));
      String var1 = System.getProperty("javaplugin.version");
      if (var1 != null) {
         var0.append(": " + ResourceHandler.getMessage("version") + " " + System.getProperty("javaplugin.version"));
      }

      var0.append("\n");
      var0.append(ResourceHandler.getMessage("using_jre_version"));
      var0.append(" ");
      var0.append(System.getProperty("java.version"));
      var0.append(" ");
      var0.append(System.getProperty("java.vm.name"));
      var0.append("\n");
      var0.append(ResourceHandler.getMessage("user_home_dir"));
      var0.append(" = ");
      var0.append(System.getProperty("user.home"));
      return var0.toString();
   }

   public void append(String var1) {
      PluginSysUtil.invokeLater(new ConsoleWindow$24(this, var1));
   }

   static boolean access$200(ConsoleWindow var0) {
      return var0.iconifiedOnClose;
   }

   private void dumpThreadGroup(ThreadGroup var1, StringBuffer var2) {
      if (var1 != null) {
         try {
            if (var1.activeCount() == 0 && var1.activeGroupCount() == 0 && !var1.isDestroyed()) {
               var1.destroy();
            }
         } catch (Throwable var6) {
         }

         var2.append("Group " + var1.getName());
         var2.append(",ac=" + var1.activeCount());
         var2.append(",agc=" + var1.activeGroupCount());
         var2.append(",pri=" + var1.getMaxPriority());
         if (var1.isDestroyed()) {
            var2.append(",destoyed");
         }

         if (var1.isDaemon()) {
            var2.append(",daemon");
         }

         var2.append("\n");
         Thread[] var3 = new Thread[1000];
         var1.enumerate(var3, false);

         for (int var4 = 0; var4 < var3.length; var4++) {
            if (var3[var4] != null) {
               var2.append("    ");
               var2.append(var3[var4].getName());
               var2.append(",");
               var2.append(var3[var4].getPriority());
               if (var3[var4].isAlive()) {
                  var2.append(",alive");
               } else {
                  var2.append(",not alive");
               }

               if (var3[var4].isDaemon()) {
                  var2.append(",dameon");
               }

               if (var3[var4].isInterrupted()) {
                  var2.append(",interrupted");
               }

               var2.append("\n");
            }
         }

         ThreadGroup[] var7 = new ThreadGroup[1000];
         var1.enumerate(var7, false);

         for (int var5 = 0; var5 < var7.length; var5++) {
            if (var7[var5] != null) {
               this.dumpThreadGroup(var7[var5], var2);
            }
         }
      }
   }

   static JTextArea access$100(ConsoleWindow var0) {
      return var0.textArea;
   }

   static void access$000(ConsoleWindow var0, ThreadGroup var1, StringBuffer var2) {
      var0.dumpThreadGroup(var1, var2);
   }
}
