package sun.plugin.cache;

import java.io.File;
import java.io.FilePermission;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.SocketPermission;
import java.net.URL;
import java.net.URLConnection;
import java.security.AccessController;
import java.security.Permission;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Random;
import sun.plugin.util.Trace;
import sun.plugin.util.UserProfile;
import sun.security.action.GetPropertyAction;

public class Cache {
   protected static long maxSize;
   protected static long threadThresholdSize;
   protected static long deleteThresholdSize;
   protected static boolean cachingDisabled = false;
   protected static Random random = new Random();
   protected static CleanupThread cleanupThread = null;
   protected static final byte INCOMPLETE = 0;
   protected static final byte UNUSABLE = 1;
   protected static final byte INUSE = 2;
   protected static final byte VERSION = 16;
   protected static final String INDEX_FILE_EXT = ".idx";
   protected static final long CLEANUP_INTERVAL = 1L;
   protected static final long MINIMUM_CACHE_SIZE = 5L;
   protected static final String DISABLED_PROP = "javaplugin.cache.disabled";
   protected static final String SIZE_PROP = "javaplugin.cache.size";
   protected static String KB = "{0} KB";
   protected static String MB = "{0} MB";
   protected static String BYTES = "{0} bytes";
   protected static String UNLIMITED = "unlimited";

   protected static final int getRandom() {
      return 268435456 + random.nextInt(1879048191);
   }

   static {
      String var0 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.cache.disabled", "false"));
      cachingDisabled = var0.equalsIgnoreCase("true");
      if (cachingDisabled) {
         msgPrintln("cache.disabled", null);
      } else {
         var0 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.cache.size", "50m"));
         var0.trim();
         long var1;
         MessageFormat var3;
         if (var0.endsWith("M") || var0.endsWith("m")) {
            var1 = 1048576L;
            var0 = var0.substring(0, var0.length() - 1);
            var3 = new MessageFormat(MB);
         } else if (!var0.endsWith("K") && !var0.endsWith("k")) {
            var1 = 1L;
            var3 = new MessageFormat(BYTES);
         } else {
            var1 = 1024L;
            var0 = var0.substring(0, var0.length() - 1);
            var3 = new MessageFormat(KB);
         }

         long var4;
         try {
            var4 = Long.valueOf(var0);
            maxSize = var1 * var4;
         } catch (NumberFormatException var8) {
            var4 = 50L;
            maxSize = 52428800L;
            var3 = new MessageFormat(MB);
         }

         String var6;
         if (var4 <= 0L) {
            var6 = UNLIMITED;
         } else {
            var6 = var3.format(new Object[]{new Long(var4)});
            ThreadGroup var7 = Thread.currentThread().getThreadGroup();

            while (var7.getParent() != null) {
               var7 = var7.getParent();
            }

            if (maxSize >= 5242880L) {
               threadThresholdSize = maxSize - 1048576L;
               deleteThresholdSize = maxSize - 2097152L;
               cleanupThread = new CleanupThread(var7, 60000L);
               cleanupThread.start();
            } else {
               cachingDisabled = true;
               msgPrintln("cache.minSize", new Object[]{var6});
               var6 = null;
            }
         }

         if (var6 != null) {
            msgPrintln("cache.enabled", null);
            msgPrintln("cache.location", new Object[]{UserProfile.getPluginCacheDirectory()});
            msgPrintln("cache.maxSize", new Object[]{var6});
         }
      }
   }

   public static void init() {
   }

   protected static final void touch(File var0) throws IOException {
      try {
         AccessController.doPrivileged(new Cache$3(var0));
      } catch (PrivilegedActionException var2) {
         throw new IOException(var2.getMessage());
      }
   }

   protected static int hashCode(URL var0) {
      int var1 = 0;
      String var2 = var0.getProtocol();
      if (var2 != null) {
         var1 += var2.hashCode();
      }

      String var3 = var0.getHost();
      if (var3 != null) {
         var1 += var3.toLowerCase().hashCode();
      }

      String var4 = var0.getFile();
      if (var4 != null) {
         var1 += var4.hashCode();
      }

      if (var0.getPort() == -1) {
         var1 += var0.getDefaultPort();
      } else {
         var1 += var0.getPort();
      }

      String var5 = var0.getRef();
      if (var5 != null) {
         var1 += var5.hashCode();
      }

      return var1;
   }

   protected static long getFileSizeFromServer(URL var0) throws IOException {
      long var1 = -1L;
      HttpURLConnection var3 = (HttpURLConnection)var0.openConnection();
      var3.setUseCaches(false);
      var3.setRequestMethod("HEAD");
      var1 = var3.getContentLength();
      var3.disconnect();
      return var1;
   }

   protected static final boolean isSupportedProtocol(URL var0) {
      String var1 = var0.getProtocol();
      return var1 != null && (var1.equalsIgnoreCase("http") || var1.equalsIgnoreCase("https"));
   }

   protected static void checkPermission(URLConnection var0) throws IOException {
      Permission var1 = var0.getPermission();
      URL var2 = var0.getURL();
      if (var1 != null) {
         SecurityManager var3 = System.getSecurityManager();
         if (var3 != null) {
            try {
               var3.checkPermission(var1);
            } catch (SecurityException var5) {
               if (var1 instanceof FilePermission && var1.getActions().indexOf("read") != -1) {
                  var3.checkRead(var1.getName());
               } else {
                  if (!(var1 instanceof SocketPermission) || var1.getActions().indexOf("connect") == -1) {
                     throw var5;
                  }

                  var3.checkConnect(var2.getHost(), var2.getPort());
               }
            }
         }
      }
   }

   protected static final void msgPrintln(String var0, Object[] var1) {
      Trace.msgPrintln(var0, var1);
   }

   protected static final String getFileExtension(String var0) {
      String var1 = "";
      int var2 = var0.lastIndexOf(46);
      if (var2 != -1) {
         var1 = var0.substring(var2);
      }

      if (var1.equalsIgnoreCase(".jar") || var1.equalsIgnoreCase(".jarjar")) {
         var1 = ".zip";
      }

      return var1;
   }

   protected static String parseKey(String var0) {
      String var1 = null;
      int var2 = var0.lastIndexOf("-");
      if (var2 != -1) {
         var1 = var0.substring(0, var2 + 1);
      }

      return var1;
   }

   protected static String getKey(URL var0) {
      String var1 = var0.getPath();
      int var2 = var1.lastIndexOf("/");
      if (var2 != -1) {
         var1 = var1.substring(var2 + 1);
      }

      int var3 = hashCode(var0);
      if (var3 < 0) {
         var3 += Integer.MIN_VALUE;
      }

      return var1 + "-" + Integer.toString(var3, 16) + "-";
   }

   protected static String getKeyOld(URL var0) {
      String var1 = var0.getPath();
      int var2 = var1.lastIndexOf("/");
      if (var2 != -1) {
         var1 = var1.substring(var2 + 1);
      }

      int var3 = var0.hashCode();
      if (var3 < 0) {
         var3 += Integer.MIN_VALUE;
      }

      return var1 + "-" + Integer.toString(var3, 16) + "-";
   }

   protected static void addToTable(File var0, Hashtable var1) {
      String var2 = parseKey(var0.getName());
      synchronized (var1) {
         ArrayList var4 = (ArrayList)var1.get(var2);
         if (var4 == null) {
            var4 = new ArrayList();
            var4.add(var0);
            var1.put(var2, var4);
         } else if (var4.indexOf(var0) == -1) {
            var4.add(var0);
         }
      }
   }

   protected static void createTable(File var0, Hashtable var1) {
      File[] var2 = var0.listFiles(new Cache$5());

      for (int var3 = 0; var3 < var2.length; var3++) {
         String var4 = parseKey(var2[var3].getName());
         ArrayList var5 = (ArrayList)var1.get(var4);
         if (var5 == null) {
            var5 = new ArrayList();
            var5.add(var2[var3]);
            var1.put(var4, var5);
         } else {
            var5.add(var2[var3]);
         }
      }
   }

   protected static void removeFromTable(File var0, Hashtable var1) {
      String var2 = parseKey(var0.getName());
      synchronized (var1) {
         ArrayList var4 = (ArrayList)var1.get(var2);
         if (var4 != null) {
            int var5 = var4.indexOf(var0);
            if (var5 != -1) {
               var4.remove(var5);
            }

            if (var4.size() == 0) {
               var1.remove(var2);
            }
         }
      }
   }

   protected static final File getDataFile(File var0, String var1) {
      String var2 = var0.getName();
      var2 = var2.substring(0, var2.length() - ".idx".length());
      var2 = var2 + getFileExtension(var1);
      return new File(var0.getParentFile(), var2);
   }

   protected static final File getIndexFile(File var0, URL var1) {
      String var2 = var0.getName();
      var2 = var2.substring(0, var2.length() - getFileExtension(var1.toString()).length());
      var2 = var2 + ".idx";
      return new File(var0.getParentFile(), var2);
   }

   protected static String generateCacheFileName(File var0, URL var1) throws IOException {
      String var2 = getKey(var1);

      String var3;
      File var4;
      File var5;
      do {
         var3 = var2 + Integer.toString(getRandom(), 16);
         var4 = new File(var0, var3 + getFileExtension(var1.toString()));
         var5 = new File(var0, var3 + ".idx");
      } while (var5.exists() || var4.exists());

      var5 = null;
      var4 = null;
      return var3;
   }

   protected static boolean updateTable(File var0, Hashtable var1, String var2) {
      boolean var3 = false;
      File[] var4 = var0.listFiles(new Cache$4(var2));

      for (int var5 = 0; var5 < var4.length; var5++) {
         synchronized (var1) {
            ArrayList var7 = (ArrayList)var1.get(var2);
            if (var7 == null) {
               var7 = new ArrayList();
               var7.add(var4[var5]);
               var1.put(var2, var7);
               var3 = true;
            } else if (var7.indexOf(var4[var5]) == -1) {
               var7.add(var4[var5]);
               var3 = true;
            }
         }
      }

      return var3;
   }

   protected static Enumeration getMatchingFiles(File var0, URL var1) {
      String var2 = getKey(var1);
      File[] var3 = var0.listFiles(new Cache$1(var2));
      return new Cache$2(var3);
   }

   protected static class CacheIOAction implements PrivilegedExceptionAction {
      public Object run() throws IOException {
         return null;
      }
   }
}
