package sun.plugin.cache;

import java.io.EOFException;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.Hashtable;
import java.util.Iterator;

public class CacheFile {
   private String name;
   private File indexFile = null;
   private File dataFile = null;
   private long size = 0L;
   private long date = 0L;
   private byte status = 1;
   private boolean usable = false;
   private boolean initialized = false;

   public int getFileType() {
      String var2 = Cache.getFileExtension(this.dataFile.getName());
      byte var1;
      if (var2.equalsIgnoreCase(".zip")) {
         var1 = 1;
      } else {
         var1 = 3;
      }

      return var1;
   }

   public long delete() {
      long var1 = 0L;
      if (this.status != 0) {
         if (this.dataFile != null) {
            long var3 = this.dataFile.length();
            Cache.msgPrintln("cache.full", new Object[]{this.dataFile.getName()});
            if (this.isLoaded(this.dataFile)) {
               Cache.msgPrintln("cache.inuse", new Object[]{this.dataFile.getName()});
            } else if (this.dataFile.delete()) {
               this.dataFile = null;
               var1 += var3;
            } else {
               Cache.msgPrintln("cache.notdeleted", new Object[]{this.dataFile.getName()});
            }
         }

         if (this.dataFile == null && this.indexFile != null) {
            long var5 = this.indexFile.length();
            Cache.msgPrintln("cache.full", new Object[]{this.indexFile.getName()});
            if (this.indexFile.delete()) {
               this.indexFile = null;
               var1 += var5;
            } else {
               Cache.msgPrintln("cache.notdeleted", new Object[]{this.indexFile.getName()});
            }
         }
      }

      return var1;
   }

   public long getDate() {
      return this.date;
   }

   public long getSize() {
      return this.size;
   }

   public void initialize() {
      if (this.dataFile != null && this.indexFile != null) {
         this.size = this.dataFile.length() + this.indexFile.length();
         this.date = this.indexFile.lastModified();
      } else if (this.dataFile != null) {
         this.size = this.dataFile.length();
      } else if (this.indexFile != null) {
         this.size = this.indexFile.length();
      }

      if (this.indexFile != null) {
         this.readStatus();
      }

      this.initialized = true;
   }

   public void readStatus() {
      RandomAccessFile var1 = null;

      try {
         var1 = new RandomAccessFile(this.indexFile, "r");
         this.status = var1.readByte();
      } catch (EOFException var14) {
         this.status = 0;
      } catch (IOException var15) {
         this.status = 0;
      } finally {
         if (var1 != null) {
            try {
               var1.close();
            } catch (IOException var13) {
            }
         }
      }
   }

   public boolean isUsable() {
      if (!this.initialized) {
         this.initialize();
      }

      return this.status != 1;
   }

   private boolean isLoaded(File var1) {
      boolean var2 = false;
      if (Cache.getFileExtension(var1.getName()).equalsIgnoreCase(".jar")) {
         Hashtable var3 = (Hashtable)JarCache.loadedJars.clone();
         Iterator var4 = var3.values().iterator();

         while (var4.hasNext() && !var2) {
            JarCache.JarReference var5 = (JarCache.JarReference)var4.next();
            if (var5 != null) {
               Object var6 = null;
               var6 = (CachedJarFile)var5.get();
               if (var6 != null) {
                  try {
                     if (new File(var6.getName()).getCanonicalPath().equals(var1.getCanonicalPath())) {
                        var2 = true;
                     }
                  } catch (IOException var9) {
                  }
               }
            }
         }
      } else {
         Hashtable var10 = (Hashtable)FileCache.loadedFiles.clone();
         Iterator var11 = var10.values().iterator();

         while (var11.hasNext() && !var2) {
            FileCache.FileReference var12 = (FileCache.FileReference)var11.next();
            if (var12 != null) {
               Object var14 = null;
               var14 = (File)var12.get();
               if (var14 != null) {
                  try {
                     if (new File(var14.getName()).getCanonicalPath().equals(var1.getCanonicalPath())) {
                        var2 = true;
                     }
                  } catch (IOException var8) {
                  }
               }
            }
         }
      }

      return var2;
   }

   public String getName() {
      return this.name;
   }

   public CacheFile(String var1) {
      this.name = var1;
   }

   public boolean before(CacheFile var1) {
      if (this.isUsable() && var1.isUsable()) {
         return this.getFileType() == var1.getFileType() ? this.getDate() < var1.getDate() : this.getFileType() == 3;
      } else {
         return !this.isUsable();
      }
   }

   public void addFile(File var1, String var2) {
      if (var2 != null) {
         if (var2.equalsIgnoreCase(".idx")) {
            this.indexFile = var1;
         } else {
            this.dataFile = var1;
         }
      }
   }
}
