package sun.plugin.cache;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.text.DateFormat;
import java.util.Date;
import java.util.Map;
import sun.net.www.MessageHeader;
import sun.plugin.net.protocol.http.HttpUtils;
import sun.plugin.util.ProgressTracker;
import sun.plugin.util.Trace;

public class CachedFileLoader {
   private URL url;
   private HttpURLConnection uc = null;
   private long lastModified = 0L;
   private long expiration = 0L;
   private boolean upToDate = false;
   private File dataFile = null;
   private File indexFile = null;
   private boolean cached = false;
   private long size = 0L;
   private MessageHeader headerFields = null;
   private static String[] fieldName = new String[]{"content-length", "last-modified", "expires", "content-type", "content-encoding", "date", "server"};

   public long getFileSize() {
      return this.size;
   }

   private boolean createCacheFiles() throws IOException {
      String var1 = FileCache.generateCacheFileName(this.url);
      this.dataFile = new File(FileCache.directory, var1 + Cache.getFileExtension(this.url.toString()));
      this.indexFile = new File(FileCache.directory, var1 + ".idx");
      RandomAccessFile var2 = null;
      boolean var3 = false;
      BufferedInputStream var4 = null;
      BufferedOutputStream var5 = null;

      try {
         var2 = new RandomAccessFile(this.indexFile, "rw");
         var2.writeByte(0);
         var2.writeUTF(this.url.toString());
         var2.writeLong(this.lastModified);
         var2.writeLong(this.expiration);
         var2.writeInt(FileType.getType(Cache.getFileExtension(this.url.toString())));
         this.writeHeaders(var2);
         var4 = new BufferedInputStream(this.uc.getInputStream());
         var5 = new BufferedOutputStream(new FileOutputStream(this.dataFile));
         int var6 = 0;
         int var7 = 0;
         byte[] var8 = new byte[2048];

         while ((var6 = var4.read(var8, 0, var8.length)) != -1) {
            var7 += var6;
            var5.write(var8, 0, var6);
         }

         var2.seek(0L);
         var2.writeByte(16);
         var3 = true;
      } finally {
         if (var4 != null) {
            var4.close();
         }

         if (var5 != null) {
            var5.close();
         }

         if (var2 != null) {
            var2.close();
         }

         if (!var3) {
            this.dataFile.delete();
            this.indexFile.delete();
            this.dataFile = null;
            this.indexFile = null;
         }
      }

      Cache.msgPrintln("cache.cached_name", new Object[]{this.dataFile.getName()});
      return true;
   }

   private boolean download() throws IOException {
      boolean var1 = false;
      if (this.uc == null) {
         this.uc = (HttpURLConnection)this.url.openConnection();
         this.uc.setUseCaches(false);
         this.uc.setAllowUserInteraction(false);
         this.uc = HttpUtils.followRedirects(this.uc);
         int var2 = this.uc.getResponseCode();
         if (var2 == 200) {
            this.size = this.uc.getContentLength();
            this.lastModified = this.uc.getLastModified();
            this.expiration = this.uc.getExpiration();
            if (this.lastModified == 0L && this.expiration == 0L) {
               Trace.msgPrintln("cache.header_fields_missing");
               return false;
            }

            this.initializeHeaderFields(this.uc);
         }
      }

      try {
         return AccessController.doPrivileged(new CachedFileLoader$3(this));
      } catch (PrivilegedActionException var3) {
         throw new IOException(var3.getMessage());
      }
   }

   private boolean getCacheFile() throws IOException {
      CachedFileLoader var1 = this;

      try {
         return AccessController.doPrivileged(new CachedFileLoader$2(this, var1));
      } catch (PrivilegedActionException var3) {
         throw new IOException(var3.getMessage());
      }
   }

   private boolean isUpToDate() throws IOException {
      boolean var1 = false;
      if (this.expiration != 0L && new Date().before(new Date(this.expiration))) {
         var1 = true;
      }

      if (!var1 && this.lastModified != 0L) {
         this.uc = (HttpURLConnection)this.url.openConnection();
         this.uc.setUseCaches(false);
         this.uc.setAllowUserInteraction(false);
         this.uc.setIfModifiedSince(this.lastModified);
         this.uc = HttpUtils.followRedirects(this.uc);
         int var2 = this.uc.getResponseCode();
         if (var2 == 304) {
            this.uc.disconnect();
            var1 = true;
         } else if (var2 >= 200 && var2 <= 299) {
            long var3 = this.lastModified;
            long var5 = this.expiration;
            this.lastModified = this.uc.getLastModified();
            this.expiration = this.uc.getExpiration();
            if (this.lastModified == var3) {
               this.uc.disconnect();
               var1 = true;
            } else {
               DateFormat var7 = DateFormat.getDateTimeInstance();
               String var8 = var7.format(new Date(var3));
               String var9 = var7.format(new Date(this.lastModified));
               Cache.msgPrintln("cache.out_of_date", new Object[]{this.url, var8, var9});
               this.size = this.uc.getContentLength();
               this.initializeHeaderFields(this.uc);
            }
         } else {
            Cache.msgPrintln("cache.response_warning", new Object[]{String.valueOf(var2), this.url});
         }
      }

      return var1;
   }

   private boolean loadFromCache() {
      boolean var1 = false;

      try {
         this.upToDate = this.isUpToDate();
         if (this.upToDate) {
            Cache.msgPrintln("cache.loading", new Object[]{this.url});
            ProgressTracker.onProgressComplete(this.url);
            Cache.touch(this.indexFile);
            var1 = true;
         } else {
            var1 = this.updateCache();
         }
      } catch (IOException var3) {
         Cache.msgPrintln("cache.load_warning", new Object[]{this.url});
      }

      return var1;
   }

   private boolean updateCache() throws IOException {
      try {
         AccessController.doPrivileged(new CachedFileLoader$4(this));
      } catch (PrivilegedActionException var3) {
         throw new IOException(var3.getMessage());
      }

      try {
         return this.download();
      } catch (IOException var4) {
         if (this.uc != null) {
            int var2 = this.uc.getResponseCode();
            if (var2 < 200 || var2 >= 300) {
               throw new DownloadException(var4, this.uc);
            }
         }

         throw var4;
      }
   }

   public void setExpiration(long var1) {
      this.expiration = var1;
   }

   public void setLastModify(long var1) {
      this.lastModified = var1;
   }

   public void setDataFile(File var1) {
      this.dataFile = var1;
   }

   public void setIndexFile(File var1) {
      this.indexFile = var1;
   }

   public void writeHeaders(RandomAccessFile var1) throws IOException {
      BufferedOutputStream var2 = new BufferedOutputStream(new FileOutputStream(var1.getFD()));
      DataOutputStream var3 = new DataOutputStream(var2);

      try {
         Map var4 = this.headerFields.getHeaders();
         if (!var4.isEmpty()) {
            var3.writeInt(var4.size());

            for (int var5 = 0; var5 < var4.size(); var5++) {
               String var6 = this.headerFields.getKey(var5);
               if (null == var6) {
                  var6 = "<null>";
               }

               var3.writeUTF(var6);
               var3.writeUTF(this.headerFields.getValue(var5));
            }

            var3.flush();
         } else {
            var3.writeInt(0);
         }
      } finally {
         ;
      }
   }

   public URL getURL() {
      return this.url;
   }

   public CachedFileLoader(URL var1) throws IOException {
      this.url = var1;
   }

   private void initializeHeaderFields(URLConnection var1) throws IOException {
      this.headerFields = new MessageHeader();
      String var2 = var1.getHeaderFieldKey(0);
      String var3 = var1.getHeaderField(0);
      if (null == var2 && null != var3) {
         this.headerFields.add(null, var3);
      }

      for (int var4 = 0; var4 < fieldName.length; var4++) {
         String var5 = var1.getHeaderField(fieldName[var4]);
         if (var5 != null) {
            this.headerFields.add(fieldName[var4], var5);
         }
      }
   }

   public void setHeaders(MessageHeader var1) {
      this.headerFields = var1;
   }

   public CachedFile load() throws IOException {
      boolean var1 = true;
      this.cached = this.getCacheFile();
      if (this.cached) {
         var1 = this.loadFromCache();
      } else {
         try {
            var1 = this.download();
         } catch (IOException var5) {
            if (this.uc != null) {
               int var3 = this.uc.getResponseCode();
               if (var3 < 200 || var3 >= 300) {
                  throw new DownloadException(var5, this.uc);
               }
            }

            throw var5;
         }

         if (var1 && this.dataFile != null && Cache.cleanupThread != null) {
            try {
               AccessController.doPrivileged(new CachedFileLoader$1(this));
            } catch (PrivilegedActionException var4) {
               throw new IOException(var4.getMessage());
            }
         }
      }

      if (var1) {
         URL var2 = this.uc != null ? this.uc.getURL() : null;
         return new CachedFile(this.dataFile, this.headerFields, var2);
      } else {
         return null;
      }
   }

   static boolean access$200(CachedFileLoader var0) throws IOException {
      return var0.createCacheFiles();
   }

   static File access$000(CachedFileLoader var0) {
      return var0.dataFile;
   }

   static File access$100(CachedFileLoader var0) {
      return var0.indexFile;
   }
}
