package sun.plugin.cache;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStreamWriter;
import java.io.RandomAccessFile;
import java.net.HttpURLConnection;
import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.StringTokenizer;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import java.util.jar.Attributes.Name;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import java.util.zip.ZipOutputStream;
import sun.plugin.net.protocol.http.HttpUtils;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.util.ProgressTracker;
import sun.plugin.util.Trace;

public class CachedJarLoader {
   private static int BUF_SIZE = 8192;
   private URL url;
   private HttpURLConnection uc = null;
   private long lastModified = 0L;
   private long expiration = 0L;
   private boolean upToDate = false;
   private boolean upToDateChecked = false;
   private File dataFile = null;
   private File indexFile = null;
   private boolean cached = false;
   private long size = 0L;
   private FileVersion version = new FileVersion();

   public long getJarSize() {
      return this.size;
   }

   private void decompress() throws IOException {
      boolean var1 = false;
      ZipInputStream var2 = null;
      ZipInputStream var3 = null;
      ZipOutputStream var4 = null;

      try {
         var3 = new ZipInputStream(new BufferedInputStream(this.uc.getInputStream(), BUF_SIZE));
         var4 = new ZipOutputStream(new BufferedOutputStream(new FileOutputStream(this.dataFile), BUF_SIZE));
         var4.setLevel(JarCache.compression);
         ZipEntry var5 = var3.getNextEntry();
         if (this.url.toString().toLowerCase().endsWith(".jarjar")) {
            while (var5 != null) {
               if (!var5.toString().toLowerCase().startsWith("meta-inf/")) {
                  if (!var5.toString().toLowerCase().endsWith(".jar")) {
                     throw new IOException(ResourceHandler.getMessage("cache.jarjar.invalid_file"));
                  }
                  break;
               }

               var5 = var3.getNextEntry();
            }

            var2 = var3;
            var3 = new ZipInputStream(var3);
            var5 = var3.getNextEntry();
         }

         for (byte[] var6 = new byte[2048]; var5 != null; var5 = var3.getNextEntry()) {
            ZipEntry var7 = (ZipEntry)var5.clone();
            var7.setCompressedSize(-1L);
            var4.putNextEntry(var7);

            int var8;
            while ((var8 = var3.read(var6, 0, var6.length)) != -1) {
               var4.write(var6, 0, var8);
            }

            var4.closeEntry();
         }

         if (var2 != null) {
            var5 = var2.getNextEntry();
            if (var5 != null) {
               Object var14 = null;
               if (!var5.toString().toLowerCase().endsWith(".jar")) {
                  var14 = ResourceHandler.getMessage("cache.jarjar.invalid_file");
               } else {
                  var14 = ResourceHandler.getMessage("cache.jarjar.multiple_jar");
               }

               throw new IOException((String)var14);
            }
         }

         var1 = true;
      } finally {
         if (var2 != null) {
            var2.close();
         }

         if (var3 != null) {
            var3.close();
         }

         if (var4 != null) {
            var4.close();
         }

         if (!var1) {
            this.dataFile.delete();
            this.indexFile.delete();
         }
      }
   }

   private void markAsIncomplete() throws IOException {
      RandomAccessFile var1 = null;

      try {
         var1 = new RandomAccessFile(this.indexFile, "rw");
         var1.writeByte(0);
      } finally {
         if (var1 != null) {
            var1.close();
         }
      }
   }

   private boolean getCacheFile() throws IOException {
      CachedJarLoader var1 = this;

      try {
         return AccessController.doPrivileged(new CachedJarLoader$4(this, var1));
      } catch (PrivilegedActionException var3) {
         throw new IOException(var3.getMessage());
      }
   }

   private boolean isUpToDate() throws IOException {
      boolean var1 = false;
      if (this.expiration != 0L && new Date().before(new Date(this.expiration))) {
         var1 = true;
      }

      if (!var1 && this.lastModified != 0L) {
         this.uc = (HttpURLConnection)this.url.openConnection();
         this.uc.setUseCaches(false);
         this.uc.setAllowUserInteraction(false);
         this.uc.setIfModifiedSince(this.lastModified);
         this.uc = HttpUtils.followRedirects(this.uc);
         int var2 = this.uc.getResponseCode();
         if (var2 == 304) {
            this.uc.disconnect();
            var1 = true;
         } else if (var2 >= 200 && var2 <= 299) {
            long var3 = this.lastModified;
            long var5 = this.expiration;
            this.lastModified = this.uc.getLastModified();
            this.expiration = this.uc.getExpiration();
            if (this.lastModified == var3) {
               this.uc.disconnect();
               var1 = true;
            } else {
               DateFormat var7 = DateFormat.getDateTimeInstance();
               String var8 = var7.format(new Date(var3));
               String var9 = var7.format(new Date(this.lastModified));
               Cache.msgPrintln("cache.out_of_date", new Object[]{this.url, var8, var9});
               this.size = this.uc.getContentLength();
            }
         } else {
            Cache.msgPrintln("cache.response_warning", new Object[]{String.valueOf(var2), this.url});
         }
      }

      return var1;
   }

   public void setExpiration(long var1) {
      this.expiration = var1;
   }

   public void setLastModify(long var1) {
      this.lastModified = var1;
   }

   public void setDataFile(File var1) {
      this.dataFile = var1;
   }

   public void setIndexFile(File var1) {
      this.indexFile = var1;
   }

   public URL getURL() {
      return this.url;
   }

   public CachedJarLoader(URL var1, boolean var2) throws IOException {
      this.url = var1;
      this.cached = this.getCacheFile();
      if (var2) {
         if (this.cached) {
            this.upToDate = this.isUpToDate();
            this.upToDateChecked = true;
         } else {
            this.size = Cache.getFileSizeFromServer(var1);
         }
      }
   }

   private CachedJarFile authenticate() throws IOException {
      boolean var1 = false;
      JarFile var2 = new JarFile(this.dataFile);
      ObjectOutputStream var3 = null;
      RandomAccessFile var4 = null;
      ArrayList var5 = new ArrayList();
      HashMap var6 = new HashMap();
      Manifest var7 = null;

      try {
         var4 = new RandomAccessFile(this.indexFile, "rw");
         var4.writeByte(0);
         var4.writeUTF(this.url.toString());
         var4.writeLong(this.lastModified);
         var4.writeLong(this.expiration);
         var4.writeInt(1);
         var4.writeUTF(this.version.getVersionAsString());
         var3 = new ObjectOutputStream(new BufferedOutputStream(new FileOutputStream(var4.getFD()), BUF_SIZE));
         var7 = var2.getManifest();
         if (var7 == null) {
            var3.writeInt(0);
         } else {
            byte[] var8 = new byte[2048];
            Enumeration var9 = var2.entries();

            while (var9.hasMoreElements()) {
               JarEntry var10 = (JarEntry)var9.nextElement();
               String var11 = var10.getName();
               if (!var11.toLowerCase().startsWith("meta-inf/") || var11.equals("META-INF/INDEX.LIST")) {
                  InputStream var12 = null;

                  try {
                     var12 = var2.getInputStream(var10);

                     while (var12.read(var8, 0, var8.length) != -1) {
                     }
                  } finally {
                     if (var12 != null) {
                        var12.close();
                     }
                  }

                  Certificate[] var13 = var10.getCertificates();
                  if (var13 != null && var13.length > 0) {
                     int[] var14 = new int[var13.length];

                     for (int var15 = 0; var15 < var13.length; var15++) {
                        int var16 = var5.indexOf(var13[var15]);
                        if (var16 == -1) {
                           var16 = var5.size();
                           var5.add(var13[var15]);
                        }

                        var14[var15] = var16;
                     }

                     var6.put(var11, var14);
                  }

                  this.removeSignature(var7, var11);
               }
            }

            ByteArrayOutputStream var31 = new ByteArrayOutputStream();
            var7.write(var31);
            var31.close();
            byte[] var32 = var31.toByteArray();
            var3.writeInt(var32.length);
            var3.write(var32);
            if (var5.isEmpty()) {
               var3.writeInt(0);
            } else {
               var3.writeInt(var5.size());
               Iterator var33 = var5.iterator();

               while (var33.hasNext()) {
                  var3.writeObject(var33.next());
               }

               BufferedWriter var34 = new BufferedWriter(new OutputStreamWriter(var3));
               Iterator var35 = var6.keySet().iterator();
               String var36 = null;

               while (var35.hasNext()) {
                  String var37 = (String)var35.next();
                  int[] var17 = (int[])var6.get(var37);
                  if (var37.indexOf("/") != -1) {
                     String var18 = var37.substring(0, var37.lastIndexOf("/"));
                     if (var36 != null && var18.equals(var36)) {
                        var37 = var37.substring(var18.length());
                     }

                     var36 = var18;
                  }

                  var34.write(var37);
                  var34.newLine();
                  String var38 = String.valueOf(var17.length);

                  for (int var19 = 0; var19 < var17.length; var19++) {
                     var38 = var38 + " " + var17[var19];
                  }

                  var34.write(var38, 0, var38.length());
                  var34.newLine();
               }

               var34.flush();
            }
         }

         var3.flush();
         var4.seek(0L);
         var4.writeByte(16);
         var1 = true;
      } finally {
         var2.close();
         if (var3 != null) {
            var3.close();
         }

         if (var4 != null) {
            var4.close();
         }

         if (!var1) {
            this.dataFile.delete();
            this.indexFile.delete();
         }
      }

      Certificate[] var29 = new Certificate[var5.size()];
      var29 = var5.toArray(var29);
      return new CachedJarFile(this.dataFile, var29, var6, var7);
   }

   private CachedJarFile authenticateFromCache() throws IOException {
      HashMap var1 = new HashMap();
      Certificate[] var2 = null;
      Manifest var3 = null;
      RandomAccessFile var4 = new RandomAccessFile(this.indexFile, "r");
      ObjectInputStream var5 = null;

      try {
         var4.readByte();
         var4.readUTF();
         var4.readLong();
         var4.readLong();
         var4.readInt();
         var4.readUTF();
         var5 = new ObjectInputStream(new BufferedInputStream(new FileInputStream(var4.getFD()), BUF_SIZE));
         int var6 = var5.readInt();
         if (var6 > 0) {
            byte[] var7 = new byte[var6];
            var5.readFully(var7, 0, var6);
            ByteArrayInputStream var8 = new ByteArrayInputStream(var7);
            var3 = new Manifest();
            var3.read(var8);
            int var9 = var5.readInt();
            if (var9 > 0) {
               var2 = new Certificate[var9];

               try {
                  for (int var10 = 0; var10 < var9; var10++) {
                     var2[var10] = (Certificate)var5.readObject();
                  }
               } catch (ClassNotFoundException var22) {
                  throw new IOException("Error reading certificates");
               }

               BufferedReader var24 = new BufferedReader(new InputStreamReader(var5));
               String var11 = var24.readLine();

               for (String var12 = null; var11 != null && !var11.equals(""); var11 = var24.readLine()) {
                  String var13 = var11;
                  if (var11.startsWith("/")) {
                     var13 = var12 + var11;
                  } else {
                     int var14 = var11.lastIndexOf("/");
                     if (var14 != -1) {
                        var12 = var11.substring(0, var14);
                     }
                  }

                  var11 = var24.readLine();
                  StringTokenizer var26 = new StringTokenizer(var11, " ", false);
                  int var15 = Integer.parseInt(var26.nextToken());
                  int[] var16 = new int[var15];

                  for (int var17 = 0; var17 < var15; var17++) {
                     var16[var17] = Integer.parseInt(var26.nextToken());
                  }

                  var1.put(var13, var16);
               }

               Cache.msgPrintln("cache.cert_load", new Object[]{this.url});
            }
         }
      } finally {
         var4.close();
         if (var5 != null) {
            var5.close();
         }
      }

      return new CachedJarFile(this.dataFile, var2, var1, var3);
   }

   private CachedJarFile download() throws IOException {
      if (this.uc == null) {
         this.uc = (HttpURLConnection)this.url.openConnection();
         this.uc.setUseCaches(false);
         this.uc.setAllowUserInteraction(false);
         this.uc = HttpUtils.followRedirects(this.uc);
         int var1 = this.uc.getResponseCode();
         if (var1 < 200 || var1 >= 300) {
            throw new IOException("Could not connect to " + this.url + " with response code " + var1);
         }

         this.lastModified = this.uc.getLastModified();
         this.expiration = this.uc.getExpiration();
      }

      if (this.lastModified == 0L && this.expiration == 0L) {
         Trace.msgPrintln("cache.header_fields_missing");
         return null;
      } else {
         Cache.msgPrintln("cache.downloading", new Object[]{this.url});

         try {
            return AccessController.doPrivileged(new CachedJarLoader$5(this));
         } catch (PrivilegedActionException var2) {
            throw new IOException(var2.getMessage());
         }
      }
   }

   public CachedJarFile load() throws IOException {
      CachedJarFile var1 = this.loadFromCache();
      if (var1 == null) {
         try {
            var1 = this.download();
         } catch (IOException var5) {
            if (this.uc != null) {
               int var3 = this.uc.getResponseCode();
               if (var3 < 200 || var3 >= 300) {
                  throw new DownloadException(var5, this.uc);
               }
            }

            throw var5;
         }

         if (var1 != null && Cache.cleanupThread != null) {
            try {
               AccessController.doPrivileged(new CachedJarLoader$1(this));
            } catch (PrivilegedActionException var4) {
               throw new IOException(var4.getMessage());
            }
         }
      }

      return var1;
   }

   private CachedJarFile loadFromCache() {
      CachedJarFile var1 = null;

      try {
         if (this.cached) {
            if (!this.upToDateChecked) {
               this.upToDate = this.isUpToDate();
            }

            if (this.upToDate) {
               Cache.msgPrintln("cache.loading", new Object[]{this.url});
               ProgressTracker.onProgressComplete(this.url);

               try {
                  var1 = AccessController.doPrivileged(new CachedJarLoader$2(this));
               } catch (PrivilegedActionException var4) {
                  throw new IOException(var4.getMessage());
               }
            } else {
               try {
                  AccessController.doPrivileged(new CachedJarLoader$3(this));
               } catch (PrivilegedActionException var3) {
                  throw new IOException(var3.getMessage());
               }
            }
         }
      } catch (IOException var5) {
         var5.printStackTrace();
         Cache.msgPrintln("cache.load_warning", new Object[]{this.url});
      }

      return var1;
   }

   static void access$400(CachedJarLoader var0) throws IOException {
      var0.markAsIncomplete();
   }

   static void access$500(CachedJarLoader var0) throws IOException {
      var0.decompress();
   }

   public void setVersion(FileVersion var1) {
      this.version = var1;
   }

   public boolean isVersionUpToDate(FileVersion var1) {
      boolean var2 = false;
      var2 = this.version.isUpToDate(var1);
      this.upToDate = var2;
      this.upToDateChecked = true;
      return var2;
   }

   static File access$000(CachedJarLoader var0) {
      return var0.dataFile;
   }

   static File access$100(CachedJarLoader var0) {
      return var0.indexFile;
   }

   private void removeSignature(Manifest var1, String var2) {
      Attributes var3 = var1.getAttributes(var2);
      if (var3 != null) {
         for (Name var6 : ((Attributes)var3.clone()).keySet()) {
            String var7 = var6.toString();
            if (var7.endsWith("-Digest") || var7.indexOf("-Digest-") != -1) {
               var3.remove(var6);
            }

            if (var7.equals("Magic:")) {
               var3.remove(var6);
            }
         }

         if (var3.isEmpty()) {
            var1.getEntries().remove(var2);
         }
      }
   }

   static URL access$300(CachedJarLoader var0) {
      return var0.url;
   }

   static CachedJarFile access$200(CachedJarLoader var0) throws IOException {
      return var0.authenticateFromCache();
   }

   static CachedJarFile access$600(CachedJarLoader var0) throws IOException {
      return var0.authenticate();
   }

   static File access$002(CachedJarLoader var0, File var1) {
      return var0.dataFile = var1;
   }

   static File access$102(CachedJarLoader var0, File var1) {
      return var0.indexFile = var1;
   }
}
