package sun.plugin.extension;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.security.AccessController;
import java.security.CodeSource;
import java.security.InvalidKeyException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivilegedActionException;
import java.security.SignatureException;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.text.MessageFormat;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.StringTokenizer;
import java.util.Map.Entry;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import java.util.jar.Manifest;
import java.util.jar.Attributes.Name;
import javax.swing.JButton;
import sun.misc.ExtensionInfo;
import sun.misc.ExtensionInstallationException;
import sun.misc.ExtensionInstallationProvider;
import sun.plugin.AppletViewer;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.security.TrustDecider;
import sun.plugin.util.DialogFactory;
import sun.plugin.util.Trace;
import sun.security.action.GetPropertyAction;

public class ExtensionInstallationImpl implements ExtensionInstallationProvider {
   private static int getAcceleratorKey(String var0) {
      return AppletViewer.getAcceleratorKey(var0);
   }

   private boolean hasMultipleSigners(Certificate[] var1) {
      Certificate var2 = var1[0];

      for (int var3 = 1; var3 < var1.length; var3++) {
         Certificate var4 = var1[var3];
         if (!this.isSigner(var2, var4)) {
            return true;
         }

         var2 = var4;
      }

      return false;
   }

   private static String getMessage(String var0) {
      return AppletViewer.getMessage(var0);
   }

   private void installJarFile(String var1, String var2) throws ExtensionInstallationException, IOException, InterruptedException {
      Trace.msgExtPrintln("optpkg.install.begin", new Object[]{var2});
      JarFile var3 = new JarFile(var2);
      Manifest var4 = var3.getManifest();
      if (var4 != null) {
         String var5 = AccessController.doPrivileged(new GetPropertyAction("java.ext.dirs"));
         StringTokenizer var6 = new StringTokenizer(var5, File.pathSeparator);
         String var7 = var6.nextToken();
         Attributes var8 = var4.getMainAttributes();
         Object var9 = new RawExtensionInstaller();
         if (var8 != null) {
            if (var8.getValue(Name.MAIN_CLASS) != null) {
               var9 = new JavaExtensionInstaller();
            } else if (var8.getValue(Name.EXTENSION_INSTALLATION) != null) {
               var9 = new NativeExtensionInstaller();
            }
         }

         Object var10 = null;
         ((ExtensionInstaller)var9).install(var1, var2, var7);
      }
   }

   private void verifyJar(String var1, String var2) throws ExtensionInstallationException, CertificateException, CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, KeyStoreException, NoSuchAlgorithmException, IOException {
      JarFile var3 = null;

      try {
         HashMap var4 = new HashMap();
         byte[] var5 = new byte[8192];
         Certificate[] var6 = null;
         var3 = new JarFile(var2, true);
         Enumeration var7 = var3.entries();

         while (var7.hasMoreElements()) {
            JarEntry var8 = (JarEntry)var7.nextElement();
            String var9 = var8.getName();
            InputStream var10 = var3.getInputStream(var8);

            while (var10.read(var5, 0, var5.length) != -1) {
            }

            var10.close();
            if (!var9.startsWith("META-INF/") && !var9.endsWith("/") && var8.getSize() != 0L) {
               Certificate[] var12 = var8.getCertificates();
               boolean var13 = var12 != null && var12.length > 0;
               if (!var13) {
                  throw new ExtensionInstallationException("Optional package installer is unsigned. (signatures missing or not parsable)");
               }

               if (var6 == null) {
                  if (this.hasMultipleSigners(var12)) {
                     throw new ExtensionInstallationException("Error: one entry has multiple certificates");
                  }

                  var6 = var12;
               } else if (!this.equalChains(var6, var12)) {
                  throw new ExtensionInstallationException("Error: Entries signed by different signer");
               }

               CodeSource var14 = (CodeSource)var4.get(var12);
               if (var14 == null) {
                  var14 = new CodeSource(new URL(var1), var12);
                  var4.put(var12, var14);
                  if (!TrustDecider.isAllPermissionGranted(var14)) {
                     throw new ExtensionInstallationException("User deny optional package installer to be launched.");
                  }
               }
            }
         }

         Manifest var20 = var3.getManifest();
         if (var20 == null) {
            throw new ExtensionInstallationException("No manifest in the optional package installer.");
         }

         for (Entry var11 : var20.getEntries().entrySet()) {
            String var23 = (String)var11.getKey();
            if (var3.getEntry(var23) == null) {
               throw new ExtensionInstallationException("Manifest entry not in the JAR file");
            }
         }
      } catch (IOException var18) {
         throw new ExtensionInstallationException("IO Error. Unable to verify optional package installer.");
      } finally {
         if (var3 != null) {
            var3.close();
         }
      }
   }

   private boolean isSigner(Certificate var1, Certificate var2) {
      try {
         var1.verify(var2.getPublicKey());
         return true;
      } catch (InvalidKeyException var4) {
         return false;
      } catch (NoSuchProviderException var5) {
         return false;
      } catch (NoSuchAlgorithmException var6) {
         return false;
      } catch (SignatureException var7) {
         return false;
      } catch (CertificateException var8) {
         return false;
      }
   }

   private boolean equalChains(Certificate[] var1, Certificate[] var2) {
      if (var1.length != var2.length) {
         return false;
      } else {
         for (int var3 = 0; var3 < var1.length; var3++) {
            if (!var1[var3].equals(var2[var3])) {
               return false;
            }
         }

         return true;
      }
   }

   private int askUserForAcknowledgment(ExtensionInfo var1, ExtensionInfo var2) {
      Object var3 = null;
      if (var2 != null) {
         String var4 = var1.name;
         if (var1.title != null) {
            var4 = var1.title;
         }

         int var5 = var2.isCompatibleWith(var1);
         switch (var5) {
            case 1:
               MessageFormat var15 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.new_spec.text"));
               Object[] var19 = new Object[]{var1.specVersion, var4, var1.url};
               var3 = var15.format(var19);
               break;
            case 2:
               MessageFormat var14 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.new_impl.text"));
               Object[] var18 = new Object[]{var1.implementationVersion, var4, var1.url};
               var3 = var14.format(var18);
               break;
            case 3:
               MessageFormat var13 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.new_vendor.text"));
               Object[] var17 = new Object[]{var1.vendor, var1.vendorId, var4, var1.url};
               var3 = var13.format(var17);
               break;
            default:
               MessageFormat var6 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.default.text"));
               Object[] var7 = new Object[]{var1.name, var1.url};
               var3 = var6.format(var7);
         }
      } else {
         MessageFormat var9 = new MessageFormat(ResourceHandler.getMessage("optpkg.prompt_user.default.text"));
         Object[] var11 = new Object[]{var1.name, var1.url};
         var3 = var9.format(var11);
      }

      JButton var10 = new JButton(getMessage("security_dialog.buttonYes"));
      JButton var12 = new JButton(getMessage("security_dialog.buttonNo"));
      var10.setMnemonic(getAcceleratorKey("security_dialog.buttonYes"));
      var12.setMnemonic(getAcceleratorKey("security_dialog.buttonNo"));
      Object[] var16 = new Object[]{var10, var12};
      DialogFactory.preLoadDialog(3, var3, getMessage("security_dialog.caption"), var16, var16[0]);
      int var20 = 0;
      if (!Trace.isAutomationEnabled()) {
         var20 = DialogFactory.showOptionDialog(3, var3, getMessage("security_dialog.caption"), var16, var16[0]);
      } else {
         Trace.msgExtPrintln("optpkg.install.automation");
         var20 = 0;
      }

      if (var20 == 0) {
         Trace.msgExtPrintln("optpkg.install.granted", new Object[]{var1.url});
      } else {
         Trace.msgExtPrintln("optpkg.install.deny");
      }

      return var20;
   }

   public boolean installExtension(ExtensionInfo var1, ExtensionInfo var2) throws ExtensionInstallationException {
      Trace.msgExtPrintln("optpkg.install.info", new Object[]{var1});

      try {
         AccessController.doPrivileged(new ExtensionInstallationImpl$1(this, var1, var2));
      } catch (Throwable var6) {
         Object var4 = var6;
         Object var5 = null;
         if (var6 instanceof PrivilegedActionException) {
            var4 = ((PrivilegedActionException)var6).getException();
            if (var4 instanceof CertificateExpiredException) {
               var5 = ResourceHandler.getMessage("optpkg.cert_expired");
            } else if (var4 instanceof CertificateNotYetValidException) {
               var5 = ResourceHandler.getMessage("optpkg.cert_notyieldvalid");
            } else if (var4 instanceof CertificateException) {
               var5 = ResourceHandler.getMessage("optpkg.cert_notverify");
            } else {
               var5 = ResourceHandler.getMessage("optpkg.general_error");
            }
         } else {
            var5 = ResourceHandler.getMessage("optpkg.general_error");
         }

         Trace.extPrintException((Throwable)var4, (String)var5, ResourceHandler.getMessage("optpkg.caption"));
         Trace.msgExtPrintln("optpkg.install.fail");
         return true;
      }

      Trace.msgExtPrintln("optpkg.install.ok");
      return true;
   }

   static void access$100(ExtensionInstallationImpl var0, String var1, String var2) throws ExtensionInstallationException, CertificateException, CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, KeyStoreException, NoSuchAlgorithmException, IOException {
      var0.verifyJar(var1, var2);
   }

   static void access$200(ExtensionInstallationImpl var0, String var1, String var2) throws ExtensionInstallationException, IOException, InterruptedException {
      var0.installJarFile(var1, var2);
   }

   static int access$000(ExtensionInstallationImpl var0, ExtensionInfo var1, ExtensionInfo var2) {
      return var0.askUserForAcknowledgment(var1, var2);
   }
}
