package sun.plugin.javascript;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.security.AccessController;
import java.security.AllPermission;
import java.security.CodeSource;
import java.security.PermissionCollection;
import java.security.SecureClassLoader;
import java.security.cert.Certificate;

public final class JSClassLoader extends SecureClassLoader {
   private static String JS_PROXY_PKG = "sun.plugin.javascript.invoke.";
   private static String TRAMPOLINE = JS_PROXY_PKG + "JSInvoke";
   private static Method bounce;
   static Class class$java$lang$reflect$Method;
   static Class class$java$lang$Object;
   static Class array$Ljava$lang$Object;

   static Class access$000() {
      return getTrampoline();
   }

   private static Class getTrampoline() {
      try {
         return Class.forName(TRAMPOLINE, true, new JSClassLoader());
      } catch (ClassNotFoundException var1) {
         return null;
      }
   }

   public static void checkPackageAccess(Class var0) {
      String var1 = var0.getName();
      int var2 = var1.lastIndexOf(".");
      if (var2 != -1) {
         String var3 = var1.substring(0, var2);
         SecurityManager var4 = System.getSecurityManager();
         if (var4 != null) {
            var4.checkPackageAccess(var3);
         }
      }
   }

   public static boolean isPackageAccessible(Class var0) {
      try {
         checkPackageAccess(var0);
         return true;
      } catch (SecurityException var2) {
         return false;
      }
   }

   private static synchronized Method bounce() throws Exception {
      if (bounce == null) {
         bounce = AccessController.doPrivileged(new JSClassLoader$1());
      }

      return bounce;
   }

   private static byte[] getBytes(URL var0) throws IOException {
      URLConnection var1 = var0.openConnection();
      if (var1 instanceof HttpURLConnection) {
         HttpURLConnection var2 = (HttpURLConnection)var1;
         int var3 = var2.getResponseCode();
         if (var3 >= 400) {
            throw new IOException("open HTTP connection failed.");
         }
      }

      int var10 = var1.getContentLength();
      BufferedInputStream var12 = new BufferedInputStream(var1.getInputStream());

      byte[] var4;
      try {
         if (var10 != -1) {
            var4 = new byte[var10];

            while (var10 > 0) {
               int var5 = var12.read(var4, var4.length - var10, var10);
               if (var5 == -1) {
                  throw new IOException("unexpected EOF");
               }

               var10 -= var5;
            }
         } else {
            var4 = new byte[8192];
            int var13 = 0;

            while ((var10 = var12.read(var4, var13, var4.length - var13)) != -1) {
               var13 += var10;
               if (var13 >= var4.length) {
                  byte[] var6 = new byte[var13 * 2];
                  System.arraycopy(var4, 0, var6, 0, var13);
                  var4 = var6;
               }
            }

            if (var13 != var4.length) {
               byte[] var14 = new byte[var13];
               System.arraycopy(var4, 0, var14, 0, var13);
               var4 = var14;
            }
         }
      } finally {
         var12.close();
      }

      return var4;
   }

   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError().initCause(var2);
      }
   }

   protected Class findClass(String var1) throws ClassNotFoundException {
      if (!var1.startsWith(JS_PROXY_PKG)) {
         throw new ClassNotFoundException(var1);
      } else {
         String var2 = var1.replace('.', '/').concat(".class");
         URL var3 = this.getResource(var2);
         if (var3 != null) {
            try {
               return this.defineClass(var1, var3);
            } catch (IOException var5) {
               throw new ClassNotFoundException(var1, var5);
            }
         } else {
            throw new ClassNotFoundException(var1);
         }
      }
   }

   protected synchronized Class loadClass(String var1, boolean var2) throws ClassNotFoundException {
      SecurityManager var3 = System.getSecurityManager();
      if (var3 != null) {
         String var4 = var1.replace('/', '.');
         if (var4.startsWith("[")) {
            int var5 = var4.lastIndexOf(91) + 2;
            if (var5 > 1 && var5 < var4.length()) {
               var4 = var4.substring(var5);
            }
         }

         int var8 = var4.lastIndexOf(46);
         if (var8 != -1) {
            var3.checkPackageAccess(var4.substring(0, var8));
         }
      }

      Class var7 = this.findLoadedClass(var1);
      if (var7 == null) {
         try {
            var7 = this.findClass(var1);
         } catch (ClassNotFoundException var6) {
         }

         if (var7 == null) {
            var7 = this.getParent().loadClass(var1);
         }
      }

      if (var2) {
         this.resolveClass(var7);
      }

      return var7;
   }

   protected PermissionCollection getPermissions(CodeSource var1) {
      PermissionCollection var2 = super.getPermissions(var1);
      var2.add(new AllPermission());
      return var2;
   }

   private Class defineClass(String var1, URL var2) throws IOException {
      byte[] var3 = getBytes(var2);
      CodeSource var4 = new CodeSource(null, (Certificate[])null);
      if (!var1.equals(TRAMPOLINE)) {
         throw new IOException("JSClassLoader: bad name " + var1);
      } else {
         return this.defineClass(var1, var3, 0, var3.length, var4);
      }
   }

   public static Object invoke(Method var0, Object var1, Object[] var2) throws Exception {
      try {
         return bounce().invoke(null, var0, var1, var2);
      } catch (InvocationTargetException var5) {
         Throwable var4 = var5.getCause();
         if (var4 instanceof InvocationTargetException) {
            throw (InvocationTargetException)var4;
         } else {
            throw var5;
         }
      }
   }
}
