package sun.plugin.javascript;

import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ReflectUtil {
   private static String getSignature(Method var0) {
      StringBuffer var1 = new StringBuffer();
      var1.append(var0.getName());
      Class[] var2 = var0.getParameterTypes();
      var1.append('(');
      if (var2.length > 0) {
         var1.append(var2[0].getName());
      }

      for (int var3 = 1; var3 < var2.length; var3++) {
         var1.append(',');
         var1.append(var2[var3].getName());
      }

      var1.append(')');
      return var1.toString();
   }

   public static Field[] getJScriptFields(Class var0) {
      ArrayList var1 = new ArrayList();
      HashMap var2 = new HashMap();

      while (var0 != null) {
         boolean var3 = getPublicFields(var0, var1, var2);
         if (var3) {
            break;
         }

         getJScriptInterfaceFields(var0, var1, var2);
         var0 = var0.getSuperclass();
      }

      return var1.toArray(new Field[var1.size()]);
   }

   public static Method[] getJScriptMethods(Class var0) {
      ArrayList var1 = new ArrayList();
      HashMap var2 = new HashMap();

      while (var0 != null) {
         boolean var3 = getPublicMethods(var0, var1, var2);
         if (var3) {
            break;
         }

         getJScriptInterfaceMethods(var0, var1, var2);
         var0 = var0.getSuperclass();
      }

      return var1.toArray(new Method[var1.size()]);
   }

   private static void initSignatureMap(List var0, Map var1) {
      for (Method var3 : var0) {
         var1.put(getSignature(var3), var3);
      }
   }

   private static void addField(List var0, Map var1, Field var2) {
      String var3 = var2.getName();
      if (!var1.containsKey(var3)) {
         var0.add(var2);
         var1.put(var3, var2);
      }
   }

   private static void addMethod(List var0, Map var1, Method var2) {
      if (var1.isEmpty()) {
         var0.add(var2);
      } else {
         String var3 = getSignature(var2);
         if (!var1.containsKey(var3)) {
            var0.add(var2);
            var1.put(var3, var2);
         }
      }
   }

   private static void getJScriptInterfaceFields(Class var0, List var1, Map var2) {
      Class[] var3 = var0.getInterfaces();

      for (int var4 = 0; var4 < var3.length; var4++) {
         Class var5 = var3[var4];
         boolean var6 = getPublicFields(var5, var1, var2);
         if (!var6) {
            getJScriptInterfaceFields(var5, var1, var2);
         }
      }
   }

   private static void getJScriptInterfaceMethods(Class var0, List var1, Map var2) {
      Class[] var3 = var0.getInterfaces();

      for (int var4 = 0; var4 < var3.length; var4++) {
         Class var5 = var3[var4];
         boolean var6 = getPublicMethods(var5, var1, var2);
         if (!var6) {
            getJScriptInterfaceMethods(var5, var1, var2);
         }
      }
   }

   private static boolean getPublicFields(Class var0, List var1, Map var2) {
      Object var3 = null;

      try {
         if (!Modifier.isPublic(var0.getModifiers())) {
            return false;
         }

         if (!JSClassLoader.isPackageAccessible(var0)) {
            return false;
         }

         var3 = var0.getFields();
      } catch (SecurityException var7) {
         return false;
      }

      boolean var4 = true;

      for (int var5 = 0; var5 < ((Object[])var3).length; var5++) {
         Class var6 = ((Object[])var3)[var5].getDeclaringClass();
         if (!Modifier.isPublic(var6.getModifiers())) {
            var4 = false;
            break;
         }
      }

      if (var4) {
         for (int var9 = 0; var9 < ((Object[])var3).length; var9++) {
            addField(var1, var2, (Field)((Object[])var3)[var9]);
         }
      } else {
         for (int var10 = 0; var10 < ((Object[])var3).length; var10++) {
            Class var11 = ((Object[])var3)[var10].getDeclaringClass();
            if (var0.equals(var11)) {
               addField(var1, var2, (Field)((Object[])var3)[var10]);
            }
         }
      }

      return var4;
   }

   private static boolean getPublicMethods(Class var0, List var1, Map var2) {
      Object var3 = null;

      try {
         if (!Modifier.isPublic(var0.getModifiers())) {
            return false;
         }

         if (!JSClassLoader.isPackageAccessible(var0)) {
            return false;
         }

         var3 = var0.getMethods();
      } catch (SecurityException var7) {
         return false;
      }

      boolean var4 = true;

      for (int var5 = 0; var5 < ((Object[])var3).length; var5++) {
         Class var6 = ((Object[])var3)[var5].getDeclaringClass();
         if (!Modifier.isPublic(var6.getModifiers())) {
            var4 = false;
            break;
         }
      }

      if (var2.isEmpty() && !var1.isEmpty()) {
         initSignatureMap(var1, var2);
      }

      if (var4) {
         for (int var9 = 0; var9 < ((Object[])var3).length; var9++) {
            addMethod(var1, var2, (Method)((Object[])var3)[var9]);
         }
      } else {
         for (int var10 = 0; var10 < ((Object[])var3).length; var10++) {
            Class var11 = ((Object[])var3)[var10].getDeclaringClass();
            if (var0.equals(var11)) {
               addMethod(var1, var2, (Method)((Object[])var3)[var10]);
            }
         }
      }

      return var4;
   }
}
