package sun.plugin.liveconnect;

import java.io.FilePermission;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.net.MalformedURLException;
import java.net.SocketPermission;
import java.net.URL;
import java.security.AccessController;
import java.security.AllPermission;
import java.security.CodeSource;
import java.security.PermissionCollection;
import java.security.Permissions;
import java.security.Policy;
import java.security.PrivilegedActionException;
import java.security.ProtectionDomain;
import java.security.cert.Certificate;
import sun.plugin.services.PlatformService;
import sun.plugin.util.Trace;

public class SecureInvocation {
   static ProtectionDomain access$200() {
      return getTrustedProtectionDomain();
   }

   private static ProtectionDomain getTrustedProtectionDomain() {
      Trace.msgLiveConnectPrintln("liveconnect.UniversalJavaPermission.enabled");
      Permissions var0 = new Permissions();
      var0.add(new AllPermission());
      return new JavaScriptProtectionDomain(var0);
   }

   static void access$000(Class var0, String var1, boolean var2) throws OriginNotAllowedException, MalformedURLException {
      checkLiveConnectCaller(var0, var1, var2);
   }

   private static void checkLiveConnectCaller(Class var0, String var1, boolean var2) throws OriginNotAllowedException, MalformedURLException {
      if (var2) {
         Trace.msgLiveConnectPrintln("liveconnect.UniversalBrowserRead.enabled");
      } else {
         ProtectionDomain var3 = var0.getProtectionDomain();
         CodeSource var4 = var3.getCodeSource();
         if (var4 == null) {
            Trace.msgLiveConnectPrintln("liveconnect.java.system");
         } else {
            URL var5 = var4.getLocation();
            URL var6 = null;
            if (var1 != null) {
               try {
                  var6 = new URL(var1);
               } catch (MalformedURLException var8) {
                  var8.printStackTrace();
                  return;
               }
            }

            if (var5 != null
               && var6 != null
               && var5.getProtocol().equalsIgnoreCase(var6.getProtocol())
               && var5.getHost().equalsIgnoreCase(var6.getHost())
               && var5.getPort() == var6.getPort()) {
               Trace.msgLiveConnectPrintln("liveconnect.same.origin");
            } else {
               throw new OriginNotAllowedException("JavaScript is not from the same origin as the Java code, caller=" + var6 + ", callee=" + var5);
            }
         }
      }
   }

   static ProtectionDomain access$100(String var0) throws MalformedURLException {
      return getDefaultProtectionDomain(var0);
   }

   private static ProtectionDomain getDefaultProtectionDomain(String var0) throws MalformedURLException {
      Trace.msgLiveConnectPrintln("liveconnect.default.policy", new Object[]{var0});
      URL var1 = null;
      if (var0 != null) {
         try {
            var1 = new URL(var0);
         } catch (MalformedURLException var6) {
         }
      }

      Policy var2 = Policy.getPolicy();
      CodeSource var3 = new CodeSource(var1, (Certificate[])null);
      PermissionCollection var4 = var2.getPermissions(var3);
      if (var1 != null && !var1.getProtocol().equals("file")) {
         String var5 = var1.getHost();
         AccessController.doPrivileged(new SecureInvocation$6(var4, var5));
      } else {
         var4.add(new FilePermission("<<ALL FILES>>", "read"));
         var4.add(new SocketPermission("localhost", "connect,accept"));
         AccessController.doPrivileged(new SecureInvocation$5(var4));
      }

      return new JavaScriptProtectionDomain(var4);
   }

   private static Object ConstructObject(Class var0, Constructor var1, Object[] var2, String var3, boolean var4, boolean var5) throws Exception {
      try {
         return AccessController.doPrivileged(new SecureInvocation$1(var0, var3, var4, var5, var1, var2));
      } catch (PrivilegedActionException var7) {
         throw var7;
      }
   }

   private static Object GetField(Class var0, Object var1, Field var2, String var3, boolean var4, boolean var5) throws Exception {
      try {
         return AccessController.doPrivileged(new SecureInvocation$3(var0, var3, var4, var5, var2, var1));
      } catch (PrivilegedActionException var7) {
         throw var7;
      }
   }

   private static void SetField(Class var0, Object var1, Field var2, Object var3, String var4, boolean var5, boolean var6) throws Exception {
      try {
         AccessController.doPrivileged(new SecureInvocation$4(var0, var4, var5, var6, var2, var1, var3));
      } catch (PrivilegedActionException var8) {
         throw var8;
      }
   }

   private static Object CallMethod(int var0, Class var1, Object var2, Method var3, Object[] var4, String var5, boolean var6, boolean var7) throws Exception {
      SecureInvocation.CallMethodThread var8 = new SecureInvocation.CallMethodThread(var0, var1, var2, var3, var4, var5, var6, var7);
      var8.start();
      PlatformService.getService().waitEvent(var0);
      return var8.getResult();
   }

   private static Object CallMethod(Class var0, Object var1, Method var2, Object[] var3, String var4, boolean var5, boolean var6) throws Exception {
      try {
         return AccessController.doPrivileged(new SecureInvocation$2(var0, var4, var5, var6, var2, var1, var3));
      } catch (PrivilegedActionException var8) {
         throw var8;
      }
   }

   static Object access$300(Class var0, Object var1, Method var2, Object[] var3, String var4, boolean var5, boolean var6) throws Exception {
      return CallMethod(var0, var1, var2, var3, var4, var5, var6);
   }

   static class CallMethodThread extends Thread {
      private Exception exception = null;
      private Object result = null;
      private int handle;
      private Class clazz;
      private Object obj;
      private Method method;
      private Object[] args;
      private String origin;
      private boolean isUniversalBrowserRead;
      private boolean isUniversalJavaPermission;

      public void run() {
         try {
            this.result = SecureInvocation.access$300(
               this.clazz, this.obj, this.method, this.args, this.origin, this.isUniversalBrowserRead, this.isUniversalJavaPermission
            );
         } catch (Exception var5) {
            this.exception = var5;
         } finally {
            PlatformService.getService().signalEvent(this.handle);
         }
      }

      public Object getResult() throws Exception {
         if (this.exception != null) {
            throw this.exception;
         } else {
            return this.result;
         }
      }

      public CallMethodThread(int var1, Class var2, Object var3, Method var4, Object[] var5, String var6, boolean var7, boolean var8) {
         this.handle = var1;
         this.clazz = var2;
         this.obj = var3;
         this.method = var4;
         this.args = var5;
         this.origin = var6;
         this.isUniversalBrowserRead = var7;
         this.isUniversalJavaPermission = var8;
      }
   }
}
