package sun.plugin.net.protocol.http;

import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.text.MessageFormat;
import java.util.List;
import java.util.Map;
import sun.net.www.MessageHeader;
import sun.plugin.cache.CachedFile;
import sun.plugin.cache.DownloadException;
import sun.plugin.cache.FileCache;
import sun.plugin.net.cookie.PluginCookieManager;
import sun.plugin.net.proxy.PluginProxyManager;
import sun.plugin.net.proxy.ProxyInfo;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.util.ProgressInputStream;
import sun.plugin.util.ThreadGroupLocal;
import sun.plugin.util.Trace;

public class HttpURLConnection extends sun.net.www.protocol.http.HttpURLConnection {
   private String proxy = null;
   private int proxyPort = -1;
   private boolean resolveProxy = true;
   boolean failedOnce = false;
   private MessageHeader cachedHeaders = null;
   private boolean progressTracking = false;
   private static MessageFormat mf1 = new MessageFormat(ResourceHandler.getMessage("net.connect.no_proxy"));
   private static MessageFormat mf2 = new MessageFormat(ResourceHandler.getMessage("net.connect.proxy_is"));
   private int callCount = 0;
   private InputStream cacheStream = null;
   private IOException failedException = null;
   private boolean securityCheck = false;
   private boolean cacheConnect = false;
   private boolean realConnect = false;
   private boolean checkSetCookie = false;

   public synchronized void addCookieHeader() {
      String var1 = PluginCookieManager.getCookieInfo(this.url);
      if (var1 != null) {
         this.addRequestProperty("cookie", var1);
      }

      this.checkSetCookie = false;
   }

   public synchronized void checkCookieHeader() {
      if (!this.checkSetCookie) {
         this.checkSetCookie = true;
         Map var1 = this.getHeaderFields();

         for (String var3 : var1.keySet()) {
            if (var3 != null && var3.equalsIgnoreCase("Set-Cookie")) {
               for (String var6 : (List)var1.get(var3)) {
                  if (var6 != null) {
                     PluginCookieManager.setCookieInfo(this.url, var6);
                  }
               }
            }
         }
      }
   }

   private void checkPermission() throws IOException {
      if (!this.securityCheck) {
         SecurityManager var1 = System.getSecurityManager();
         if (var1 != null) {
            var1.checkConnect(this.url.getHost(), this.url.getPort());
         }

         this.securityCheck = true;
      }
   }

   public synchronized void connect() throws IOException {
      if (!this.connected) {
         this.checkPermission();
         if (this.getRequestMethod().equalsIgnoreCase("GET") && ThreadGroupLocal.get("javaplugin.progressTracking") != null) {
            this.progressTracking = true;
         }

         try {
            this.connectWithCache();
         } catch (DownloadException var2) {
            this.cachedHeaders = var2.getHeaders();
            this.failedException = var2.getIOException();
            throw this.failedException;
         } catch (IOException var3) {
         }

         if (this.cacheStream == null) {
            this.connectSetup();
            this.createConnection();
         }

         this.connected = true;
      }
   }

   private void connectSetup() throws IOException {
      if (!this.realConnect) {
         if (this.proxy == null && this.resolveProxy) {
            ProxyInfo var1 = PluginProxyManager.getProxyInfo(this.url);
            if (var1 != null) {
               this.proxy = var1.getProxy();
               this.proxyPort = var1.getPort();
            }
         }

         if (this.proxy == null) {
            Object[] var2 = new Object[]{this.url};
            Trace.netPrintln(mf1.format(var2), 2);
         } else {
            Object[] var3 = new Object[]{this.url, this.proxy + (this.proxyPort != -1 ? ":" + this.proxyPort : "")};
            Trace.netPrintln(mf2.format(var3), 2);
         }

         if (this.getRequestProperty("cookie") == null) {
            String var4 = PluginCookieManager.getCookieInfo(this.url);
            if (var4 != null) {
               this.addRequestProperty("cookie", var4);
            }
         }

         this.realConnect = true;
      }
   }

   private void connectWithCache() throws IOException {
      if (!this.cacheConnect) {
         if (this.getUseCaches() && this.getRequestMethod().equalsIgnoreCase("GET")) {
            CachedFile var1 = FileCache.get(this.url);
            if (var1 != null) {
               InputStream var2 = null;

               try {
                  var2 = AccessController.doPrivileged(new HttpURLConnection$1(this, var1));
               } catch (PrivilegedActionException var4) {
               }

               if (var2 != null) {
                  this.responseCode = 200;
                  this.cachedHeaders = var1.getHeaderFields();
                  URL var3 = var1.getURL();
                  if (var3 != null) {
                     this.url = var3;
                  }

                  if (this.progressTracking) {
                     this.cacheStream = new ProgressInputStream(var2, this);
                  } else {
                     this.cacheStream = var2;
                  }
               }
            }
         }

         this.cacheConnect = true;
      }
   }

   void createConnection() throws IOException {
      if ("http".equals(this.url.getProtocol()) && !this.failedOnce) {
         this.http = HttpClient.New(this.url, this.proxy, this.proxyPort, this.resolveProxy);
      } else {
         this.http = this.getProxiedClient(this.url, this.proxy, this.proxyPort);
      }

      this.ps = (PrintStream)this.http.getOutputStream();
   }

   public synchronized void disconnect() {
      super.disconnect();
      if (this.cacheStream != null) {
         this.cacheStream = null;
      }

      if (this.cachedHeaders != null) {
         this.cachedHeaders.reset();
      }
   }

   public synchronized InputStream getInputStream() throws IOException {
      if (this.failedException != null) {
         throw this.failedException;
      } else {
         this.connect();

         InputStream var2;
         try {
            this.callCount++;
            if (this.cacheStream != null) {
               return this.cacheStream;
            }

            InputStream var1 = super.getInputStream();
            if (this.callCount != 1) {
               return var1;
            }

            if (var1 != null) {
               if (this.progressTracking && !(var1 instanceof ProgressInputStream)) {
                  this.cacheStream = new ProgressInputStream(var1, this);
               } else {
                  this.cacheStream = var1;
               }
            }

            this.checkCookieHeader();
            var2 = this.cacheStream;
         } finally {
            this.callCount--;
         }

         return var2;
      }
   }

   public String getHeaderField(int var1) {
      try {
         this.getInputStream();
      } catch (IOException var3) {
      }

      return null != this.cachedHeaders ? this.cachedHeaders.getValue(var1) : super.getHeaderField(var1);
   }

   public String getHeaderFieldKey(int var1) {
      try {
         this.getInputStream();
      } catch (IOException var3) {
      }

      return null != this.cachedHeaders ? this.cachedHeaders.getKey(var1) : super.getHeaderFieldKey(var1);
   }

   public String getHeaderField(String var1) {
      String var2 = null;

      try {
         this.getInputStream();
      } catch (IOException var4) {
      }

      if (this.cachedHeaders != null) {
         var2 = this.cachedHeaders.findValue(var1);
      } else {
         var2 = super.getHeaderField(var1);
      }

      return var2;
   }

   public HttpURLConnection(URL var1, String var2, int var3) throws IOException {
      this(var1, var2, var3, true);
   }

   public HttpURLConnection(URL var1, String var2, int var3, boolean var4) throws IOException {
      super(var1, var2, var3);
      this.proxy = var2;
      this.proxyPort = var3;
      this.resolveProxy = var4;
   }

   protected sun.net.www.http.HttpClient getNewClient(URL var1) throws IOException {
      this.failedOnce = true;
      return this.getProxiedClient(var1, this.proxy, this.proxyPort);
   }

   public HttpURLConnection(URL var1, Handler var2) throws IOException {
      super(var1, var2);
   }

   protected sun.net.www.http.HttpClient getProxiedClient(URL var1, String var2, int var3) throws IOException {
      return new HttpClient(var1, var2, var3, this.resolveProxy);
   }
}
