package sun.plugin.net.protocol.jar;

import java.io.BufferedInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import sun.net.www.protocol.jar.JarURLConnection;
import sun.plugin.cache.JarCache;
import sun.plugin.util.URLUtil;

public class CachedJarURLConnection extends JarURLConnection {
   private URL jarFileURL = null;
   private String entryName;
   private JarEntry jarEntry;
   private JarFile jarFile;
   private String contentType;
   private boolean useJarCache = false;

   public int getContentLength() {
      return !this.useJarCache ? super.getContentLength() : -1;
   }

   public void connect() throws IOException {
      if (!this.connected) {
         if (this.getUseCaches()) {
            this.jarFile = JarCache.get(this.jarFileURL);
         }

         if (this.jarFile != null) {
            this.useJarCache = true;
         } else {
            super.connect();
            this.jarFile = super.getJarFile();
         }

         if (this.entryName != null) {
            this.jarEntry = this.jarFile.getJarEntry(this.entryName);
            if (this.jarEntry == null) {
               throw new FileNotFoundException("JAR entry " + this.entryName + " not found in " + this.jarFile.getName());
            }
         }

         this.connected = true;
      }
   }

   public InputStream getInputStream() throws IOException {
      this.connect();
      if (!this.useJarCache) {
         return super.getInputStream();
      } else {
         Object var1 = null;
         if (this.entryName == null) {
            throw new IOException("no entry name specified");
         } else if (this.jarEntry == null) {
            throw new FileNotFoundException("JAR entry " + this.entryName + " not found in " + this.jarFile.getName());
         } else {
            return this.jarFile.getInputStream(this.jarEntry);
         }
      }
   }

   public Object getContent() throws IOException {
      Object var1 = null;
      this.connect();
      if (!this.useJarCache) {
         return super.getContent();
      } else {
         if (this.entryName == null) {
            var1 = this.getJarFile();
         } else {
            var1 = super.getContent();
         }

         return var1;
      }
   }

   public String getContentType() {
      if (!this.connected) {
         try {
            this.connect();
         } catch (IOException var3) {
         }
      }

      if (!this.useJarCache) {
         return super.getContentType();
      } else {
         if (this.contentType == null) {
            if (this.entryName == null) {
               this.contentType = "x-java/jar";
            } else {
               try {
                  this.connect();
                  InputStream var1 = this.getJarFile().getInputStream(this.jarEntry);
                  this.contentType = guessContentTypeFromStream(new BufferedInputStream(var1));
                  var1.close();
               } catch (IOException var2) {
               }
            }

            if (this.contentType == null) {
               this.contentType = guessContentTypeFromName(this.entryName);
            }

            if (this.contentType == null) {
               this.contentType = "content/unknown";
            }
         }

         return this.contentType;
      }
   }

   public synchronized URL getJarFileURL() {
      if (this.jarFileURL == null) {
         this.jarFileURL = super.getJarFileURL();

         try {
            this.jarFileURL = new URL(URLUtil.canonicalize(this.jarFileURL.toString()));
         } catch (MalformedURLException var2) {
         }
      }

      return this.jarFileURL;
   }

   public JarEntry getJarEntry() throws IOException {
      this.connect();
      return this.jarEntry;
   }

   public JarFile getJarFile() throws IOException {
      this.connect();
      return this.jarFile;
   }

   public CachedJarURLConnection(URL var1, Handler var2) throws MalformedURLException, IOException {
      super(var1, var2);
      this.getJarFileURL();
      this.entryName = this.getEntryName();
   }
}
