package sun.plugin.net.proxy;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;
import sun.plugin.util.Trace;

final class ManualProxyHandler implements ProxyHandler {
   private BrowserProxyInfo bpi = null;
   private List proxyOverridePatterns = null;

   public boolean isProxyCacheSupported() {
      return true;
   }

   public boolean isSupported(int var1) {
      return var1 == 1;
   }

   private boolean isProxyOverriden(String var1) {
      for (Pattern var3 : this.proxyOverridePatterns) {
         Matcher var4 = var3.matcher(var1);
         if (var4.matches()) {
            return true;
         }
      }

      return false;
   }

   public void init(BrowserProxyInfo var1) throws ProxyConfigException {
      Trace.msgNetPrintln("net.proxy.loading.manual");
      if (!this.isSupported(var1.getType())) {
         throw new ProxyConfigException("Unable to support proxy type: " + var1.getType());
      } else {
         this.bpi = var1;
         this.proxyOverridePatterns = new ArrayList();
         String[] var2 = this.bpi.getOverrides();
         if (var2 != null) {
            Trace.msgNetPrintln("net.proxy.pattern.convert");

            for (int var3 = 0; var2 != null && var3 < var2.length; var3++) {
               String var4 = var2[var3];

               try {
                  if (var4.equals("<local>")) {
                     this.proxyOverridePatterns.add(Pattern.compile("[^.]+"));
                     Trace.netPrintln("    <local> --> [^.]+");
                  } else {
                     Pattern var5 = this.canonicalizePattern(var4);
                     this.proxyOverridePatterns.add(var5);
                     Trace.netPrintln("    " + var4 + " --> " + var5.pattern());
                  }
               } catch (PatternSyntaxException var6) {
                  var6.printStackTrace();
                  Trace.msgNetPrintln("net.proxy.bypass.convert.error");
               }
            }
         }

         Trace.msgNetPrintln("net.proxy.loading.done");
      }
   }

   private Pattern canonicalizePattern(String var1) throws PatternSyntaxException {
      if (var1 == null) {
         return null;
      } else {
         StringBuffer var2 = new StringBuffer();

         for (int var3 = 0; var3 < var1.length(); var3++) {
            char var4 = var1.charAt(var3);
            if (var4 == '*') {
               var2.append(".*");
            } else {
               var2.append(Character.toUpperCase(var4));
            }
         }

         return Pattern.compile(var2.toString());
      }
   }

   public ProxyInfo[] getProxyInfo(URL var1) {
      String var2 = var1.getProtocol();
      String var3 = var1.getHost();
      if (this.isProxyOverriden(var3.toUpperCase())) {
         return new ProxyInfo[]{new ProxyInfo(null)};
      } else {
         String var4 = null;
         int var5 = -1;
         if (var2.equals("http")) {
            var4 = this.bpi.getHttpHost();
            var5 = this.bpi.getHttpPort();
         } else if (var2.equals("https")) {
            var4 = this.bpi.getHttpsHost();
            var5 = this.bpi.getHttpsPort();
         } else if (var2.equals("ftp")) {
            var4 = this.bpi.getFtpHost();
            var5 = this.bpi.getFtpPort();
         } else if (var2.equals("gopher")) {
            var4 = this.bpi.getGopherHost();
            var5 = this.bpi.getGopherPort();
         }

         return new ProxyInfo[]{new ProxyInfo(var4, var5, this.bpi.getSocksHost(), this.bpi.getSocksPort())};
      }
   }
}
