package sun.plugin.net.proxy;

import java.net.URL;
import java.security.AccessController;
import java.util.Calendar;
import java.util.HashMap;
import sun.plugin.services.ServiceUnavailableException;

final class SmartProxyHandler implements ProxyHandler {
   private ProxyHandler realHandler = null;
   private HashMap proxyCache = new HashMap();
   private int pingTimeout;
   private long aliveTimeout;
   private long deadTimeout;

   public boolean isProxyCacheSupported() {
      return this.realHandler.isProxyCacheSupported();
   }

   public boolean isSupported(int var1) {
      return this.realHandler.isSupported(var1);
   }

   public void init(BrowserProxyInfo var1) throws ProxyConfigException {
      this.realHandler.init(var1);
   }

   public SmartProxyHandler(ProxyHandler var1) {
      this.proxyCache.put(new ProxyInfo(null, -1), new SmartProxyHandler.ProxyRecord(this, true, -1L));
      AccessController.doPrivileged(new SmartProxyHandler$1(this));
      this.realHandler = var1;
   }

   private boolean pingProxy(ProxyInfo var1) {
      String var2 = var1.getProxy();
      int var3 = -1;
      if (var2 != null) {
         var3 = var1.getPort();
      } else {
         var2 = var1.getSocksProxy();
         if (var2 == null) {
            return true;
         }

         var3 = var1.getSocksPort();
      }

      Boolean var6 = AccessController.doPrivileged(new SmartProxyHandler$2(this, var2, var3));
      return var6;
   }

   static int access$000(SmartProxyHandler var0) {
      return var0.pingTimeout;
   }

   static int access$002(SmartProxyHandler var0, int var1) {
      return var0.pingTimeout = var1;
   }

   static long access$102(SmartProxyHandler var0, long var1) {
      return var0.aliveTimeout = var1;
   }

   static long access$202(SmartProxyHandler var0, long var1) {
      return var0.deadTimeout = var1;
   }

   public ProxyInfo[] getProxyInfo(URL var1) throws ServiceUnavailableException {
      ProxyInfo[] var2 = this.realHandler.getProxyInfo(var1);

      for (int var3 = 0; var3 < var2.length; var3++) {
         String var4 = var2[var3].toString();
         SmartProxyHandler.ProxyRecord var5 = (SmartProxyHandler.ProxyRecord)this.proxyCache.get(var4);
         if (var5 == null) {
            SmartProxyHandler.ProxyRecord var6 = new SmartProxyHandler.ProxyRecord(this, false, Calendar.getInstance().getTimeInMillis());
            this.proxyCache.put(var4, var6);
            if (this.pingProxy(var2[var3])) {
               var6.setStatus(true);
               return new ProxyInfo[]{var2[var3]};
            }
         } else {
            long var11 = Calendar.getInstance().getTimeInMillis();
            boolean var8 = var5.getStatus();
            long var9 = var5.getTimeStamp();
            if (var9 > 0L && (var8 && var11 - var9 >= this.aliveTimeout || !var8 && var11 - var9 >= this.deadTimeout)) {
               var8 = this.pingProxy(var2[var3]);
               var5.setTimeStamp(var11);
               var5.setStatus(var8);
            }

            if (var8) {
               return new ProxyInfo[]{var2[var3]};
            }
         }
      }

      return new ProxyInfo[]{var2[0]};
   }

   private class ProxyRecord {
      private boolean isAlive;
      private long timeStamp;
      private final SmartProxyHandler this$0;

      public long getTimeStamp() {
         return this.timeStamp;
      }

      public boolean getStatus() {
         return this.isAlive;
      }

      public void setTimeStamp(long var1) {
         this.timeStamp = var1;
      }

      public void setStatus(boolean var1) {
         this.isAlive = var1;
      }

      public ProxyRecord(SmartProxyHandler var1, boolean var2, long var3) {
         this.this$0 = var1;
         this.isAlive = false;
         this.timeStamp = 0L;
         this.isAlive = var2;
         this.timeStamp = var3;
      }
   }
}
