package sun.plugin.panel;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.ResourceBundle;
import javax.swing.JButton;
import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import sun.plugin.util.Trace;

public class ActivatorPanel extends ActivatorSubPanel implements ActionListener, PropertyChangeListener {
   private DefaultPanel defaultPanel;
   private BasicPanel basicPanel;
   private AdvancedPanel advancedPanel;
   private BrowserPanel browserPanel;
   private ProxyPanel proxyPanel;
   private CertificatePanel certPanel;
   private CachePanel cachePanel;
   private UpdatePanel updatePanel = null;
   JButton cancel;
   JButton apply;
   JButton help;
   String currentTab = "";
   boolean showWindowPanels = false;
   private ResourceBundle rb = null;
   String helpFile = "";
   private MessageHandler mh = new MessageHandler("panel");

   public void setAdvancedPanelText() {
      this.advancedPanel.setJavaParmsText();
   }

   public void setCertificatePanelText() {
      this.certPanel.reset();
   }

   public void showControlPanelHelp() {
      JEditorPane var1 = new JEditorPane();
      var1.setEditable(false);

      try {
         this.rb = ResourceBundle.getBundle("sun.plugin.resources.ControlPanelHelp");
      } catch (Exception var8) {
         Trace.printException(this, var8, this.mh.getMessage("help.error.text"), this.mh.getMessage("help.error.caption"));
      }

      try {
         if (this.rb != null) {
            this.helpFile = this.rb.getString("help.file");
         }
      } catch (Exception var7) {
         Trace.printException(this, var7, this.mh.getMessage("help.error.text"), this.mh.getMessage("help.error.caption"));
      }

      JScrollPane var2 = new JScrollPane(var1);
      var2.setVerticalScrollBarPolicy(22);
      var2.setHorizontalScrollBarPolicy(32);
      var2.setPreferredSize(new Dimension(700, 500));
      var1.setText(this.helpFile);
      var1.setCaretPosition(0);
      JPanel var3 = new JPanel();
      var3.setLayout(new FlowLayout(1));
      JButton var4 = new JButton(this.mh.getMessage("help_close"));
      var4.setMnemonic(this.mh.getAcceleratorKey("help_close"));
      var3.add(var4);
      JFrame var5 = new JFrame(this.mh.getMessage("help_title"));
      var5.setDefaultCloseOperation(2);
      var5.addWindowListener(new ActivatorPanel$2(this, var5));
      ActivatorPanel$3 var6 = new ActivatorPanel$3(this, var5);
      var4.addActionListener(var6);
      var5.getContentPane().add(var2, "Center");
      var5.getContentPane().add(var3, "South");
      var5.pack();
      var5.setVisible(true);
   }

   public void setAdvancedPanel(int var1) {
      this.advancedPanel.setTextSize(var1);
   }

   public void actionPerformed(ActionEvent var1) {
      if (var1.getSource() == this.cancel) {
         try {
            this.model.reset();
            PlatformDependentInterface var2 = getPlatformObject();
            if (var2 != null) {
               var2.onLoad(this.model);
            }

            this.basicPanel.reset();
            this.advancedPanel.reset();
            if (this.browserPanel != null) {
               this.browserPanel.reset();
            }

            if (this.updatePanel != null) {
               this.updatePanel.reset();
            }

            this.proxyPanel.reset();
            this.certPanel.reset();
            this.cachePanel.reset();
            this.apply.setEnabled(false);
         } catch (Exception var5) {
            Trace.printException(this, var5);
         }
      }

      if (var1.getSource() == this.apply) {
         try {
            this.model.applyChanges();
            this.apply.setEnabled(false);
            PlatformDependentInterface var6 = getPlatformObject();
            if (var6 != null) {
               var6.onSave(this.model);
            }
         } catch (Exception var4) {
            Trace.printException(this, var4, this.mh.getMessage("apply_failed") + ": " + var4.getMessage(), this.mh.getMessage("apply_failed_title"));
         }
      }

      if (var1.getSource() == this.help) {
         try {
            if (this.help.isEnabled()) {
               this.help.setEnabled(false);
               this.showControlPanelHelp();
            }
         } catch (Exception var3) {
            Trace.printException(this, var3);
         }
      }
   }

   public void propertyChange(PropertyChangeEvent var1) {
      if (this.apply != null) {
         this.apply.setEnabled(true);
      }
   }

   public ConfigurationInfo getModel() {
      return this.model;
   }

   ActivatorPanel(ConfigurationInfo var1) {
      super(var1);
      PlatformDependentInterface var2 = getPlatformObject();
      if (var2 != null) {
         var2.onLoad(var1);
      }

      var1.addPropertyChangeListener(this);
      JTabbedPane var3 = new JTabbedPane();
      this.basicPanel = new BasicPanel(var1);
      var3.addTab(this.mh.getMessage("basic"), this.basicPanel);
      this.advancedPanel = new AdvancedPanel(var1);
      var3.addTab(this.mh.getMessage("advanced"), this.advancedPanel);
      if (var1.isShowBrowserPanel()) {
         this.browserPanel = new BrowserPanel(var1);
         var3.addTab(this.mh.getMessage("browser"), this.browserPanel);
         this.showWindowPanels = true;
      }

      this.proxyPanel = new ProxyPanel(var1);
      var3.addTab(this.mh.getMessage("proxies"), this.proxyPanel);
      this.cachePanel = new CachePanel(var1);
      var3.addTab(this.mh.getMessage("cache"), this.cachePanel);
      this.certPanel = new CertificatePanel(var1);
      var3.addTab(this.mh.getMessage("cert"), this.certPanel);
      if (var1.isShowBrowserPanel() && var1.showUpdatePanel()) {
         this.updatePanel = new UpdatePanel(var1);
         var3.addTab(this.mh.getMessage("update"), this.updatePanel);
      }

      this.defaultPanel = new DefaultPanel(var1);
      var3.addTab(this.mh.getMessage("about"), this.defaultPanel);
      this.setLayout(new BorderLayout());
      this.add("Center", var3);
      JPanel var4 = new JPanel();
      this.apply = this.addButton(var4, this.mh.getMessage("apply"));
      this.apply.setMnemonic(this.mh.getAcceleratorKey("apply"));
      this.cancel = this.addButton(var4, this.mh.getMessage("cancel"));
      this.cancel.setMnemonic(this.mh.getAcceleratorKey("cancel"));
      this.help = this.addButton(var4, this.mh.getMessage("help"));
      this.help.setMnemonic(this.mh.getAcceleratorKey("help"));
      this.apply.setEnabled(false);
      this.add("South", var4);
      var3.addChangeListener(new ActivatorPanel$1(this));
   }

   private JButton addButton(JPanel var1, String var2) {
      JButton var3 = new JButton(var2);
      var3.addActionListener(this);
      var1.add(var3);
      return var3;
   }
}
