package sun.plugin.panel;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.text.MessageFormat;
import java.text.NumberFormat;
import java.util.Hashtable;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.PlainDocument;
import sun.plugin.cache.JarCacheViewer;
import sun.plugin.util.DialogFactory;

public class CachePanel extends ActivatorSubPanel implements ActionListener {
   JCheckBox enabled = null;
   JTextField location = null;
   JButton choose = null;
   JRadioButton unlimited = null;
   JRadioButton maximum = null;
   JTextField size = null;
   JComboBox units = null;
   JSlider compression = null;
   JButton clear = null;
   JButton view = null;
   private MessageHandler mh = new MessageHandler("jarcache");

   void reset() {
      boolean var1 = this.model.getCacheEnabled();
      this.enabled.setSelected(var1);
      this.enableComponents(var1);
      this.location.setText(this.model.getCacheLocation());

      long var2;
      try {
         String var4 = this.model.getCacheSize().trim();
         byte var5 = 0;
         if (var4.endsWith("M") || var4.endsWith("m")) {
            var4 = var4.substring(0, var4.length() - 1);
            var5 = 0;
         } else if (!var4.endsWith("K") && !var4.endsWith("k")) {
            var5 = 2;
         } else {
            var4 = var4.substring(0, var4.length() - 1);
            var5 = 1;
         }

         var2 = Long.valueOf(var4);
         if (var2 == 0L) {
            this.unlimited.setSelected(true);
         } else {
            this.maximum.setSelected(true);
            this.units.setSelectedIndex(var5);
         }
      } catch (NumberFormatException var6) {
         var2 = 50L;
         this.maximum.setSelected(true);
         this.units.setSelectedIndex(0);
      }

      if (var2 != 0L) {
         NumberFormat var7 = NumberFormat.getInstance();
         var7.setGroupingUsed(false);
         this.size.setText(var7.format(var2));
      }

      this.compression.setValue(this.model.getJARCacheCompression());
   }

   private void updateSize() {
      String var1 = this.size.getText().trim();
      if (var1.equals("")) {
         var1 = "0";
      }

      long var2 = Long.valueOf(var1);
      var1 = Long.toString(var2);
      int var4 = this.units.getSelectedIndex();
      String[] var5 = new String[]{"m", "k", ""};
      var1 = var1 + var5[var4];
      this.model.setCacheSize(var1);
   }

   private void enableComponents(boolean var1) {
      this.setEnabled(this.location, var1);
      this.setEnabled(this.choose, var1);
      this.setEnabled(this.unlimited, var1);
      this.setEnabled(this.maximum, var1);
      this.setEnabled(this.size, var1);
      this.setEnabled(this.units, var1);
      this.setEnabled(this.compression, var1);
      this.setEnabled(this.clear, var1);
      this.setEnabled(this.view, var1);
   }

   public void actionPerformed(ActionEvent var1) {
      try {
         if (var1.getSource() == this.enabled) {
            boolean var2 = this.enabled.isSelected();
            this.enableComponents(var2);
            this.model.setCacheEnabled(var2);
         } else if (var1.getSource() == this.unlimited) {
            this.model.setCacheSize("0");
         } else if (var1.getSource() == this.maximum) {
            this.updateSize();
         } else if (var1.getSource() == this.clear) {
            MessageFormat var10 = new MessageFormat(this.mh.getMessage("erase.confirm.text"));
            String var3 = this.model.getCacheLocation();
            String var4 = var10.format(new Object[]{var3});
            String var5 = this.mh.getMessage("erase.confirm.caption");
            int var6 = DialogFactory.showConfirmDialog(this, var4, var5);
            if (var6 == 0) {
               String var7 = File.separator;
               this.deleteFiles(new File(var3 + var7 + "jar"));
               this.deleteFiles(new File(var3 + var7 + "file"));
            }
         } else if (var1.getSource() == this.units) {
            this.maximum.setSelected(true);
            this.updateSize();
         } else if (var1.getSource() == this.choose) {
            JFileChooser var11 = new JFileChooser();
            var11.setFileSelectionMode(1);
            var11.setDialogTitle(this.mh.getMessage("select_title"));
            var11.setApproveButtonText(this.mh.getMessage("select"));
            String var12 = this.mh.getMessage("select_tooltip");
            var11.setApproveButtonToolTipText(var12);
            char var13 = this.mh.getMessage("select_mnemonic").charAt(0);
            var11.setApproveButtonMnemonic(var13);
            File var14 = new File(this.model.getCacheLocation());
            var11.setCurrentDirectory(var14);
            if (var11.showDialog(this, null) == 0) {
               String var15;
               try {
                  var15 = var11.getSelectedFile().getCanonicalPath();
               } catch (IOException var8) {
                  var15 = var11.getSelectedFile().getPath();
               }

               this.model.setCacheLocation(var15);
               this.location.setText(var15);
            }
         } else if (var1.getSource() == this.view) {
            new JarCacheViewer(this.model.getCacheLocation());
         }
      } catch (Exception var9) {
         DialogFactory.showExceptionDialog(this, var9);
      }
   }

   private void deleteFiles(File var1) {
      try {
         if (var1.exists() && var1.isDirectory()) {
            File[] var2 = var1.listFiles();

            for (int var3 = 0; var3 < var2.length; var3++) {
               var2[var3].delete();
            }
         }
      } catch (Throwable var4) {
         DialogFactory.showExceptionDialog(this, var4);
      }
   }

   private void setEnabled(JComponent var1, boolean var2) {
      var1.setEnabled(var2);
      var1.repaint();
   }

   static void access$300(CachePanel var0) {
      var0.updateSize();
   }

   public CachePanel(ConfigurationInfo var1) {
      super(var1);
      this.setLayout(new BoxLayout(this, 1));
      JPanel var2 = new JPanel();
      var2.setLayout(new BoxLayout(var2, 0));
      var2.setBorder(BorderFactory.createEmptyBorder(6, 6, 6, 4));
      this.enabled = new JCheckBox(this.mh.getMessage("enabled"));
      this.enabled.addActionListener(this);
      var2.add(this.enabled);
      var2.add(Box.createHorizontalGlue());
      this.view = new JButton(this.mh.getMessage("view"));
      this.view.setMnemonic(this.mh.getAcceleratorKey("view"));
      this.view.addActionListener(this);
      var2.add(this.view);
      var2.add(Box.createRigidArea(new Dimension(5, 0)));
      this.clear = new JButton(this.mh.getMessage("clear"));
      this.clear.setMnemonic(this.mh.getAcceleratorKey("clear"));
      this.clear.addActionListener(this);
      var2.add(this.clear);
      this.add(var2);
      JPanel var3 = new JPanel();
      GridBagLayout var4 = new GridBagLayout();
      GridBagConstraints var5 = new GridBagConstraints();
      var3.setLayout(var4);
      Border var6 = BorderFactory.createEtchedBorder();
      var3.setBorder(
         BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4), BorderFactory.createTitledBorder(var6, this.mh.getMessage("settings")))
      );
      JLabel var7 = new JLabel(this.mh.getMessage("location"));
      var5.anchor = 17;
      var5.weighty = 3.0;
      var5.fill = 0;
      var5.insets = new Insets(5, 10, 5, 10);
      var4.setConstraints(var7, var5);
      var3.add(var7);
      this.location = new CachePanel.LocationField(this, null);
      this.location.setDocument(new CachePanel.LocationDocument(this, null));
      var5.weightx = 1.0;
      var5.gridwidth = 3;
      var5.insets = new Insets(5, 0, 5, 2);
      var5.fill = 2;
      var4.setConstraints(this.location, var5);
      var3.add(this.location);
      this.choose = new JButton(UIManager.getIcon("FileView.directoryIcon"));
      this.choose.setMnemonic(this.mh.getAcceleratorKey("browseDirectory"));
      this.choose.setMargin(new Insets(0, 2, 0, 2));
      this.choose.addActionListener(this);
      var5.fill = 0;
      var5.gridwidth = 0;
      var5.insets = new Insets(5, 2, 5, 10);
      var5.weightx = 0.0;
      var4.setConstraints(this.choose, var5);
      var3.add(this.choose);
      var7 = new JLabel(this.mh.getMessage("size"));
      var5.weightx = 0.0;
      var5.weighty = 0.0;
      var5.gridwidth = 1;
      var5.insets = new Insets(5, 10, 5, 10);
      var4.setConstraints(var7, var5);
      var3.add(var7);
      ButtonGroup var8 = new ButtonGroup();
      this.unlimited = new JRadioButton(this.mh.getMessage("unlimited"));
      this.unlimited.addActionListener(this);
      this.unlimited.setMargin(new Insets(0, 0, 0, 0));
      var5.weightx = 1.0;
      var5.gridwidth = 0;
      var5.insets = new Insets(5, 0, 0, 0);
      var4.setConstraints(this.unlimited, var5);
      var8.add(this.unlimited);
      var3.add(this.unlimited);
      this.maximum = new JRadioButton(this.mh.getMessage("maximum"));
      this.maximum.setMargin(new Insets(0, 0, 0, 0));
      this.maximum.addActionListener(this);
      var5.gridwidth = 1;
      var5.gridx = 1;
      var5.weightx = 0.0;
      var5.insets = new Insets(0, 0, 10, 0);
      var4.setConstraints(this.maximum, var5);
      var8.add(this.maximum);
      var3.add(this.maximum);
      this.size = new JTextField(7);
      this.size.setDocument(new CachePanel.SizeDocument(this, null));
      var5.gridx = -1;
      var4.setConstraints(this.size, var5);
      var3.add(this.size);
      String[] var9 = new String[]{this.mh.getMessage("mb"), this.mh.getMessage("kb"), this.mh.getMessage("bytes")};
      this.units = new JComboBox<>(var9);
      this.units.addActionListener(this);
      var5.gridwidth = 1;
      var5.insets = new Insets(0, 2, 10, 10);
      var4.setConstraints(this.units, var5);
      var3.add(this.units);
      var7 = new JLabel(this.mh.getMessage("compression"));
      var5.anchor = 18;
      var5.gridy = 3;
      var5.weightx = 0.0;
      var5.weighty = 1.0;
      var5.gridwidth = 1;
      var5.insets = new Insets(5, 10, 5, 10);
      var4.setConstraints(var7, var5);
      var3.add(var7);
      this.compression = new JSlider(0, 9, 0);
      this.compression.addChangeListener(new CachePanel$1(this, var1));
      Hashtable var10 = new Hashtable(2);
      var10.put(new Integer(0), new JLabel(this.mh.getMessage("no_compression")));
      var10.put(new Integer(9), new JLabel(this.mh.getMessage("high_compression")));
      this.compression.setLabelTable(var10);
      this.compression.setPaintLabels(true);
      this.compression.setMajorTickSpacing(1);
      this.compression.setPaintTicks(true);
      this.compression.setSnapToTicks(true);
      var5.weightx = 1.0;
      var5.gridheight = 2;
      var5.gridwidth = 0;
      var5.fill = 2;
      var5.insets = new Insets(5, 0, 5, 10);
      var4.setConstraints(this.compression, var5);
      var3.add(this.compression);
      this.add(var3);
      this.reset();
   }

   private class LocationDocument extends PlainDocument {
      private final CachePanel this$0;

      public void remove(int var1, int var2) throws BadLocationException {
         super.remove(var1, var2);
         this.this$0.model.setCacheLocation(this.this$0.location.getText());
      }

      private LocationDocument(CachePanel var1) {
         this.this$0 = var1;
      }

      public void insertString(int var1, String var2, AttributeSet var3) throws BadLocationException {
         super.insertString(var1, var2, var3);
         this.this$0.model.setCacheLocation(this.this$0.location.getText());
      }

      LocationDocument(CachePanel var1, CachePanel$1 var2) {
         this(var1);
      }
   }

   private class LocationField extends JTextField {
      private final CachePanel this$0;

      public Dimension getPreferredSize() {
         Dimension var1 = super.getPreferredSize();
         var1.width = 10;
         return var1;
      }

      private LocationField(CachePanel var1) {
         this.this$0 = var1;
      }

      LocationField(CachePanel var1, CachePanel$1 var2) {
         this(var1);
      }
   }

   private class SizeDocument extends PlainDocument {
      private final CachePanel this$0;

      public void remove(int var1, int var2) throws BadLocationException {
         super.remove(var1, var2);
         this.this$0.maximum.setSelected(true);
         CachePanel.access$300(this.this$0);
      }

      private boolean isNumeric(String var1) {
         try {
            Long.valueOf(var1);
            return true;
         } catch (NumberFormatException var3) {
            return false;
         }
      }

      private SizeDocument(CachePanel var1) {
         this.this$0 = var1;
      }

      public void insertString(int var1, String var2, AttributeSet var3) throws BadLocationException {
         if (this.isNumeric(var2)) {
            super.insertString(var1, var2, var3);
            this.this$0.maximum.setSelected(true);
            CachePanel.access$300(this.this$0);
         } else {
            Toolkit.getDefaultToolkit().beep();
         }
      }

      SizeDocument(CachePanel var1, CachePanel$1 var2) {
         this(var1);
      }
   }
}
