package sun.plugin.panel;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.PrintStream;
import java.security.KeyStore;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.Arrays;
import java.util.Collection;
import java.util.Enumeration;
import java.util.TreeSet;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JScrollPane;
import javax.swing.border.EmptyBorder;
import sun.misc.BASE64Encoder;
import sun.plugin.security.CertificateDialog;
import sun.plugin.util.DialogFactory;
import sun.plugin.util.Trace;

final class CertAllPanel extends ActivatorSubPanel implements ActionListener {
   private JList certList;
   private JButton removeButton;
   private JButton viewCertButton;
   private JButton exportButton;
   private JButton importButton;
   private String radioPos;
   private static MessageHandler mh = new MessageHandler("cert");

   void reset() {
      Collection var1 = null;
      if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
         var1 = this.model.getCertificateAliases();
      } else if (this.getRadioPos() == mh.getMessage("SecureSite_value")) {
         var1 = this.model.getHttpsCertificateAliases();
      } else if (this.getRadioPos() == mh.getMessage("SignerCA_value")) {
         var1 = this.model.getRootCACertificateAliases();
      } else if (this.getRadioPos() == mh.getMessage("SecureSiteCA_value")) {
         var1 = this.model.getHttpsRootCACertAliases();
      }

      if (var1 != null && var1.size() != 0) {
         TreeSet var2 = new TreeSet(var1);
         this.certList.setListData(var2.toArray());
      } else {
         this.certList.setListData(new String[0]);
      }

      boolean var3 = var1 != null && var1.size() > 0;
      if (this.getRadioPos() != mh.getMessage("SignerCA_value") && this.getRadioPos() != mh.getMessage("SecureSiteCA_value")) {
         this.setEnabled(this.removeButton, var3);
         this.setEnabled(this.exportButton, var3);
         this.setEnabled(this.importButton, true);
         this.setEnabled(this.viewCertButton, var3);
      } else {
         this.setEnabled(this.removeButton, false);
         this.setEnabled(this.exportButton, false);
         this.setEnabled(this.importButton, false);
         this.setEnabled(this.viewCertButton, var3);
      }

      if (var3) {
         this.certList.setSelectedIndex(0);
      }
   }

   private boolean compareCharArray(char[] var1, char[] var2) {
      if (var1.length != var2.length) {
         return false;
      } else {
         for (int var3 = 0; var3 < var1.length; var3++) {
            if (var1[var3] != var2[var3]) {
               return false;
            }
         }

         return true;
      }
   }

   public void actionPerformed(ActionEvent var1) {
      int var2 = this.certList.getSelectedIndex();
      String var3 = (String)this.certList.getSelectedValue();
      if (var1.getSource() == this.removeButton) {
         if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
            this.model.deactivateCertificate(var3);
         } else {
            this.model.deactivateHttpsCertificate(var3);
         }

         this.reset();
      } else if (var1.getSource() == this.viewCertButton) {
         X509Certificate var4 = null;
         if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
            var4 = (X509Certificate)this.model.getCertificate(var3);
         } else if (this.getRadioPos() == mh.getMessage("SecureSite_value")) {
            var4 = (X509Certificate)this.model.getHttpsCertificate(var3);
         } else if (this.getRadioPos() == mh.getMessage("SignerCA_value")) {
            var4 = (X509Certificate)this.model.getRootCACertificate(var3);
         } else if (this.getRadioPos() == mh.getMessage("SecureSiteCA_value")) {
            var4 = (X509Certificate)this.model.getHttpsRootCACertificate(var3);
         }

         X509Certificate[] var5 = new X509Certificate[]{var4};
         if (var5.length > 0 && var5[0] instanceof X509Certificate) {
            CertificateDialog var23 = new CertificateDialog(this, var5, 0, var5.length);
            var23.DoModal();
         } else {
            Object var6 = null;
            if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
               var6 = this.model.getImpCertificate(var3);
            } else {
               var6 = this.model.getImpHttpsCertificate(var3);
            }

            X509Certificate[] var7 = new X509Certificate[]{(X509Certificate)var6};
            CertificateDialog var8 = new CertificateDialog(this, var7, 0, var7.length);
            var8.DoModal();
         }
      } else if (var1.getSource() == this.importButton) {
         JFileChooser var18 = new JFileChooser();
         CertFileFilter var20 = new CertFileFilter();
         var20.addExtension("csr");
         var20.addExtension("p12");
         var20.setDescription("Certificate Files");
         var18.setFileFilter(var20);
         var18.setFileSelectionMode(0);
         var18.setDialogType(0);
         var18.setMultiSelectionEnabled(false);
         int var24 = var18.showOpenDialog(this);
         if (var24 == 0) {
            File var26 = var18.getSelectedFile();
            if (var26 == null) {
               return;
            }

            try {
               InputStream var28 = System.in;
               FileInputStream var29 = new FileInputStream(var26);
               boolean var9 = false;
               var9 = this.importCertificate(var29);
               if (!var9) {
                  InputStream var10 = System.in;
                  FileInputStream var32 = new FileInputStream(var26);
                  this.importPKCS12Certificate(var32);
               }
            } catch (Throwable var16) {
               DialogFactory.showExceptionDialog(this, var16, getMessage("dialog.import.file.text"), getMessage("dialog.import.error.caption"));
            }
         }

         this.reset();
      } else if (var1.getSource() == this.exportButton) {
         X509Certificate var19 = null;
         if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
            var19 = (X509Certificate)this.model.getCertificate(var3);
         } else if (this.getRadioPos() == mh.getMessage("SecureSite_value")) {
            var19 = (X509Certificate)this.model.getHttpsCertificate(var3);
         } else if (this.getRadioPos() == mh.getMessage("SignerCA_value")) {
            var19 = (X509Certificate)this.model.getRootCACertificate(var3);
         } else if (this.getRadioPos() == mh.getMessage("SecureSiteCA_value")) {
            var19 = (X509Certificate)this.model.getHttpsRootCACertificate(var3);
         }

         if (!(var19 instanceof X509Certificate)) {
            if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
               var19 = this.model.getImpCertificate(var3);
            } else {
               var19 = this.model.getImpHttpsCertificate(var3);
            }
         }

         if (var19 != null) {
            JFileChooser var21 = new JFileChooser();
            var21.setFileSelectionMode(0);
            var21.setDialogType(1);
            var21.setMultiSelectionEnabled(false);
            int var25 = var21.showSaveDialog(this);
            if (var25 == 0) {
               File var27 = var21.getSelectedFile();
               if (var27 == null) {
                  return;
               }

               PrintStream var30 = null;

               try {
                  var30 = new PrintStream(new BufferedOutputStream(new FileOutputStream(var27)));
                  this.exportCertificate(var19, var30);
               } catch (Throwable var15) {
                  DialogFactory.showExceptionDialog(this, var15, getMessage("dialog.export.text"), getMessage("dialog.export.error.caption"));
               } finally {
                  if (var30 != null) {
                     var30.close();
                  }
               }
            }
         } else {
            DialogFactory.showErrorDialog(this, getMessage("dialog.export.text"), getMessage("dialog.export.error.caption"));
         }
      }
   }

   void importPKCS12Certificate(InputStream var1) {
      KeyStore var2 = null;
      char[] var3 = null;

      try {
         var2 = KeyStore.getInstance("PKCS12");
         String var4 = getMessage("dialog.password.text");
         JPasswordField var21 = new JPasswordField();
         Object[] var22 = new Object[]{new JLabel(var4.toString()), var21};
         JButton var23 = new JButton(getMessage("dialog.password.okButton"));
         JButton var8 = new JButton(getMessage("dialog.password.cancelButton"));
         String var9 = getMessage("dialog.password.caption");
         Object[] var10 = new Object[]{var23, var8};
         int var11 = DialogFactory.showOptionDialog(this, var22, var9, var10, var10[0]);
         var3 = var21.getPassword();
         if (var11 == 0) {
            var2.load(var1, var3);
            Enumeration var12 = var2.aliases();

            while (var12.hasMoreElements()) {
               Object var13 = null;
               String var14 = (String)var12.nextElement();
               var13 = (X509Certificate)var2.getCertificate(var14);
               if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
                  this.model.deactivateImpCertificate((X509Certificate)var13);
               } else if (this.getRadioPos() == mh.getMessage("SecureSite_value")) {
                  this.model.deactivateImpHttpsCertificate((X509Certificate)var13);
               }
            }
         }
      } catch (Throwable var18) {
         String var5 = "uninitializedValue";
         if (!this.compareCharArray(var3, var5.toCharArray())) {
            String var6 = getMessage("dialog.import.password.text");
            String var7 = getMessage("dialog.import.error.caption");
            DialogFactory.showExceptionDialog(this, var18, var6, var7);
         }
      } finally {
         if (var3 != null) {
            Arrays.fill(var3, ' ');
         }
      }
   }

   boolean importCertificate(InputStream var1) {
      CertificateFactory var2 = null;
      Object var3 = null;

      try {
         var2 = CertificateFactory.getInstance("X.509");
         var3 = (X509Certificate)var2.generateCertificate(var1);
         if (this.getRadioPos() == mh.getMessage("SignedApplet_value")) {
            this.model.deactivateImpCertificate((X509Certificate)var3);
         } else if (this.getRadioPos() == mh.getMessage("SecureSite_value")) {
            this.model.deactivateImpHttpsCertificate((X509Certificate)var3);
         }
      } catch (CertificateParsingException var5) {
         return false;
      } catch (CertificateException var6) {
         DialogFactory.showExceptionDialog(this, var6, getMessage("dialog.import.format.text"), getMessage("dialog.import.error.caption"));
      }

      return true;
   }

   String getRadioPos() {
      return this.radioPos == null ? mh.getMessage("SignedApplet_value") : this.radioPos;
   }

   void setRadioPos(String var1) {
      this.radioPos = var1;
   }

   private void setEnabled(JComponent var1, boolean var2) {
      var1.setEnabled(var2);
      var1.repaint();
   }

   CertAllPanel(ConfigurationInfo var1) {
      super(var1);
      this.setLayout(new BoxLayout(this, 1));
      this.add(Box.createRigidArea(new Dimension(1, 5)));
      JPanel var2 = new JPanel();
      var2.setLayout(new BorderLayout());
      var2.setBorder(new EmptyBorder(0, 5, 0, 5));
      this.certList = new JList();
      this.certList.setSelectionMode(0);
      var2.add(new JScrollPane(this.certList), "Center");
      this.removeButton = new JButton(mh.getMessage("remove_button"));
      this.removeButton.setMnemonic(mh.getAcceleratorKey("remove_button"));
      this.removeButton.addActionListener(this);
      this.exportButton = new JButton(mh.getMessage("export_button"));
      this.exportButton.setMnemonic(mh.getAcceleratorKey("export_button"));
      this.exportButton.addActionListener(this);
      this.importButton = new JButton(mh.getMessage("import_button"));
      this.importButton.setMnemonic(mh.getAcceleratorKey("import_button"));
      this.importButton.addActionListener(this);
      this.viewCertButton = new JButton(mh.getMessage("details_button"));
      this.viewCertButton.setMnemonic(mh.getAcceleratorKey("details_button"));
      this.viewCertButton.addActionListener(this);
      JPanel var3 = new JPanel();
      var3.setLayout(new FlowLayout(1));
      var3.add(this.importButton);
      var3.add(this.exportButton);
      var3.add(this.removeButton);
      var3.add(this.viewCertButton);
      var2.add(var3, "South");
      this.add(var2);
   }

   void exportCertificate(X509Certificate var1, PrintStream var2) {
      BASE64Encoder var3 = new BASE64Encoder();
      var2.println("-----BEGIN CERTIFICATE-----");

      try {
         var3.encodeBuffer(var1.getEncoded(), var2);
      } catch (Throwable var5) {
         Trace.printException(this, var5);
      }

      var2.println("-----END CERTIFICATE-----");
   }

   private static String getMessage(String var0) {
      return mh.getMessage(var0);
   }
}
