package sun.plugin.panel;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.Principal;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.text.MessageFormat;
import java.util.Collection;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Properties;
import java.util.Vector;
import sun.plugin.security.HttpsRootCACertStore;
import sun.plugin.security.PluginCertificateStore;
import sun.plugin.security.PluginHttpsCertStore;
import sun.plugin.security.RootCACertificateStore;
import sun.plugin.util.DialogFactory;
import sun.plugin.util.Trace;
import sun.plugin.util.UserProfile;

public class ConfigurationInfo {
   private static File theUserPropertiesFile;
   private Properties props;
   private String showConsole = "hide";
   private boolean showException = false;
   private boolean showSysTray = true;
   private String[][] installedJREs;
   private String[][] installedJDKs;
   private boolean useDefaultProxy = true;
   private String proxySettings;
   private String proxyByPass;
   private String autoProxyURL;
   private String javaParms;
   private String javaVersion;
   private String javaRuntimePath = null;
   private String javaRuntimeType = "Default";
   private boolean cacheEnabled;
   private String cacheLocation = null;
   private String cacheSize;
   private int JARCacheCompression;
   private File defaultCacheLocation;
   private boolean iexplorerDefault = false;
   private boolean netscape6Default = false;
   private boolean mozillaDefault = false;
   private boolean showBrowserPanel = false;
   private HashMap activeCertsMap = new HashMap();
   private HashMap inactiveCertsMap = new HashMap();
   private HashMap inactiveImpCertsMap = new HashMap();
   private HashMap activeHttpsCertsMap = new HashMap();
   private HashMap inactiveHttpsCertsMap = new HashMap();
   private HashMap inactiveImpHttpsCertsMap = new HashMap();
   private HashMap activeRootCACertsMap = new HashMap();
   private HashMap activeHttpsRootCACertsMap = new HashMap();
   private PropertyChangeSupport pcs = new PropertyChangeSupport(this);
   private MessageHandler mh = new MessageHandler("config");
   private boolean autoupdatecheck_enabled = true;
   private int update_notify = 0;
   private int update_frequency = 1;
   private int update_day = 1;
   private int update_schedule = 0;
   private String update_lastrun;
   private boolean isAdminUser = true;
   private boolean isJavaUpdateEnabled = true;
   private boolean isSchedPlatform = true;

   int getJARCacheCompression() {
      return this.JARCacheCompression;
   }

   public int getUpdateDay() {
      return this.update_day;
   }

   public int getUpdateFrequency() {
      return this.update_frequency;
   }

   public int getUpdateNotify() {
      return this.update_notify;
   }

   public int getUpdateSchedule() {
      return this.update_schedule;
   }

   public ConfigurationInfo() {
      if (theUserPropertiesFile == null) {
         theUserPropertiesFile = new File(UserProfile.getPropertyFile());
         new File(theUserPropertiesFile.getParent()).mkdirs();
      }

      this.reset();
   }

   public void applyChanges() throws IOException {
      this.props.put("javaplugin.console", this.showConsole);
      this.props.put("javaplugin.exception", this.showException ? "true" : "false");
      if (this.useDefaultProxy) {
         this.props.put("javaplugin.proxy.usebrowsersettings", "true");
      } else {
         this.props.put("javaplugin.proxy.usebrowsersettings", "false");
      }

      if (this.proxySettings != null) {
         this.props.put("javaplugin.proxy.settings", this.proxySettings);
      } else {
         this.props.remove("javaplugin.proxy.settings");
      }

      if (this.proxyByPass != null) {
         this.props.put("javaplugin.proxy.bypass", this.proxyByPass);
      } else {
         this.props.remove("javaplugin.proxy.bypass");
      }

      try {
         if (this.autoProxyURL != null && !this.autoProxyURL.trim().equals("")) {
            new URL(this.autoProxyURL);
            this.props.put("javaplugin.proxy.auto.url", this.autoProxyURL);
         } else {
            this.props.remove("javaplugin.proxy.auto.url");
         }
      } catch (MalformedURLException var17) {
         DialogFactory.showExceptionDialog(var17, this.mh.getMessage("proxy.autourl.invalid.text"), this.mh.getMessage("proxy.autourl.invalid.caption"));
         this.props.remove("javaplugin.proxy.auto.url");
         this.autoProxyURL = null;
      }

      if (this.javaRuntimeType != null) {
         this.props.put("javaplugin.jre.type", this.javaRuntimeType);
      } else {
         this.javaRuntimeType = "Default";
         this.props.put("javaplugin.jre.type", "Default");
      }

      String var1 = null;
      if (this.javaVersion != null && this.javaVersion.length() > 0) {
         String[][] var2 = (String[][])null;
         if (this.javaRuntimeType.equalsIgnoreCase("JRE")) {
            var2 = this.getInstalledJREList();
         }

         if (this.javaRuntimeType.equalsIgnoreCase("JDK")) {
            var2 = this.getInstalledJDKList();
         }

         if (var2 != null) {
            for (int var3 = 0; var3 < var2.length; var3++) {
               if (var2[var3][0].equalsIgnoreCase(this.javaVersion)) {
                  var1 = var2[var3][1];
               }
            }
         }
      }

      if (this.javaRuntimeType.equalsIgnoreCase("Other") && this.javaRuntimePath != null && !this.javaRuntimePath.trim().equals("")) {
         var1 = this.javaRuntimePath;
      }

      if (var1 != null) {
         this.props.put("javaplugin.jre.path", var1);
      } else {
         this.props.put("javaplugin.jre.type", "Default");
         this.props.put("javaplugin.jre.path", "Default");
      }

      if (this.javaVersion != null && this.javaVersion.length() > 0) {
         this.props.put("javaplugin.jre.version", this.javaVersion);
      } else {
         this.props.remove("javaplugin.jre.version");
      }

      if (this.javaParms != null && this.javaParms.length() > 0) {
         if (this.javaVersion != null && this.javaVersion.length() > 0) {
            this.props.put("javaplugin.jre." + this.javaVersion + ".params", this.javaParms);
         }

         this.props.put("javaplugin.jre.params", this.javaParms);
      } else {
         if (this.javaVersion != null && this.javaVersion.length() > 0) {
            this.props.remove("javaplugin.jre." + this.javaVersion + ".params");
         }

         this.props.remove("javaplugin.jre.params");
      }

      if (!this.cacheEnabled) {
         this.props.put("javaplugin.cache.disabled", "true");
      } else {
         this.props.remove("javaplugin.cache.disabled");
      }

      File var18 = new File(this.cacheLocation);
      if (var18.equals(this.defaultCacheLocation)) {
         this.props.remove("javaplugin.cache.directory");
      } else {
         this.props.put("javaplugin.cache.directory", this.cacheLocation);
      }

      if (!this.cacheSize.equals("50m")) {
         this.props.put("javaplugin.cache.size", this.cacheSize);
      } else {
         this.props.remove("javaplugin.cache.size");
      }

      if (this.JARCacheCompression != 0) {
         this.props.put("javaplugin.cache.compression", String.valueOf(this.JARCacheCompression));
      } else {
         this.props.remove("javaplugin.cache.compression");
      }

      try {
         FileOutputStream var19 = new FileOutputStream(theUserPropertiesFile);
         BufferedOutputStream var4 = new BufferedOutputStream(var19);
         PrintWriter var5 = new PrintWriter(var4);
         var5.println(this.mh.getMessage("property_file_header"));
         var5.flush();
         this.props.store(var4, "");
         var4.close();
         var19.close();
         PluginCertificateStore var6 = new PluginCertificateStore();
         PluginHttpsCertStore var7 = new PluginHttpsCertStore();
         var6.load();
         var7.load();
         Collection var8 = this.inactiveCertsMap.values();
         Iterator var9 = var8.iterator();

         while (var9.hasNext()) {
            var6.remove((Certificate)var9.next());
         }

         Collection var10 = this.inactiveImpCertsMap.values();
         Iterator var11 = var10.iterator();

         while (var11.hasNext()) {
            var6.add((Certificate)var11.next());
         }

         Collection var12 = this.inactiveHttpsCertsMap.values();
         Iterator var13 = var12.iterator();

         while (var13.hasNext()) {
            var7.remove((Certificate)var13.next());
         }

         Collection var14 = this.inactiveImpHttpsCertsMap.values();
         Iterator var15 = var14.iterator();

         while (var15.hasNext()) {
            var7.add((Certificate)var15.next());
         }

         var6.save();
         var7.save();
      } catch (Exception var16) {
         Trace.printException(var16);
      }

      this.inactiveCertsMap.clear();
      this.inactiveImpCertsMap.clear();
      this.inactiveHttpsCertsMap.clear();
      this.inactiveImpHttpsCertsMap.clear();
   }

   protected void firePropertyChange() {
      this.pcs.firePropertyChange(null, null, null);
   }

   public void reset() {
      this.firePropertyChange();
      this.props = new Properties();

      try {
         FileInputStream var1 = new FileInputStream(theUserPropertiesFile);
         BufferedInputStream var2 = new BufferedInputStream(var1);
         this.props.load(var2);
         var2.close();
         var1.close();
      } catch (Exception var14) {
      }

      String var16 = this.props.getProperty("javaplugin.console");
      if (var16 != null) {
         this.showConsole = var16;
      } else {
         this.showConsole = "hide";
      }

      var16 = this.props.getProperty("javaplugin.exception");
      if (var16 != null && !var16.equals("false")) {
         this.showException = true;
      } else {
         this.showException = false;
      }

      var16 = this.props.getProperty("javaplugin.proxy.usebrowsersettings");
      if (var16 != null && !var16.equals("true")) {
         this.useDefaultProxy = false;
      } else {
         this.useDefaultProxy = true;
      }

      this.proxySettings = this.props.getProperty("javaplugin.proxy.settings");
      this.proxyByPass = this.props.getProperty("javaplugin.proxy.bypass");

      try {
         String var21 = this.props.getProperty("javaplugin.proxy.auto.url");
         if (var21 != null && !var21.trim().equals("")) {
            new URL(var21);
            this.autoProxyURL = var21;
         }
      } catch (MalformedURLException var13) {
         DialogFactory.showExceptionDialog(var13, this.mh.getMessage("proxy.autourl.invalid.text"), this.mh.getMessage("proxy.autourl.invalid.caption"));
         this.autoProxyURL = null;
      }

      this.javaRuntimePath = this.props.getProperty("javaplugin.jre.path");
      this.javaRuntimeType = this.props.getProperty("javaplugin.jre.type");
      if (this.javaRuntimeType == null) {
         if (this.javaRuntimePath != null && !this.javaRuntimePath.trim().equals("")) {
            this.javaRuntimeType = "Other";
         } else {
            this.javaRuntimeType = "Default";
         }
      } else if (this.javaRuntimeType.equalsIgnoreCase("JRE")) {
         this.javaRuntimeType = "JRE";
      } else if (this.javaRuntimeType.equalsIgnoreCase("JDK")) {
         this.javaRuntimeType = "JDK";
      } else if (this.javaRuntimeType.equalsIgnoreCase("Other")) {
         if (this.javaRuntimePath != null && !this.javaRuntimePath.trim().equals("")) {
            this.javaRuntimeType = "Other";
         } else {
            this.javaRuntimeType = "Default";
         }
      } else {
         this.javaRuntimeType = "Default";
      }

      if (this.javaRuntimeType == null) {
         this.javaRuntimeType = "Default";
      }

      this.javaVersion = this.props.getProperty("javaplugin.jre.version");
      this.javaParms = this.props.getProperty("javaplugin.jre.params");
      var16 = this.props.getProperty("javaplugin.cache.disabled");
      if (var16 != null && var16.equalsIgnoreCase("true")) {
         this.cacheEnabled = false;
      } else {
         this.cacheEnabled = true;
      }

      this.defaultCacheLocation = new File(UserProfile.getPluginCacheDirectory());
      this.cacheLocation = this.props.getProperty("javaplugin.cache.directory");
      if (this.cacheLocation == null) {
         this.cacheLocation = this.defaultCacheLocation.getPath();
      }

      this.cacheSize = this.props.getProperty("javaplugin.cache.size", "50m");
      System.setProperty("javaplugin.cache.size", this.cacheSize);
      var16 = this.props.getProperty("javaplugin.cache.compression");
      if (var16 != null) {
         try {
            this.JARCacheCompression = Integer.valueOf(var16);
         } catch (NumberFormatException var12) {
            this.JARCacheCompression = 0;
         }
      } else {
         this.JARCacheCompression = 0;
      }

      this.activeCertsMap.clear();
      this.inactiveCertsMap.clear();
      this.inactiveImpCertsMap.clear();
      this.activeHttpsCertsMap.clear();
      this.inactiveHttpsCertsMap.clear();
      this.inactiveImpHttpsCertsMap.clear();
      this.activeRootCACertsMap.clear();
      this.activeHttpsRootCACertsMap.clear();

      try {
         PluginCertificateStore var22 = new PluginCertificateStore();
         PluginHttpsCertStore var3 = new PluginHttpsCertStore();
         RootCACertificateStore var4 = RootCACertificateStore.getInstance();
         HttpsRootCACertStore var5 = new HttpsRootCACertStore();
         var22.load();
         var3.load();
         var4.load();
         var5.load();
         Iterator var6 = var22.iterator();
         Iterator var7 = var3.iterator();
         Iterator var8 = var4.iterator();
         Iterator var9 = var5.iterator();

         while (var6.hasNext()) {
            X509Certificate var10 = (X509Certificate)var6.next();
            String var11 = this.extractAliasName(var10);
            this.activeCertsMap.put(var11, var10);
         }

         while (var7.hasNext()) {
            X509Certificate var23 = (X509Certificate)var7.next();
            String var26 = this.extractAliasName(var23);
            this.activeHttpsCertsMap.put(var26, var23);
         }

         while (var8.hasNext()) {
            X509Certificate var24 = (X509Certificate)var8.next();
            String var27 = this.extractAliasName(var24);
            this.activeRootCACertsMap.put(var27, var24);
         }

         while (var9.hasNext()) {
            X509Certificate var25 = (X509Certificate)var9.next();
            String var28 = this.extractAliasName(var25);
            this.activeHttpsRootCACertsMap.put(var28, var25);
         }
      } catch (Exception var15) {
         Trace.printException(var15);
      }
   }

   public boolean getAutoUpdateCheckEnabled() {
      return this.autoupdatecheck_enabled;
   }

   boolean getCacheEnabled() {
      return this.cacheEnabled;
   }

   public boolean getUpdateSchedPlatform() {
      return this.isSchedPlatform;
   }

   public boolean isIExplorerDefault() {
      return this.iexplorerDefault;
   }

   public boolean isMozillaDefault() {
      return this.mozillaDefault;
   }

   public boolean isNetscape6Default() {
      return this.netscape6Default;
   }

   public boolean isShowBrowserPanel() {
      return this.showBrowserPanel;
   }

   public boolean isShowExceptionEnabled() {
      return this.showException;
   }

   public boolean isSysTrayEnabled() {
      return this.showSysTray;
   }

   public boolean showUpdatePanel() {
      return this.isAdminUser && this.isJavaUpdateEnabled;
   }

   public boolean useDefaultProxy() {
      return this.useDefaultProxy;
   }

   void setJARCacheCompression(int var1) {
      this.JARCacheCompression = var1;
      this.firePropertyChange();
   }

   public void setUpdateDay(int var1) {
      this.update_day = var1;
      this.firePropertyChange();
   }

   public void setUpdateFrequency(int var1) {
      this.update_frequency = var1;
      this.firePropertyChange();
   }

   public void setUpdateNotify(int var1) {
      this.update_notify = var1;
      this.firePropertyChange();
   }

   public void setUpdateSchedule(int var1) {
      this.update_schedule = var1;
      this.firePropertyChange();
   }

   public void setAdminUser(boolean var1) {
      this.isAdminUser = var1;
   }

   public void setAutoUpdateCheckEnabled(boolean var1) {
      this.autoupdatecheck_enabled = var1;
      this.firePropertyChange();
   }

   void setCacheEnabled(boolean var1) {
      this.cacheEnabled = var1;
      this.firePropertyChange();
   }

   public void setDefaultProxySettings(boolean var1) {
      this.useDefaultProxy = var1;
      this.firePropertyChange();
   }

   public void setIExplorerDefault(boolean var1) {
      this.iexplorerDefault = var1;
      this.firePropertyChange();
   }

   public void setMozillaDefault(boolean var1) {
      this.mozillaDefault = var1;
      this.firePropertyChange();
   }

   public void setNetscape6Default(boolean var1) {
      this.netscape6Default = var1;
      this.firePropertyChange();
   }

   public void setShowBrowserPanel(boolean var1) {
      this.showBrowserPanel = var1;
   }

   public void setShowException(boolean var1) {
      this.showException = var1;
      this.firePropertyChange();
   }

   public void setShowSysTray(boolean var1) {
      this.showSysTray = var1;
      this.firePropertyChange();
   }

   public void setUpdateEnabled(boolean var1) {
      this.isJavaUpdateEnabled = var1;
   }

   public void setUpdateSchedPlatform(boolean var1) {
      this.isSchedPlatform = var1;
   }

   public void addPropertyChangeListener(PropertyChangeListener var1) {
      this.pcs.addPropertyChangeListener(var1);
   }

   public void removePropertyChangeListener(PropertyChangeListener var1) {
      this.pcs.removePropertyChangeListener(var1);
   }

   public String getAutoProxyURL() {
      return this.autoProxyURL;
   }

   String getCacheLocation() {
      return this.cacheLocation;
   }

   String getCacheSize() {
      return this.cacheSize;
   }

   public String getJavaParms() {
      return this.javaParms;
   }

   public String getJavaRuntimeType() {
      return this.javaRuntimeType != null && this.javaRuntimeType.equalsIgnoreCase("Other") ? this.javaRuntimePath : this.javaRuntimeType;
   }

   public String getJavaRuntimeVersion() {
      return this.javaVersion;
   }

   public String getProxyByPass() {
      return this.proxyByPass;
   }

   public String getProxySettingsString() {
      return this.proxySettings;
   }

   public String getUpdateLastRun() {
      return this.update_lastrun;
   }

   public String isConsoleEnabled() {
      return this.showConsole;
   }

   public String[][] getInstalledJDKList() {
      return this.installedJDKs;
   }

   public String[][] getInstalledJREList() {
      return this.installedJREs;
   }

   public void deactivateCertificate(String var1) {
      Object var2 = this.activeCertsMap.remove(var1);
      this.inactiveCertsMap.put(var1, var2);
      this.firePropertyChange();
   }

   public void deactivateHttpsCertificate(String var1) {
      Object var2 = this.activeHttpsCertsMap.remove(var1);
      this.inactiveHttpsCertsMap.put(var1, var2);
      this.firePropertyChange();
   }

   public void setAutoProxyURL(String var1) {
      this.autoProxyURL = var1;
      this.firePropertyChange();
   }

   void setCacheLocation(String var1) {
      this.cacheLocation = var1;
      this.firePropertyChange();
   }

   void setCacheSize(String var1) {
      this.cacheSize = var1;
      this.firePropertyChange();
   }

   public void setConsoleEnabled(String var1) {
      this.showConsole = var1;
      this.firePropertyChange();
   }

   public void setJavaParms(String var1) {
      this.javaParms = var1;
      this.firePropertyChange();
   }

   public void setJavaRuntimeType(String var1) {
      if (var1 != null) {
         if (var1.equalsIgnoreCase("Default")) {
            this.javaRuntimeType = "Default";
            this.javaRuntimePath = null;
         } else if (var1.equalsIgnoreCase("JDK")) {
            this.javaRuntimeType = "JDK";
            this.javaRuntimePath = null;
         } else if (var1.equalsIgnoreCase("JRE")) {
            this.javaRuntimeType = "JRE";
            this.javaRuntimePath = null;
         } else {
            this.javaRuntimeType = "Other";
            this.javaRuntimePath = var1;
         }

         this.firePropertyChange();
      }
   }

   public void setJavaRuntimeVersion(String var1) {
      if (this.javaVersion != var1) {
         this.javaVersion = var1;
         if (var1 != null && var1.length() > 0) {
            String var3 = this.props.getProperty("javaplugin.jre." + this.javaVersion + ".params");
            if (var3 != null && !var3.equals("")) {
               this.javaParms = var3;
            }
         } else {
            String var2 = this.props.getProperty("javaplugin.jre.params");
            if (var2 != null && !var2.equals("")) {
               this.javaParms = var2;
            }
         }

         this.firePropertyChange();
      }
   }

   public void setProxyByPass(String var1) {
      this.proxyByPass = var1;
      this.firePropertyChange();
   }

   public void setProxySettingsString(String var1) {
      this.proxySettings = var1;
      this.firePropertyChange();
   }

   public void setUpdateLastRun(String var1) {
      this.update_lastrun = var1;
      this.firePropertyChange();
   }

   public void deactivateImpCertificate(X509Certificate var1) {
      String var2 = this.extractAliasName(var1);
      this.activeCertsMap.put(var2, var1);
      this.inactiveImpCertsMap.put(var2, var1);
      this.firePropertyChange();
   }

   public void deactivateImpHttpsCertificate(X509Certificate var1) {
      String var2 = this.extractAliasName(var1);
      this.activeHttpsCertsMap.put(var2, var1);
      this.inactiveImpHttpsCertsMap.put(var2, var1);
      this.firePropertyChange();
   }

   public Collection getCertificateAliases() {
      return this.activeCertsMap.keySet();
   }

   public Collection getHttpsCertificateAliases() {
      return this.activeHttpsCertsMap.keySet();
   }

   public Collection getHttpsRootCACertAliases() {
      return this.activeHttpsRootCACertsMap.keySet();
   }

   public Collection getRootCACertificateAliases() {
      return this.activeRootCACertsMap.keySet();
   }

   public void setInstalledJDKList(Vector var1) {
      String[][] var2 = new String[var1.size() / 2][2];
      int var3 = 0;
      Enumeration var6 = var1.elements();

      while (var6.hasMoreElements()) {
         String var4 = (String)var6.nextElement();
         String var5 = (String)var6.nextElement();
         if (var4.trim().lastIndexOf(".") > 2) {
            var2[var3][0] = var4;
            var2[var3][1] = var5;
            var3++;
         }
      }

      this.installedJDKs = new String[var3][2];

      for (int var7 = 0; var7 < var3; var7++) {
         this.installedJDKs[var7][0] = var2[var7][0];
         this.installedJDKs[var7][1] = var2[var7][1];
      }
   }

   public void setInstalledJREList(Vector var1) {
      String[][] var2 = new String[var1.size() / 2][2];
      int var3 = 0;
      Enumeration var6 = var1.elements();

      while (var6.hasMoreElements()) {
         String var4 = (String)var6.nextElement();
         String var5 = (String)var6.nextElement();
         if (var4.trim().lastIndexOf(".") > 2) {
            var2[var3][0] = var4;
            var2[var3][1] = var5;
            var3++;
         }
      }

      this.installedJREs = new String[var3][2];

      for (int var7 = 0; var7 < var3; var7++) {
         this.installedJREs[var7][0] = var2[var7][0];
         this.installedJREs[var7][1] = var2[var7][1];
      }
   }

   private String extractAliasName(X509Certificate var1) {
      String var2 = this.mh.getMessage("unknownSubject");
      String var3 = this.mh.getMessage("unknownIssuer");

      try {
         Principal var4 = var1.getSubjectDN();
         Principal var5 = var1.getIssuerDN();
         String var6 = var4.getName();
         String var7 = var5.getName();
         var2 = this.extractFromQuote(var6, "CN=");
         if (var2 == null) {
            String var8 = this.extractFromQuote(var6, "O=");
            String var9 = this.extractFromQuote(var6, "OU=");
            if (var8 != null || var9 != null) {
               MessageFormat var10 = new MessageFormat(this.mh.getMessage("certShowOOU"));
               Object[] var11 = new Object[]{var8, var9};
               if (var8 == null) {
                  var11[0] = "";
               }

               if (var9 == null) {
                  var11[1] = "";
               }

               var2 = var10.format(var11);
            }
         }

         if (var2 == null) {
            var2 = this.mh.getMessage("unknownSubject");
         }

         var3 = this.extractFromQuote(var7, "CN=");
         if (var3 == null) {
            String var15 = this.extractFromQuote(var7, "O=");
            String var16 = this.extractFromQuote(var7, "OU=");
            if (var15 != null || var16 != null) {
               MessageFormat var17 = new MessageFormat(this.mh.getMessage("certShowOOU"));
               Object[] var18 = new Object[]{var15, var16};
               if (var15 == null) {
                  var18[0] = "";
               }

               if (var16 == null) {
                  var18[1] = "";
               }

               var3 = var17.format(var18);
            }
         }

         if (var3 == null) {
            var3 = this.mh.getMessage("unknownIssuer");
         }
      } catch (Exception var12) {
         Trace.printException(var12);
      }

      MessageFormat var13 = new MessageFormat(this.mh.getMessage("certShowName"));
      Object[] var14 = new Object[]{var2, var3};
      return var13.format(var14);
   }

   public Certificate getCertificate(String var1) {
      try {
         PluginCertificateStore var2 = new PluginCertificateStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public Certificate getHttpsCertificate(String var1) {
      try {
         PluginHttpsCertStore var2 = new PluginHttpsCertStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public Certificate getHttpsRootCACertificate(String var1) {
      try {
         HttpsRootCACertStore var2 = new HttpsRootCACertStore();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public Certificate getRootCACertificate(String var1) {
      try {
         RootCACertificateStore var2 = RootCACertificateStore.getInstance();
         var2.load();

         for (X509Certificate var4 : var2) {
            String var5 = this.extractAliasName(var4);
            if (var5.equals(var1)) {
               return var4;
            }
         }
      } catch (Exception var6) {
         Trace.printException(var6);
      }

      return null;
   }

   public X509Certificate getImpCertificate(String var1) {
      Object var2 = this.inactiveImpCertsMap.get(var1);
      return (X509Certificate)var2;
   }

   public X509Certificate getImpHttpsCertificate(String var1) {
      Object var2 = this.inactiveImpHttpsCertsMap.get(var1);
      return (X509Certificate)var2;
   }

   private String extractFromQuote(String var1, String var2) {
      if (var1 == null) {
         return null;
      } else {
         int var3 = var1.indexOf(var2);
         int var4 = 0;
         if (var3 >= 0) {
            var3 += var2.length();
            if (var1.charAt(var3) == '"') {
               var4 = var1.indexOf(34, ++var3);
            } else {
               var4 = var1.indexOf(44, var3);
            }

            return var4 < 0 ? var1.substring(var3) : var1.substring(var3, var4);
         } else {
            return null;
         }
      }
   }
}
