package sun.plugin.panel;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.text.DateFormat;
import java.text.DateFormatSymbols;
import java.text.MessageFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Locale;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.border.Border;
import javax.swing.event.ChangeListener;
import sun.plugin.util.DialogFactory;

public class UpdatePanel extends ActivatorSubPanel implements ActionListener {
   private MessageHandler mh = new MessageHandler("update");
   private static final String update_image = "sun/plugin/panel/JavaUpdateIcon-48.png";
   private JButton updateButton;
   private JButton advancedButton;
   private JComboBox notify;
   private JCheckBox updateCheckBox;
   private JLabel textDescLabel;
   private JLabel lastRunLabel;
   private String textDesc;
   private DateFormat df = new SimpleDateFormat("EEE, dd MMM yyyy hh:mm:ss zzz", Locale.US);
   private String sysTrayIconText = this.mh.getMessage("desc_systrayicon.text");
   private String ntfyInstallText = this.mh.getMessage("notify_install.text");
   private String ntfyDownldText = this.mh.getMessage("notify_download.text");
   private String[] weekDays;
   private String[] atComboBoxText;

   public void reset() {
      if (this.model.getUpdateSchedPlatform()) {
         this.updateCheckBox.setSelected(this.model.getAutoUpdateCheckEnabled());
      } else {
         this.updateCheckBox.setEnabled(false);
      }

      this.notify.setSelectedIndex(this.model.getUpdateNotify());
      this.setText();
      String var1 = this.model.getUpdateLastRun();
      GregorianCalendar var2 = new GregorianCalendar();

      try {
         var2.setTime(this.df.parse(var1));
      } catch (Exception var8) {
         var1 = null;
         System.out.println("got exception:" + var8);
      }

      if (var1 == null) {
         var1 = new String("    ");
      } else {
         DateFormat var4 = DateFormat.getTimeInstance(3);
         DateFormat var5 = DateFormat.getDateInstance(3);
         MessageFormat var3 = new MessageFormat(this.mh.getMessage("lastrun.text"));
         String var6 = var4.format(var2.getTime());
         String var7 = var5.format(var2.getTime());
         var1 = var3.format(new String[]{var6, var7});
      }

      this.lastRunLabel.setText(var1);
   }

   private void setText() {
      if (!this.updateCheckBox.isSelected()) {
         this.notify.setEnabled(false);
         this.advancedButton.setEnabled(false);
         this.textDesc = this.mh.getMessage("desc_autooff.text");
         this.textDescLabel.setText(this.textDesc);
      } else {
         this.notify.setEnabled(true);
         this.advancedButton.setEnabled(true);
         int var1 = this.model.getUpdateFrequency();
         String var3 = this.atComboBoxText[this.model.getUpdateSchedule()];
         String var4 = null;
         if (var1 == 0) {
            this.textDesc = this.mh.getMessage("desc_check_daily.text");
            MessageFormat var2 = new MessageFormat(this.textDesc);
            this.textDesc = var2.format(new String[]{var3});
         } else if (var1 == 2) {
            this.textDesc = this.mh.getMessage("desc_check_monthly.text");
            var4 = String.valueOf(this.model.getUpdateDay());
         } else {
            this.textDesc = this.mh.getMessage("desc_check_weekly.text");
            var4 = String.valueOf(this.weekDays[this.model.getUpdateDay()]);
         }

         if (var4 != null) {
            MessageFormat var6 = new MessageFormat(this.textDesc);
            this.textDesc = var6.format(new String[]{var4, var3});
         }

         this.textDesc = this.textDesc + this.sysTrayIconText;
         var1 = this.notify.getSelectedIndex();
         if (var1 == 1) {
            this.textDesc = this.textDesc + this.mh.getMessage("desc_notify_download.text");
         } else {
            this.textDesc = this.textDesc + this.mh.getMessage("desc_notify_install.text");
         }

         this.textDescLabel.setText(this.textDesc);
      }
   }

   public void actionPerformed(ActionEvent var1) {
      try {
         if (var1.getSource() == this.updateButton) {
            String var2 = System.getProperty("java.home") + File.separator + "bin" + File.separator + "jucheck.exe";
            Runtime.getRuntime().exec(var2);
         } else if (var1.getSource() == this.advancedButton) {
            new UpdatePanel.AdvancedDialog(this, this, this.model, this.mh);
         } else if (var1.getSource() == this.notify) {
            int var4 = this.notify.getSelectedIndex();
            this.model.setUpdateNotify(var4);
            this.setText();
         } else if (var1.getSource() == this.updateCheckBox) {
            boolean var5 = this.updateCheckBox.isSelected();
            this.model.setAutoUpdateCheckEnabled(var5);
            this.setText();
         }
      } catch (Exception var3) {
         DialogFactory.showExceptionDialog(this, var3);
      }
   }

   public String[] getAtComboBoxText() {
      return this.atComboBoxText;
   }

   public String[] getWeekDays() {
      return this.weekDays;
   }

   UpdatePanel(ConfigurationInfo var1) {
      super(var1);
      this.setLayout(new BoxLayout(this, 0));
      this.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
      JPanel var2 = new JPanel();
      JLabel var3 = new JLabel();
      ImageIcon var4 = new ImageIcon(ClassLoader.getSystemResource("sun/plugin/panel/JavaUpdateIcon-48.png"));
      var3.setIcon(var4);
      var2.add(var3);
      this.add(var2);
      DateFormatSymbols var5 = new DateFormatSymbols();
      DateFormat var6 = DateFormat.getTimeInstance(3);
      SimpleDateFormat var7 = new SimpleDateFormat("H:mm");
      this.weekDays = var5.getWeekdays();
      this.atComboBoxText = new String[24];

      for (int var9 = 0; var9 < 24; var9++) {
         try {
            Date var8 = var7.parse(var9 + ":00");
            this.atComboBoxText[var9] = var6.format(var8);
         } catch (Exception var12) {
            this.atComboBoxText[var9] = var9 + ":00";
         }
      }

      JPanel var13 = new JPanel();
      var13.setLayout(new GridBagLayout());
      GridBagConstraints var10 = new GridBagConstraints();
      var10.anchor = 17;
      var10.fill = 0;
      var10.insets = new Insets(5, 0, 0, 0);
      var10.weighty = 0.0;
      var10.weightx = 0.0;
      var10.gridwidth = 0;
      JLabel var11 = new JLabel(this.mh.getMessage("desc.text"));
      var13.add(var11, var10);
      var10.weighty = 2.0;
      var10.gridwidth = 3;
      var10.insets = new Insets(10, 0, 0, 5);
      var13.add(new JLabel(this.mh.getMessage("notify.text")), var10);
      this.notify = new JComboBox();
      this.notify.setMaximumRowCount(3);
      this.notify.addItem(this.ntfyInstallText);
      this.notify.addItem(this.ntfyDownldText);
      this.notify.addActionListener(this);
      var10.insets = new Insets(10, 0, 0, 15);
      var10.gridwidth = -1;
      var10.anchor = 17;
      var13.add(this.notify, var10);
      var10.gridwidth = 0;
      var13.add(new JLabel(""), var10);
      var10.insets = new Insets(10, 0, 0, 0);
      var10.gridwidth = -1;
      this.updateCheckBox = new JCheckBox(this.mh.getMessage("autoupdate.text"));
      this.updateCheckBox.addActionListener(this);
      var13.add(this.updateCheckBox, var10);
      var10.anchor = 13;
      var10.gridwidth = 0;
      var10.insets = new Insets(10, 15, 0, 15);
      this.advancedButton = new JButton(this.mh.getMessage("advanced_button.text"));
      this.advancedButton.addActionListener(this);
      var13.add(this.advancedButton, var10);
      var10.gridwidth = 0;
      var10.weighty = 3.0;
      var10.insets = new Insets(0, 0, 0, 0);
      var10.anchor = 17;
      this.textDescLabel = new JLabel(" ");
      var13.add(this.textDescLabel, var10);
      var10.weighty = 2.0;
      var10.gridwidth = -1;
      this.lastRunLabel = new JLabel(" ");
      var13.add(this.lastRunLabel, var10);
      var10.anchor = 13;
      var10.gridwidth = 0;
      var10.insets = new Insets(0, 15, 0, 15);
      this.updateButton = new JButton(this.mh.getMessage("update_button.text"));
      this.updateButton.addActionListener(this);
      var13.add(this.updateButton, var10);
      this.add(var13);
      this.reset();
   }

   static void access$000(UpdatePanel var0) {
      var0.setText();
   }

   static MessageHandler access$100(UpdatePanel var0) {
      return var0.mh;
   }

   private class AdvancedDialog implements ActionListener {
      ChangeListener changeListener;
      private JRadioButton RButton1;
      private JRadioButton RButton2;
      private JRadioButton RButton3;
      private ButtonGroup FreqGroup;
      private String[] weekDays;
      private String[] atComboBoxText;
      private JComboBox at;
      private JComboBox every;
      JSpinner day;
      SpinnerNumberModel daymodel;
      private String atLabelText;
      private String everyLabelText;
      private String dayLabelText;
      private JLabel whenLabel1;
      private JLabel whenLabel2;
      private JLabel descLabel;
      private JLabel dummyLabel;
      JPanel whenPanel1;
      JPanel whenPanel2;
      JPanel whenPanel;
      GridBagConstraints c;
      private final UpdatePanel this$0;

      void reset() {
      }

      void setPanelOptions() {
         String var1 = null;
         String var2 = null;
         if (this.RButton1.isSelected()) {
            this.day.setVisible(false);
            this.every.setVisible(false);
            this.whenLabel1.setText("  ");
            this.whenLabel2.setText(this.atLabelText);
            this.whenPanel1.add(this.dummyLabel);
            this.whenPanel2.add(this.at);
            this.at.setVisible(true);
            this.dummyLabel.setVisible(true);
            var1 = UpdatePanel.access$100(this.this$0).getMessage("advanced_desc1.text");
            MessageFormat var3 = new MessageFormat(var1);
            var1 = var3.format(new String[]{(String)this.at.getItemAt(this.at.getSelectedIndex())});
         } else if (this.RButton2.isSelected()) {
            this.day.setVisible(false);
            this.dummyLabel.setVisible(false);
            this.whenLabel1.setText(this.everyLabelText);
            this.whenLabel2.setText(this.atLabelText);
            this.whenPanel1.add(this.every, this.c);
            this.whenPanel2.add(this.at);
            this.every.setVisible(true);
            this.at.setVisible(true);
            var2 = (String)this.every.getItemAt(this.every.getSelectedIndex());
            var1 = UpdatePanel.access$100(this.this$0).getMessage("advanced_desc2.text");
         } else if (this.RButton3.isSelected()) {
            this.dummyLabel.setVisible(false);
            this.every.setVisible(false);
            this.whenLabel1.setText(this.dayLabelText);
            this.whenLabel2.setText(this.atLabelText);
            this.whenPanel1.add(this.day);
            this.whenPanel2.add(this.at);
            this.day.setVisible(true);
            this.at.setVisible(true);
            var2 = String.valueOf(((Integer)this.day.getValue()).intValue());
            var1 = UpdatePanel.access$100(this.this$0).getMessage("advanced_desc3.text");
         }

         if (var2 != null) {
            MessageFormat var5 = new MessageFormat(var1);
            var1 = var5.format(new String[]{var2, (String)this.at.getItemAt(this.at.getSelectedIndex())});
         }

         this.descLabel.setText(var1);
      }

      public void actionPerformed(ActionEvent var1) {
         try {
            if (var1.getSource() == this.RButton1
               || var1.getSource() == this.RButton2
               || var1.getSource() == this.RButton3
               || var1.getSource() == this.every
               || var1.getSource() == this.at) {
               this.setPanelOptions();
            }
         } catch (Exception var3) {
         }
      }

      public AdvancedDialog(UpdatePanel var1, UpdatePanel var2, ConfigurationInfo var3, MessageHandler var4) {
         this.this$0 = var1;
         this.changeListener = new UpdatePanel$1(this);
         JPanel var5 = new JPanel();
         var5.setLayout(new GridBagLayout());
         this.c = new GridBagConstraints();
         this.c.anchor = 17;
         this.c.fill = 0;
         this.c.insets = new Insets(5, 0, 0, 0);
         this.c.weighty = 1.0;
         this.c.weightx = 0.0;
         this.c.gridwidth = 0;
         var5.add(new JLabel(var4.getMessage("advanced_title1.text")), this.c);
         JPanel var6 = new JPanel();
         var6.setLayout(new BoxLayout(var6, 1));
         Border var7 = BorderFactory.createEtchedBorder();
         var6.setBorder(
            BorderFactory.createCompoundBorder(
               BorderFactory.createEmptyBorder(4, 4, 4, 4), BorderFactory.createTitledBorder(var7, var4.getMessage("advanced_title2.text"))
            )
         );
         this.RButton1 = new JRadioButton(var4.getMessage("check_daily.text"));
         this.RButton2 = new JRadioButton(var4.getMessage("check_weekly.text"));
         this.RButton3 = new JRadioButton(var4.getMessage("check_monthly.text"));
         this.FreqGroup = new ButtonGroup();
         this.FreqGroup.add(this.RButton1);
         this.FreqGroup.add(this.RButton2);
         this.FreqGroup.add(this.RButton3);
         this.RButton1.addActionListener(this);
         this.RButton2.addActionListener(this);
         this.RButton3.addActionListener(this);
         var6.add(this.RButton1);
         var6.add(this.RButton2);
         var6.add(this.RButton3);
         this.c.weighty = 3.0;
         this.c.weightx = 0.0;
         this.c.gridwidth = 2;
         this.c.insets = new Insets(0, 0, 0, 0);
         var5.add(var6, this.c);
         this.whenPanel = new JPanel();
         this.whenPanel.setLayout(new GridBagLayout());
         this.whenPanel
            .setBorder(
               BorderFactory.createCompoundBorder(
                  BorderFactory.createEmptyBorder(4, 4, 4, 4), BorderFactory.createTitledBorder(var7, var4.getMessage("advanced_title3.text"))
               )
            );
         this.atComboBoxText = var2.getAtComboBoxText();
         this.weekDays = var2.getWeekDays();
         this.dummyLabel = new JLabel("    ");
         this.everyLabelText = var4.getMessage("check_day.text");
         this.atLabelText = var4.getMessage("check_time.text");
         this.dayLabelText = var4.getMessage("check_date.text");
         this.whenLabel1 = new JLabel();
         this.whenLabel2 = new JLabel();
         this.every = new JComboBox();
         this.every.setMaximumRowCount(7);
         this.every.addItem(this.weekDays[1]);
         this.every.addItem(this.weekDays[2]);
         this.every.addItem(this.weekDays[3]);
         this.every.addItem(this.weekDays[4]);
         this.every.addItem(this.weekDays[5]);
         this.every.addItem(this.weekDays[6]);
         this.every.addItem(this.weekDays[7]);
         this.every.addActionListener(this);
         this.at = new JComboBox();
         this.at.setMaximumRowCount(this.atComboBoxText.length);

         for (int var8 = 0; var8 < this.atComboBoxText.length; var8++) {
            this.at.addItem(this.atComboBoxText[var8]);
         }

         this.at.addActionListener(this);
         this.daymodel = new SpinnerNumberModel(1, 1, 31, 1);
         this.day = new JSpinner(this.daymodel);
         this.daymodel.addChangeListener(this.changeListener);
         this.c.anchor = 17;
         this.whenPanel1 = new JPanel();
         this.whenPanel2 = new JPanel();
         this.c.insets = new Insets(0, 10, 0, 5);
         this.c.gridwidth = 2;
         this.c.gridheight = 2;
         this.c.weighty = 0.0;
         this.c.weightx = 0.0;
         this.whenPanel.add(this.whenLabel1, this.c);
         this.c.gridwidth = 0;
         this.c.weightx = 1.0;
         this.c.fill = 2;
         this.whenPanel.add(this.whenPanel1, this.c);
         this.c.gridwidth = 2;
         this.c.fill = 0;
         this.c.weightx = 0.0;
         this.c.gridheight = 0;
         this.whenPanel.add(this.whenLabel2, this.c);
         this.c.weightx = 1.0;
         this.c.fill = 2;
         this.c.gridwidth = 0;
         this.whenPanel.add(this.whenPanel2, this.c);
         this.c.weightx = 2.0;
         this.c.weighty = 3.0;
         this.c.fill = 1;
         this.c.gridheight = -1;
         this.c.insets = new Insets(0, 5, 0, 0);
         this.c.gridwidth = 0;
         var5.add(this.whenPanel, this.c);
         if (var3.getUpdateFrequency() == 0) {
            this.RButton1.setSelected(true);
         } else if (var3.getUpdateFrequency() == 2) {
            this.RButton3.setSelected(true);
            this.day.setValue(new Integer(var3.getUpdateDay()));
         } else {
            this.RButton2.setSelected(true);
            this.every.setSelectedIndex(var3.getUpdateDay() - 1);
         }

         this.at.setSelectedIndex(var3.getUpdateSchedule());
         this.descLabel = new JLabel("  ");
         this.descLabel.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4), BorderFactory.createTitledBorder(var7, "")));
         this.c.fill = 2;
         this.c.weightx = 1.0;
         this.c.weighty = 1.0;
         this.c.insets = new Insets(0, 0, 0, 0);
         this.c.gridwidth = 0;
         var5.add(this.descLabel, this.c);
         this.setPanelOptions();
         JOptionPane var11 = new JOptionPane(var5, -1, 2);
         JDialog var9 = var11.createDialog(null, var4.getMessage("advanced_title.text"));
         var9.setModal(true);
         var9.setDefaultCloseOperation(2);
         var9.show();
         Integer var10 = (Integer)var11.getValue();
         if (var10 != null && var10 == 0) {
            var3.setUpdateSchedule(this.at.getSelectedIndex());
            if (this.RButton1.isSelected()) {
               var3.setUpdateFrequency(0);
               var3.setUpdateDay(0);
            } else if (this.RButton3.isSelected()) {
               var3.setUpdateFrequency(2);
               var3.setUpdateDay((Integer)this.day.getValue());
            } else {
               var3.setUpdateFrequency(1);
               var3.setUpdateDay(this.every.getSelectedIndex() + 1);
            }
         }

         UpdatePanel.access$000(var2);
      }
   }
}
