package sun.plugin.security;

import java.io.IOException;
import java.security.AccessController;
import java.security.GeneralSecurityException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import sun.plugin.util.Trace;
import sun.plugin.util.UserProfile;

public final class HttpsRootCACertStore implements CertificateStore {
   private static String _filename = null;
   private long _LastModified = 0L;
   private KeyStore _jssecacerts = RootCACertificateStore.createEmptyKeyStore();

   static {
      _filename = UserProfile.getHttpsRootCertFile();
   }

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      if (_filename != null) {
         long var1 = RootCACertificateStore.getFileLastModified(_filename);
         if (var1 != this._LastModified) {
            Trace.msgSecurityPrintln("roothttpscertstore.cert.loading", new Object[]{_filename});

            try {
               AccessController.doPrivileged(new HttpsRootCACertStore$1(this));
            } catch (PrivilegedActionException var5) {
               Exception var4 = var5.getException();
               if (var4 instanceof IOException) {
                  throw (IOException)var4;
               }

               if (var4 instanceof CertificateException) {
                  throw (CertificateException)var4;
               }

               if (var4 instanceof KeyStoreException) {
                  throw (KeyStoreException)var4;
               }

               if (var4 instanceof NoSuchAlgorithmException) {
                  throw (NoSuchAlgorithmException)var4;
               }

               Trace.securityPrintException(var5);
            }

            this._LastModified = var1;
         }
      }

      Trace.msgSecurityPrintln("roothttpscertstore.cert.loaded", new Object[]{_filename});
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.saving", new Object[]{_filename});
   }

   static String access$100() {
      return _filename;
   }

   public KeyStore getKeyStore() {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.getkeystore");
      return this._jssecacerts;
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.adding");
      throw new KeyStoreException("Cannot add Https root CA certificate");
   }

   public void remove(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.removing");
      throw new KeyStoreException("Cannot remove Https root CA certificate");
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.instore");
      return false;
   }

   public boolean verify(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.canverify");
      Trace.msgSecurityPrintln("roothttpscertstore.cert.tobeverified", new Object[]{var1});
      Enumeration var2 = this._jssecacerts.aliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         Certificate var4 = this._jssecacerts.getCertificate(var3);
         Trace.msgSecurityPrintln("roothttpscertstore.cert.tobecompared", new Object[]{var4});

         try {
            var1.verify(var4.getPublicKey());
            Trace.msgSecurityPrintln("roothttpscertstore.cert.verify.ok");
            return true;
         } catch (GeneralSecurityException var6) {
         }
      }

      Trace.msgSecurityPrintln("roothttpscertstore.cert.verify.fail");
      return false;
   }

   public Iterator iterator() throws KeyStoreException {
      Trace.msgSecurityPrintln("roothttpscertstore.cert.iterator");
      HashSet var1 = new HashSet();
      Enumeration var2 = this._jssecacerts.aliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         Certificate var4 = this._jssecacerts.getCertificate(var3);
         var1.add(var4);
      }

      return var1.iterator();
   }

   static KeyStore access$000(HttpsRootCACertStore var0) {
      return var0._jssecacerts;
   }

   static KeyStore access$002(HttpsRootCACertStore var0, KeyStore var1) {
      return var0._jssecacerts = var1;
   }
}
