package sun.plugin.security;

import java.awt.AWTPermission;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.AccessController;
import java.security.AllPermission;
import java.security.CodeSource;
import java.security.PermissionCollection;
import java.security.Policy;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.PropertyPermission;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import sun.applet.AppletClassLoader;
import sun.awt.AppContext;
import sun.net.www.ParseUtil;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.util.ProgressTracker;
import sun.plugin.util.Trace;

public final class PluginClassLoader extends AppletClassLoader {
   private static RuntimePermission usePolicyPermission;
   private URL base;
   private HashMap JARJARtoJAR = new HashMap();

   protected void release() {
      if (!this.JARJARtoJAR.isEmpty()) {
         Trace.msgPrintln("pluginclassloader.deleting_files");

         for (Object var3 : this.JARJARtoJAR.keySet()) {
            File var4 = (File)this.JARJARtoJAR.get(var3);
            if (var4 != null) {
               Trace.msgPrintln("pluginclassloader.file", new Object[]{var4.getPath()});
               var4.delete();
            }
         }

         this.JARJARtoJAR.clear();
      }

      super.release();
   }

   protected void addJar(String var1) throws IOException {
      if (var1.toUpperCase().endsWith(".JARJAR") && this.base.getProtocol().equalsIgnoreCase("file")) {
         String var2 = this.base.toString() + var1;
         if (!this.JARJARtoJAR.containsKey(var2)) {
            JarFile var3 = null;
            File var4 = null;
            boolean var5 = false;

            try {
               var3 = new JarFile(this.base.getPath() + var1, true);
               Enumeration var6 = var3.entries();
               int var7 = 0;
               if (!var6.hasMoreElements()) {
                  throw new IOException("Invalid jarjar file");
               }

               JarEntry var8 = null;

               while (var6.hasMoreElements()) {
                  var8 = (JarEntry)var6.nextElement();
                  if (!var8.toString().toUpperCase().startsWith("META-INF/")) {
                     if (!var8.toString().toUpperCase().endsWith(".JAR")) {
                        throw new IOException("Invalid entry in jarjar file.");
                     }

                     if (++var7 > 1) {
                        break;
                     }
                  }
               }

               if (var7 > 1) {
                  var8 = null;
                  throw new IOException("Multiple JAR files inside JARJAR file");
               }

               byte[] var9 = new byte[8192];
               BufferedInputStream var10 = null;
               BufferedOutputStream var11 = null;
               FileOutputStream var12 = null;
               InputStream var13 = var3.getInputStream(var8);
               boolean var14 = false;

               try {
                  var4 = File.createTempFile(var8.toString().substring(0, var8.toString().lastIndexOf(46)), ".jar");
                  Trace.msgPrintln("pluginclassloader.created_file", new Object[]{var4.getPath()});
                  ProgressTracker.onProgressComplete(this.base.toString() + var1);
                  var10 = new BufferedInputStream(var13);
                  var12 = new FileOutputStream(var4);
                  var11 = new BufferedOutputStream(var12);

                  int var15;
                  while ((var15 = var10.read(var9, 0, var9.length)) != -1) {
                     var11.write(var9, 0, var15);
                  }

                  var11.flush();
                  this.JARJARtoJAR.put(this.base.toString() + var1, var4);
                  var14 = true;

                  URL var16;
                  try {
                     var16 = var4.toURL();
                  } catch (MalformedURLException var27) {
                     throw new IllegalArgumentException("name");
                  }

                  this.addURL(var16);
               } finally {
                  if (var10 != null) {
                     var10.close();
                  }

                  if (var11 != null) {
                     var11.close();
                  }

                  if (var12 != null) {
                     var12.close();
                  }

                  Object var31 = null;
                  Object var32 = null;
                  Object var33 = null;
                  if (!var14) {
                     Trace.msgPrintln("pluginclassloader.empty_file", new Object[]{var4.getName()});
                     if (var4 != null) {
                        var4.delete();
                     }
                  }
               }
            } finally {
               if (var3 != null) {
                  var3.close();
               }
            }
         }
      } else {
         super.addJar(var1);
         if (this.base.getProtocol().equalsIgnoreCase("file")) {
            ProgressTracker.onProgressComplete(this.base.toString() + var1);
         }
      }
   }

   public URL getBaseURL() {
      return this.base;
   }

   public PluginClassLoader(URL var1) {
      super(var1);
      this.base = var1;
   }

   public void addLocalJar(URL var1) {
      this.addURL(var1);
   }

   protected PermissionCollection getPermissions(CodeSource var1) {
      PermissionCollection var2 = super.getPermissions(var1);
      URL var3 = var1.getLocation();
      if (var3 != null && var3.getProtocol().equals("file")) {
         String var4 = ParseUtil.decode(var3.getFile());
         if (var4 != null) {
            var4 = var4.replace('/', File.separatorChar);
            String var5 = File.separator + System.getProperty("java.home") + File.separator + "axbridge" + File.separator + "lib";

            try {
               var4 = new File(var4).getCanonicalPath();
               var5 = new File(var5).getCanonicalPath();
               if (var4 != null && var5 != null && var4.startsWith(var5)) {
                  var2.add(new AllPermission());
                  return var2;
               }
            } catch (IOException var10) {
            }
         }
      }

      Object var13 = null;
      Policy var16 = AccessController.doPrivileged(new PluginClassLoader$1(this));
      var13 = var16.getPermissions(var1);
      var2.add(new RuntimePermission("accessClassInPackage.sun.audio"));
      var2.add(new PropertyPermission("browser", "read"));
      var2.add(new PropertyPermission("browser.version", "read"));
      var2.add(new PropertyPermission("browser.vendor", "read"));
      var2.add(new PropertyPermission("http.agent", "read"));
      var2.add(new PropertyPermission("javaplugin.version", "read"));
      if (usePolicyPermission == null) {
         usePolicyPermission = new RuntimePermission("usePolicy");
      }

      if (!var13.implies(usePolicyPermission) && var1.getCertificates() != null) {
         try {
            if (TrustDecider.isAllPermissionGranted(var1)) {
               var2.add(new AllPermission());
            }
         } catch (CertificateExpiredException var7) {
            Trace.securityPrintException(var7, ResourceHandler.getMessage("rsa.cert_expired"), ResourceHandler.getMessage("security_dialog.caption"));
         } catch (CertificateNotYetValidException var8) {
            Trace.securityPrintException(var8, ResourceHandler.getMessage("rsa.cert_notyieldvalid"), ResourceHandler.getMessage("security_dialog.caption"));
         } catch (Exception var9) {
            Trace.securityPrintException(var9, ResourceHandler.getMessage("rsa.general_error"), ResourceHandler.getMessage("security_dialog.caption"));
         }
      }

      if (!var2.implies(new AWTPermission("accessClipboard"))) {
         AppContext.getAppContext().put("UNTRUSTED_CLIPBOARD_ACCESS_KEY", Boolean.TRUE);
      }

      return var2;
   }

   public Enumeration findResources(String var1) throws IOException {
      return this.findResourcesByURLPath(var1);
   }

   private Enumeration findResourcesByURLPath(String var1) throws IOException {
      return (Enumeration)(var1 != null && var1.indexOf("META-INF/services/javax.sound") != -1 ? new PluginClassLoader$2(this) : super.findResources(var1));
   }
}
