package sun.plugin.security;

import java.io.IOException;
import java.security.AccessController;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Random;
import sun.plugin.util.Trace;
import sun.plugin.util.UserProfile;

public final class PluginHttpsCertStore implements CertificateStore {
   private static String _filename = null;
   private long _LastModified = 0L;
   private KeyStore _deploymentcerts = RootCACertificateStore.createEmptyKeyStore();

   static {
      _filename = UserProfile.getHttpsCertificateFile();
   }

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      if (_filename != null) {
         long var1 = RootCACertificateStore.getFileLastModified(_filename);
         if (var1 != this._LastModified) {
            Trace.msgSecurityPrintln("jpihttpscertstore.cert.loading", new Object[]{_filename});

            try {
               AccessController.doPrivileged(new PluginHttpsCertStore$1(this));
            } catch (PrivilegedActionException var5) {
               Exception var4 = var5.getException();
               if (var4 instanceof IOException) {
                  throw (IOException)var4;
               }

               if (var4 instanceof CertificateException) {
                  throw (CertificateException)var4;
               }

               if (var4 instanceof KeyStoreException) {
                  throw (KeyStoreException)var4;
               }

               if (var4 instanceof NoSuchAlgorithmException) {
                  throw (NoSuchAlgorithmException)var4;
               }

               Trace.securityPrintException(var5);
            }

            this._LastModified = var1;
         }
      }

      Trace.msgSecurityPrintln("jpihttpscertstore.cert.loaded", new Object[]{_filename});
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.saving", new Object[]{_filename});

      try {
         AccessController.doPrivileged(new PluginHttpsCertStore$2(this));
      } catch (PrivilegedActionException var3) {
         Exception var2 = var3.getException();
         if (var2 instanceof IOException) {
            throw (IOException)var2;
         }

         if (var2 instanceof CertificateException) {
            throw (CertificateException)var2;
         }

         if (var2 instanceof KeyStoreException) {
            throw (KeyStoreException)var2;
         }

         if (var2 instanceof NoSuchAlgorithmException) {
            throw (NoSuchAlgorithmException)var2;
         }

         Trace.securityPrintException(var3);
      }

      Trace.msgSecurityPrintln("jpihttpscertstore.cert.saved", new Object[]{_filename});
   }

   static String access$100() {
      return _filename;
   }

   public KeyStore getKeyStore() {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.getkeystore");
      return this._deploymentcerts;
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.adding");
      if (!this.contains(var1)) {
         Random var2 = new Random();
         boolean var3 = false;
         Object var4 = null;

         do {
            var4 = "deploymentcert" + var2.nextLong();
            Certificate var5 = this._deploymentcerts.getCertificate((String)var4);
            if (var5 == null) {
               var3 = true;
            }
         } while (!var3);

         this._deploymentcerts.setCertificateEntry((String)var4, var1);
         Trace.msgSecurityPrintln("jpihttpscertstore.cert.added", new Object[]{var4});
      }
   }

   public void remove(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.removing");
      String var2 = this._deploymentcerts.getCertificateAlias(var1);
      if (var2 != null) {
         this._deploymentcerts.deleteEntry(var2);
      }

      Trace.msgSecurityPrintln("jpihttpscertstore.cert.removed", new Object[]{var2});
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.instore");
      Object var2 = null;
      var2 = this._deploymentcerts.getCertificateAlias(var1);
      return var2 != null;
   }

   public boolean verify(Certificate var1) {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.canverify");
      return false;
   }

   public Iterator iterator() throws KeyStoreException {
      Trace.msgSecurityPrintln("jpihttpscertstore.cert.iterator");
      HashSet var1 = new HashSet();
      Enumeration var2 = this._deploymentcerts.aliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         Certificate var4 = this._deploymentcerts.getCertificate(var3);
         var1.add(var4);
      }

      return var1.iterator();
   }

   static KeyStore access$000(PluginHttpsCertStore var0) {
      return var0._deploymentcerts;
   }

   static KeyStore access$002(PluginHttpsCertStore var0, KeyStore var1) {
      return var0._deploymentcerts = var1;
   }
}
