package sun.plugin.security;

import java.io.IOException;
import java.security.AccessController;
import java.security.GeneralSecurityException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Iterator;
import sun.plugin.util.Trace;
import sun.plugin.util.UserProfile;

public final class RootCACertificateStore implements CertificateStore {
   private static String _filename = null;
   private long _LastModified = 0L;
   private KeyStore _cacerts = createEmptyKeyStore();
   private static RootCACertificateStore _rcs = null;

   static {
      _filename = UserProfile.getRootCertificateFile();
   }

   private RootCACertificateStore() {
   }

   public void load() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      if (_filename != null) {
         long var1 = getFileLastModified(_filename);
         if (var1 != this._LastModified) {
            Trace.msgSecurityPrintln("rootcertstore.cert.loading", new Object[]{_filename});

            try {
               AccessController.doPrivileged(new RootCACertificateStore$1(this));
            } catch (PrivilegedActionException var5) {
               Exception var4 = var5.getException();
               if (var4 instanceof IOException) {
                  throw (IOException)var4;
               }

               if (var4 instanceof CertificateException) {
                  throw (CertificateException)var4;
               }

               if (var4 instanceof KeyStoreException) {
                  throw (KeyStoreException)var4;
               }

               if (var4 instanceof NoSuchAlgorithmException) {
                  throw (NoSuchAlgorithmException)var4;
               }

               Trace.securityPrintException(var5);
            }

            this._LastModified = var1;
         }
      }

      Trace.msgSecurityPrintln("rootcertstore.cert.loaded", new Object[]{_filename});
   }

   public void save() throws IOException, CertificateException, KeyStoreException, NoSuchAlgorithmException {
      Trace.msgSecurityPrintln("rootcertstore.cert.saving", new Object[]{_filename});
   }

   static String access$100() {
      return _filename;
   }

   static long getFileLastModified(String var0) {
      long var1 = 0L;

      try {
         var1 = AccessController.doPrivileged(new RootCACertificateStore$2(var0));
      } catch (PrivilegedActionException var4) {
         Trace.securityPrintException(var4);
      }

      return var1;
   }

   public static KeyStore createEmptyKeyStore() {
      KeyStore var0 = null;

      try {
         var0 = KeyStore.getInstance("JKS");
         var0.load(null, null);
      } catch (Exception var2) {
      }

      return var0;
   }

   public KeyStore getKeyStore() {
      Trace.msgSecurityPrintln("rootcertstore.cert.getkeystore");
      return this._cacerts;
   }

   public void add(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.adding");
      throw new KeyStoreException("Cannot add root CA certificate");
   }

   public void remove(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.removing");
      throw new KeyStoreException("Cannot remove root CA certificate");
   }

   public boolean contains(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.instore");
      return this._cacerts.getCertificateAlias(var1) != null;
   }

   public boolean verify(Certificate var1) throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.canverify");
      new StringBuffer();
      Trace.msgSecurityPrintln("rootcertstore.cert.tobeverified", new Object[]{var1});
      Enumeration var3 = this._cacerts.aliases();

      while (var3.hasMoreElements()) {
         String var4 = (String)var3.nextElement();
         Certificate var5 = this._cacerts.getCertificate(var4);
         Trace.msgSecurityPrintln("rootcertstore.cert.tobecompared", new Object[]{var5});

         try {
            var1.verify(var5.getPublicKey());
            Trace.msgSecurityPrintln("rootcertstore.cert.verify.ok");
            return true;
         } catch (GeneralSecurityException var7) {
         }
      }

      Trace.msgSecurityPrintln("rootcertstore.cert.verify.fail");
      return false;
   }

   public Iterator iterator() throws KeyStoreException {
      Trace.msgSecurityPrintln("rootcertstore.cert.iterator");
      HashSet var1 = new HashSet();
      Enumeration var2 = this._cacerts.aliases();

      while (var2.hasMoreElements()) {
         String var3 = (String)var2.nextElement();
         Certificate var4 = this._cacerts.getCertificate(var3);
         var1.add(var4);
      }

      return var1.iterator();
   }

   public static synchronized RootCACertificateStore getInstance() {
      if (_rcs == null) {
         _rcs = new RootCACertificateStore();
      }

      return _rcs;
   }

   static KeyStore access$000(RootCACertificateStore var0) {
      return var0._cacerts;
   }

   static KeyStore access$002(RootCACertificateStore var0, KeyStore var1) {
      return var0._cacerts = var1;
   }
}
