package sun.plugin.security;

import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class StripClassFile {
   private static final int CONSTANT_Class = 7;
   private static final int CONSTANT_Fieldref = 9;
   private static final int CONSTANT_Methodref = 10;
   private static final int CONSTANT_InterfaceMethodref = 11;
   private static final int CONSTANT_String = 8;
   private static final int CONSTANT_Integer = 3;
   private static final int CONSTANT_Float = 4;
   private static final int CONSTANT_Long = 5;
   private static final int CONSTANT_Double = 6;
   private static final int CONSTANT_NameAndType = 12;
   private static final int CONSTANT_Utf8 = 1;
   private static final String[] requiredTypes = new String[]{"Code", "ConstantValue", "Exceptions", "InnerClasses", "Synthetic"};
   private StripClassFile.ByteStream bs;
   private DataInputStream dis;
   int magic;
   short minor_version;
   short major_version;
   int constant_pool_count;
   StripClassFile.ConstantPool[] constant_pool;

   private void parseCodeAttribute() throws IOException {
      int var1 = this.bs.getOffset();
      int var2 = this.dis.readInt();
      this.dis.skip(2L);
      this.dis.skip(2L);
      int var3 = this.dis.readInt();
      this.dis.skip(var3);
      int var4 = this.dis.readUnsignedShort();
      this.dis.skip(8 * var4);
      int var5 = this.bs.getOffset();
      int var6 = this.dis.readUnsignedShort();

      for (int var7 = 0; var7 < var6; var7++) {
         int var8 = this.bs.getOffset();
         if (!this.parseAttributeInfo()) {
            int var9 = this.bs.getOffset() - var8;
            this.bs.decrementCount(var5);
            this.bs.removeBytes(var8, this.bs.getOffset());
            this.bs.setOffset(var8);
            this.bs.decrementLength(var1, var9);
         }
      }
   }

   private void parseFieldInfo() throws IOException {
      int var1 = this.dis.readUnsignedShort();
      int var2 = this.dis.readUnsignedShort();
      this.validateName(var2);
      int var3 = this.dis.readUnsignedShort();
      this.validateName(var3);
      int var4 = this.dis.readUnsignedShort();

      for (int var5 = 0; var5 < var4; var5++) {
         this.parseAttributeInfo();
      }
   }

   private void parseMethodInfo() throws IOException {
      this.dis.skip(2L);
      int var1 = this.dis.readUnsignedShort();
      this.validateName(var1);
      int var2 = this.dis.readUnsignedShort();
      this.validateName(var2);
      int var3 = this.dis.readUnsignedShort();

      for (int var4 = 0; var4 < var3; var4++) {
         this.parseAttributeInfo();
      }
   }

   private void stripClassFile() throws IOException {
      this.magic = this.dis.readInt();
      this.minor_version = this.dis.readShort();
      this.major_version = this.dis.readShort();
      this.constant_pool_count = this.dis.readUnsignedShort();
      this.constant_pool = new StripClassFile.ConstantPool[this.constant_pool_count - 1];
      int var1 = this.bs.getOffset();

      for (int var2 = 0; var2 < 2; var2++) {
         boolean var3 = var2 == 0;
         boolean var4 = var2 != 0;
         this.bs.setOffset(var1);

         for (int var5 = 0; var5 < this.constant_pool_count - 1; var5++) {
            StripClassFile.ConstantPool var6 = this.constant_pool[var5];
            var6 = new StripClassFile.ConstantPool(this, var4 && var6.invalid);
            this.constant_pool[var5] = var6;
            if (var6.tag == 5 || var6.tag == 6) {
               var5++;
            }
         }

         for (int var14 = 0; var14 < this.constant_pool_count - 1; var14++) {
            StripClassFile.ConstantPool var18 = this.constant_pool[var14];
            var18.verify(this.constant_pool);
            if (var18.tag == 5 || var18.tag == 6) {
               var14++;
            }
         }

         this.dis.skip(2L);
         int var15 = this.dis.readUnsignedShort();
         int var19 = this.dis.readUnsignedShort();
         short var7 = this.dis.readShort();

         for (int var8 = 0; var8 < var7; var8++) {
            int var9 = this.dis.readUnsignedShort();
         }

         short var20 = this.dis.readShort();

         for (int var21 = 0; var21 < var20; var21++) {
            this.parseFieldInfo();
         }

         short var22 = this.dis.readShort();

         for (int var10 = 0; var10 < var22; var10++) {
            this.parseMethodInfo();
         }
      }

      int var11 = this.bs.getOffset();
      short var12 = this.dis.readShort();

      for (int var13 = 0; var13 < var12; var13++) {
         int var16 = this.bs.getOffset();
         if (!this.parseAttributeInfo()) {
            this.bs.decrementCount(var11);
            this.bs.removeBytes(var16, this.bs.getOffset());
            this.bs.setOffset(var16);
         }
      }
   }

   private boolean parseAttributeInfo() throws IOException {
      int var1 = this.dis.readUnsignedShort();
      StripClassFile.ConstantPool var2 = this.constant_pool[var1 - 1];
      String var3 = var2.string;
      if (var3.equals("Code")) {
         this.parseCodeAttribute();
         return true;
      } else {
         int var4 = this.dis.readInt();
         this.dis.skip(var4);
         return this.attributeRequired(var3);
      }
   }

   private static boolean validJavaCharacter(char var0, boolean var1) {
      if (var0 != '/' && var0 != '(' && var0 != ')' && var0 != ';' && var0 != '[') {
         return var1 ? Character.isJavaIdentifierStart(var0) : Character.isJavaIdentifierPart(var0);
      } else {
         return true;
      }
   }

   private boolean validateClassName(int var1) throws IOException {
      StripClassFile.ConstantPool var2 = this.constant_pool[var1 - 1];
      var1 = var2.nameIndex;
      return this.validateName(var1);
   }

   private boolean validateName(int var1) throws IOException {
      StripClassFile.ConstantPool var2 = this.constant_pool[var1 - 1];
      if (var2.string != null && !var2.string.equals("<init>") && !var2.string.equals("<clinit>")) {
         for (int var3 = 0; var3 < var2.string.length(); var3++) {
            char var4 = var2.string.charAt(var3);
            if (!validJavaCharacter(var4, var3 == 0)) {
               var2.invalid = true;
               return false;
            }
         }

         return true;
      } else {
         return true;
      }
   }

   public byte[] strip(byte[] var1) throws Exception {
      int var2 = var1.length;
      byte[] var3 = new byte[var2];
      System.arraycopy(var1, 0, var3, 0, var2);

      try {
         this.bs = new StripClassFile.ByteStream(this, var3);
         this.dis = new DataInputStream(this.bs);
         this.stripClassFile();
      } catch (Exception var6) {
         throw var6;
      }

      int var4 = this.bs.getOffset();
      byte[] var5 = new byte[var4];
      var3 = this.bs.getArray();
      System.arraycopy(var3, 0, var5, 0, var4);
      return var5;
   }

   boolean attributeRequired(String var1) {
      for (int var2 = 0; var2 < requiredTypes.length; var2++) {
         if (var1.equals(requiredTypes[var2])) {
            return true;
         }
      }

      return false;
   }

   static void charToUnicode(char var0, StringBuffer var1) {
      var1.append("U");
      String var2 = Integer.toHexString(var0);

      for (int var3 = var2.length(); var3 < 4; var3++) {
         var1.append('0');
      }

      var1.append(var2);
   }

   static boolean access$200(StripClassFile var0, int var1) throws IOException {
      return var0.validateClassName(var1);
   }

   static boolean access$300(StripClassFile var0, int var1) throws IOException {
      return var0.validateName(var1);
   }

   static DataInputStream access$000(StripClassFile var0) {
      return var0.dis;
   }

   static String makeValid(String var0) {
      int var1 = var0.length();
      if (var1 == 0) {
         return "";
      } else {
         StringBuffer var2 = new StringBuffer(var1 * 5);
         char[] var3 = var0.toCharArray();

         for (int var4 = 0; var4 < var1; var4++) {
            char var5 = var3[var4];
            if (validJavaCharacter(var5, var4 == 0)) {
               var2.append(var3[var4]);
            } else {
               charToUnicode(var3[var4], var2);
            }
         }

         return var2.toString();
      }
   }

   static StripClassFile.ByteStream access$100(StripClassFile var0) {
      return var0.bs;
   }

   private class ByteStream extends InputStream {
      private byte[] array;
      private int offset;
      private int length;
      private final StripClassFile this$0;

      public int getOffset() {
         return this.offset;
      }

      public int read() throws IOException {
         if (this.offset == this.length) {
            throw new IOException();
         } else {
            return this.array[this.offset++] & 0xFF;
         }
      }

      public byte[] getArray() {
         return this.array;
      }

      public void decrementCount(int var1) {
         int var2 = this.array[var1] & 255;
         int var3 = this.array[var1 + 1] & 255;
         int var4 = (var2 << 8) + (var3 << 0) - 1;
         this.array[var1] = (byte)(var4 >>> 8 & 0xFF);
         this.array[var1 + 1] = (byte)(var4 >>> 0 & 0xFF);
      }

      public void setOffset(int var1) {
         this.offset = var1;
      }

      public void addBytes(int var1, int var2) {
         byte[] var3 = new byte[this.length + var2];
         System.arraycopy(this.array, 0, var3, 0, var1);
         System.arraycopy(this.array, var1, var3, var1 + var2, this.length - var1);
         this.array = var3;
         this.length += var2;
      }

      public void decrementLength(int var1, int var2) {
         int var3 = this.array[var1] & 255;
         int var4 = this.array[var1 + 1] & 255;
         int var5 = this.array[var1 + 2] & 255;
         int var6 = this.array[var1 + 3] & 255;
         int var7 = (var3 << 24) + (var4 << 16) + (var5 << 8) + (var6 << 0);
         var7 -= var2;
         this.array[var1] = (byte)(var7 >>> 24 & 0xFF);
         this.array[var1 + 1] = (byte)(var7 >>> 16 & 0xFF);
         this.array[var1 + 2] = (byte)(var7 >>> 8 & 0xFF);
         this.array[var1 + 3] = (byte)(var7 >>> 0 & 0xFF);
      }

      public void removeBytes(int var1, int var2) {
         System.arraycopy(this.array, var2, this.array, var1, this.length - var2);
         this.length -= var2 - var1;
      }

      public void setByte(int var1, int var2) {
         this.array[var1] = (byte)var2;
      }

      public void write(byte[] var1) throws IOException {
         if (this.offset + var1.length > this.length) {
            throw new IOException();
         } else {
            for (int var2 = 0; var2 < var1.length; var2++) {
               this.array[this.offset++] = var1[var2];
            }
         }
      }

      ByteStream(StripClassFile var1, byte[] var2) {
         this.this$0 = var1;
         this.array = var2;
         this.offset = 0;
         this.length = var2.length;
      }
   }

   private class ConstantPool {
      byte tag;
      int nameIndex;
      String string;
      int stringOffset;
      int descriptorIndex;
      boolean invalid;
      private final StripClassFile this$0;

      ConstantPool(StripClassFile var1, boolean var2) throws IOException {
         this.this$0 = var1;
         this.tag = (byte)StripClassFile.access$000(var1).read();
         switch (this.tag) {
            case 1:
               this.stringOffset = StripClassFile.access$100(var1).getOffset();
               this.string = StripClassFile.access$000(var1).readUTF();
               if (var2) {
                  int var3 = StripClassFile.access$100(var1).getOffset() - this.stringOffset;
                  ByteArrayOutputStream var4 = new ByteArrayOutputStream();
                  DataOutputStream var5 = new DataOutputStream(var4);
                  this.string = StripClassFile.makeValid(this.string);
                  var5.writeUTF(this.string);
                  byte[] var6 = var4.toByteArray();
                  Object var7 = null;
                  StripClassFile.access$100(var1).addBytes(this.stringOffset, var6.length - var3);
                  StripClassFile.access$100(var1).setOffset(this.stringOffset);
                  StripClassFile.access$100(var1).write(var6);
               }
               break;
            case 2:
            default:
               throw new IOException();
            case 3:
            case 4:
               StripClassFile.access$000(var1).skip(4L);
               break;
            case 5:
            case 6:
               StripClassFile.access$000(var1).skip(8L);
               break;
            case 7:
            case 8:
               this.nameIndex = StripClassFile.access$000(var1).readUnsignedShort();
               break;
            case 9:
            case 10:
            case 11:
               this.nameIndex = StripClassFile.access$000(var1).readUnsignedShort();
               this.descriptorIndex = StripClassFile.access$000(var1).readUnsignedShort();
               break;
            case 12:
               this.nameIndex = StripClassFile.access$000(var1).readUnsignedShort();
               this.descriptorIndex = StripClassFile.access$000(var1).readUnsignedShort();
         }
      }

      void verify(StripClassFile.ConstantPool[] var1) throws IOException {
         switch (this.tag) {
            case 1:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
               break;
            case 2:
            default:
               throw new IOException();
            case 9:
               StripClassFile.access$200(this.this$0, this.nameIndex);
               break;
            case 10:
               StripClassFile.access$200(this.this$0, this.nameIndex);
               break;
            case 11:
               StripClassFile.access$200(this.this$0, this.nameIndex);
               break;
            case 12:
               StripClassFile.access$300(this.this$0, this.nameIndex);
               StripClassFile.access$300(this.this$0, this.descriptorIndex);
         }
      }
   }
}
