package sun.plugin.security;

import java.io.IOException;
import java.security.CodeSource;
import java.security.GeneralSecurityException;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.Principal;
import java.security.PublicKey;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.security.auth.x500.X500Principal;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.util.PluginSysUtil;
import sun.plugin.util.Trace;
import sun.security.util.DerInputStream;
import sun.security.util.DerValue;
import sun.security.x509.NetscapeCertTypeExtension;

public class TrustDecider {
   private static CertificateStore rootStore = RootCACertificateStore.getInstance();
   private static CertificateStore permanentStore = new PluginCertificateStore();
   private static CertificateStore sessionStore = new SessionCertificateStore();
   private static CertificateStore deniedStore = new DeniedCertificateStore();
   private static Map trustedX500Principals;
   private static final String OID_BASIC_CONSTRAINTS = "2.5.29.19";
   private static final String OID_KEY_USAGE = "2.5.29.15";
   private static final String OID_EXTENDED_KEY_USAGE = "2.5.29.37";
   private static final String OID_NETSCAPE_CERT_TYPE = "2.16.840.1.113730.1.1";
   private static final String OID_EKU_ANY_USAGE = "2.5.29.37.0";
   private static final String OID_EKU_CODE_SIGNING = "1.3.6.1.5.5.7.3.3";
   private static final String NSCT_OBJECT_SIGNING_CA = "object_signing_ca";
   private static final String NSCT_OBJECT_SIGNING = "object_signing";
   private static final String NSCT_SSL_CA = "ssl_ca";
   private static final String NSCT_S_MIME_CA = "s_mime_ca";
   static final boolean $assertionsDisabled = !(TrustDecider.class$sun$plugin$security$TrustDecider == null
         ? (TrustDecider.class$sun$plugin$security$TrustDecider = class$("sun.plugin.security.TrustDecider"))
         : TrustDecider.class$sun$plugin$security$TrustDecider)
      .desiredAssertionStatus();
   static Class class$sun$plugin$security$TrustDecider;

   public static void reset() {
      rootStore = RootCACertificateStore.getInstance();
      permanentStore = new PluginCertificateStore();
      sessionStore = new SessionCertificateStore();
      deniedStore = new DeniedCertificateStore();
   }

   public static boolean isAllPermissionGranted(CodeSource var0) throws CertificateEncodingException, CertificateExpiredException, CertificateNotYetValidException, CertificateParsingException, CertificateException, KeyStoreException, NoSuchAlgorithmException, IOException {
      Certificate[] var1 = var0.getCertificates();
      String var2 = var0.getLocation().toString();
      if (var1 == null) {
         return false;
      } else {
         int var3 = 0;
         int var4 = 0;
         int var5 = 0;
         LinkedList var6 = new LinkedList();
         Object var7 = null;
         rootStore.load();
         permanentStore.load();
         sessionStore.load();
         deniedStore.load();

         while (var4 < var1.length) {
            int var8 = var3;

            while (
               var8 + 1 < var1.length
                  && var1[var8] instanceof X509Certificate
                  && var1[var8 + 1] instanceof X509Certificate
                  && isIssuerOf((X509Certificate)var1[var8], (X509Certificate)var1[var8 + 1])
            ) {
               var8++;
            }

            var4 = var8 + 1;
            if (deniedStore.contains(var1[var3])) {
               var6.add(var5, new Boolean(true));
            } else {
               var6.add(var5, new Boolean(false));
               if (permanentStore.contains(var1[var3])) {
                  return true;
               }

               if (sessionStore.contains(var1[var3])) {
                  return true;
               }
            }

            var3 = var4;
            var5++;
         }

         boolean var31 = false;
         boolean var9 = false;
         boolean var10 = false;
         var3 = 0;
         var4 = 0;
         KeyStore var11 = rootStore.getKeyStore();
         getCertMap(var11);
         Date var12 = new Date();
         var1 = canonicalize(var1, var12);

         for (int var25 = 0; var4 < var1.length; var25++) {
            CertificateExpiredException var14 = null;
            CertificateNotYetValidException var15 = null;

            int var13;
            for (var13 = var3; var13 < var1.length; var13++) {
               X509Certificate var16 = null;
               Object var17 = null;
               if (var1[var13] instanceof X509Certificate) {
                  var16 = (X509Certificate)var1[var13];
               }

               if (var13 + 1 < var1.length && var1[var13 + 1] instanceof X509Certificate) {
                  var17 = (X509Certificate)var1[var13 + 1];
               } else {
                  var17 = var16;
               }

               try {
                  var16.checkValidity();
               } catch (CertificateExpiredException var20) {
                  if (var14 == null) {
                     var14 = var20;
                  }
               } catch (CertificateNotYetValidException var21) {
                  if (var15 == null) {
                     var15 = var21;
                  }
               }

               if (!rootStore.contains(var16) && var13 + 1 != var1.length && isIssuerOf(var16, (X509Certificate)var17)) {
                  Set var18 = var16.getCriticalExtensionOIDs();
                  if (var18 == null) {
                     var18 = Collections.EMPTY_SET;
                  }

                  if (!checkBasicConstraints(var16, var18, var13 - var3)) {
                     Trace.msgSecurityPrintln("trustdecider.check.basicconstraints");
                     var7 = ResourceHandler.getMessage("trustdecider.check.basicconstraints");
                     throw new CertificateException((String)var7);
                  }

                  if (var13 == var3) {
                     if (!checkLeafKeyUsage(var16, var18)) {
                        Trace.msgSecurityPrintln("trustdecider.check.leafkeyusage");
                        var7 = ResourceHandler.getMessage("trustdecider.check.leafkeyusage");
                        throw new CertificateException((String)var7);
                     }
                  } else if (!checkSignerKeyUsage(var16, var18)) {
                     Trace.msgSecurityPrintln("trustdecider.check.signerkeyusage");
                     var7 = ResourceHandler.getMessage("trustdecider.check.signerkeyusage");
                     throw new CertificateException((String)var7);
                  }

                  if (!var18.isEmpty()) {
                     Trace.msgSecurityPrintln("trustdecider.check.extensions");
                     var7 = ResourceHandler.getMessage("trustdecider.check.extensions");
                     throw new CertificateException((String)var7);
                  }
               }

               if (!isIssuerOf(var16, (X509Certificate)var17)) {
                  break;
               }

               try {
                  var16.verify(var17.getPublicKey());
               } catch (GeneralSecurityException var19) {
                  Trace.msgSecurityPrintln("trustdecider.check.signature");
                  var7 = ResourceHandler.getMessage("trustdecider.check.signature");
                  throw new CertificateException((String)var7);
               }
            }

            var4 = var13 < var1.length ? var13 + 1 : var13;
            Boolean var32 = (Boolean)var6.get(var25);
            if (!var32) {
               if (!rootStore.verify(var1[var4 - 1])) {
                  var31 = true;
               }

               if (var14 != null || var15 != null) {
                  var9 = true;
               }

               int var34 = showSecurityDialog(var1, var3, var4, var31, var9);
               if (var34 == 0) {
                  Trace.msgSecurityPrintln("trustdecider.user.grant.session");
                  sessionStore.add(var1[var3]);
                  sessionStore.save();
                  var10 = true;
               } else if (var34 == 2) {
                  Trace.msgSecurityPrintln("trustdecider.user.grant.forever");
                  permanentStore.add(var1[var3]);
                  permanentStore.save();
                  var10 = true;
               } else {
                  Trace.msgSecurityPrintln("trustdecider.user.deny");
                  deniedStore.add(var1[var3]);
                  deniedStore.save();
               }

               if (var10) {
                  return true;
               }
            }

            var3 = var4;
         }

         return false;
      }
   }

   private static synchronized void getCertMap(KeyStore var0) throws KeyStoreException {
      trustedX500Principals = new HashMap();
      if (var0 != null) {
         Enumeration var1 = var0.aliases();

         while (var1.hasMoreElements()) {
            String var2 = (String)var1.nextElement();
            if (var0.isCertificateEntry(var2)) {
               Certificate var3 = var0.getCertificate(var2);
               if (var3 instanceof X509Certificate) {
                  addTrustedCert((X509Certificate)var3);
               }
            }
         }
      }
   }

   static int showSecurityDialog(Certificate[] var0, int var1, int var2, boolean var3, boolean var4) {
      int var5 = -1;

      try {
         var5 = (Integer)PluginSysUtil.execute(new TrustDecider$1(var0, var1, var2, var3, var4));
      } catch (Exception var7) {
         if (!$assertionsDisabled) {
            throw new AssertionError();
         }
      }

      return var5;
   }

   private static void addTrustedCert(X509Certificate var0) {
      X500Principal var1 = var0.getSubjectX500Principal();
      Object var2 = (Collection)trustedX500Principals.get(var1);
      if (var2 == null) {
         var2 = new ArrayList();
         trustedX500Principals.put(var1, var2);
      }

      var2.add(var0);
   }

   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError().initCause(var2);
      }
   }

   private static boolean getNetscapeCertTypeBit(X509Certificate var0, String var1) throws CertificateException, IOException {
      byte[] var2 = var0.getExtensionValue("2.16.840.1.113730.1.1");
      if (var2 == null) {
         return false;
      } else {
         DerInputStream var3 = new DerInputStream(var2);
         byte[] var4 = var3.getOctetString();
         var4 = new DerValue(var4).getUnalignedBitString().toByteArray();
         NetscapeCertTypeExtension var5 = new NetscapeCertTypeExtension(var4);
         Boolean var6 = (Boolean)var5.get(var1);
         return var6;
      }
   }

   private static boolean isIssuerOf(X509Certificate var0, X509Certificate var1) {
      Principal var2 = var0.getIssuerDN();
      Principal var3 = var1.getSubjectDN();
      return var2.equals(var3);
   }

   private static boolean checkLeafKeyUsage(X509Certificate var0, Set var1) throws CertificateException, IOException {
      var1.remove("2.5.29.15");
      boolean[] var2 = var0.getKeyUsage();
      if (var2 != null) {
         if (var2.length == 0) {
            Trace.msgSecurityPrintln("trustdecider.check.leafkeyusage.length");
            return false;
         }

         boolean var3 = var2[0];
         if (!var3) {
            Trace.msgSecurityPrintln("trustdecider.check.leafkeyusage.digitalsignature");
            return false;
         }
      }

      List var4 = var0.getExtendedKeyUsage();
      if (var4 != null && var1.contains("2.5.29.37")) {
         var1.remove("2.5.29.37");
         if (!var4.contains("2.5.29.37.0") && !var4.contains("1.3.6.1.5.5.7.3.3")) {
            Trace.msgSecurityPrintln("trustdecider.check.leafkeyusage.extkeyusageinfo");
            return false;
         }
      }

      if (var0.getExtensionValue("2.16.840.1.113730.1.1") != null && !getNetscapeCertTypeBit(var0, "object_signing")) {
         Trace.msgSecurityPrintln("trustdecider.check.leafkeyusage.certtypebit");
         return false;
      } else {
         return true;
      }
   }

   private static boolean checkSignerKeyUsage(X509Certificate var0, Set var1) throws CertificateException, IOException {
      var1.remove("2.5.29.15");
      boolean[] var2 = var0.getKeyUsage();
      if (var2 == null || var2.length >= 6 && var2[5]) {
         List var3 = var0.getExtendedKeyUsage();
         if (var3 != null && var1.contains("2.5.29.37")) {
            var1.remove("2.5.29.37");
            if (!var3.contains("2.5.29.37.0")) {
               Trace.msgSecurityPrintln("trustdecider.check.signerkeyusage.keyusage");
               return false;
            }
         }

         return true;
      } else {
         Trace.msgSecurityPrintln("trustdecider.check.signerkeyusage.lengthandbit");
         return false;
      }
   }

   private static boolean checkBasicConstraints(X509Certificate var0, Set var1, int var2) throws CertificateException, IOException {
      var1.remove("2.5.29.19");
      var1.remove("2.16.840.1.113730.1.1");
      if (var2 == 0) {
         return true;
      } else {
         if (var0.getExtensionValue("2.5.29.19") == null) {
            if (var0.getExtensionValue("2.16.840.1.113730.1.1") == null) {
               Trace.msgSecurityPrintln("trustdecider.check.basicconstraints.extensionvalue");
               return false;
            }

            if (!getNetscapeCertTypeBit(var0, "object_signing_ca")) {
               Trace.msgSecurityPrintln("trustdecider.check.basicconstraints.certtypebit");
               return false;
            }
         } else {
            if (var0.getExtensionValue("2.16.840.1.113730.1.1") != null
               && (getNetscapeCertTypeBit(var0, "ssl_ca") || getNetscapeCertTypeBit(var0, "s_mime_ca") || getNetscapeCertTypeBit(var0, "object_signing_ca"))
               && !getNetscapeCertTypeBit(var0, "object_signing_ca")) {
               Trace.msgSecurityPrintln("trustdecider.check.basicconstraints.bitvalue");
               return false;
            }

            int var3 = var0.getBasicConstraints();
            if (var3 < 0) {
               Trace.msgSecurityPrintln("trustdecider.check.basicconstraints.enduser");
               return false;
            }

            if (var2 - 1 > var3) {
               Trace.msgSecurityPrintln("trustdecider.check.basicconstraints.pathlength");
               return false;
            }
         }

         return true;
      }
   }

   private static Certificate[] canonicalize(Certificate[] var0, Date var1) throws CertificateException {
      ArrayList var2 = new ArrayList(var0.length);
      boolean var3 = false;
      if (var0.length == 0) {
         return var0;
      } else {
         for (int var4 = 0; var4 < var0.length; var4++) {
            X509Certificate var5 = (X509Certificate)var0[var4];
            X509Certificate var6 = getTrustedCertificate(var5, var1);
            if (var6 != null) {
               Trace.msgSecurityPrintln("trustdecider.check.canonicalize.updatecert");
               var5 = var6;
               var3 = true;
            }

            var2.add(var5);
            X500Principal var7 = ((X509Certificate)var0[var4]).getSubjectX500Principal();
            X500Principal var8 = ((X509Certificate)var0[var4]).getIssuerX500Principal();
            X500Principal var9 = null;
            if (var4 < var0.length - 1) {
               var9 = ((X509Certificate)var0[var4 + 1]).getSubjectX500Principal();
            }

            if (!var8.equals(var7) && !var8.equals(var9)) {
               X509Certificate var10 = getTrustedIssuerCertificate((X509Certificate)var0[var4], var1);
               if (var10 != null) {
                  Trace.msgSecurityPrintln("trustdecider.check.canonicalize.missing");
                  var3 = true;
                  var2.add(var10);
               }
            }
         }

         return var3 ? var2.toArray(new Certificate[var2.size()]) : var0;
      }
   }

   private static X509Certificate getTrustedCertificate(X509Certificate var0, Date var1) {
      X500Principal var2 = var0.getSubjectX500Principal();
      List var3 = (List)trustedX500Principals.get(var2);
      if (var3 == null) {
         return null;
      } else {
         X500Principal var4 = var0.getIssuerX500Principal();
         PublicKey var5 = var0.getPublicKey();
         Iterator var6 = var3.iterator();

         X509Certificate var7;
         while (true) {
            if (!var6.hasNext()) {
               return null;
            }

            var7 = (X509Certificate)var6.next();
            if (!var7.equals(var0) && var7.getIssuerX500Principal().equals(var4) && var7.getPublicKey().equals(var5)) {
               try {
                  var7.checkValidity(var1);
                  break;
               } catch (Exception var9) {
               }
            }
         }

         Trace.msgSecurityPrintln("trustdecider.check.gettrustedcert.find");
         return var7;
      }
   }

   private static X509Certificate getTrustedIssuerCertificate(X509Certificate var0, Date var1) {
      X500Principal var2 = var0.getIssuerX500Principal();
      List var3 = (List)trustedX500Principals.get(var2);
      if (var3 == null) {
         return null;
      } else {
         for (X509Certificate var5 : var3) {
            try {
               var5.checkValidity(var1);
            } catch (Exception var7) {
               continue;
            }

            Trace.msgSecurityPrintln("trustdecider.check.gettrustedissuercert.find");
            return var5;
         }

         return null;
      }
   }
}
