package sun.plugin.security;

import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.security.AccessController;
import java.security.Principal;
import java.security.PrivilegedActionException;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.text.MessageFormat;
import java.util.ArrayList;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.LookAndFeel;
import sun.plugin.resources.ResourceHandler;
import sun.plugin.util.DialogFactory;
import sun.plugin.util.PluginUIManager;
import sun.plugin.util.Trace;

class TrustDeciderDialog implements ActionListener {
   public static final int TrustOption_GrantThisSession = 0;
   public static final int TrustOption_Deny = 1;
   public static final int TrustOption_GrantAlways = 2;
   private Certificate[] certs = null;
   private int start = 0;
   private int end = 0;
   private boolean rootCANotValid = false;
   private boolean timeNotValid = false;
   private boolean httpsDialog = false;
   private CertificateDialog dialog = null;

   int DoModal() {
      LookAndFeel var1 = null;

      int var30;
      try {
         var1 = PluginUIManager.setTheme();
         int var2 = -1;
         if (this.certs[this.start] instanceof X509Certificate && this.certs[this.end - 1] instanceof X509Certificate) {
            X509Certificate var3 = (X509Certificate)this.certs[this.start];
            X509Certificate var4 = (X509Certificate)this.certs[this.end - 1];
            Principal var5 = var3.getSubjectDN();
            Principal var6 = var4.getIssuerDN();
            String var7 = var5.getName();
            Object var8 = null;
            int var9 = var7.indexOf("CN=");
            int var10 = 0;
            if (var9 < 0) {
               var8 = getMessage("security_dialog.unknown.subject");
            } else {
               try {
                  var9 += 3;
                  if (var7.charAt(var9) == '"') {
                     var10 = var7.indexOf(34, ++var9);
                  } else {
                     var10 = var7.indexOf(44, var9);
                  }

                  if (var10 < 0) {
                     var8 = var7.substring(var9);
                  } else {
                     var8 = var7.substring(var9, var10);
                  }
               } catch (IndexOutOfBoundsException var28) {
                  var8 = getMessage("security_dialog.unknown.subject");
               }
            }

            String var11 = var6.getName();
            Object var12 = null;
            var9 = var11.indexOf("O=");
            int var36 = 0;
            if (var9 < 0) {
               var12 = getMessage("security_dialog.unknown.issuer");
            } else {
               try {
                  var9 += 2;
                  if (var11.charAt(var9) == '"') {
                     var36 = var11.indexOf(34, ++var9);
                  } else {
                     var36 = var11.indexOf(44, var9);
                  }

                  if (var36 < 0) {
                     var12 = var11.substring(var9);
                  } else {
                     var12 = var11.substring(var9, var36);
                  }
               } catch (IndexOutOfBoundsException var27) {
                  var12 = getMessage("security_dialog.unknown.issuer");
               }
            }

            ArrayList var13 = new ArrayList();
            Object var14 = null;
            if (this.getHttpsDialog()) {
               var14 = new MessageFormat(getMessage("security_dialog_https.text0"));
            } else {
               var14 = new MessageFormat(getMessage("security_dialog.text0"));
            }

            Object[] var15 = new Object[]{var8, var12};
            var13.add(var14.format(var15));
            var13.add("");
            if (this.rootCANotValid) {
               JLabel var16 = new JLabel(getMessage("security_dialog.rootCANotValid"));
               var16.setIcon(this.getWarningIcon());
               var13.add(var16);
            } else {
               JLabel var41 = new JLabel(getMessage("security_dialog.rootCAValid"));
               var41.setIcon(this.getInfoIcon());
               var13.add(var41);
            }

            var13.add("");
            if (this.timeNotValid) {
               JLabel var42 = new JLabel(getMessage("security_dialog.timeNotValid"));
               var42.setIcon(this.getWarningIcon());
               var13.add(var42);
            } else {
               JLabel var43 = new JLabel(getMessage("security_dialog.timeValid"));
               var43.setIcon(this.getInfoIcon());
               var13.add(var43);
            }

            var14 = new MessageFormat(getMessage("security_dialog.text1"));
            Object[] var44 = new Object[]{var8, var8};
            var13.add(var14.format(var44));
            JButton var17 = new JButton(getMessage("security_dialog.buttonViewCert"));
            var17.setMnemonic(getAcceleratorKey("security_dialog.buttonViewCert"));
            var17.addActionListener(this);
            JPanel var18 = new JPanel();
            var18.add(var17);
            var18.setLayout(new FlowLayout(2));
            var13.add(var18);
            JButton var19 = new JButton(getMessage("security_dialog.buttonYes"));
            JButton var20 = new JButton(getMessage("security_dialog.buttonNo"));
            JButton var21 = new JButton(getMessage("security_dialog.buttonAlways"));
            var19.setMnemonic(getAcceleratorKey("security_dialog.buttonYes"));
            var20.setMnemonic(getAcceleratorKey("security_dialog.buttonNo"));
            var21.setMnemonic(getAcceleratorKey("security_dialog.buttonAlways"));
            Object[] var22 = new Object[]{var19, var20, var21};
            if (!Trace.isAutomationEnabled()) {
               var2 = DialogFactory.showOptionDialog(4, var13.toArray(), getMessage("security_dialog.caption"), var22, var22[0]);
            } else {
               Trace.msgSecurityPrintln("trustdecider.automation.trustcert");
               var2 = 0;
            }
         }

         var30 = var2;
      } finally {
         PluginUIManager.restoreTheme(var1);
      }

      return var30;
   }

   private boolean getHttpsDialog() {
      return this.httpsDialog;
   }

   public void setHttpsDialog(boolean var1) {
      this.httpsDialog = var1;
   }

   public void actionPerformed(ActionEvent var1) {
      this.dialog.DoModal();
   }

   private static int getAcceleratorKey(String var0) {
      return ResourceHandler.getAcceleratorKey(var0);
   }

   TrustDeciderDialog(Certificate[] var1, int var2, int var3, boolean var4, boolean var5) {
      this.certs = var1;
      this.start = var2;
      this.end = var3;
      this.rootCANotValid = var4;
      this.timeNotValid = var5;
      this.dialog = new CertificateDialog(var1, var2, var3);
   }

   private Icon getInfoIcon() {
      return this.getIcon("javax/swing/plaf/metal/icons/Inform.gif");
   }

   private Icon getWarningIcon() {
      return this.getIcon("javax/swing/plaf/metal/icons/Warn.gif");
   }

   private static String getMessage(String var0) {
      return ResourceHandler.getMessage(var0);
   }

   private Icon getIcon(String var1) {
      Icon var2 = null;

      try {
         var2 = AccessController.doPrivileged(new TrustDeciderDialog$1(this, var1));
      } catch (PrivilegedActionException var4) {
         var4.printStackTrace();
      }

      return var2;
   }
}
