package sun.plugin.security;

import java.security.AccessController;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.X509Certificate;
import javax.net.ssl.TrustManager;
import javax.net.ssl.TrustManagerFactory;
import javax.net.ssl.X509TrustManager;
import sun.plugin.util.Trace;

public final class X509PluginTrustManager implements X509TrustManager {
   private X509TrustManager trustManager = null;
   private static CertificateStore rootStore = null;
   private static CertificateStore httpsRootStore = null;
   private static CertificateStore permanentStore = null;
   private static CertificateStore sessionStore = null;
   private static CertificateStore deniedStore = null;
   static final boolean $assertionsDisabled = !(X509PluginTrustManager.class$sun$plugin$security$X509PluginTrustManager == null
         ? (X509PluginTrustManager.class$sun$plugin$security$X509PluginTrustManager = class$("sun.plugin.security.X509PluginTrustManager"))
         : X509PluginTrustManager.class$sun$plugin$security$X509PluginTrustManager)
      .desiredAssertionStatus();
   static Class class$sun$plugin$security$X509PluginTrustManager;

   static {
      reset();
   }

   public X509PluginTrustManager() throws KeyStoreException, NoSuchAlgorithmException, NoSuchProviderException, CertificateException {
      TrustManagerFactory var1 = TrustManagerFactory.getInstance("SunX509", "SunJSSE");
      var1.init((KeyStore)null);
      TrustManager[] var2 = var1.getTrustManagers();
      this.trustManager = (X509TrustManager)var2[0];
   }

   public static void reset() {
      rootStore = RootCACertificateStore.getInstance();
      httpsRootStore = new HttpsRootCACertStore();
      permanentStore = new PluginHttpsCertStore();
      sessionStore = new SessionCertificateStore();
      deniedStore = new DeniedCertificateStore();
   }

   public X509Certificate[] getAcceptedIssuers() {
      return this.trustManager.getAcceptedIssuers();
   }

   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError().initCause(var2);
      }
   }

   public synchronized void checkClientTrusted(X509Certificate[] var1, String var2) throws CertificateException {
      boolean var3 = false;
      boolean var4 = false;
      if (!$assertionsDisabled && this.trustManager == null) {
         throw new AssertionError();
      } else {
         int var5 = 1;

         try {
            rootStore.load();
            httpsRootStore.load();
            permanentStore.load();
            sessionStore.load();
            deniedStore.load();
            if (deniedStore.contains(var1[0])) {
               throw new CertificateException("Certificate has been denied");
            }

            int var6;
            try {
               this.trustManager.checkClientTrusted(var1, var2);
               return;
            } catch (CertificateException var11) {
               if (sessionStore.contains(var1[0])) {
                  return;
               }

               if (permanentStore.contains(var1[0])) {
                  return;
               }

               var6 = 0;
            }

            for (; var6 < var1.length; var6++) {
               if (!rootStore.verify(var1[var6]) && !httpsRootStore.verify(var1[var6])) {
                  var3 = true;
               }

               try {
                  var1[var6].checkValidity();
               } catch (CertificateExpiredException var9) {
                  var4 = true;
               } catch (CertificateNotYetValidException var10) {
                  var4 = true;
               }
            }

            if (!Trace.isAutomationEnabled()) {
               try {
                  var5 = AccessController.doPrivileged(new X509PluginTrustManager$1(this, var1, var3, var4));
               } catch (Exception var12) {
                  if (!$assertionsDisabled) {
                     throw new AssertionError();
                  }
               }
            } else {
               Trace.msgSecurityPrintln("x509trustmgr.automation.ignoreclientcert");
               var5 = 0;
            }

            if (var5 == 0) {
               sessionStore.add(var1[0]);
               sessionStore.save();
            } else if (var5 == 2) {
               permanentStore.add(var1[0]);
               permanentStore.save();
            } else {
               deniedStore.add(var1[0]);
               deniedStore.save();
            }
         } catch (CertificateException var13) {
            throw var13;
         } catch (Throwable var14) {
            var14.printStackTrace();
         }

         if (var5 != 0 && var5 != 2) {
            throw new CertificateException("Plugin couldn't trust Client");
         }
      }
   }

   public synchronized void checkServerTrusted(X509Certificate[] var1, String var2) throws CertificateException {
      boolean var3 = false;
      boolean var4 = false;
      if (!$assertionsDisabled && this.trustManager == null) {
         throw new AssertionError();
      } else {
         int var5 = 1;

         try {
            rootStore.load();
            httpsRootStore.load();
            permanentStore.load();
            sessionStore.load();
            deniedStore.load();
            if (deniedStore.contains(var1[0])) {
               throw new CertificateException("Certificate has been denied");
            }

            int var6;
            try {
               this.trustManager.checkServerTrusted(var1, var2);
               return;
            } catch (CertificateException var11) {
               if (sessionStore.contains(var1[0])) {
                  return;
               }

               if (permanentStore.contains(var1[0])) {
                  return;
               }

               var6 = 0;
            }

            for (; var6 < var1.length; var6++) {
               if (!rootStore.verify(var1[var6]) && !httpsRootStore.verify(var1[var6])) {
                  var3 = true;
               }

               try {
                  var1[var6].checkValidity();
               } catch (CertificateExpiredException var9) {
                  var4 = true;
               } catch (CertificateNotYetValidException var10) {
                  var4 = true;
               }
            }

            if (!Trace.isAutomationEnabled()) {
               try {
                  var5 = AccessController.doPrivileged(new X509PluginTrustManager$3(this, var1, var3, var4));
               } catch (Exception var12) {
                  if (!$assertionsDisabled) {
                     throw new AssertionError();
                  }
               }
            } else {
               Trace.msgSecurityPrintln("x509trustmgr.automation.ignoreservercert");
               var5 = 0;
            }

            if (var5 == 0) {
               sessionStore.add(var1[0]);
               sessionStore.save();
            } else if (var5 == 2) {
               permanentStore.add(var1[0]);
               permanentStore.save();
            } else {
               deniedStore.add(var1[0]);
               deniedStore.save();
            }
         } catch (CertificateException var13) {
            throw var13;
         } catch (Throwable var14) {
            var14.printStackTrace();
         }

         if (var5 != 0 && var5 != 2) {
            throw new CertificateException("Plugin couldn't trust Server");
         }
      }
   }
}
