package sun.plugin.util;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Insets;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.lang.reflect.Array;
import java.net.URL;
import java.security.AccessController;
import java.text.MessageFormat;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.LookAndFeel;
import javax.swing.SwingUtilities;
import sun.plugin.resources.ResourceHandler;

public class DialogFactory {
   public static final int ERROR_MESSAGE = 1;
   public static final int INFORMATION_MESSAGE = 2;
   public static final int WARNING_MESSAGE = 3;
   public static final int QUESTION_MESSAGE = 4;
   public static final int PLAIN_MESSAGE = 5;
   private static String confirmDialogTitle = ResourceHandler.getMessage("usability.confirmDialogTitle");
   private static String inputDialogTitle = ResourceHandler.getMessage("usability.inputDialogTitle");
   private static String messageDialogTitle = ResourceHandler.getMessage("usability.messageDialogTitle");
   private static String exceptionDialogTitle = ResourceHandler.getMessage("usability.exceptionDialogTitle");
   private static String optionDialogTitle = ResourceHandler.getMessage("usability.optionDialogTitle");
   private static String aboutDialogTitle = ResourceHandler.getMessage("usability.aboutDialogTitle");
   private static String javaHomeLink = ResourceHandler.getMessage("usability.java.home.link");
   private static final String LEGAL_NOTE_BASE = "sun/plugin/util/legal";
   static final boolean $assertionsDisabled = !(DialogFactory.class$sun$plugin$util$DialogFactory == null
         ? (DialogFactory.class$sun$plugin$util$DialogFactory = class$("sun.plugin.util.DialogFactory"))
         : DialogFactory.class$sun$plugin$util$DialogFactory)
      .desiredAssertionStatus();
   static Class class$sun$plugin$util$DialogFactory;

   static int showUpdateCheckDialog() {
      String var0 = ResourceHandler.getMessage("autoupdatecheck.buttonYes");
      String var1 = ResourceHandler.getMessage("autoupdatecheck.buttonNo");
      String var2 = ResourceHandler.getMessage("autoupdatecheck.buttonAskLater");
      String var3 = ResourceHandler.getMessage("autoupdatecheck.caption");
      String var4 = ResourceHandler.getMessage("autoupdatecheck.message");
      JButton var5 = new JButton(var0);
      JButton var6 = new JButton(var1);
      JButton var7 = new JButton(var2);
      var5.setMnemonic(ResourceHandler.getAcceleratorKey("autoupdatecheck.buttonYes"));
      var6.setMnemonic(ResourceHandler.getAcceleratorKey("autoupdatecheck.buttonNo"));
      var7.setMnemonic(ResourceHandler.getAcceleratorKey("autoupdatecheck.buttonAskLater"));
      Object[] var8 = new Object[]{var5, var6, var7};
      return showOptionDialogImpl(null, 3, var4, var3, var8, var8[0], false);
   }

   static void access$000() {
      showAboutPluginDialogImpl();
   }

   public static void showAboutPluginDialog() {
      try {
         PluginSysUtil.execute(new DialogFactory$2());
      } catch (Exception var1) {
         var1.printStackTrace();
         if (!$assertionsDisabled) {
            throw new AssertionError();
         }
      }
   }

   private static void showAboutPluginDialogImpl() {
      AccessController.doPrivileged(new DialogFactory$3());
   }

   public static int showConfirmDialog(Object var0) {
      return showConfirmDialog(null, var0, confirmDialogTitle);
   }

   static void access$1000(Object var0) {
      fixSwingLayoutBug(var0);
   }

   private static void fixSwingLayoutBug(Object var0) {
      if (var0 != null) {
         if (var0 instanceof JTextArea) {
            JTextArea var3 = (JTextArea)var0;
            var3.getUI().getPreferredSize(var3);
         } else {
            if (var0.getClass().isArray()) {
               int var1 = Array.getLength(var0);

               for (int var2 = 0; var2 < var1; var2++) {
                  fixSwingLayoutBug(Array.get(var0, var2));
               }
            }
         }
      }
   }

   public static void showInformationDialog(Object var0) {
      showInformationDialog(null, var0, messageDialogTitle);
   }

   static String access$100() {
      return aboutDialogTitle;
   }

   static void access$400(String var0) {
      launchLink(var0);
   }

   private static native void launchLink(String var0);

   public static void showErrorDialog(String var0) {
      showErrorDialog(null, var0, messageDialogTitle);
   }

   public static void showExceptionDialog(Throwable var0) {
      showExceptionDialog(null, var0, var0.toString(), exceptionDialogTitle);
   }

   public static Icon loadIcon() {
      Icon var0 = null;

      try {
         var0 = AccessController.doPrivileged(new DialogFactory$1());
      } catch (Throwable var2) {
         var2.printStackTrace();
      }

      return var0;
   }

   static JPanel access$200() {
      return createInfoPane();
   }

   private static JPanel createInfoPane() {
      JPanel var0 = new JPanel(new BorderLayout());
      var0.setForeground(Color.WHITE);
      var0.setBackground(Color.WHITE);
      var0.setBorder(BorderFactory.createLineBorder(Color.BLACK));

      try {
         URL var1 = ClassLoader.getSystemResource("sun/plugin/util/aboutjava.png");
         ImageIcon var2 = new ImageIcon(var1);
         JLabel var3 = new JLabel(var2);
         JPanel var4 = new JPanel(new BorderLayout());
         var4.setForeground(Color.WHITE);
         var4.setBackground(Color.WHITE);
         var4.add(var3, "Center");
         var4.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
         var0.add("North", var4);
         int var5 = var2.getIconWidth() - 8;
         JPanel var6 = new JPanel();
         var6.setLayout(new BoxLayout(var6, 1));
         var6.setBorder(BorderFactory.createEmptyBorder(0, 8, 4, 8));
         var6.setForeground(Color.WHITE);
         var6.setBackground(Color.WHITE);
         String var7 = MessageFormat.format(
               ResourceHandler.getMessage("about.java.version"), System.getProperty("java.version"), System.getProperty("java.runtime.version")
            )
            + '\n'
            + ResourceHandler.getMessage("about.legal.note");
         JTextArea var8 = new JTextArea();
         var8.setBorder(BorderFactory.createEmptyBorder(0, 4, 0, 4));
         var8.setEditable(false);
         var8.setLineWrap(true);
         var8.setWrapStyleWord(true);
         var8.setText(var7);
         Font var9 = var8.getFont();
         FontMetrics var10 = var8.getFontMetrics(var9);
         int var11 = var10.stringWidth(ResourceHandler.getMessage("about.legal.note"));
         int var12 = var11 / (var5 - 8) + 2;
         var8.setRows(var12);
         var6.add(var8);
         var6.add(Box.createVerticalStrut(30));
         String var13 = ResourceHandler.getMessage("about.prompt.info");
         String var14 = ResourceHandler.getMessage("about.home.link");
         String var15 = "<font face=" + var9.getFamily() + " size=-1>" + var13 + " <a style='color:blue' href=" + var14 + '>' + var14 + "</a></font>";
         JEditorPane var16 = new JEditorPane("text/html", var15);
         Insets var17 = var16.getMargin();
         var10 = var16.getFontMetrics(var9);
         var11 = var10.stringWidth(var13 + ' ' + var14);
         var12 = var11 / (var5 - var17.left - var17.right) + 1;
         Dimension var18 = new Dimension(var5, var12 * (var10.getHeight() + var10.getMaxDescent()) + var17.top + var17.bottom);
         var16.setPreferredSize(var18);
         var16.setEditable(false);
         var16.addHyperlinkListener(new DialogFactory$4(var16, var15));
         var6.add(var16);
         var0.add(var6, "Center");
      } catch (Exception var19) {
      }

      return var0;
   }

   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError().initCause(var2);
      }
   }

   public static int showConfirmDialog(Component var0, Object var1) {
      return showConfirmDialog(var0, var1, confirmDialogTitle);
   }

   public static void showInformationDialog(Component var0, Object var1) {
      showInformationDialog(var0, var1, messageDialogTitle);
   }

   public static void showErrorDialog(Component var0, String var1) {
      showErrorDialog(var0, var1, messageDialogTitle);
   }

   private static void showMessageDialog(int var0, Object var1, String var2, boolean var3) {
      showMessageDialog(null, var0, var1, var2, var3);
   }

   public static String showInputDialog(Object var0) {
      return showInputDialog(null, var0, inputDialogTitle);
   }

   public static int showConfirmDialog(Object var0, String var1) {
      return showConfirmDialog(null, var0, var1);
   }

   public static void showInformationDialog(Object var0, String var1) {
      showInformationDialog(null, var0, var1);
   }

   public static void showErrorDialog(String var0, String var1) {
      showErrorDialog(null, var0, var1);
   }

   public static void showExceptionDialog(Throwable var0, String var1) {
      showExceptionDialog(var0, var1, exceptionDialogTitle);
   }

   public static void showExceptionDialog(Component var0, Throwable var1) {
      showExceptionDialog(var0, var1, var1.toString(), exceptionDialogTitle);
   }

   private static Object extractMessage(JOptionPane var0, Object var1) {
      if (var1 instanceof Object[]) {
         return extractMessage(var0, (Object[])var1);
      } else if (var1 instanceof String) {
         return extractMessage(var0, (String)var1);
      } else {
         return var1 instanceof Exception ? extractMessage(var0, (Throwable)((Exception)var1)) : var1;
      }
   }

   private static Object extractMessage(JOptionPane var0, Object[] var1) {
      Object[] var2 = null;
      if (var1 != null) {
         var2 = new Object[var1.length];

         for (int var3 = 0; var3 < var1.length; var3++) {
            var2[var3] = extractMessage(var0, var1[var3]);
         }
      }

      return var2;
   }

   private static Object extractMessage(JOptionPane var0, String var1) {
      return formatStringMessage(var0, var1);
   }

   private static Object formatStringMessage(JOptionPane var0, String var1) {
      if (!$assertionsDisabled && var1 == null) {
         throw new AssertionError();
      } else {
         if (var1 == null) {
            var1 = "null";
         }

         int var2 = var1.indexOf("</html>");
         if (var2 == -1) {
            JTextArea var3 = new JTextArea();
            var3.setColumns(40);
            var3.setAutoscrolls(true);
            var3.setEditable(false);
            var3.setLineWrap(true);
            var3.setWrapStyleWord(true);
            var3.setBackground(var0.getBackground());
            var3.setText(var1);
            return var3;
         } else {
            return var2 + 7 == var1.length()
               ? new JLabel(var1)
               : new Object[]{new JLabel(var1.substring(0, var2 + 7)), formatStringMessage(var0, var1.substring(var2 + 7))};
         }
      }
   }

   private static Object extractMessage(JOptionPane var0, Throwable var1) {
      return formatExceptionMessage(var0, var1);
   }

   private static Object formatExceptionMessage(JOptionPane var0, Throwable var1) {
      StringWriter var2 = new StringWriter();
      PrintWriter var3 = new PrintWriter(var2);
      var1.printStackTrace(var3);
      JTextArea var4 = new JTextArea("" + var2.toString());
      var4.setColumns(40);
      var4.setRows(10);
      var4.setEditable(false);
      JScrollPane var5 = new JScrollPane(var4);
      var4.setBackground(var0.getBackground());
      return var5;
   }

   static void access$800(Component var0, int var1, Object var2, String var3, boolean var4) {
      showMessageDialogImpl(var0, var1, var2, var3, var4);
   }

   private static void showMessageDialog(Component var0, int var1, Object var2, String var3, boolean var4) {
      try {
         PluginSysUtil.execute(new DialogFactory$8(var0, var1, var2, var3, var4));
      } catch (Exception var6) {
         if (!$assertionsDisabled) {
            throw new AssertionError();
         }
      }
   }

   private static void showMessageDialogImpl(Component var0, int var1, Object var2, String var3, boolean var4) {
      LookAndFeel var5 = null;

      try {
         var5 = PluginUIManager.setTheme();
         JOptionPane var6 = new JOptionPane();
         switch (var1) {
            case 1:
               var6.setMessageType(0);
               break;
            case 2:
               var6.setMessageType(1);
               break;
            case 3:
               var6.setMessageType(2);
               break;
            case 4:
               var6.setMessageType(3);
         }

         var6.setOptionType(-1);
         var6.setWantsInput(false);
         Object var7 = extractMessage(var6, var2);
         if (var3 == null) {
            var3 = messageDialogTitle;
         }

         showDialog(var6, var0, var3, var7, var4);
      } finally {
         PluginUIManager.restoreTheme(var5);
      }
   }

   public static String showInputDialog(Component var0, Object var1) {
      return showInputDialog(var0, var1, inputDialogTitle);
   }

   static int access$500(Component var0, Object var1, String var2) {
      return showConfirmDialogImpl(var0, var1, var2);
   }

   public static int showConfirmDialog(Component var0, Object var1, String var2) {
      try {
         return (Integer)PluginSysUtil.execute(new DialogFactory$5(var0, var1, var2));
      } catch (Exception var4) {
         if (!$assertionsDisabled) {
            throw new AssertionError();
         } else {
            return 0;
         }
      }
   }

   private static int showConfirmDialogImpl(Component var0, Object var1, String var2) {
      LookAndFeel var3 = null;

      int var7;
      try {
         var3 = PluginUIManager.setTheme();
         JButton var4 = new JButton(ResourceHandler.getMessage("usability.confirm.yes"));
         JButton var5 = new JButton(ResourceHandler.getMessage("usability.confirm.no"));
         var4.setMnemonic(ResourceHandler.getAcceleratorKey("usability.confirm.yes"));
         var5.setMnemonic(ResourceHandler.getAcceleratorKey("usability.confirm.no"));
         Object[] var6 = new Object[]{var4, var5};
         if (var2 == null) {
            var2 = confirmDialogTitle;
         }

         var7 = showOptionDialog(var0, 4, var1, var2, var6, var6[0]);
      } finally {
         PluginUIManager.restoreTheme(var3);
      }

      return var7;
   }

   public static void showInformationDialog(Component var0, Object var1, String var2) {
      showMessageDialog(var0, 2, var1, var2, true);
   }

   public static void showErrorDialog(Component var0, String var1, String var2) {
      showMessageDialog(var0, 1, var1, var2, true);
   }

   public static String showInputDialog(Object var0, String var1) {
      return showInputDialog(null, var0, var1);
   }

   public static void showExceptionDialog(Throwable var0, String var1, String var2) {
      showExceptionDialog(null, var0, var1, var2);
   }

   public static void showExceptionDialog(Component var0, Throwable var1, String var2) {
      showExceptionDialog(var0, var1, var2, exceptionDialogTitle);
   }

   public static int showOptionDialog(int var0, Object var1, String var2, Object[] var3, Object var4) {
      return showOptionDialog(null, var0, var1, var2, var3, var4);
   }

   public static void preLoadDialog(int var0, Object var1, String var2, Object[] var3, Object var4) {
      showOptionDialogImpl(null, var0, var1, var2, var3, var3[0], true);
   }

   public static int showOptionDialog(Object var0, String var1, Object[] var2, Object var3) {
      return showOptionDialog(null, var0, var1, var2, var3);
   }

   private static boolean showDialog(JOptionPane var0, Component var1, String var2, Object var3) {
      return showDialog(var0, var1, var2, var3, true, false);
   }

   static boolean access$300(JOptionPane var0, Component var1, String var2, Object var3, boolean var4) {
      return showDialog(var0, var1, var2, var3, var4);
   }

   private static boolean showDialog(JOptionPane var0, Component var1, String var2, Object var3, boolean var4) {
      return showDialog(var0, var1, var2, var3, var4, false);
   }

   private static boolean showDialog(JOptionPane var0, Component var1, String var2, Object var3, boolean var4, boolean var5) {
      boolean var6 = true;

      try {
         var0.setValue(null);
         DialogFactory$12 var7 = new DialogFactory$12(var0, var1, var2, var3, var4, var5);
         if (var5 || SwingUtilities.isEventDispatchThread()) {
            var7.run();
         } else if (var4) {
            SwingUtilities.invokeAndWait(var7);
         } else {
            SwingUtilities.invokeLater(var7);
         }
      } catch (Exception var8) {
         var8.printStackTrace();
         var6 = false;
      }

      return var6;
   }

   static String access$700(Component var0, Object var1, String var2) {
      return showInputDialogImpl(var0, var1, var2);
   }

   public static String showInputDialog(Component var0, Object var1, String var2) {
      try {
         return (String)PluginSysUtil.execute(new DialogFactory$7(var0, var1, var2));
      } catch (Exception var4) {
         if (!$assertionsDisabled) {
            throw new AssertionError();
         } else {
            return null;
         }
      }
   }

   private static String showInputDialogImpl(Component var0, Object var1, String var2) {
      LookAndFeel var3 = null;

      String var11;
      try {
         var3 = PluginUIManager.setTheme();
         String var4 = null;
         JOptionPane var5 = new JOptionPane();
         var5.setMessageType(3);
         var5.setOptionType(2);
         var5.setWantsInput(true);
         Object var6 = extractMessage(var5, var1);
         if (var2 == null) {
            var2 = inputDialogTitle;
         }

         if (showDialog(var5, var0, var2, var6)) {
            Object var7 = var5.getInputValue();
            if (var7 != null) {
               if (var7 instanceof String) {
                  var4 = var7.toString();
               }

               Trace.msgPrintln("dialogfactory.user.typed", new Object[]{var4});
            }
         }

         var11 = var4;
      } finally {
         PluginUIManager.restoreTheme(var3);
      }

      return var11;
   }

   static void access$900(Component var0, Throwable var1, String var2, String var3) {
      showExceptionDialogImpl(var0, var1, var2, var3);
   }

   public static void showExceptionDialog(Component var0, Throwable var1, String var2, String var3) {
      try {
         PluginSysUtil.execute(new DialogFactory$9(var0, var1, var2, var3));
      } catch (Exception var5) {
         if (!$assertionsDisabled) {
            throw new AssertionError();
         }
      }
   }

   private static void showExceptionDialogImpl(Component var0, Throwable var1, String var2, String var3) {
      LookAndFeel var4 = null;

      try {
         var4 = PluginUIManager.setTheme();
         JOptionPane var5 = new JOptionPane();
         var5.setMessageType(0);
         var5.setOptionType(-1);
         var5.setWantsInput(false);
         Component var6 = (Component)extractMessage(var5, var1);
         JPanel var7 = new JPanel();
         JButton var8 = new JButton(ResourceHandler.getMessage("usability.moreInfo"));
         var8.setMnemonic(ResourceHandler.getAcceleratorKey("usability.moreInfo"));
         var7.setLayout(new FlowLayout(2));
         var7.add(var8);
         JPanel var9 = new JPanel();
         JButton var10 = new JButton(ResourceHandler.getMessage("usability.lessInfo"));
         var10.setMnemonic(ResourceHandler.getAcceleratorKey("usability.lessInfo"));
         JPanel var11 = new JPanel();
         var11.setLayout(new FlowLayout(2));
         var11.add(var10);
         var9.setLayout(new BorderLayout());
         var9.add(var11, "Center");
         var9.add(var6, "South");
         JPanel var12 = new JPanel();
         var12.setLayout(new BorderLayout());
         var12.add(var7, "Center");
         var8.addActionListener(new DialogFactory$10(var12, var7, var9));
         var10.addActionListener(new DialogFactory$11(var12, var9, var7));
         Object[] var13 = new Object[]{extractMessage(var5, var2), var12};
         if (var3 == null) {
            var3 = exceptionDialogTitle;
         }

         showDialog(var5, var0, var3, var13);
      } finally {
         PluginUIManager.restoreTheme(var4);
      }
   }

   public static int showOptionDialog(Component var0, int var1, Object var2, String var3, Object[] var4, Object var5) {
      try {
         return (Integer)PluginSysUtil.execute(new DialogFactory$6(var0, var1, var2, var3, var4, var5));
      } catch (Exception var7) {
         if (!$assertionsDisabled) {
            throw new AssertionError();
         } else {
            return 0;
         }
      }
   }

   static int access$600(Component var0, int var1, Object var2, String var3, Object[] var4, Object var5, boolean var6) {
      return showOptionDialogImpl(var0, var1, var2, var3, var4, var5, var6);
   }

   private static int showOptionDialogImpl(Component var0, int var1, Object var2, String var3, Object[] var4, Object var5, boolean var6) {
      LookAndFeel var7 = null;

      int var16;
      try {
         var7 = PluginUIManager.setTheme();
         int var8 = -1;
         JOptionPane var9 = new JOptionPane();
         switch (var1) {
            case 1:
               var9.setMessageType(0);
               break;
            case 2:
               var9.setMessageType(1);
               break;
            case 3:
               var9.setMessageType(2);
               break;
            case 4:
               var9.setMessageType(3);
         }

         var9.setOptions(var4);
         var9.setInitialValue(var5);
         var9.setWantsInput(false);
         Object var10 = extractMessage(var9, var2);
         if (var3 == null) {
            var3 = optionDialogTitle;
         }

         if (showDialog(var9, var0, var3, var10, true, var6)) {
            Object var11 = var9.getValue();
            if (var11 != null) {
               for (int var12 = 0; var12 < var4.length; var12++) {
                  if (var4[var12].equals(var11)) {
                     var8 = var12;
                     break;
                  }
               }

               Trace.msgPrintln("dialogfactory.user.selected", new Object[]{new Integer(var8)});
            }
         }

         var16 = var8;
      } finally {
         PluginUIManager.restoreTheme(var7);
      }

      return var16;
   }

   public static int showOptionDialog(Component var0, Object var1, String var2, Object[] var3, Object var4) {
      return showOptionDialog(var0, 5, var1, var2, var3, var4);
   }
}
