package sun.plugin.util;

import java.io.File;
import java.security.AccessController;
import sun.plugin.services.PlatformService;
import sun.security.action.GetPropertyAction;

final class PluginConfig extends DeploymentConfig {
   private static final String CACHE_VERSION = "v1.0";

   PluginConfig() {
      new File(this.getPluginCacheDirectory()).mkdirs();
   }

   private String getCacheDirectorySubStructure() {
      return "javapi" + File.separator + "v1.0";
   }

   protected String getInfrastructurePath() {
      return PlatformService.getService().getInfrastructurePath();
   }

   public String getLogDirectory() {
      String var1 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.outputfiles.path"));
      if (var1 == null || var1.trim().equals("")) {
         var1 = super.getLogDirectory();
      }

      return var1;
   }

   public String getPluginCacheDirectory() {
      String var1 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.cache.directory"));
      if (var1 == null || var1.trim().equals("")) {
         var1 = super.getCacheDirectory() + File.separator + this.getCacheDirectorySubStructure();
      }

      return var1;
   }

   protected String getSystemProfilePath() {
      String var1 = PlatformService.getService().getSystemProfilePath();
      if (var1 == null) {
         var1 = this.getUserProfilePath();
      }

      return var1;
   }

   protected String getUserProfilePath() {
      String var1 = AccessController.doPrivileged(new GetPropertyAction("javaplugin.user.profile"));
      if (var1 == null || var1.trim().equals("")) {
         var1 = PlatformService.getService().getUserProfilePath();
         if (var1 == null) {
            var1 = AccessController.doPrivileged(new GetPropertyAction("user.home"));
         }
      }

      return var1;
   }
}
