package sun.plugin.util;

import java.awt.EventQueue;
import java.awt.Frame;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.event.InvocationEvent;
import java.lang.reflect.InvocationTargetException;
import java.security.AccessController;
import javax.swing.JDialog;
import javax.swing.SwingUtilities;
import sun.awt.AppContext;
import sun.awt.SunToolkit;
import sun.security.action.GetPropertyAction;

public final class PluginSysUtil {
   private static EventQueue pluginEventQueue = null;
   private static ThreadGroup pluginThreadGroup = null;
   private static ClassLoader pluginSysClassLoader = null;

   private static boolean isOnWindows() {
      String var0 = AccessController.doPrivileged(new GetPropertyAction("os.name"));
      return var0.indexOf("Windows") != -1;
   }

   public static void invokeAndWait(Runnable var0) throws InterruptedException, InvocationTargetException {
      if (EventQueue.isDispatchThread()) {
         throw new Error("Cannot call invokeAndWait from the event dispatcher thread");
      } else {
         PluginSysUtil$1AWTInvocationLock var1 = new PluginSysUtil$1AWTInvocationLock();
         InvocationEvent var2 = new InvocationEvent(Toolkit.getDefaultToolkit(), var0, var1, true);
         synchronized (var1) {
            pluginEventQueue.postEvent(var2);
            var1.wait();
         }

         Exception var3 = var2.getException();
         if (var3 != null) {
            throw new InvocationTargetException(var3);
         }
      }
   }

   public static void invokeLater(Runnable var0) {
      pluginEventQueue.postEvent(new InvocationEvent(Toolkit.getDefaultToolkit(), var0));
   }

   static ThreadGroup access$100() {
      return pluginThreadGroup;
   }

   public static synchronized ThreadGroup getPluginThreadGroup() {
      if (pluginThreadGroup == null) {
         pluginSysClassLoader = Thread.currentThread().getContextClassLoader();
         pluginThreadGroup = new ThreadGroup(Thread.currentThread().getThreadGroup(), "Plugin Thread Group");
         createAppContext(pluginThreadGroup);
      }

      return pluginThreadGroup;
   }

   private static void createAppContext(ThreadGroup var0) {
      PluginSysUtil.AppContextCreatorThread var1 = new PluginSysUtil.AppContextCreatorThread(var0);
      synchronized (var1.synObject) {
         var1.start();

         try {
            var1.synObject.wait();
         } catch (InterruptedException var5) {
         }
      }
   }

   static EventQueue access$002(EventQueue var0) {
      pluginEventQueue = var0;
      return var0;
   }

   public static Object execute(PluginSysAction var0) throws Exception {
      if (Thread.currentThread().getThreadGroup().equals(pluginThreadGroup)) {
         return var0.execute();
      } else {
         PluginSysUtil.SysExecutionThread var1 = new PluginSysUtil.SysExecutionThread(var0);
         var1.setContextClassLoader(pluginSysClassLoader);
         if (SwingUtilities.isEventDispatchThread()) {
            synchronized (var1.syncObject) {
               PluginSysUtil.DummyDialog var3 = new PluginSysUtil.DummyDialog(null, true);
               var1.theDummy = var3;
               var3.addWindowListener(new PluginSysUtil$2(var1, var3));
               Rectangle var4 = new Rectangle(new Point(0, 0), Toolkit.getDefaultToolkit().getScreenSize());
               if (!isOnWindows()) {
                  var3.setLocation(var4.x + var4.width / 2 - 50, var4.y + var4.height / 2);
               } else {
                  var3.setLocation(-100, -100);
               }

               var3.setResizable(false);
               var3.toBack();
               var3.show();

               try {
                  var1.syncObject.wait();
               } catch (InterruptedException var13) {
               } finally {
                  var3.hide();
               }
            }
         } else {
            var1.start();

            try {
               var1.join();
            } catch (InterruptedException var12) {
            }
         }

         if (var1.exception != null) {
            throw var1.exception;
         } else {
            return var1.result;
         }
      }
   }

   public static Thread createPluginSysThread(Runnable var0) {
      Thread var1 = new Thread(pluginThreadGroup, var0);
      var1.setContextClassLoader(pluginSysClassLoader);
      return var1;
   }

   public static Thread createPluginSysThread(Runnable var0, String var1) {
      Thread var2 = new Thread(pluginThreadGroup, var0, var1);
      var2.setContextClassLoader(pluginSysClassLoader);
      return var2;
   }

   private static class AppContextCreatorThread extends Thread {
      Object synObject = new Object();

      public void run() {
         synchronized (this.synObject) {
            AppContext var2 = SunToolkit.createNewAppContext();
            PluginSysUtil.access$002((EventQueue)var2.get(AppContext.EVENT_QUEUE_KEY));
            this.synObject.notifyAll();
         }
      }

      public AppContextCreatorThread(ThreadGroup var1) {
         super(var1, "AppContext Creator Thread");
      }
   }

   private static class DummyDialog extends JDialog {
      private ThreadGroup _unsecureGroup = Thread.currentThread().getThreadGroup();

      public void secureHide() {
         new Thread(this._unsecureGroup, new PluginSysUtil$1(this)).start();
      }

      DummyDialog(Frame var1, boolean var2) {
         super(var1, var2);
      }
   }

   static class SysExecutionThread extends Thread {
      Exception exception = null;
      Object result = null;
      PluginSysAction action = null;
      Object syncObject = new Object();
      PluginSysUtil.DummyDialog theDummy = null;

      public void run() {
         try {
            this.result = this.action.execute();
         } catch (Exception var12) {
            this.exception = var12;
         } finally {
            if (this.theDummy != null) {
               this.theDummy.secureHide();
            }

            synchronized (this.syncObject) {
               this.syncObject.notifyAll();
            }
         }
      }

      public SysExecutionThread(PluginSysAction var1) {
         super(PluginSysUtil.access$100(), "SysExecutionThead");
         this.action = var1;
      }
   }
}
