package sun.plugin.util;

import java.io.IOException;
import java.io.InputStream;
import java.net.URLConnection;

public class ProgressInputStream extends InputStream {
   private int progressStep = 8192;
   private InputStream is = null;
   private int curPos = 0;
   private int markPos = 0;
   private int total = -1;
   private boolean bStartBinding = false;
   private URLConnection conn = null;
   private String url = null;
   private int lastProgress = 0;

   public int available() throws IOException {
      return this.is.available();
   }

   public int read() throws IOException {
      int var1 = this.is.read();
      this.updateProgress(1);
      return var1;
   }

   public synchronized void close() throws IOException {
      this.is.close();
      if (this.bStartBinding) {
         this.bStartBinding = false;
         ProgressTracker.onProgressAvailable(this.url, this.curPos, this.total);
         ProgressTracker.onStopBinding(this.url);
      }
   }

   public synchronized void reset() throws IOException {
      this.is.reset();
      if (this.markSupported()) {
         this.curPos = this.markPos;
      } else {
         this.curPos = 0;
      }
   }

   public boolean markSupported() {
      return this.is.markSupported();
   }

   public synchronized void mark(int var1) {
      this.is.mark(var1);
      if (this.markSupported()) {
         this.markPos = this.curPos;
      }
   }

   private synchronized void updateProgress(int var1) {
      if (var1 != -1) {
         if (!this.bStartBinding) {
            this.bStartBinding = true;
            this.total = this.conn.getContentLength();
            ProgressTracker.onStartBinding(this.url);
         }

         this.curPos += var1;
         if (this.curPos / this.progressStep > this.lastProgress) {
            this.lastProgress = this.curPos / this.progressStep;
            ProgressTracker.onProgressAvailable(this.url, this.curPos, this.total);
         }
      }
   }

   public long skip(long var1) throws IOException {
      return this.is.skip(var1);
   }

   public int read(byte[] var1) throws IOException {
      int var2 = this.is.read(var1);
      this.updateProgress(var2);
      return var2;
   }

   public int read(byte[] var1, int var2, int var3) throws IOException {
      int var4 = this.is.read(var1, var2, var3);
      this.updateProgress(var4);
      return var4;
   }

   public ProgressInputStream(InputStream var1, URLConnection var2) {
      this.is = var1;
      this.conn = var2;
      this.url = var2.getURL().toString();
   }
}
