package sun.plugin.viewer.context;

import java.applet.Applet;
import java.applet.AudioClip;
import java.awt.Image;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.net.SocketPermission;
import java.net.URL;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Vector;
import sun.applet.ActivatorAppletAudioClipRef;
import sun.applet.ActivatorAppletImageRef;
import sun.applet.AppletPanel;
import sun.plugin.util.Trace;
import sun.plugin.viewer.AppletPanelCache;

public abstract class DefaultPluginAppletContext implements PluginAppletContext {
   protected AppletPanel appletPanel;
   private static HashMap imageRefs = new HashMap();
   private static HashMap audioClipStore = new HashMap();
   private int persistStreamMaxSize = 65536;
   private static HashMap streamStore = new HashMap();

   private void stopAudioClips() {
      try {
         synchronized (audioClipStore) {
            HashMap var2 = (HashMap)audioClipStore.get(this.appletPanel.getCodeBase());
            if (var2 != null) {
               for (ActivatorAppletAudioClipRef var5 : var2.values()) {
                  var5.setDoDownload(false);
                  AudioClip var6 = (AudioClip)var5.get();
                  var5.setDoDownload(true);
                  if (var6 != null) {
                     var6.stop();
                  }
               }
            }
         }
      } catch (Throwable var9) {
      }
   }

   protected void doShowStatus(String var1) {
      Thread var3 = new Thread(new DefaultPluginAppletContext$2(this, this, var1), "showStatus Thread");
      var3.start();
   }

   public void showStatus(String var1) {
      if (var1 != null) {
         int var2 = var1.indexOf("\n");
         if (var2 != -1) {
            this.doShowStatus(var1.substring(0, var2));
         } else {
            this.doShowStatus(var1);
         }
      }
   }

   public void showDocument(URL var1) {
      this.showDocument(var1, "_top");
   }

   public Enumeration getApplets() {
      Vector var1 = new Vector();
      Object[] var2 = AppletPanelCache.getAppletPanels();

      for (int var3 = 0; var3 < var2.length; var3++) {
         AppletPanel var4 = (AppletPanel)var2[var3];
         if (var4 != null && var4.isActive() && var4.getDocumentBase().equals(this.appletPanel.getDocumentBase())) {
            try {
               if (this.checkConnect(this.appletPanel.getCodeBase().getHost(), var4.getCodeBase().getHost())) {
                  var1.addElement(var4.getApplet());
               }
            } catch (InvocationTargetException var6) {
               this.showStatus(var6.getTargetException().getMessage());
            } catch (Exception var7) {
               this.showStatus(var7.getMessage());
            }
         }
      }

      Applet var8 = this.appletPanel.getApplet();
      if (!var1.contains(var8)) {
         var1.addElement(var8);
      }

      return var1.elements();
   }

   public Iterator getStreamKeys() {
      Iterator var1 = null;
      HashMap var2 = (HashMap)streamStore.get(this.appletPanel.getCodeBase());
      if (var2 != null) {
         synchronized (var2) {
            var1 = var2.keySet().iterator();
         }
      }

      return var1;
   }

   public void addAppletPanelInContext(AppletPanel var1) {
      this.appletPanel = var1;
      AppletPanelCache.add(var1);
   }

   public void removeAppletPanelFromContext(AppletPanel var1) {
      AppletPanelCache.remove(var1);
   }

   public Applet getApplet(String var1) {
      var1 = var1.toLowerCase();
      Object[] var2 = AppletPanelCache.getAppletPanels();

      for (int var3 = 0; var3 < var2.length; var3++) {
         AppletPanel var4 = (AppletPanel)var2[var3];
         if (var4 != null && (var4.isActive() || this.appletPanel == var4)) {
            String var5 = var4.getParameter("name");
            if (var5 != null) {
               var5 = var5.toLowerCase();
            }

            if (var1.equals(var5) && var4.getDocumentBase().equals(this.appletPanel.getDocumentBase())) {
               try {
                  if (!this.checkConnect(this.appletPanel.getCodeBase().getHost(), var4.getCodeBase().getHost())) {
                     return null;
                  }
               } catch (InvocationTargetException var7) {
                  this.showStatus(var7.getTargetException().getMessage());
                  return null;
               } catch (Exception var8) {
                  this.showStatus(var8.getMessage());
                  return null;
               }

               return var4.getApplet();
            }
         }
      }

      return null;
   }

   public AudioClip getAudioClip(URL var1) {
      if (var1 == null) {
         return null;
      } else {
         System.getSecurityManager().checkConnect(var1.getHost(), var1.getPort());
         ActivatorAppletAudioClipRef var2 = null;
         synchronized (audioClipStore) {
            HashMap var4 = (HashMap)audioClipStore.get(this.appletPanel.getCodeBase());
            if (var4 == null) {
               var4 = new HashMap();
               audioClipStore.put(this.appletPanel.getCodeBase(), var4);
            }

            var2 = (ActivatorAppletAudioClipRef)var4.get(var1);
            if (var2 == null) {
               var2 = new ActivatorAppletAudioClipRef(var1);
               var4.put(var1, var2);
            }
         }

         AudioClip var8 = (AudioClip)var2.get();
         Trace.msgPrintln("appletcontext.audio.loaded", new Object[]{var1});
         return var8;
      }
   }

   public Image getImage(URL var1) {
      if (var1 == null) {
         return null;
      } else {
         System.getSecurityManager().checkConnect(var1.getHost(), var1.getPort());
         ActivatorAppletImageRef var2 = null;
         synchronized (imageRefs) {
            var2 = (ActivatorAppletImageRef)imageRefs.get(var1);
            if (var2 == null) {
               var2 = new ActivatorAppletImageRef(var1);
               imageRefs.put(var1, var2);
            }
         }

         Image var7 = (Image)var2.get();
         Trace.msgPrintln("appletcontext.image.loaded", new Object[]{var1});
         return var7;
      }
   }

   public InputStream getStream(String var1) {
      ByteArrayInputStream var2 = null;
      HashMap var3 = (HashMap)streamStore.get(this.appletPanel.getCodeBase());
      if (var3 != null) {
         synchronized (var3) {
            byte[] var5 = (byte[])var3.get(var1);
            if (var5 != null) {
               var2 = new ByteArrayInputStream(var5);
            }
         }
      }

      return var2;
   }

   public void setStream(String var1, InputStream var2) throws IOException {
      HashMap var3 = (HashMap)streamStore.get(this.appletPanel.getCodeBase());
      if (var3 == null) {
         var3 = new HashMap();
         streamStore.put(this.appletPanel.getCodeBase(), var3);
      }

      synchronized (var3) {
         if (var2 != null) {
            byte[] var5 = (byte[])var3.get(var1);
            if (var5 == null) {
               int var6 = var2.available();
               if (var6 >= this.persistStreamMaxSize) {
                  throw new IOException("Stream size exceeds the maximum limit");
               }

               var5 = new byte[var6];
               var2.read(var5, 0, var6);
               var3.put(var1, var5);
            } else {
               var3.remove(var1);
               this.setStream(var1, var2);
            }
         } else {
            var3.remove(var1);
         }
      }
   }

   private boolean checkConnect(String var1, String var2) throws Exception {
      SocketPermission var3 = new SocketPermission(var1, "connect");
      SocketPermission var4 = new SocketPermission(var2, "connect");
      return var3.implies(var4);
   }

   private String getNameFromURL(URL var1) {
      try {
         String var2 = var1.getFile();
         int var3 = var2.lastIndexOf(47);
         return var2.substring(var3 + 1);
      } catch (Throwable var4) {
         return null;
      }
   }

   public void doShowDocument(URL var1, String var2) {
      Thread var4 = new Thread(new DefaultPluginAppletContext$1(this, var1, var2), "showDocument Thread");
      var4.start();
   }

   public void showDocument(URL var1, String var2) {
      StringBuffer var3 = new StringBuffer();

      for (int var4 = 0; var4 < var2.length(); var4++) {
         char var5 = var2.charAt(var4);
         if (!Character.isLetterOrDigit(var5) && var5 != '_') {
            var3.append('_');
         } else {
            var3.append(var5);
         }
      }

      this.doShowDocument(var1, var3.toString());
   }
}
